(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1640475,      34945]*)
(*NotebookOutlinePosition[   1642273,      34999]*)
(*  CellTagsIndexPosition[   1642151,      34992]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Boids Model", "Title"],

Cell[TextData[{
  "Linking ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and Repast for Agent Interaction"
}], "Subtitle"],

Cell["Charles M. Macal, Ph.D., P.E.", "Author",
  TextJustification->0],

Cell[TextData[{
  StyleBox["Center for Complex Adaptive Agent Systems Simulation ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(\((CAS\^2\)\)],
    FontFamily->"Times New Roman"],
  StyleBox[")",
    FontFamily->"Times New Roman"],
  "\nDecision and Information Sciences Division\nArgonne National Laboratory\n\
Argonne, IL 60439  USA\nemail: macal@anl.gov\nOctober 7, 2005"
}], "TextAboutAuthor"],

Cell[TextData[StyleBox["Argonne National Laboratory (ANL), with facilities in \
the states of Illinois and Idaho, is owned by the United States Government, \
and operated by the University of Chicago under a contract with the \
Department of Energy. This material resulted from work developed under a U.S. \
Government contract and is subject to the following license: the Government \
is granted for itself and others acting on its behalf a paid-up, \
nonexclusive, irrevocable worldwide license in this material to reproduce, \
prepare derivative works, and perform publically and display publically. Any \
use of this material for other than Government purposes is outside the scope \
of this license.",
  FontFamily->"Times New Roman",
  FontWeight->"Plain"]], "Text",
  CellFrame->True,
  FontFamily->"Arial",
  FontSize->8,
  FontWeight->"Bold"],

Cell[TextData[{
  "*",
  StyleBox["Mathematica\[Trademark]",
    FontSlant->"Italic"],
  " is a product of Wolfram Research, Inc. (http://www.wolfram.com/)."
}], "SmallText",
  FontSize->9],

Cell[CellGroupData[{

Cell["Presentation at 2005 WTC: ", "Section"],

Cell[CellGroupData[{

Cell["\<\
LINKING MATHEMATICA AND THE REPAST AGENT-BASED MODELING TOOLKIT: COMBINING \
THE BEST OF BOTH WORLDS \
\>", "Subsection"],

Cell["\<\
Charles M. Macal and Thomas Howe 
Argonne National Laboratory \
\>", "Text"],

Cell["\<\
Wolfram Technology Conference, Champaign, IL
Oct. 6-8, 2005
\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Abstract ",
  FontSize->12]], "Subsubsection"],

Cell[TextData[StyleBox["This presentation describes linking Mathematica with \
the Java-based Repast agent-based modeling toolkit in an interactive and \
seamless agent simulation environment. Mathematica is used as the environment \
for constructing the agent models and Repast is used for its discrete-event \
simulation features and simulation controls. Repast, the REcursive Porous \
Agent Simulation Toolkit, is the leading free and open source large-scale \
agent-based modeling and simulation library (Repast Home Page, \
http://repast.sourceforge.nett/). In general, agent-based modeling toolkits \
support the development of flexible models of agent behaviors emphasising \
sophisticated social interactions and social structure development. \
Large-scale agent-based modeling environments, such as Repast, support \
features specific to agent modeling, including the availability of \
sophisticated time schedulers, agent communications mechanisms, flexible \
interaction topologies, and facilities for storing and displaying agent \
states. Typically, Repast users build simulations by incorporating Repast \
library components into their own Java programs or by using a visual \
scripting environment. We describe a new configuration for building \
agent-based models in which Repast simulation classes are extended to call \
various Mathematica programs that model agent behavior. Interactive controls \
provided by Repast include Initialize, Step, Run, and Pause for controlling \
the course of the simulation. Mathematica\[CloseCurlyQuote]s JLink classes \
provide user functionality for interacting withand contolling the simulation \
as it progresses. Mathematica\[CloseCurlyQuote]s mathematical modeling \
libraries, visualization capabilities, statistical analysis routines, and \
database capabilities are then available to the agent-based modeling \
environment. The agent modeling environment written in Mathematica includes \
agent update functions that are executed each time period in the simulation. \
The agent update functions include updating the agent location and the \
agent's status, based on agent interactions and external events that affect \
the agents. The linked Mathematica-Repast system is an interpreted \
environment, requiring no compilation or linking steps that are required by \
general programming languages or agent-based modeling toolkits alone. The \
linked system also allows users to access the full range of Repast-provided \
Java classes as well as the Mathematica classes provided through JLink. One \
of the features of the linked system is that it naturally provides a \
real-time, interactive animation system for agent-based simulations. Several \
examples are presented. \n",
  FontSize->12]], "Text"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Run program", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Simulate[25, 
        motion \[Rule] straightLine\  (*\ brownian\ straightLine\ *) , 
        drawCollisionQ \[Rule] False];\)\)], "Input",
  Background->RGBColor[0.6, 1, 0.6],
  CellTags->"run simulation"],

Cell[BoxData[
    InterpretationBox[\("There are "\[InvisibleSpace]"25"\[InvisibleSpace]" \
agents."\),
      SequenceForm[ "There are ", "25", " agents."],
      Editable->False]], "Print",
  CellTags->"run simulation"],

Cell[BoxData[
    InterpretationBox[\("Simulation completed at time "\[InvisibleSpace]206\
\[InvisibleSpace]"."\),
      SequenceForm[ "Simulation completed at time ", 206, "."],
      Editable->False]], "Print",
  CellTags->"run simulation"],

Cell[BoxData[
    \("exit button pressed."\)], "Print",
  CellTags->"run simulation"],

Cell[BoxData[
    InterpretationBox[\("cmPreyL created: time series of agent CM locations \
during simulation of length "\[InvisibleSpace]\(207\ "."\)\),
      SequenceForm[ 
      "cmPreyL created: time series of agent CM locations during simulation \
of length ", 
        Times[ 207, "."]],
      Editable->False]], "Print",
  CellTags->"run simulation"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
%%ImageSize: 500 330 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.0191863 0.00462321 0.282006 0.000997737 [
[.01919 -0.0125 -5 -14 ]
[.01919 -0.0125 5 0 ]
[.25035 -0.0125 -8 -14 ]
[.25035 -0.0125 8 0 ]
[.48151 -0.0125 -11 -14 ]
[.48151 -0.0125 11 0 ]
[.71267 -0.0125 -11 -14 ]
[.71267 -0.0125 11 0 ]
[.94383 -0.0125 -11 -14 ]
[.94383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -16 -28 ]
[.5 -0.0125 16 -14 ]
[-0.0125 .08246 -25.5 -7 ]
[-0.0125 .08246 0 7 ]
[-0.0125 .18223 -25.5 -7 ]
[-0.0125 .18223 0 7 ]
[-0.0125 .28201 -10 -7 ]
[-0.0125 .28201 0 7 ]
[-0.0125 .38178 -22 -7 ]
[-0.0125 .38178 0 7 ]
[-0.0125 .48155 -22 -7 ]
[-0.0125 .48155 0 7 ]
[-0.0125 .58133 -22 -7 ]
[-0.0125 .58133 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .3 -39.5 -89.5 ]
[-0.01875 .3 -25.5 89.5 ]
[ 0 .6 .125 0 ]
[ 1 0 .125 0 ]
[.5 .6125 -125.5 0 ]
[.5 .6125 125.5 15 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.01919 0 m
.01919 .00625 L
s
gsave
.01919 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.25035 0 m
.25035 .00625 L
s
gsave
.25035 -0.0125 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.48151 0 m
.48151 .00625 L
s
gsave
.48151 -0.0125 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.71267 0 m
.71267 .00625 L
s
gsave
.71267 -0.0125 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.94383 0 m
.94383 .00625 L
s
gsave
.94383 -0.0125 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.06542 0 m
.06542 .00375 L
s
.11165 0 m
.11165 .00375 L
s
.15788 0 m
.15788 .00375 L
s
.20411 0 m
.20411 .00375 L
s
.29658 0 m
.29658 .00375 L
s
.34281 0 m
.34281 .00375 L
s
.38904 0 m
.38904 .00375 L
s
.43528 0 m
.43528 .00375 L
s
.52774 0 m
.52774 .00375 L
s
.57397 0 m
.57397 .00375 L
s
.6202 0 m
.6202 .00375 L
s
.66644 0 m
.66644 .00375 L
s
.7589 0 m
.7589 .00375 L
s
.80513 0 m
.80513 .00375 L
s
.85136 0 m
.85136 .00375 L
s
.8976 0 m
.8976 .00375 L
s
.99006 0 m
.99006 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -77 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
(Time) show
91.000 15.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08246 m
.00625 .08246 L
s
gsave
-0.0125 .08246 -86.5 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.500 15.000 moveto
(200) show
1.000 setlinewidth
grestore
0 .18223 m
.00625 .18223 L
s
gsave
-0.0125 .18223 -86.5 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
66.500 15.000 moveto
(100) show
1.000 setlinewidth
grestore
0 .28201 m
.00625 .28201 L
s
gsave
-0.0125 .28201 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .38178 m
.00625 .38178 L
s
gsave
-0.0125 .38178 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .48155 m
.00625 .48155 L
s
gsave
-0.0125 .48155 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .58133 m
.00625 .58133 L
s
gsave
-0.0125 .58133 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .10241 m
.00375 .10241 L
s
0 .12237 m
.00375 .12237 L
s
0 .14232 m
.00375 .14232 L
s
0 .16228 m
.00375 .16228 L
s
0 .20219 m
.00375 .20219 L
s
0 .22214 m
.00375 .22214 L
s
0 .2421 m
.00375 .2421 L
s
0 .26205 m
.00375 .26205 L
s
0 .30196 m
.00375 .30196 L
s
0 .32192 m
.00375 .32192 L
s
0 .34187 m
.00375 .34187 L
s
0 .36183 m
.00375 .36183 L
s
0 .40173 m
.00375 .40173 L
s
0 .42169 m
.00375 .42169 L
s
0 .44164 m
.00375 .44164 L
s
0 .4616 m
.00375 .4616 L
s
0 .50151 m
.00375 .50151 L
s
0 .52146 m
.00375 .52146 L
s
0 .54142 m
.00375 .54142 L
s
0 .56137 m
.00375 .56137 L
s
0 .0625 m
.00375 .0625 L
s
0 .04255 m
.00375 .04255 L
s
0 .02259 m
.00375 .02259 L
s
0 .00264 m
.00375 .00264 L
s
.25 Mabswid
0 0 m
0 .6 L
s
gsave
-0.01875 .3 -183 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
150.5 11 translate
90 rotate
-150.5 -11 translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
(CM) show
81.000 15.000 moveto
(\\() show
86.000 15.000 moveto
(X) show
97.000 15.000 moveto
(=) show
107.000 15.000 moveto
(Red) show
129.000 15.000 moveto
(,) show
137.000 15.000 moveto
(Y) show
148.000 15.000 moveto
(=) show
158.000 15.000 moveto
(Blue) show
183.000 15.000 moveto
(,) show
189.000 15.000 moveto
(d) show
199.000 15.000 moveto
(=) show
209.000 15.000 moveto
(Gold) show
234.000 15.000 moveto
(\\)) show
238.000 15.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01919 .59375 m
.01919 .6 L
s
.25035 .59375 m
.25035 .6 L
s
.48151 .59375 m
.48151 .6 L
s
.71267 .59375 m
.71267 .6 L
s
.94383 .59375 m
.94383 .6 L
s
.125 Mabswid
.06542 .59625 m
.06542 .6 L
s
.11165 .59625 m
.11165 .6 L
s
.15788 .59625 m
.15788 .6 L
s
.20411 .59625 m
.20411 .6 L
s
.29658 .59625 m
.29658 .6 L
s
.34281 .59625 m
.34281 .6 L
s
.38904 .59625 m
.38904 .6 L
s
.43528 .59625 m
.43528 .6 L
s
.52774 .59625 m
.52774 .6 L
s
.57397 .59625 m
.57397 .6 L
s
.6202 .59625 m
.6202 .6 L
s
.66644 .59625 m
.66644 .6 L
s
.7589 .59625 m
.7589 .6 L
s
.80513 .59625 m
.80513 .6 L
s
.85136 .59625 m
.85136 .6 L
s
.8976 .59625 m
.8976 .6 L
s
.99006 .59625 m
.99006 .6 L
s
.25 Mabswid
0 .6 m
1 .6 L
s
.99375 .08246 m
1 .08246 L
s
.99375 .18223 m
1 .18223 L
s
.99375 .28201 m
1 .28201 L
s
.99375 .38178 m
1 .38178 L
s
.99375 .48155 m
1 .48155 L
s
.99375 .58133 m
1 .58133 L
s
.125 Mabswid
.99625 .10241 m
1 .10241 L
s
.99625 .12237 m
1 .12237 L
s
.99625 .14232 m
1 .14232 L
s
.99625 .16228 m
1 .16228 L
s
.99625 .20219 m
1 .20219 L
s
.99625 .22214 m
1 .22214 L
s
.99625 .2421 m
1 .2421 L
s
.99625 .26205 m
1 .26205 L
s
.99625 .30196 m
1 .30196 L
s
.99625 .32192 m
1 .32192 L
s
.99625 .34187 m
1 .34187 L
s
.99625 .36183 m
1 .36183 L
s
.99625 .40173 m
1 .40173 L
s
.99625 .42169 m
1 .42169 L
s
.99625 .44164 m
1 .44164 L
s
.99625 .4616 m
1 .4616 L
s
.99625 .50151 m
1 .50151 L
s
.99625 .52146 m
1 .52146 L
s
.99625 .54142 m
1 .54142 L
s
.99625 .56137 m
1 .56137 L
s
.99625 .0625 m
1 .0625 L
s
.99625 .04255 m
1 .04255 L
s
.99625 .02259 m
1 .02259 L
s
.99625 .00264 m
1 .00264 L
s
.25 Mabswid
1 0 m
1 .6 L
s
0 .28201 m
1 .28201 L
s
gsave
.5 .6125 -186.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.000 moveto
(Agent) show
108.000 15.000 moveto
(Center) show
160.000 15.000 moveto
(of) show
178.000 15.000 moveto
(Mass) show
219.000 15.000 moveto
(and) show
249.000 15.000 moveto
(Distance) show
310.000 15.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 .85 0 r
.005 w
.02381 .28201 m
.02843 .28282 L
.03306 .28527 L
.03768 .28722 L
.0423 .28925 L
.04693 .29033 L
.05155 .29056 L
.05617 .29082 L
.0608 .29144 L
.06542 .29284 L
.07004 .29466 L
.07466 .29546 L
.07929 .29671 L
.08391 .29977 L
.08853 .30429 L
.09316 .30934 L
.09778 .31526 L
.1024 .32148 L
.10703 .32764 L
.11165 .33397 L
.11627 .33999 L
.1209 .34586 L
.12552 .35065 L
.13014 .35428 L
.13477 .35736 L
.13939 .35948 L
.14401 .35811 L
.14864 .35539 L
.15326 .35321 L
.15788 .35221 L
.16251 .35307 L
.16713 .35507 L
.17175 .35839 L
.17638 .36284 L
.181 .36821 L
.18562 .37437 L
.19025 .38074 L
.19487 .38735 L
.19949 .39464 L
.20411 .4025 L
.20874 .41077 L
.21336 .4194 L
.21798 .42822 L
.22261 .43761 L
.22723 .44694 L
.23185 .45595 L
.23648 .46535 L
.2411 .47482 L
.24572 .48448 L
.25035 .4933 L
Mistroke
.25497 .50215 L
.25959 .51126 L
.26422 .51993 L
.26884 .52876 L
.27346 .53741 L
.27809 .54612 L
.28271 .55453 L
.28733 .56285 L
.29196 .57036 L
.29658 .57724 L
.3012 .58261 L
.30583 .58571 L
.31045 .58539 L
.31507 .58198 L
.31969 .57504 L
.32432 .56568 L
.32894 .55483 L
.33356 .54335 L
.33819 .53159 L
.34281 .5198 L
.34743 .5081 L
.35206 .49646 L
.35668 .48488 L
.3613 .47334 L
.36593 .46183 L
.37055 .45036 L
.37517 .43889 L
.3798 .42745 L
.38442 .41601 L
.38904 .40403 L
.39367 .39201 L
.39829 .38002 L
.40291 .36758 L
.40754 .35514 L
.41216 .34273 L
.41678 .33034 L
.42141 .31806 L
.42603 .30604 L
.43065 .295 L
.43528 .29052 L
.4399 .29892 L
.44452 .31046 L
.44914 .32255 L
.45377 .33481 L
.45839 .34716 L
.46301 .35955 L
.46764 .37202 L
.47226 .38441 L
.47688 .39676 L
.48151 .40887 L
Mistroke
.48613 .42072 L
.49075 .43251 L
.49538 .44441 L
.5 .45568 L
.50462 .46589 L
.50925 .47456 L
.51387 .48172 L
.51849 .4873 L
.52312 .4924 L
.52774 .49694 L
.53236 .50203 L
.53699 .50687 L
.54161 .51074 L
.54623 .51392 L
.55086 .51621 L
.55548 .51528 L
.5601 .51305 L
.56472 .50975 L
.56935 .50509 L
.57397 .49949 L
.57859 .49312 L
.58322 .48648 L
.58784 .47999 L
.59246 .47372 L
.59709 .46791 L
.60171 .4627 L
.60633 .45811 L
.61096 .45434 L
.61558 .45141 L
.6202 .44941 L
.62483 .44836 L
.62945 .4483 L
.63407 .44919 L
.6387 .45099 L
.64332 .4538 L
.64794 .45762 L
.65257 .46201 L
.65719 .46719 L
.66181 .47282 L
.66644 .47886 L
.67106 .48556 L
.67568 .49283 L
.68031 .50054 L
.68493 .50863 L
.68955 .5171 L
.69417 .52564 L
.6988 .53418 L
.70342 .5422 L
.70804 .54941 L
.71267 .55545 L
Mistroke
.71729 .56008 L
.72191 .5629 L
.72654 .5636 L
.73116 .56196 L
.73578 .55774 L
.74041 .55153 L
.74503 .54428 L
.74965 .53549 L
.75428 .52571 L
.7589 .51552 L
.76352 .50469 L
.76815 .49349 L
.77277 .48239 L
.77739 .47135 L
.78202 .46055 L
.78664 .44999 L
.79126 .43982 L
.79589 .43009 L
.80051 .42095 L
.80513 .41285 L
.80975 .40558 L
.81438 .3993 L
.819 .39424 L
.82362 .39029 L
.82825 .38745 L
.83287 .38514 L
.83749 .38342 L
.84212 .38236 L
.84674 .38187 L
.85136 .38216 L
.85599 .38407 L
.86061 .38735 L
.86523 .39158 L
.86986 .39648 L
.87448 .40199 L
.8791 .40797 L
.88373 .41407 L
.88835 .42128 L
.89297 .42887 L
.8976 .43735 L
.90222 .44607 L
.90684 .45547 L
.91147 .46528 L
.91609 .47473 L
.92071 .48563 L
.92534 .49727 L
.92996 .509 L
.93458 .52066 L
.9392 .53017 L
.94383 .53552 L
Mistroke
.94845 .53576 L
.95307 .53191 L
.9577 .52654 L
.96232 .52008 L
.96694 .51337 L
.97157 .50623 L
.97619 .49895 L
Mfstroke
1 0 0 r
.02381 .28201 m
.02843 .28245 L
.03306 .28449 L
.03768 .28631 L
.0423 .28807 L
.04693 .28975 L
.05155 .29027 L
.05617 .29081 L
.0608 .29096 L
.06542 .29059 L
.07004 .29013 L
.07466 .28837 L
.07929 .28523 L
.08391 .2813 L
.08853 .27758 L
.09316 .27369 L
.09778 .2702 L
.1024 .2661 L
.10703 .26247 L
.11165 .25836 L
.11627 .25463 L
.1209 .25082 L
.12552 .2479 L
.13014 .24495 L
.13477 .24158 L
.13939 .23793 L
.14401 .23424 L
.14864 .22993 L
.15326 .22596 L
.15788 .2217 L
.16251 .21663 L
.16713 .21161 L
.17175 .20647 L
.17638 .20124 L
.181 .19594 L
.18562 .1905 L
.19025 .18531 L
.19487 .1803 L
.19949 .17494 L
.20411 .16935 L
.20874 .16367 L
.21336 .15783 L
.21798 .15193 L
.22261 .14561 L
.22723 .13951 L
.23185 .13387 L
.23648 .12795 L
.2411 .12254 L
.24572 .11684 L
.25035 .11163 L
Mistroke
.25497 .10618 L
.25959 .10103 L
.26422 .0971 L
.26884 .09382 L
.27346 .09154 L
.27809 .08991 L
.28271 .08937 L
.28733 .08946 L
.29196 .09093 L
.29658 .09341 L
.3012 .09751 L
.30583 .10331 L
.31045 .1117 L
.31507 .12146 L
.31969 .13202 L
.32432 .1421 L
.32894 .1511 L
.33356 .15887 L
.33819 .16536 L
.34281 .17094 L
.34743 .17607 L
.35206 .1808 L
.35668 .18533 L
.3613 .18977 L
.36593 .1942 L
.37055 .19868 L
.37517 .20321 L
.3798 .20779 L
.38442 .21244 L
.38904 .2175 L
.39367 .22265 L
.39829 .22791 L
.40291 .2336 L
.40754 .23942 L
.41216 .24537 L
.41678 .25147 L
.42141 .25762 L
.42603 .26377 L
.43065 .26992 L
.43528 .27605 L
.4399 .28223 L
.44452 .28845 L
.44914 .29466 L
.45377 .30097 L
.45839 .30733 L
.46301 .31371 L
.46764 .31985 L
.47226 .32552 L
.47688 .33087 L
.48151 .33624 L
Mistroke
.48613 .34137 L
.49075 .34654 L
.49538 .35268 L
.5 .35895 L
.50462 .36518 L
.50925 .3713 L
.51387 .37684 L
.51849 .38189 L
.52312 .38767 L
.52774 .39377 L
.53236 .40035 L
.53699 .40718 L
.54161 .41354 L
.54623 .42092 L
.55086 .42954 L
.55548 .43754 L
.5601 .44459 L
.56472 .45029 L
.56935 .45394 L
.57397 .4557 L
.57859 .45586 L
.58322 .4555 L
.58784 .45503 L
.59246 .45435 L
.59709 .45365 L
.60171 .4529 L
.60633 .45203 L
.61096 .45116 L
.61558 .45022 L
.6202 .44927 L
.62483 .44826 L
.62945 .44722 L
.63407 .44613 L
.6387 .44497 L
.64332 .44384 L
.64794 .44265 L
.65257 .44112 L
.65719 .43948 L
.66181 .43746 L
.66644 .43506 L
.67106 .43256 L
.67568 .42999 L
.68031 .42728 L
.68493 .42441 L
.68955 .42145 L
.69417 .41818 L
.6988 .41454 L
.70342 .41008 L
.70804 .40477 L
.71267 .39852 L
Mistroke
.71729 .39137 L
.72191 .38322 L
.72654 .37392 L
.73116 .36385 L
.73578 .35348 L
.74041 .34386 L
.74503 .33545 L
.74965 .32808 L
.75428 .32121 L
.7589 .31468 L
.76352 .30778 L
.76815 .30049 L
.77277 .29305 L
.77739 .28567 L
.78202 .27825 L
.78664 .2709 L
.79126 .26358 L
.79589 .25628 L
.80051 .24897 L
.80513 .24165 L
.80975 .2343 L
.81438 .22689 L
.819 .21939 L
.82362 .21208 L
.82825 .20503 L
.83287 .19892 L
.83749 .19369 L
.84212 .18934 L
.84674 .1859 L
.85136 .18306 L
.85599 .18 L
.86061 .17697 L
.86523 .17432 L
.86986 .17224 L
.87448 .17032 L
.8791 .16919 L
.88373 .16806 L
.88835 .16733 L
.89297 .16694 L
.8976 .1662 L
.90222 .16561 L
.90684 .16458 L
.91147 .16332 L
.91609 .16131 L
.92071 .15897 L
.92534 .15536 L
.92996 .15105 L
.93458 .14484 L
.9392 .13845 L
.94383 .13245 L
Mistroke
.94845 .12731 L
.95307 .12363 L
.9577 .11944 L
.96232 .11575 L
.96694 .11283 L
.97157 .111 L
.97619 .10994 L
Mfstroke
0 0 1 r
.02381 .28201 m
.02843 .28133 L
.03306 .2799 L
.03768 .27907 L
.0423 .27805 L
.04693 .27894 L
.05155 .27977 L
.05617 .28183 L
.0608 .28497 L
.06542 .28862 L
.07004 .2917 L
.07466 .29386 L
.07929 .29635 L
.08391 .29976 L
.08853 .30384 L
.09316 .30805 L
.09778 .3131 L
.1024 .31813 L
.10703 .32325 L
.11165 .32828 L
.11627 .33312 L
.1209 .33773 L
.12552 .34158 L
.13014 .34406 L
.13477 .3456 L
.13939 .34572 L
.14401 .34125 L
.14864 .3337 L
.15326 .32593 L
.15788 .31795 L
.16251 .30985 L
.16713 .30157 L
.17175 .29333 L
.17638 .28532 L
.181 .27713 L
.18562 .26942 L
.19025 .26205 L
.19487 .25456 L
.19949 .24703 L
.20411 .23927 L
.20874 .23125 L
.21336 .2232 L
.21798 .21524 L
.22261 .20712 L
.22723 .19895 L
.23185 .19083 L
.23648 .18259 L
.2411 .17361 L
.24572 .1649 L
.25035 .15705 L
Mistroke
.25497 .14954 L
.25959 .14129 L
.26422 .13228 L
.26884 .1224 L
.27346 .11184 L
.27809 .10075 L
.28271 .08923 L
.28733 .07755 L
.29196 .06606 L
.29658 .05486 L
.3012 .04468 L
.30583 .03643 L
.31045 .03094 L
.31507 .02861 L
.31969 .03027 L
.32432 .03523 L
.32894 .04264 L
.33356 .05149 L
.33819 .06136 L
.34281 .07175 L
.34743 .08227 L
.35206 .09294 L
.35668 .10365 L
.3613 .11437 L
.36593 .12507 L
.37055 .13572 L
.37517 .14634 L
.3798 .15693 L
.38442 .16747 L
.38904 .17842 L
.39367 .18939 L
.39829 .20028 L
.40291 .21145 L
.40754 .22255 L
.41216 .23357 L
.41678 .24453 L
.42141 .25545 L
.42603 .26635 L
.43065 .27723 L
.43528 .28809 L
.4399 .29892 L
.44452 .30972 L
.44914 .32052 L
.45377 .33129 L
.45839 .34204 L
.46301 .35278 L
.46764 .36368 L
.47226 .37471 L
.47688 .38583 L
.48151 .39669 L
Mistroke
.48613 .40738 L
.49075 .41797 L
.49538 .42822 L
.5 .4377 L
.50462 .44601 L
.50925 .45261 L
.51387 .45777 L
.51849 .46136 L
.52312 .46394 L
.52774 .4656 L
.53236 .46749 L
.53699 .46881 L
.54161 .46913 L
.54623 .46771 L
.55086 .46389 L
.55548 .45586 L
.5601 .44617 L
.56472 .43546 L
.56935 .42415 L
.57397 .41289 L
.57859 .40177 L
.58322 .39023 L
.58784 .37825 L
.59246 .36597 L
.59709 .35341 L
.60171 .34071 L
.60633 .32788 L
.61096 .31498 L
.61558 .30202 L
.6202 .28906 L
.62483 .2761 L
.62945 .26315 L
.63407 .2502 L
.6387 .23728 L
.64332 .22437 L
.64794 .21108 L
.65257 .19783 L
.65719 .18455 L
.66181 .17135 L
.66644 .15821 L
.67106 .14502 L
.67568 .13186 L
.68031 .11875 L
.68493 .10571 L
.68955 .09273 L
.69417 .07998 L
.6988 .06747 L
.70342 .05551 L
.70804 .04444 L
.71267 .03462 L
Mistroke
.71729 .02634 L
.72191 .01998 L
.72654 .01583 L
.73116 .01429 L
.73578 .0157 L
.74041 .01967 L
.74503 .02523 L
.74965 .03274 L
.75428 .04148 L
.7589 .05079 L
.76352 .06082 L
.76815 .07133 L
.77277 .08193 L
.77739 .0927 L
.78202 .1035 L
.78664 .11439 L
.79126 .12527 L
.79589 .13617 L
.80051 .14705 L
.80513 .15754 L
.80975 .16802 L
.81438 .17847 L
.819 .18886 L
.82362 .19933 L
.82825 .20994 L
.83287 .2209 L
.83749 .23215 L
.84212 .24348 L
.84674 .2549 L
.85136 .26649 L
.85599 .27851 L
.86061 .29 L
.86523 .30227 L
.86986 .31447 L
.87448 .32585 L
.8791 .33803 L
.88373 .34876 L
.88835 .36105 L
.89297 .37327 L
.8976 .38555 L
.90222 .39763 L
.90684 .40967 L
.91147 .42167 L
.91609 .43226 L
.92071 .44425 L
.92534 .45608 L
.92996 .46742 L
.93458 .4773 L
.9392 .48444 L
.94383 .48671 L
Mistroke
.94845 .48315 L
.95307 .47531 L
.9577 .46468 L
.96232 .45242 L
.96694 .43983 L
.97157 .42703 L
.97619 .41414 L
Mfstroke
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 330},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009a0001W2000`400?l00000o`00003oo`3ooooo
0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo
003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooodT0
oooo0P0000050?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000`3oool01@37alL0
J6QX0000001=CDd0YjNW0?l0oooo3@3oool00?l0ooooB@3oool2000000D0oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`030=WIf@000000000000<0000000<0S8b<0?ooo`3o
ool0o`3oool:0?ooo`00o`3ooom90?ooo`8000001@3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo00<0O7al0000003QhN40o`3oool@0?ooo`00o`3ooom90?ooo`8000001@3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo1`00003o0?ooo``0oooo003o
0?ooodT0oooo0P0000050?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool6
0000000304e=C@3oool0oooo0?l0oooo2P3oool00?l0ooooB@3oool2000000D0oooo0P0000020?oo
o`80000000H0alO70?3`l000000000000<O7a`3YjNT200000080oooo00L0O7al0000003QhN40oooo
0>7Qh@000000VYZJ0?l0oooo303oool00?l0ooooB@3oool2000000D0oooo0P0000020?ooo`D00000
00D0O7al000000000000000006QXJ0020?ooo`030=WIf@000000000000<0000000<0hN7Q0?ooo`3o
ool0o`3oool:0?ooo`00o`3ooom90?ooo`8000001@3oool200000080oooo0P000000203@d=00CDe=
06QXJ03YjNT0d=3@04e=C@1XJ6P0jNWY0`3oool01@3@d=00J6QX0000001XJ6P0fMWI0?l0oooo3@3o
ool00?l0ooooB@3oool200000?l0oooo:03oool00?l0ooooAP3oool800000080oooo0P00003o0?oo
ob40oooo003o0?ooodH0oooo200000020?ooo`800000o`3ooolQ0?ooo`00o`3ooooo0?ooog<0oooo
003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0
ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo00140?ooo`0409ZJVP000000
00000:NWYgT0oooo00D0jNWY08b<S0000000CDe=0;:b/P030?ooo`0409ZJVP00000000000:NWYgH0
oooo0P0000030?ooo`0409ZJVP00000000000:NWY`<0oooo00@0VYZJ000000000000YjNWLP3oool2
00000080oooo00D0jNWY08b<S0000000CDe=0;:b/P030?ooo`0409ZJVP00000000000:NWYfl0oooo
00<0CDe=0000000000000`0000020?ooo`0409ZJVP00000000000:NWY`<0oooo00@0VYZJ00000000
0000YjNW6P3oool004<0oooo00H0_Kfm00000037alL0alO70000002b/[9h0?ooo`0907alO0000000
jNWY0<O7a`000000YjNW0?ooo`2m_Kd000000080alO700<000000;:b/P3oool0M03oool200000080
oooo00T0_Kfm00000037alL0alO70000002b/[80oooo0;fm_@0000000P37alL00`000000/[:b0?oo
o`1`0?ooo`8000000P3oool02@1lO7`000000>WYj@37alL000000:NWY`3oool0_Kfm000000020<O7
a`030000002b/[80oooo06d0oooo00<0YjNW00000037alL0103oool02@2m_Kd000000<O7a`37alL0
00000;:b/P3oool0_Kfm000000020<O7a`030000002b/[80oooo01P0oooo00130?ooo`0607alO000
0000oooo0?ooo`000000O7alO03oool01@000000CDe=0?ooo`1lO7`000000080oooo00<0000007al
O03oool0M03oool200000080oooo00T0O7al0000003oool0oooo0000001lO7`0oooo07alO0000000
0P3oool00`000000O7al0?ooo`1`0?ooo`8000001P3oool01@000000CDe=0?ooo`1lO7`000000080
oooo00<0000007alO03oool0K@3oool0103`l?00000004e=C@3YjNT30?ooo`0907alO0000000oooo
0?ooo`000000O7al0?ooo`1lO7`000000080oooo00<0000007alO03oool0603oool004<0oooo0P00
00020?ooo`800000O03oool2000000030?ooo`00000000000080oooo0P00001e0?ooo`8000000P3o
ool200000080oooo0P0000000`3oool00000000000020?ooo`800000L@3oool2000000H0oooo0P00
00000`3oool00000000000020?ooo`800000K`3oool00`37alL0000004e=C@030?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P00000I0?ooo`00@`3oool200000080oooo0P00001l
0?ooo`030000001=CDd0oooo008000000P3oool2000007D0oooo0P0000020?ooo`8000000P3oool2
000000030?ooo`00000000000080oooo0P00001a0?ooo`8000001P3oool00`000000CDe=0?ooo`02
00000080oooo0P00001`0?ooo`0308b<S0000000S8b<0080oooo0P0000020?ooo`80000000<0oooo
0000000000000P3oool2000001T0oooo00130?ooo`8000000P3oool2000007P0oooo00L0S8b<0000
003YjNT0alO70000002WYjL0oooo008000000P3oool2000007D0oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P00001a0?ooo`8000000P3oool01`2<S8`000000>WY
j@37alL000000:NWY`3oool00P0000020?ooo`800000L@3oool0101XJ6P000000<O7a`3oool20000
0080oooo0P0000000`3oool00000000000020?ooo`8000006@3oool004<0oooo0P0000020?ooo`80
0000N03oool01@2<S8`0000004e=C@000000S8b<0080oooo0P0000020?ooo`800000L`3oool0102<
S8`0oooo0000000000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P00001_
0?ooo`0408b<S03oool0000000000080oooo00D0S8b<0000001=CDd0000008b<S0020?ooo`800000
0P3oool200000740oooo00@0hN7Q0000001=CDd0oooo0P0000020?ooo`80000000<0oooo00000000
00000P3oool2000001T0oooo00130?ooo`0607alO0000000oooo0?ooo`000000O7alN03oool00`2m
_Kd000000=3@d0040?ooo`0607alO0000000oooo0?ooo`000000O7alL`3oool010000000O7al0000
000000020?ooo`0907alO0000000oooo0?ooo`000000O7al0?ooo`1lO7`000000080oooo00<00000
07alO03oool0KP3oool010000000O7al0000000000020?ooo`030;fm_@000000d=3@00@0oooo00H0
O7al0000003oool0oooo0000001lO7ab0?ooo`80000000<0oooo07alO00000000P3oool01@000000
O7al0?ooo`1lO7`000000080oooo00<0000007alO03oool0603oool004<0oooo00H0/[:b00000037
alL0alO70000002b/[9h0?ooo`030=WIf@000000VYZJ00@0oooo00H0/[:b00000037alL0alO70000
002b/[9c0?ooo`040>WYj@2<S8`0000000000080oooo00T0/[:b00000037alL0alO70000002b/[80
oooo0;:b/P0000000P37alL00`000000/[:b0?ooo`1^0?ooo`040>WYj@2<S8`0000000000080oooo
00<0fMWI0000002JVYX0103oool01P2b/[8000000<O7a`37alL000000;:b/Vh0oooo00T0J6QX0000
003YjNT0jNWY0000002WYjL0oooo0;:b/P0000000P37alL01@000000/[:b0?ooo`2b/[8000000080
alO700<000000;:b/P3oool0603oool004@0oooo00@0YjNW000000000000YjNWN@3oool00`3`l?00
00000000000300000080oooo00@0YjNW000000000000YjNWMP3oool00`2JVYX000000?ooo`020?oo
o`040:NWY`00000000000:NWY`<0oooo00@0YjNW000000000000YjNWLP3oool01@2JVYX000000?oo
o`3oool0l?3`00D000000P3oool0102WYjL000000000002WYjM_0?ooo`050>WYj@1lO7`000000000
002WYjL00`3oool0102WYjL000000000002WYjL30?ooo`040:NWY`00000000000:NWYaX0oooo003o
0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0oooo
L`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0
ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0ooooL`3oool003/0ooooo`00003o
000003L000000@3oool003/0oooo100000070?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<000000@3oool003/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo01`0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?ooool0oooo<`3oool100000040oooo000k
0?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool0o`3ooooo0?oooc<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooi/0
oooo00<0003o0?ooo`3oool0U03oool100000040oooo000k0?ooo`030000003oool0oooo0?l0oooo
V03oool60000oi@0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooiL0oooo2000
0?nC0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0o`3ooonF0?ooo`<0003o103oool4
0000oi40oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooiH0oooo0P000?l60?oo
o`@0003oT03oool100000040oooo000k0?ooo`@00000o`3ooonD0?ooo`80003o2@3oool30000ohd0
oooo0`0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oooi@0oooo0P000?l;0?ooo`<0003o
SP3oool100000040oooo000k0?ooo`030000003oool0oooo0?l0ooooT`3oool20000o`d0oooo0P00
0?n>0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0[`3oool00`000?l0oooo0?ooo`3P
0?ooo`030000o`3oool0oooo00d0oooo0P000?n=0?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool0[@3oool60000omh0oooo0P000?l@0?ooo`030000o`3oool0oooo08/0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`2/0?ooo`L0003og@3oool20000oa40oooo0P000?n<0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool0Z`3oool30000o`@0oooo0P000?oK0?ooo`80003o
4`3oool00`000?l0oooo0?ooo`2:0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0ZP3o
ool30000o`H0oooo0P000?oI0?ooo`<0003o4`3oool20000oh/0oooo0@0000010?ooo`00>`3oool0
0`000000oooo0?ooo`2Z0?ooo`80003o203oool00`000?l0oooo0?ooo`3G0?ooo`80003o5@3oool0
0`000?l0oooo0?ooo`290?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0Z@3oool20000
o`T0oooo0P000?oH0?ooo`80003o5@3oool20000ohX0oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`2X0?ooo`80003o2`3oool20000omH0oooo0`000?lF0?ooo`80003oR@3oool100000040
oooo000k0?ooo`030000003oool0oooo0:P0oooo00<0003o0?ooo`3oool02`3oool20000omD0oooo
0P000?lH0?ooo`030000o`3oool0oooo08L0oooo0@0000010?ooo`00>`3oool400000:H0oooo0P00
0?l>0?ooo`030000o`3oool0oooo0=<0oooo0P000?lH0?ooo`80003oQP3oool300000040oooo000k
0?ooo`030000003oool0oooo0:L0oooo00<0003o0?ooo`3oool03@3oool20000om@0oooo00<0003o
0?ooo`3oool05`3oool20000ohP0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2V0?oo
o`80003o403oool00`000?l0oooo0?ooo`3A0?ooo`80003o6P3oool20000ohL0oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`2V0?ooo`80003o403oool20000om80oooo00<0003o0?ooo`3o
ool06@3oool20000ohL0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2U0?ooo`<0003o
4@3oool20000om00oooo0P000?lL0?ooo`030000o`3oool0oooo08D0oooo0@0000010?ooo`00>`3o
ool00`000000oooo0?ooo`2U0?ooo`80003o4`3oool00`000?l0oooo0?ooo`3>0?ooo`030000o`3o
ool0oooo01/0oooo0P000?n60?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0Y@3oool2
0000oa<0oooo0P000?o>0?ooo`80003o7P3oool00`000?l0oooo0?ooo`240?ooo`4000000@3oool0
03/0oooo00<000000?ooo`3oool0Y@3oool00`000?l0oooo0?ooo`0B0?ooo`80003ocP3oool00`00
0?l0oooo0?ooo`0M0?ooo`80003oQ@3oool100000040oooo000k0?ooo`030000003oool0oooo0:@0
oooo0P000?lE0?ooo`80003oc03oool20000ob00oooo00<0003o0?ooo`3oool0P`3oool100000040
oooo000k0?ooo`030000003oool0oooo0:@0oooo00<0003o0?ooo`3oool0503oool20000ol`0oooo
0P000?lP0?ooo`80003oQ03oool100000040oooo000k0?ooo`030000003oool0oooo0:<0oooo0P00
0?lG0?ooo`030000o`3oool0oooo0<T0oooo0P000?lR0?ooo`030000o`3oool0oooo0880oooo0@00
00010?ooo`00>`3oool400000:80oooo00<0003o0?ooo`3oool05P3oool20000olX0oooo0P000?lR
0?ooo`80003oP@3oool300000040oooo000k0?ooo`030000003oool0oooo0:80oooo0P000?lI0?oo
o`030000o`3oool0oooo0<L0oooo0`000?lS0?ooo`030000o`3oool0oooo0840oooo0@0000010?oo
o`00>`3oool00`000000oooo0?ooo`2R0?ooo`030000o`3oool0oooo01P0oooo0P000?o80?ooo`80
003o903oool20000oh80oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2Q0?ooo`80003o
6`3oool00`000?l0oooo0?ooo`350?ooo`<0003o9@3oool00`000?l0oooo0?ooo`200?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0X@3oool00`000?l0oooo0?ooo`0J0?ooo`80003oaP3o
ool20000obH0oooo0P000?n10?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0X03oool2
0000oad0oooo00<0003o0?ooo`3oool0a03oool20000obL0oooo00<0003o0?ooo`3oool0O`3oool1
00000040oooo000k0?ooo`030000003oool0oooo0:00oooo00<0003o0?ooo`3oool0703oool20000
ol@0oooo0`000?lW0?ooo`80003oP03oool100000040oooo000K0?ooo`0304e=C@000000000000<0
00000P3oool0102JVYX000000000002WYjL30?ooo`0409ZJVP00000000000:NWY`d0oooo00<00000
0?ooo`3oool0W`3oool20000oah0oooo0P000?o40?ooo`80003o:03oool20000oh00oooo0@000001
0?ooo`006`3oool00`2WYjL000000<O7a`040?ooo`090;fm_@000000alO70<O7a`000000/[:b0?oo
o`2m_Kd000000080alO700<000000;:b/P3oool02`3oool00`000000oooo0?ooo`2O0?ooo`030000
o`3oool0oooo01d0oooo0`000?o30?ooo`80003o:03oool30000ogl0oooo0@0000010?ooo`00603o
ool3000000040?3`l0000000CDe=0>WYj@<0oooo00T0O7al0000003oool0oooo0000001lO7`0oooo
07alO00000000P3oool00`000000O7al0?ooo`0;0?ooo`030000003oool0oooo09h0oooo0P000?lP
0?ooo`80003o``3oool20000obT0oooo0P000?mo0?ooo`4000000@3oool001`0oooo00<0alO70000
001=CDd00`3oool200000080oooo0P0000000`3oool00000000000020?ooo`800000303oool00`00
0000oooo0?ooo`2N0?ooo`80003o803oool20000ol80oooo0`000?lY0?ooo`80003oO`3oool10000
0040oooo000M0?ooo`0308b<S0000000S8b<0080oooo0P0000020?ooo`80000000<0oooo00000000
00000P3oool2000000`0oooo1@00002K0?ooo`<0003o8@3oool00`000?l0oooo0?ooo`300?ooo`80
003o:`3oool00`000?l0oooo0?ooo`1j0?ooo`@000000@3oool001h0oooo00@0J6QX00000037alL0
oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool2000000`0oooo00<000000?ooo`3o
ool0W@3oool20000ob80oooo0P000?o00?ooo`<0003o:`3oool20000ogh0oooo0@0000010?ooo`00
7P3oool0103QhN40000004e=C@3oool200000080oooo0P0000000`3oool00000000000020?ooo`80
0000303oool00`000000oooo0?ooo`2M0?ooo`80003o8`3oool00`000?l0oooo0?ooo`2n0?ooo`80
003o;@3oool00`000?l0oooo0?ooo`1l0?ooo`4000000@3oool001l0oooo0P0000000`3oool0O7al
000000020?ooo`050000001lO7`0oooo07alO00000000P3oool00`000000O7al0?ooo`0;0?ooo`03
0000003oool0oooo09d0oooo0P000?lS0?ooo`80003o_`3oool20000obd0oooo0P000?mm0?ooo`40
00000@3oool001/0oooo00T0J6QX0000003YjNT0jNWY0000002WYjL0oooo0;:b/P0000000P37alL0
1@000000/[:b0?ooo`2b/[8000000080alO700<000000;:b/P3oool02`3oool00`000000oooo0?oo
o`2H0?ooo`@0o`000`000?l40?l00200oooo00<0003o0?ooo`3oool0_03oool30000obh0oooo00<0
003o0?ooo`3oool0N`3oool100000040oooo000K0?ooo`050>WYj@1lO7`000000000002WYjL00`3o
ool0102WYjL000000000002WYjL30?ooo`040:NWY`00000000000:NWY`d0oooo00<000000?ooo`3o
ool0UP3oool60?l00080003o203o000M0?ooo`80003o_@3oool20000obl0oooo0P000?ml0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool0U@3oool40?l00080oooo0`000?l40?ooo`@0o`00
7P3oool00`000?l0oooo0?ooo`2j0?ooo`<0003o<03oool00`000?l0oooo0?ooo`1j0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0TP3oool50?l000@0oooo0P000?l80?ooo`80o`007@3o
ool20000ok/0oooo0P000?la0?ooo`80003oN`3oool100000040oooo000k0?ooo`030000003oool0
oooo0980oooo103o00050?ooo`80003o2@3oool20?l001d0oooo00<0003o0?ooo`3oool0^@3oool2
0000oc40oooo0P000?mk0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0T@3oool20?l0
00L0oooo0`000?l:0?ooo`80o`00703oool20000okT0oooo0`000?la0?ooo`<0003oNP3oool10000
0040oooo000k0?ooo`030000003oool0oooo0900oooo0P3o00080?ooo`80003o2`3oool30?l001`0
oooo00<0003o0?ooo`3oool0]`3oool20000oc<0oooo0P000?mj0?ooo`4000000@3oool003/0oooo
1000002>0?ooo`80o`00203oool30000o``0oooo0`3o000K0?ooo`80003o^03oool20000oc<0oooo
0P000?mh0?ooo`<000000@3oool003/0oooo00<000000?ooo`3oool0SP3oool30?l000P0oooo0P00
0?l>0?ooo`80o`00703oool00`000?l0oooo0?ooo`2f0?ooo`80003o=03oool00`000?l0oooo0?oo
o`1h0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0S@3oool30?l000T0oooo0P000?l?
0?ooo`80o`006`3oool20000okH0oooo0`000?ld0?ooo`80003oN@3oool100000040oooo000k0?oo
o`030000003oool0oooo08d0oooo0P3o00090?ooo`<0003o403oool00`3o0000oooo0?ooo`0I0?oo
o`80003o]P3oool20000ocH0oooo00<0003o0?ooo`3oool0M`3oool100000040oooo00040?ooo`03
0=3@d02<S8`000000080000000<0S8b<0=3@d03oool0;`3oool00`000000oooo0?ooo`2<0?ooo`80
o`002P3oool20000oa40oooo0P3o000J0?ooo`<0003o]@3oool20000ocH0oooo0P000?mh0?ooo`40
00000@3oool000<0oooo00<0YjNW0000000000001@0000000`2WYjL0oooo0?ooo`0]0?ooo`030000
003oool0oooo08/0oooo0P3o000;0?ooo`80003o4P3oool20?l001X0oooo0P000?nd0?ooo`<0003o
=`3oool00`000?l0oooo0?ooo`1T0?ooo`H0o`00303oool100000040oooo00020?ooo`040;fm_@00
0000CDe=0=WIf@<0oooo00@0fMWI04e=C@000000_Kfm;P3oool00`000000oooo0?ooo`2:0?ooo`<0
o`002`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01P0oooo0P000?nd0?ooo`80
003o>03oool20000of<0oooo203o000<0?ooo`4000000@3oool00080oooo00<0O7al0000003QhN40
1@3oool00`3QhN40000006QXJ00^0?ooo`030000003oool0oooo08T0oooo0`3o000;0?ooo`80003o
503oool20?l001X0oooo00<0003o0?ooo`3oool0/@3oool30000ocT0oooo00<0003o0?ooo`3oool0
H03oool40?l00140oooo0@0000010?ooo`000P3oool2000000L0oooo0P00000^0?ooo`030000003o
ool0oooo08P0oooo0`3o000<0?ooo`030000o`3oool0oooo01<0oooo0P3o000J0?ooo`80003o/P3o
ool20000ocX0oooo0P000?mO0?ooo`@0o`004`3oool100000040oooo00020?ooo`80000000<0l?3`
0?ooo`3oool00`3oool00`3`l?0000000000000^0?ooo`030000003oool0oooo08L0oooo0`3o000<
0?ooo`80003o5P3oool20?l001X0oooo00<0003o0?ooo`3oool0/03oool20000oc/0oooo00<0003o
0?ooo`3oool0G03oool40?l001@0oooo0@0000010?ooo`000P3oool0102JVYX0000007alO03`l?03
0?ooo`040?3`l01lO7`0000009ZJVRh0oooo00<000000?ooo`3oool0QP3oool30?l000d0oooo00<0
003o0?ooo`3oool05@3oool20?l001X0oooo0P000?n`0?ooo`<0003o>`3oool20000oe`0oooo0`3o
000F0?ooo`4000000@3oool00080oooo00@0hN7Q000000000000S8b<0`3oool0102<S8`000000000
003QhN4^0?ooo`030000003oool0oooo08D0oooo0`3o000=0?ooo`80003o603oool00`3o0000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo0:h0oooo0P000?lm0?ooo`030000o`3oool0oooo05T0oooo
0`3o000G0?ooo`4000000@3oool000<0oooo00<0fMWI06QXJ03QhN400`3oool00`3QhN40O7al0>7Q
h@0_0?ooo`@00000Q03oool20?l000h0oooo00<0003o0?ooo`3oool05`3oool20?l001X0oooo0P00
0?n^0?ooo`<0003o?@3oool20000oeP0oooo103o000F0?ooo`<000000@3oool003/0oooo00<00000
0?ooo`3oool0Q03oool20?l000h0oooo0P000?lJ0?ooo`030?l0003oool0oooo01T0oooo00<0003o
0?ooo`3oool0[03oool20000ocl0oooo00<0003o0?ooo`3oool0E@3oool40?l001T0oooo0@000001
0?ooo`00>`3oool00`000000oooo0?ooo`230?ooo`80o`003P3oool20000oa/0oooo0P3o000J0?oo
o`80003o[@3oool20000ocl0oooo0P000?mF0?ooo`80o`006`3oool100000040oooo00020?ooo`/0
0000;P3oool00`000000oooo0?ooo`220?ooo`80o`003`3oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01P0oooo0P000?n/0?ooo`<0003o?`3oool20000oeD0oooo0P3o000L0?ooo`40
00000@3oool00080oooo2`00000^0?ooo`030000003oool0oooo0840oooo0`3o000>0?ooo`80003o
7@3oool20?l001T0oooo0`000?n[0?ooo`80003o@03oool30000oe<0oooo0P3o000M0?ooo`400000
0@3oool00080oooo0P0000000`1=CDd0YjNW0=WIf@0d0?ooo`030000003oool0oooo0800oooo0`3o
000?0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0603oool20000ojX0oooo0`00
0?m10?ooo`80003oD`3oool00`3o0000oooo0?ooo`0L0?ooo`4000000@3oool000<0oooo00<0d=3@
08b<S00000000P0000000`2JVYX0d=3@0?ooo`0`0?ooo`030000003oool0oooo0800oooo0P3o000?
0?ooo`80003o7`3oool20?l001T0oooo0P000?nZ0?ooo`80003o@P3oool20000oe80oooo0P3o000N
0?ooo`4000000@3oool000D0oooo00<0l?3`0<O7a`1lO7`00`0000000`2<S8`0alO70?ooo`0]0?oo
o`030000003oool0oooo07l0oooo0P3o000?0?ooo`<0003o7`3oool20?l001X0oooo00<0003o0?oo
o`3oool0Z03oool20000od80oooo0`000?m@0?ooo`80o`007`3oool100000040oooo00080?ooo`03
0>7Qh@1XJ6P0000000800000;P3oool00`000000oooo0?ooo`1n0?ooo`80o`00403oool20000ob00
oooo0`3o000I0?ooo`80003oZ03oool30000od<0oooo0P000?m?0?ooo`80o`00803oool100000040
oooo00050?ooo`030?3`l037alL0O7al00<0000000<0S8b<0<O7a`3oool0;@3oool00`000000oooo
0?ooo`1n0?ooo`030?l0003oool0oooo00l0oooo0P000?lQ0?ooo`80o`006P3oool00`000?l0oooo
0?ooo`2V0?ooo`80003oA03oool30000odd0oooo0P3o000Q0?ooo`4000000@3oool000<0oooo00<0
d=3@08b<S00000000P0000000`2JVYX0d=3@0?ooo`0`0?ooo`030000003oool0oooo07d0oooo0P3o
000A0?ooo`030000o`3oool0oooo0200oooo0P3o000J0?ooo`80003oY`3oool20000odD0oooo0P00
0?m<0?ooo`<0o`008@3oool100000040oooo00020?ooo`80000000<0CDe=0:NWY`3IfMT0=03oool4
000007/0oooo0P3o000A0?ooo`80003o8`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0
oooo0:D0oooo0P000?m50?ooo`80003oB`3oool30?l00200oooo0`0000010?ooo`000P3oool;0000
02h0oooo00<000000?ooo`3oool0N`3oool20?l00140oooo0P000?lT0?ooo`80o`006P3oool20000
ojD0oooo0`000?m50?ooo`<0003oBP3oool20?l002<0oooo0@0000010?ooo`000P3oool;000002h0
oooo00<000000?ooo`3oool0NP3oool20?l00180oooo00<0003o0?ooo`3oool0903oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo0:<0oooo0P000?m70?ooo`80003oB@3oool20?l002@0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`1i0?ooo`<0o`004@3oool20000obH0oooo
0P3o000J0?ooo`80003oY03oool20000odL0oooo0`000?m80?ooo`030?l0003oool0oooo02<0oooo
0@0000010?ooo`00103oool0103YjNT0/[:b08b<S01=CDd20000000404e=C@2<S8`0_Kfm0>WYjBd0
oooo00<000000?ooo`3oool0N03oool30?l00180oooo00<0003o0?ooo`3oool09P3oool20?l001X0
oooo00<0003o0?ooo`3oool0X@3oool30000odP0oooo0P000?m70?ooo`80o`009@3oool100000040
oooo00020?ooo`030>7Qh@2<S8`0000000T0000000<0S8b<0>7Qh@3oool0:P3oool00`000000oooo
0?ooo`1h0?ooo`80o`004P3oool20000obT0oooo00<0o`000?ooo`3oool0603oool20000oj80oooo
0P000?m90?ooo`80003oA@3oool30?l002H0oooo0@0000010?ooo`000P3oool20000000306QXJ02m
_Kd0hN7Q00@0oooo00<0hN7Q0;fm_@1XJ6P00P00000[0?ooo`030000003oool0oooo07L0oooo0P3o
000C0?ooo`030000o`3oool0oooo02P0oooo0P3o000J0?ooo`030000o`3oool0oooo09l0oooo0`00
0?m90?ooo`<0003o@`3oool40?l002H0oooo0@0000010?ooo`000P3oool00`2<S8`0hN7Q0?ooo`09
0?ooo`030>7Qh@2<S8`0oooo02X0oooo00<000000?ooo`3oool0M`3oool00`3o0000oooo0?ooo`0A
0?ooo`80003o:`3oool20?l001T0oooo0P000?nP0?ooo`80003oB`3oool20000od80oooo0`3o000X
0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0MP3oool20?l001<0oooo00<0003o0?oo
o`3oool0:`3oool20?l001T0oooo00<0003o0?ooo`3oool0WP3oool20000od/0oooo0P000?m10?oo
o`<0o`00:@3oool100000040oooo00020?ooo`030>WYj@3oool0oooo00L0oooo00<0jNWY0?ooo`3o
ool0;03oool00`000000oooo0?ooo`1e0?ooo`80o`004`3oool20000obh0oooo00<0o`000?ooo`3o
ool05`3oool20000oih0oooo0`000?m<0?ooo`030000o`3oool0oooo03d0oooo103o000Z0?ooo`40
00000@3oool00080oooo00<000000;:b/P3oool01P3oool00`2b/[8000000?ooo`0]0?ooo`030000
003oool0oooo07@0oooo0`3o000B0?ooo`80003o;`3oool20?l001P0oooo0P000?nN0?ooo`80003o
C@3oool20000ocd0oooo103o000[0?ooo`4000000@3oool00080oooo00@0CDe=0000001XJ6P0fMWI
0`3oool0103IfMT0J6QX0000001=CDd^0?ooo`@00000LP3oool30?l001<0oooo00<0003o0?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`0F0?ooo`<0003oW@3oool20000odh0oooo00<0003o0?ooo`3o
ool0>03oool50?l002/0oooo0`0000010?ooo`000`3oool01P2WYjL000000000002<S8`0hN7Q08b<
S080000000<0YjNW0?ooo`3oool0;@3oool00`000000oooo0?ooo`1c0?ooo`80o`004`3oool20000
oc40oooo0P3o000H0?ooo`80003oW03oool30000odh0oooo0P000?lg0?ooo`H0o`00;P3oool10000
0040oooo00040?ooo`030>7Qh@1XJ6P000000080000000<0J6QX0>7Qh@3oool0;`3oool00`000000
oooo0?ooo`1b0?ooo`80o`00503oool00`000?l0oooo0?ooo`0a0?ooo`80o`005`3oool20000oi`0
oooo0P000?m@0?ooo`80003o;P3oool;0?l00340oooo0@0000010?ooo`00103oool00`3QhN40J6QX
000000020000000306QXJ03QhN40oooo02l0oooo00<000000?ooo`3oool0L@3oool20?l001@0oooo
0P000?lc0?ooo`<0o`005`3oool00`000?l0oooo0?ooo`2J0?ooo`80003oD@3oool00`000?l0oooo
0?ooo`0T0?oooa40o`00<`3oool100000040oooo00030?ooo`060:NWY`000000000008b<S03QhN40
S8b<0P0000000`2WYjL0oooo0?ooo`0]0?ooo`030000003oool0oooo0700oooo0P3o000D0?ooo`80
003o=@3oool30?l001H0oooo0P000?nK0?ooo`80003oD@3oool20000ob<0oooo2`3o000k0?ooo`40
00000@3oool00080oooo00@0CDe=0000001=CDd0fMWI0`3oool0103IfMT0CDe=0000001=CDd^0?oo
o`030000003oool0oooo06l0oooo0`3o000D0?ooo`030000o`3oool0oooo03D0oooo0P3o000G0?oo
o`030000o`3oool0oooo09P0oooo0`000?mB0?ooo`030000o`3oool0oooo01h0oooo1P3o00130?oo
o`4000000@3oool00080oooo00<000000;:b/P3oool01P3oool00`2b/[8000000?ooo`0]0?ooo`03
0000003oool0oooo06h0oooo0`3o000D0?ooo`80003o>03oool20?l001H0oooo0P000?nI0?ooo`80
003oD`3oool20000oa`0oooo1`3o00150?ooo`4000000@3oool00080oooo00<0jNWY0?ooo`3oool0
1`3oool00`3YjNT0oooo0?ooo`0?0?ooo`8000000`3oool0102JVYX000000000002WYjL30?ooo`04
09ZJVP00000000000:NWY`d0oooo00<000000?ooo`3oool0K@3oool30?l001D0oooo00<0003o0?oo
o`3oool0>03oool20?l001H0oooo00<0003o0?ooo`3oool0U`3oool20000oe@0oooo00<0003o0?oo
o`3oool0603oool60?l004P0oooo0@0000010?ooo`007P3oool200000080oooo00T0_Kfm00000037
alL0alO70000002b/[80oooo0;fm_@0000000P37alL00`000000/[:b0?ooo`0;0?ooo`030000003o
ool0oooo06`0oooo0`3o000E0?ooo`80003o>`3oool20?l001D0oooo0P000?nG0?ooo`<0003oE03o
ool20000oaL0oooo1@3o001;0?ooo`4000000@3oool001P0oooo0`0000030?ooo`8000000P3oool0
2@1lO7`000000?ooo`3oool0000007alO03oool0O7al000000020?ooo`030000001lO7`0oooo00/0
oooo00<000000?ooo`3oool0J`3oool30?l001D0oooo0`000?lk0?ooo`<0o`005@3oool00`000?l0
oooo0?ooo`2E0?ooo`80003oEP3oool00`000?l0oooo0?ooo`0D0?ooo`@0o`00C@3oool100000040
oooo000N0?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000020?ooo`800000
303oool00`000000oooo0?ooo`1[0?ooo`80o`005P3oool20000ocd0oooo0`3o000D0?ooo`80003o
U@3oool30000oeH0oooo0P000?lD0?ooo`<0o`00C`3oool100000040oooo000N0?ooo`8000000P3o
ool200000080oooo0P0000000`3oool00000000000020?ooo`800000303oool5000006P0oooo0P3o
000G0?ooo`80003o?P3oool30?l001<0oooo0P000?nE0?ooo`80003oE`3oool20000oa<0oooo0`3o
001=0?ooo`@000000@3oool000D0oooo0P0000000`3oool000000000000D0?ooo`8000000P3oool2
00000080oooo0P0000000`3oool00000000000020?ooo`800000303oool00`000000oooo0?ooo`1Y
0?ooo`80o`00603oool00`000?l0oooo0?ooo`0n0?ooo`@0o`004@3oool20000oiD0oooo0P000?mG
0?ooo`<0003o403oool40?l00540oooo0@0000010?ooo`001@3oool2000000030?ooo`0000000000
0180oooo00@0S8b<0?ooo`00000000000P3oool200000080oooo0P0000000`3oool0000000000002
0?ooo`800000303oool00`000000oooo0?ooo`1X0?ooo`80o`00603oool20000od40oooo0`3o000A
0?ooo`<0003oT`3oool30000oeP0oooo0P000?l?0?ooo`@0o`00DP3oool100000040oooo00050?oo
o`80000000<0oooo0000000000004P3oool010000000O7al0000000000020?ooo`0907alO0000000
oooo0?ooo`000000O7al0?ooo`1lO7`000000080oooo00<0000007alO03oool02`3oool00`000000
oooo0?ooo`1W0?ooo`<0o`005`3oool20000od@0oooo0P3o000A0?ooo`80003oT`3oool20000oeT0
oooo0P000?l<0?ooo`D0o`00E03oool100000040oooo00050?ooo`80000000<0oooo000000000000
4P3oool0103YjNT0S8b<0000000000020?ooo`090;:b/P000000alO70<O7a`000000/[:b0?ooo`2b
/[8000000080alO700<000000;:b/P3oool02`3oool00`000000oooo0?ooo`1V0?ooo`<0o`005`3o
ool20000odH0oooo0P3o000@0?ooo`80003oTP3oool30000oeX0oooo00<0003o0?ooo`3oool02P3o
ool40?l005D0oooo0@0000010?ooo`001@3oool2000000030?ooo`000000000001@0oooo00<0VYZJ
0000003oool00P3oool0102WYjL000000000002WYjL30?ooo`040:NWY`00000000000:NWY`d0oooo
00<000000?ooo`3oool0IP3oool20?l001P0oooo00<0003o0?ooo`3oool0AP3oool20?l00100oooo
00<0003o0?ooo`3oool0T03oool20000oe/0oooo0P000?l:0?ooo`80o`00F03oool100000040oooo
00050?ooo`80000000<0oooo000000000000<@3oool00`000000oooo0?ooo`1U0?ooo`80o`00603o
ool20000odP0oooo103o000>0?ooo`80003oT@3oool20000oe`0oooo00<0003o0?ooo`3oool01`3o
ool20?l005T0oooo0@0000010?ooo`001@3oool2000000030?ooo`00000000000340oooo00<00000
0?ooo`3oool0I03oool20?l001P0oooo0`000?m90?ooo`<0o`003`3oool00`000?l0oooo0?ooo`2>
0?ooo`<0003oG03oool20000o`L0oooo0P3o001J0?ooo`4000000@3oool000D0oooo0P0000000`3o
ool000000000000a0?ooo`030000003oool0oooo06<0oooo0P3o000I0?ooo`80003oC03oool20?l0
00h0oooo0P000?n?0?ooo`80003oGP3oool00`000?l0oooo0?ooo`040?ooo`<0o`00FP3oool10000
0040oooo000k0?ooo`030000003oool0oooo0680oooo0`3o000I0?ooo`80003oC@3oool20?l000h0
oooo00<0003o0?ooo`3oool0S03oool30000oeh0oooo0P000?l40?ooo`<0o`00F`3oool100000040
oooo000k0?ooo`030000003oool0oooo0640oooo0`3o000J0?ooo`030000o`3oool0oooo04d0oooo
0P3o000=0?ooo`80003oS@3oool20000of00oooo00@0003o0?ooo`3oool0oooo0`3o001L0?ooo`40
00000@3oool003/0oooo00<000000?ooo`3oool0H03oool30?l001X0oooo0P000?m?0?ooo`@0o`00
303oool00`000?l0oooo0?ooo`2;0?ooo`80003oH03oool20000o`040?ooo`3o0000o`000?l005d0
oooo0@0000010?ooo`00>`3oool4000005h0oooo0`3o000J0?ooo`80003oD@3oool40?l000/0oooo
0P000?n<0?ooo`80003oH03oool20000o`<0o`00G03oool300000040oooo000k0?ooo`030000003o
ool0oooo05h0oooo0`3o000J0?ooo`80003oE03oool30?l000/0oooo00<0003o0?ooo`3oool0R@3o
ool30000of00oooo0`000?l00`3o0000oooo0?ooo`1M0?ooo`4000000@3oool00080oooo2`00000^
0?ooo`030000003oool0oooo05h0oooo0P3o000K0?ooo`030000o`3oool0oooo05@0oooo0`3o000:
0?ooo`80003oRP3oool20000of80oooo0P000?mP0?ooo`4000000@3oool00080oooo2`00000^0?oo
o`030000003oool0oooo05d0oooo0P3o000K0?ooo`80003oE`3oool30?l000X0oooo00<0003o0?oo
o`3oool0R03oool20000of80oooo0P000?mP0?ooo`4000000@3oool00080oooo0P0000030?ooo`80
0000<P3oool00`000000oooo0?ooo`1L0?ooo`80o`006`3oool20000oeT0oooo0`3o00090?ooo`80
003oR@3oool20000of40oooo0P3o00000`000?l0oooo0?ooo`1N0?ooo`4000000@3oool00080oooo
0P0000030?ooo`800000<P3oool00`000000oooo0?ooo`1K0?ooo`80o`00703oool00`000?l0oooo
0?ooo`1I0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`260?ooo`<0003oH@3oool0103o0000oooo
0000o`000?mO0?ooo`4000000@3oool00080oooo0P0000030?ooo`80000000<0d=3@0?ooo`3oool0
;`3oool00`000000oooo0?ooo`1J0?ooo`<0o`006`3oool20000oe`0oooo0`3o00080?ooo`80003o
Q`3oool20000of40oooo0P3o00020?ooo`030000o`3oool0oooo05d0oooo0@0000010?ooo`000P3o
ool2000000<0oooo0P0000000`1=CDd0oooo0?ooo`0_0?ooo`030000003oool0oooo05T0oooo0`3o
000L0?ooo`030000o`3oool0oooo05`0oooo0`3o00070?ooo`80003oQP3oool30000of00oooo0P3o
00030?ooo`80003oGP3oool100000040oooo00020?ooo`0:06QXJ0000000alO70?ooo`37alL00000
06QXJ0000000J6QX0>7QhBl0oooo00<000000?ooo`3oool0F03oool30?l001`0oooo0P000?mO0?oo
o`80o`001`3oool30000ohD0oooo0P000?mP0?ooo`80o`001@3oool00`000?l0oooo0?ooo`1L0?oo
o`4000000@3oool00080oooo00<0_Kfm0000000000000`0000001@3IfMT0/[:b000000000000/[:b
02h0oooo00<000000?ooo`3oool0E`3oool30?l001`0oooo0`000?mP0?ooo`80o`001`3oool20000
ohD0oooo0P000?mP0?ooo`030?l0003oool0oooo00@0oooo0P000?mM0?ooo`4000000@3oool000<0
oooo00D0_Kfm04e=C@000000J6QX0=3@d0020?ooo`030;:b/P000000000002h0oooo00<000000?oo
o`3oool0EP3oool30?l001d0oooo0P000?mR0?ooo`80o`001P3oool20000oh@0oooo0`000?mO0?oo
o`80o`001`3oool00`000?l0oooo0?ooo`1K0?ooo`4000000@3oool000/0oooo00<0jNWY08b<S03o
ool0;@3oool4000005@0oooo0`3o000N0?ooo`80003oH`3oool20?l000H0oooo00<0003o0?ooo`3o
ool0PP3oool20000oel0oooo0`3o00070?ooo`80003oFP3oool300000040oooo000k0?ooo`030000
003oool0oooo05@0oooo0`3o000O0?ooo`030000o`3oool0oooo0680oooo0`3o00050?ooo`80003o
PP3oool30000oel0oooo0P3o00080?ooo`80003oG03oool100000040oooo00060?ooo`060=WIf@1l
O7`000000000001lO7`0fMWI;`3oool00`000000oooo0?ooo`1B0?ooo`@0o`007`3oool20000ofD0
oooo0`3o00050?ooo`030000o`3oool0oooo0800oooo0P000?mP0?ooo`80o`002@3oool20000oe/0
oooo0@0000010?ooo`001@3oool00`3@d=00000000000004000000030<O7a`3oool0oooo02`0oooo
00<000000?ooo`3oool0D@3oool40?l001l0oooo0P000?mW0?ooo`<0o`00103oool20000oh40oooo
0P000?mP0?ooo`030?l0003oool0oooo00P0oooo0P000?mK0?ooo`4000000@3oool000D0oooo00<0
J6QX0000003QhN400P0000000`3QhN40000006QXJ00^0?ooo`030000003oool0oooo0540oooo0P3o
000P0?ooo`80003oJ@3oool30?l000@0oooo00<0003o0?ooo`3oool0O`3oool20000oel0oooo0P3o
000:0?ooo`<0003oFP3oool100000040oooo00050?ooo`80000000@0oooo000000000000oooo0P00
000^0?ooo`030000003oool0oooo0500oooo0P3o000Q0?ooo`030000o`3oool0oooo06T0oooo0`3o
00030?ooo`80003oO`3oool30000oeh0oooo0P3o000<0?ooo`80003oFP3oool100000040oooo0005
0?ooo`0306QXJ0000000hN7Q0080000000<0oooo0000001=CDd0;P3oool00`000000oooo0?ooo`1?
0?ooo`80o`008@3oool20000of`0oooo0P3o00040?ooo`030000o`3oool0oooo07d0oooo0P000?mN
0?ooo`80o`003@3oool30000oeT0oooo0@0000010?ooo`001@3oool00`3IfMT00000000000020000
00030?ooo`000000YjNW02h0oooo00<000000?ooo`3oool0C@3oool30?l00240oooo0`000?m]0?oo
o`80o`000`3oool20000ogh0oooo0P000?mN0?ooo`030?l0003oool0oooo00d0oooo0P000?mI0?oo
o`4000000@3oool000H0oooo00H0hN7Q09ZJVP1=CDd000000?ooo`2<S8`_0?ooo`030000003oool0
oooo04`0oooo103o000Q0?ooo`80003oK`3oool0103o0000oooo0?ooo`3oool20000ogh0oooo0P00
0?mM0?ooo`80o`003`3oool20000oeT0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`1:
0?ooo`@0o`008`3oool20000ofl0oooo0P3o00020?ooo`80003oO@3oool30000oe`0oooo0P3o000@
0?ooo`<0003oF03oool100000040oooo00060?ooo`060=3@d01lO7`000000000001lO7`0fMWI;`3o
ool00`000000oooo0?ooo`190?ooo`@0o`00903oool00`000?l0oooo0?ooo`1_0?ooo`80o`0000@0
oooo0000o`000?l0003oO03oool20000oe`0oooo0P3o000B0?ooo`80003oF03oool100000040oooo
00050?ooo`030<O7a`000000000000@0000000<0d=3@0?ooo`3oool0;03oool4000004L0oooo0`3o
000U0?ooo`80003oL@3oool30?l000030?ooo`000?l0003o07/0oooo0`000?mL0?ooo`030?l0003o
ool0oooo0140oooo0P000?mF0?ooo`<000000@3oool000D0oooo00P0CDe=0000002b/[80l?3`0?oo
o`2WYjL0000004e=CBh0oooo00<000000?ooo`3oool0A`3oool30?l002D0oooo0P000?mc0?ooo`<0
o`000P000?mk0?ooo`80003oG03oool20?l001@0oooo00<0003o0?ooo`3oool0EP3oool100000040
oooo00050?ooo`0304e=C@000000oooo00<0oooo00<0000004e=C@3oool0;@3oool00`000000oooo
0?ooo`140?ooo`D0o`009@3oool20000ogD0oooo0P3o00000`3oool0003o0?ooo`1j0?ooo`80003o
G03oool00`3o0000oooo0?ooo`0C0?ooo`80003oE`3oool100000040oooo00050?ooo`030=3@d000
0000/[:b0080l?3`00<0YjNW0000003@d=00;P3oool00`000000oooo0?ooo`130?ooo`D0o`009P3o
ool00`000?l0oooo0?ooo`1e0?ooo`80o`000P000?mi0?ooo`<0003oF`3oool20?l001H0oooo00<0
003o0?ooo`3oool0E@3oool100000040oooo00020?ooo`/00000;P3oool00`000000oooo0?ooo`12
0?ooo`<0o`00:03oool20000ogP0oooo00<0o`000?ooo`000?l0N@3oool20000oe`0oooo00<0o`00
0?ooo`3oool05@3oool20000oeH0oooo0@0000010?ooo`000P3oool;000002h0oooo00<000000?oo
o`3oool0@03oool40?l002P0oooo0P000?mi0?ooo`80o`000P000?mg0?ooo`<0003oF`3oool20?l0
01P0oooo00<0003o0?ooo`3oool0E03oool100000040oooo000k0?ooo`030000003oool0oooo03l0
oooo103o000X0?ooo`80003oN`3oool20?l000030000o`3oool0oooo07D0oooo0P000?mK0?ooo`80
o`006@3oool20000oeD0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0m0?ooo`@0o`00
:P3oool00`000?l0oooo0?ooo`1j0?ooo`80o`000P000?me0?ooo`<0003oFP3oool20?l001/0oooo
00<0003o0?ooo`3oool0D`3oool100000040oooo000;0?ooo`80000000<0jNWY08b<S03oool0:`3o
ool00`000000oooo0?ooo`0l0?ooo`@0o`00:P3oool20000ogd0oooo0P3o00000`000?l0oooo0?oo
o`1c0?ooo`80003oF`3oool00`3o0000oooo0?ooo`0J0?ooo`80003oE03oool100000040oooo000;
0?ooo`80000000<0J6QX0>7Qh@3oool0:`3oool00`000000oooo0?ooo`0l0?ooo`80o`00;03oool0
0`000?l0oooo0?ooo`1m0?ooo`030?l000000?l0003o07@0oooo0P000?mJ0?ooo`80o`00703oool2
0000oe@0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0k0?ooo`80o`00;03oool20000
oh00oooo00<0o`000000o`3o0000LP3oool30000oeX0oooo00<0o`000?ooo`3oool0703oool20000
oe<0oooo0@0000010?ooo`00>`3oool4000003T0oooo0P3o000]0?ooo`030000o`3oool0oooo0800
oooo0P000?l00`3o0000oooo0?ooo`1_0?ooo`80003oFP3oool20?l001h0oooo0P000?mA0?ooo`<0
00000@3oool003/0oooo00<000000?ooo`3oool0>03oool30?l002d0oooo0P000?n30?ooo`030000
o`3o0000oooo06l0oooo0`000?mJ0?ooo`030?l0003oool0oooo01d0oooo0`000?mB0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0=`3oool40?l002`0oooo0P000?n40?ooo`80003o00<0
o`000?ooo`3oool0K@3oool20000oeX0oooo0P3o000P0?ooo`80003oDP3oool100000040oooo000k
0?ooo`030000003oool0oooo03H0oooo0`3o000^0?ooo`030000o`3oool0oooo08@0oooo00<0003o
0?l0003oool0KP3oool20000oeT0oooo0P3o000Q0?ooo`<0003oD@3oool100000040oooo000k0?oo
o`030000003oool0oooo03D0oooo0`3o000^0?ooo`80003oQP3oool20000o`030?l0003oool0oooo
06/0oooo0`000?mH0?ooo`80o`008`3oool20000oe40oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`0c0?ooo`@0o`00;`3oool00`000?l0oooo0?ooo`250?ooo`80003o0P3o001/0?ooo`80
003oF@3oool00`3o0000oooo0?ooo`0R0?ooo`80003oD@3oool100000040oooo00020?ooo`030>7Q
h@3oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool40?l002l0oooo0P000?n70?ooo`<0003o
0P3o001[0?ooo`80003oF03oool20?l002@0oooo0P000?mA0?ooo`4000000@3oool00080oooo00<0
000009ZJVP3`l?00=P3oool00`000000oooo0?ooo`0`0?ooo`@0o`00<@3oool00`000?l0oooo0?oo
o`270?ooo`80003o0`3o001Z0?ooo`80003oE`3oool20?l002D0oooo0`000?m@0?ooo`4000000@3o
ool00080oooo00@0J6QX000000000000/[:b9@3oool0102JVYX000000000002WYjL<0?ooo`030000
003oool0oooo01D0oooo00<0003o0?ooo`3oool05`3oool40?l00340oooo0P000?n90?ooo`80003o
00<0oooo0?l0003o0000J@3oool30000oeL0oooo00<0o`000?ooo`3oool09@3oool20000oe00oooo
0@0000010?ooo`000`3oool01@2m_Kd0CDe=0000001=CDd0_Kfm0280oooo00H0_Kfm00000037alL0
alO70000002b/[8;0?ooo`030000003oool0oooo01<0oooo1P000?lE0?ooo`<0o`00<`3oool00`00
0?l0oooo0?ooo`290?ooo`030000o`3oool0oooo0080o`00J03oool20000oeL0oooo0P3o000W0?oo
o`80003oD03oool100000040oooo00050?ooo`030;fm_@1=CDd0000000D000007@3oool01P1lO7`0
00000?ooo`3oool0000007alO0/0oooo00<000000?ooo`3oool0403oool=0000oa00oooo0`3o000c
0?ooo`80003oR`3oool20000o`80oooo0P3o001W0?ooo`80003oE`3oool00`3o0000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo04h0oooo0@0000010?ooo`001@3oool00`2m_Kd0CDe=000000050000
01d0oooo0P0000020?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`T0003o103oool60000
o`h0oooo0`3o000c0?ooo`80003oS@3oool010000?l0oooo0?ooo`3oool20?l006D0oooo0`000?mF
0?ooo`80o`00:@3oool20000odl0oooo0@0000010?ooo`000`3oool01@2m_Kd0CDe=0000001=CDd0
_Kfm0280oooo0P0000020?ooo`8000002`3oool=000000L0003o2`0000050000o`X000000`3o000d
000000030000o`000000000008`000000P000?l3000000030?l000000000000006<000000P000?mG
000000030?l000000000000002T0000000<0003o000000000000CP0000010?ooo`000P3oool0101X
J6P000000000002WYjLT0?ooo`8000000P3oool2000000/0oooo00<000000?ooo`3oool02P3oool0
0`3o0000003o0?l000070?l000T0oooo1@000?l80?ooo`<0o`00=03oool20000ohl0oooo00@0003o
0?ooo`3oool0oooo0P3o001S0?ooo`<0003oEP3oool20?l002/0oooo0P000?m>0?ooo`4000000@3o
ool00080oooo00<0000009ZJVP3`l?009@3oool200000080oooo0P00000;0?ooo`030000003oool0
oooo00h0oooo0P3of@060?l000X0oooo0`000?l50?ooo`@0o`00=@3oool00`000?l0oooo0?ooo`2>
0?ooo`80003o0`3oool20?l00680oooo0P000?mG0?ooo`030?l0003oool0oooo02/0oooo00<0003o
0?ooo`3oool0C03oool100000040oooo00020?ooo`030>7Qh@3oool0oooo02D0oooo00H0O7al0000
003oool0oooo0000001lO7`;0?ooo`030000003oool0oooo0100oooo0`3of@060?l000P0oooo0`00
0?l00`3oool0o`000?l000040?l003D0oooo0P000?nA0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0H03oool20000oeH0oooo0P3o000]0?ooo`80003oC@3oool100000040oooo000Z
0?ooo`060;:b/P000000alO70<O7a`000000/[:b2`3oool00`000000oooo0?ooo`0C0?ooo`80omT0
2@3o00040?ooo`@0003o0`3o000f0?ooo`80003oTP3oool20000o`<0oooo0P3o001P0?ooo`<0003o
E@3oool20?l002l0oooo00<0003o0?ooo`3oool0B`3oool100000040oooo000[0?ooo`040:NWY`00
000000000:NWY``0oooo00<000000?ooo`3oool05@3oool30?oI00/0o`001P000?le0?ooo`80003o
T@3oool30?oI00030000o`3oool0oooo0080oooo0P3o001O0?ooo`80003oE@3oool20?l00300oooo
0P000?m<0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool06`3oool20?oI00H0o`000P3o
f@050000oc@0oooo00<0003o0?ooo`3oool0S`3oool40?oI0080003o103oool20?l005h0oooo0P00
0?mE0?ooo`030?l0003oool0oooo02l0oooo0P000?m<0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool08P3oool60?oI00<0003o<P3oool20000oi00oooo0`3of@020?ooo`030?oI00000?l0
oooo00@0oooo00<0o`000?ooo`3oool0F`3oool30000oe@0oooo0P3o000a0?ooo`80003oC03oool1
00000040oooo00050?ooo`80000000<0oooo000000000000<@3oool00`000000oooo0?ooo`0U0?oo
o`@0omT00`000?l`0?ooo`<0003oT03oool20?oI00@0oooo0P000?l40?ooo`80o`00G03oool20000
oeD0oooo00<0o`000?ooo`3oool0<03oool30000od/0oooo0@0000010?ooo`001@3oool200000003
0?ooo`00000000000340oooo00<000000?ooo`3oool0:P3oool40000obh0oooo0P000?nA0?ooo`80
omT01@3oool00`000?l0oooo0?ooo`030?ooo`80o`00F`3oool20000oe@0oooo0P3o000c0?ooo`80
003oB`3oool100000040oooo00050?ooo`80000000<0oooo000000000000<@3oool00`000000oooo
0?ooo`0[0?ooo`@0003o;@3oool20000oi00oooo0`3of@050?ooo`80003o1@3oool00`3o0000oooo
0?ooo`1I0?ooo`80003oE03oool00`3o0000oooo0?ooo`0b0?ooo`80003oB`3oool100000040oooo
00050?ooo`80000000<0oooo000000000000<@3oool4000002`0oooo0`000?l/0?ooo`030000o`3o
ool0oooo08l0oooo0P3of@060?ooo`80003o1@3oool20?l005T0oooo0`000?mC0?ooo`80o`00=03o
ool30000odP0oooo0`0000010?ooo`001@3oool2000000030?ooo`00000000000340oooo00<00000
0?ooo`3oool0;P3oool30000obX0oooo0P000?nA0?ooo`80omT01P3oool30000o`D0oooo0P3o001H
0?ooo`80003oD`3oool20?l003H0oooo0P000?m:0?ooo`4000000@3oool000D0oooo0P0000000`3o
ool000000000000a0?ooo`030000003oool0oooo02l0oooo10000?lW0?ooo`80003oT@3oool30?oI
00H0oooo00<0omT00000o`000?l01P3oool20?l005H0oooo0`000?mB0?ooo`80o`00=`3oool30000
odT0oooo0@0000010?ooo`001@3oool2000000030?ooo`00000000000340oooo00<000000?ooo`3o
ool0<03oool40000obD0oooo0P000?nB0?ooo`80omT0203oool20000o`L0oooo00<0o`000?ooo`3o
ool0E03oool20000oe<0oooo00<0o`000?ooo`3oool0=`3oool20000odT0oooo0@0000010?ooo`00
1@3oool2000000030?ooo`00000000000340oooo00<000000?ooo`3oool0<@3oool0103of@00003o
0000o`000?lT0?ooo`030000o`3oool0oooo0900oooo0`3of@080?ooo`030?oI00000?l0oooo00H0
oooo0P3o001E0?ooo`80003oDP3oool20?l003T0oooo0P000?m90?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0<P3oool0103of@00003o0000o`000?lR0?ooo`80003oTP3oool20?oI00T0
oooo00<0omT00000o`000?l01`3oool20?l005<0oooo0`000?mA0?ooo`80o`00>`3oool20000odP0
oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0c0?ooo`030?oI00000?l0003o0240oooo
0P000?nC0?ooo`80omT02P3oool00`3of@00003o0?ooo`070?ooo`80o`00DP3oool20000oe40oooo
0P3o000l0?ooo`80003oB03oool100000040oooo000k0?ooo`030000003oool0oooo03@0oooo00<0
omT00000o`000?l0803oool00`000?l0oooo0?ooo`2A0?ooo`<0omT02P3oool00`3of@00003o0000
o`080?ooo`030?l0003oool0oooo04l0oooo0`000?mA0?ooo`030?l0003oool0oooo03`0oooo00<0
003o0?ooo`3oool0AP3oool100000040oooo000k0?ooo`030000003oool0oooo03D0oooo00<0omT0
0000o`000?l07P3oool20000oi<0oooo0P3of@0<0?ooo`030?oI00000?l0oooo00L0oooo0P3o001@
0?ooo`80003oD@3oool20?l003h0oooo0P000?m70?ooo`4000000@3oool003/0oooo00<000000?oo
o`3oool0=P3oool00`3of@00003o0000o`0M0?ooo`030000o`3oool0oooo0940oooo0`3of@0<0?oo
o`030?oI00000?l0003o00P0oooo0P3o001?0?ooo`80003oD@3oool00`3o0000oooo0?ooo`0n0?oo
o`030000o`3oool0oooo04D0oooo0@0000010?ooo`000P3oool;000002h0oooo00<000000?ooo`3o
ool0=P3oool0103of@00003o0000o`000?lK0?ooo`80003oT`3oool20?oI00d0oooo0P3of@000`00
0?l0oooo0?ooo`070?ooo`80o`00C@3oool30000oe00oooo0P3o00100?ooo`80003oAP3oool10000
0040oooo00020?ooo`/00000;P3oool4000003H0oooo00@0omT00000o`000?l0003o6P3oool00`00
0?l0oooo0?ooo`2A0?ooo`<0omT03P3oool00`3of@00003o0000o`080?ooo`<0o`00C03oool20000
oe40oooo00<0o`000?ooo`3oool0@03oool00`000?l0oooo0?ooo`120?ooo`<000000@3oool00080
oooo0P0000020?ooo`8000000`3oool2000002h0oooo00<000000?ooo`3oool0=`3oool20?oI0080
003o6@3oool20000oi<0oooo0P3of@0?0?ooo`030?oI00000?l0003o00T0oooo0`3o001:0?ooo`<0
003oD03oool20?l00480oooo0P000?m50?ooo`4000000@3oool00080oooo0P0000020?ooo`800000
0`3oool2000002h0oooo00<000000?ooo`3oool0>03oool20?oI0080003o603oool00`000?l0oooo
0?ooo`2B0?ooo`80omT0403oool20000o`X0oooo0P3o001:0?ooo`80003oD03oool20?l004@0oooo
00<0003o0?ooo`3oool0@`3oool100000040oooo00020?ooo`8000000P3oool2000000<0oooo0P00
000^0?ooo`030000003oool0oooo03T0oooo0P3of@020000oaH0oooo0P000?nC0?ooo`<0omT0403o
ool30000o`X0oooo0P3o00190?ooo`80003oC`3oool20?l004D0oooo0P000?m40?ooo`4000000@3o
ool00080oooo0P0000020?ooo`8000000`3oool2000002h0oooo00<000000?ooo`3oool0>P3oool2
0?oI0080003o503oool20000oi@0oooo0P3of@0A0?ooo`030?oI00000?l0003o00/0oooo0P3o0017
0?ooo`<0003oC`3oool00`3o0000oooo0?ooo`140?ooo`80003oA03oool100000040oooo00020?oo
o`0404e=C@000000hN7Q0>7Qh@80000000D0_Kfm0?ooo`37alL0000006QXJ00^0?ooo`030000003o
ool0oooo03/0oooo00@0omT00000o`000?l0003o4`3oool00`000?l0oooo0?ooo`2B0?ooo`<0omT0
4@3oool00`3of@00003o0000o`0<0?ooo`80o`00AP3oool20000odl0oooo0P3o00160?ooo`80003o
A03oool100000040oooo00020?ooo`050:NWY`00000000000000002<S8`01@0000000`2m_Kd0oooo
0?ooo`0/0?ooo`030000003oool0oooo03/0oooo0P3of@030000oa40oooo0P000?nD0?ooo`80omT0
4`3oool00`3of@00003o0?ooo`0;0?ooo`<0o`00A@3oool20000odl0oooo00<0o`000?ooo`3oool0
A@3oool30000od<0oooo0@0000010?ooo`000`3oool02@2<S8`0000008b<S03`l?00_Kfm04e=C@00
0000CDe=0;:b/P0_0?ooo`030000003oool0oooo03`0oooo0P3of@030000oa00oooo00<0003o0?oo
o`3oool0T`3oool20?oI01<0oooo00<0omT00000o`000?l0303oool30?l004<0oooo0`000?m>0?oo
o`80o`00B03oool20000od<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`0l0?ooo`<0
omT010000?l=0?ooo`80003oU03oool30?oI01@0oooo00<0omT00000o`3oool0303oool30?l00480
oooo0P000?m?0?ooo`030?l0003oool0oooo04L0oooo0P000?m30?ooo`4000000@3oool003/0oooo
00<000000?ooo`3oool0?@3oool30?oI00@0003o303oool00`000?l0oooo0?ooo`2C0?ooo`80omT0
5@3oool00`3of@00003o0000o`0=0?ooo`<0o`00@@3oool20000odh0oooo0P3o001:0?ooo`030000
o`3oool0oooo0440oooo0@0000010?ooo`000P3oool;000002h0oooo00<000000?ooo`3oool0?P3o
ool20?oI0080oooo0`000?l:0?ooo`80003oU@3oool20?oI01H0oooo00<0omT00000o`3oool03@3o
ool30?l00400oooo0P000?m=0?ooo`80o`00B`3oool20000od80oooo0@0000010?ooo`000P3oool;
000002h0oooo1000000n0?ooo`80omT00P3oool30000o`P0oooo0P000?nF0?ooo`80omT05P3oool0
0`3of@00003o0000o`0>0?ooo`80o`00?`3oool30000odd0oooo00<0o`000?ooo`3oool0B`3oool0
0`000?l0oooo0?ooo`0n0?ooo`<000000@3oool003/0oooo00<000000?ooo`3oool0@03oool20?oI
0080oooo10000?l50?ooo`<0003oU@3oool30?oI01L0oooo00<0omT00000o`3oool03P3oool20?l0
03h0oooo0P000?m=0?ooo`80o`00C@3oool20000od40oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`110?ooo`80omT00P3oool50000o`80oooo0`000?nF0?ooo`80omT0603oool00`3of@00
003o0000o`0?0?ooo`80o`00?03oool30000odd0oooo00<0o`000?ooo`3oool0C@3oool00`000?l0
oooo0?ooo`0o0?ooo`4000000@3oool000D0oooo1P0000000`1lO7`0jNWY0?ooo`0]0?ooo`030000
003oool0oooo0480oooo0P3of@030?ooo`L0003oUP3oool30?oI01T0oooo00<0omT00000o`3oool0
3`3oool00`3o0000oooo0?ooo`0j0?ooo`80003oC@3oool20?l004l0oooo0P000?m00?ooo`400000
0@3oool000D0oooo1`0000000`1lO7`0oooo0?ooo`0/0?ooo`030000003oool0oooo0480oooo0`3o
f@040?ooo`@0003oU`3oool20?oI01X0oooo00<0omT00000o`000?l03`3oool20?l003/0oooo0P00
0?m<0?ooo`80o`00D@3oool00`000?l0oooo0?ooo`0n0?ooo`4000000@3oool000X0oooo00<0fMWI
000000000000;P3oool00`000000oooo0?ooo`130?ooo`<0omT0403oool00`3of@00oooo0?ooo`2;
0?ooo`80omT06P3oool20?oI00030000o`3oool0oooo00h0oooo0P3o000i0?ooo`<0003oC03oool0
0`3o0000oooo0?ooo`1@0?ooo`80003o?`3oool100000040oooo000;0?ooo`030000001XJ6P0oooo
02d0oooo00<000000?ooo`3oool0A03oool40?oI00`0oooo1P3of@290?ooo`<0omT06`3oool00`3o
f@00003o0000o`0@0?ooo`80o`00>03oool20000od`0oooo0P3o001B0?ooo`80003o?`3oool10000
0040oooo000:0?ooo`030:NWY`000000d=3@02h0oooo00<000000?ooo`3oool0A@3oool40?oI00P0
oooo303of@260?ooo`80omT0703oool20?oI00030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool0=@3oool30000od`0oooo00<0o`000?ooo`3oool0D@3oool20000ocl0oooo0@0000010?ooo`00
1@3oool8000002h0oooo00<000000?ooo`3oool0A`3oool30?oI00H0oooo1@3of@040?ooo`D0omT0
Q03oool30?oI01`0oooo0P3of@020000oa00oooo0P3o000f0?ooo`80003oC03oool20?l005<0oooo
0`000?ln0?ooo`4000000@3oool000D0oooo2000000^0?ooo`030000003oool0oooo04P0oooo1@3o
f@020?ooo`<0omT02P3oool30?oI08<0oooo0P3of@0N0?ooo`030?oI00000?l0003o0140oooo0P3o
000e0?ooo`80003oC03oool20?l005@0oooo0P000?ln0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool0B@3oool80?oI00`0oooo0`3of@220?ooo`80omT07P3oool0103of@00003o0000o`00
0?lA0?ooo`030?l0003oool0oooo0380oooo0`000?m;0?ooo`<0o`00E03oool20000och0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`1<0?ooo`@0omT03P3oool40?oI07l0oooo0`3of@0O
0?ooo`030?oI00000?l0003o0140oooo0P3o000c0?ooo`80003oC03oool20?l005D0oooo0`000?lm
0?ooo`4000000@3oool000H0oooo00H0fMWI07alO0000000000007alO03IfMT_0?ooo`@00000GP3o
ool40?oI07h0oooo0P3of@0P0?ooo`030?oI00000?l0003o0180oooo0P3o000b0?ooo`80003oC03o
ool20?l005H0oooo0P000?lk0?ooo`<000000@3oool000D0oooo00<0d=3@00000000000010000000
0`37alL0oooo0?ooo`0/0?ooo`030000003oool0oooo0640oooo0`3of@1m0?ooo`80omT0803oool2
0?oI00030000o`3oool0oooo0140oooo0P3o000a0?ooo`80003oC03oool00`3o0000oooo0?ooo`1E
0?ooo`<0003o?03oool100000040oooo00050?ooo`0306QXJ0000000hN7Q0080000000<0hN7Q0000
001XJ6P0;P3oool00`000000oooo0?ooo`1R0?ooo`<0omT0O03oool20?oI0200oooo0P3of@020000
oa<0oooo0P3o000_0?ooo`<0003oB`3oool20?l005P0oooo0P000?ll0?ooo`4000000@3oool000D0
oooo0P000000103oool000000000003oool2000002h0oooo00<000000?ooo`3oool0H`3oool20?oI
07/0oooo0`3of@0Q0?ooo`80omT000<0003o0?ooo`3oool04@3oool30?l002h0oooo0P000?m<0?oo
o`030?l0003oool0oooo05L0oooo0P000?ll0?ooo`4000000@3oool000D0oooo00<0J6QX0000003Q
hN400P0000000`3oool0000004e=C@0^0?ooo`030000003oool0oooo06@0oooo0P3of@1j0?ooo`80
omT08P3oool20?oI0080003o4`3oool30?l002`0oooo0`000?m;0?ooo`80o`00F@3oool30000oc/0
oooo0@0000010?ooo`001@3oool00`3IfMT0000000000002000000030?ooo`000000YjNW02h0oooo
00<000000?ooo`3oool0I@3oool00`3of@00oooo0?ooo`1g0?ooo`<0omT08P3oool30?oI00030000
o`3oool0oooo0180oooo0P3o000/0?ooo`80003oC03oool00`3o0000oooo0?ooo`1I0?ooo`80003o
>`3oool100000040oooo00060?ooo`060>7Qh@2JVYX0CDe=0000003oool0S8b<;`3oool00`000000
oooo0?ooo`1U0?ooo`80omT0N03oool20?oI02@0oooo0P3of@020000oa@0oooo0P3o000[0?ooo`80
003oB`3oool20?l005/0oooo0`000?lj0?ooo`4000000@3oool000/0oooo0P0000000`3YjNT0S8b<
0?ooo`0>0?ooo`8000000`3oool0102JVYX000000000002WYjL30?ooo`0409ZJVP00000000000:NW
Y`d0oooo00<000000?ooo`3oool0IP3oool20?oI07L0oooo0P3of@0T0?ooo`<0omT000<0003o0?oo
o`3oool04`3oool20?l002T0oooo0`000?m;0?ooo`030?l0003oool0oooo05/0oooo0P000?lj0?oo
o`4000000@3oool000/0oooo0P0000000`1XJ6P0hN7Q0?ooo`0>0?ooo`8000000P3oool02@2m_Kd0
00000<O7a`37alL000000;:b/P3oool0_Kfm000000020<O7a`030000002b/[80oooo00/0oooo00<0
00000?ooo`3oool0IP3oool30?oI07D0oooo0`3of@0U0?ooo`80omT00P000?lE0?ooo`80o`00:03o
ool20000od/0oooo0P3o001M0?ooo`<0003o>@3oool100000040oooo000N0?ooo`8000000P3oool0
2@1lO7`000000?ooo`3oool0000007alO03oool0O7al000000020?ooo`030000001lO7`0oooo00/0
oooo00<000000?ooo`3oool0I`3oool30?oI07@0oooo0P3of@0V0?ooo`80omT00P000?lE0?ooo`<0
o`009P3oool30000od/0oooo0P3o001N0?ooo`80003o>@3oool100000040oooo000N0?ooo`800000
0P3oool200000080oooo0P0000000`3oool00000000000020?ooo`800000303oool00`000000oooo
0?ooo`1X0?ooo`80omT0L`3oool30?oI02H0oooo0P3of@030000oaD0oooo0`3o000U0?ooo`80003o
B`3oool20?l005l0oooo0P000?li0?ooo`4000000@3oool001h0oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P00000<0?ooo`D00000I`3oool20?oI0780oooo0P3o
f@0X0?ooo`80omT00P000?lF0?ooo`80o`00903oool30000od/0oooo0P3o000o0?ooo`/0omT05@3o
ool30000ocD0oooo100000010?ooo`007P3oool200000080oooo0P0000020?ooo`80000000<0oooo
0000000000000P3oool2000000`0oooo00<000000?ooo`3oool0JP3oool00`3of@00oooo0?ooo`1_
0?ooo`<0omT0:03oool20?oI0080003o5`3oool20?l002<0oooo0P000?m<0?ooo`030?l0003oool0
oooo03/0oooo3`3of@0E0?ooo`80003o>03oool100000040oooo000L0?ooo`0408b<S03oool00000
00000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool2000000`0oooo00<00000
0?ooo`3oool0JP3oool20?oI0700oooo0P3of@0Z0?ooo`80omT000<0003o0?ooo`3oool05P3oool2
0?l00280oooo0P000?m;0?ooo`80o`00>P3oool70?oI00T0oooo103of@0C0?ooo`<0003o=`3oool1
00000040oooo000L0?ooo`040000001lO7`0000000000080oooo00T0O7al0000003oool0oooo0000
001lO7`0oooo07alO00000000P3oool00`000000O7al0?ooo`0;0?ooo`030000003oool0oooo06/0
oooo00<0omT00?ooo`3oool0KP3oool20?oI02X0oooo0P3of@020000oaP0oooo00<0o`000?ooo`3o
ool07`3oool30000odX0oooo0P3o000j0?ooo`D0omT03@3oool30?oI01@0oooo0P000?lg0?ooo`40
00000@3oool000H0oooo00H0d=3@07alO0000000000007alO03IfMT@0?ooo`040>WYj@2<S8`00000
00000080oooo00T0/[:b00000037alL0alO70000002b/[80oooo0;:b/P0000000P37alL00`000000
/[:b0?ooo`0;0?ooo`030000003oool0oooo06/0oooo0P3of@1^0?ooo`<0omT0:P3oool20?oI0003
0?ooo`000?l0oooo01L0oooo0P3o000P0?ooo`80003oBP3oool20?l003X0oooo0`3of@0B0?ooo`80
omT04`3oool20000ocL0oooo0@0000010?ooo`001@3oool00`37alL0000000000004000000030=3@
d03oool0oooo00l0oooo00<0VYZJ0000003oool00P3oool0102WYjL000000000002WYjL30?ooo`04
0:NWY`00000000000:NWY`d0oooo00<000000?ooo`3oool0K03oool20?oI06d0oooo0P3of@0[0?oo
o`<0omT00P000?lH0?ooo`80o`007P3oool30000odX0oooo00<0o`000?ooo`3oool0=`3oool40?oI
01@0oooo0P3of@0B0?ooo`80003o=`3oool100000040oooo00050?ooo`0804e=C@000000/[:b0?3`
l03oool0YjNW0000001=CDd^0?ooo`030000003oool0oooo06d0oooo0P3of@1[0?ooo`<0omT0;03o
ool20?oI00030?ooo`000?l0oooo01P0oooo0P3o000M0?ooo`80003oBP3oool20?l003P0oooo103o
f@0F0?ooo`80omT04@3oool30000ocH0oooo0@0000010?ooo`001@3oool00`1=CDd000000?ooo`03
0?ooo`030000001=CDd0oooo02d0oooo00<000000?ooo`3oool0KP3oool00`3of@00oooo0?ooo`1Y
0?ooo`80omT0;@3oool20?oI00030?ooo`000?l0003o01T0oooo0P3o000L0?ooo`80003oB@3oool2
0?l003T0oooo0P3of@0H0?ooo`@0omT0403oool20000ocH0oooo0@0000010?ooo`001@3oool00`3@
d=0000000;:b/P020?3`l0030:NWY`000000d=3@02h0oooo00<000000?ooo`3oool0KP3oool20?oI
06X0oooo0P3of@0]0?ooo`<0omT000<0oooo0000o`3oool0603oool30?l001X0oooo0`000?m80?oo
o`80o`00>@3oool20?oI01X0oooo103of@0?0?ooo`80003o=P3oool100000040oooo00020?ooo`/0
0000;P3oool00`000000oooo0?ooo`1_0?ooo`030?oI003oool0oooo06L0oooo0`3of@0^0?ooo`80
omT000<0oooo0000o`000?l06@3oool30?l001T0oooo0P000?m90?ooo`030?l0003oool0oooo03L0
oooo0P3of@0M0?ooo`<0omT03P3oool30000ocD0oooo0@0000010?ooo`000P3oool;000002h0oooo
00<000000?ooo`3oool0K`3oool20?oI06P0oooo0P3of@0_0?ooo`<0omT000<0oooo0000o`3oool0
6@3oool20?l001T0oooo0P000?m80?ooo`80o`00>03oool20?oI01l0oooo0`3of@0>0?ooo`80003o
=@3oool100000040oooo000k0?ooo`@00000K`3oool20?oI06L0oooo0P3of@0`0?ooo`80omT000<0
oooo0000o`000?l06P3oool20?l001L0oooo0`000?m80?ooo`030?l0003oool0oooo03H0oooo0`3o
f@0P0?ooo`80omT03P3oool30000oc80oooo0`0000010?ooo`00>`3oool00`000000oooo0?ooo`1a
0?ooo`030?oI003oool0oooo06D0oooo0P3of@0`0?ooo`80omT00P3oool00`000?l0oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01D0oooo0P000?m80?ooo`80o`00=`3oool30?oI0280oooo0P3of@0>
0?ooo`80003o=03oool100000040oooo000k0?ooo`030000003oool0oooo0740oooo0P3of@1V0?oo
o`030?oI003oool0oooo02l0oooo0`3of@000`3oool0003o0000o`0J0?ooo`80o`005@3oool30000
odL0oooo0P3o000h0?ooo`80omT0903oool00`3of@00oooo0?ooo`0<0?ooo`80003o=03oool10000
0040oooo000k0?ooo`030000003oool0oooo0780oooo00<0omT00?ooo`3oool0H`3oool20?oI0380
oooo0P3of@020?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool04`3oool20000odL0
oooo0`3o000g0?ooo`80omT09@3oool20?oI00d0oooo0`000?lc0?ooo`4000000@3oool000D0oooo
0P0000000`3oool000000000000a0?ooo`030000003oool0oooo0780oooo0P3of@1T0?ooo`030?oI
003oool0oooo0340oooo0`3of@000`3oool0003o0000o`0J0?ooo`80o`00503oool20000odH0oooo
0`3o000g0?ooo`80omT09`3oool20?oI00d0oooo0P000?lc0?ooo`4000000@3oool000D0oooo0P00
00000`3oool000000000000a0?ooo`030000003oool0oooo07<0oooo00<0omT00?ooo`3oool0H@3o
ool20?oI03@0oooo0P3of@000`3oool0003o0000o`0K0?ooo`80o`004P3oool30000od@0oooo103o
000h0?ooo`030?oI003oool0oooo02H0oooo0`3of@0<0?ooo`<0003o<P3oool100000040oooo0005
0?ooo`80000000<0oooo000000000000<@3oool00`000000oooo0?ooo`1c0?ooo`80omT0HP3oool0
0`3of@00oooo0?ooo`0c0?ooo`<0omT00`000?lK0?ooo`80o`004@3oool20000od@0oooo103o000h
0?ooo`80omT0:@3oool30?oI00`0oooo0P000?lU0?ooo`030000o`3oool0oooo00X0oooo0@000001
0?ooo`001@3oool2000000030?ooo`00000000000340oooo00<000000?ooo`3oool0M03oool00`3o
f@00oooo0?ooo`1O0?ooo`80omT0=P3oool20?oI00030?ooo`000?l0003o01`0oooo00<0o`000?oo
o`3oool03P3oool30000od@0oooo0P3o000j0?ooo`030?oI003oool0oooo02T0oooo0P3of@0<0?oo
o`80003o903oool30000o`/0oooo0@0000010?ooo`001@3oool2000000030?ooo`00000000000340
oooo00<000000?ooo`3oool0M03oool20?oI0600oooo00<0omT00?ooo`3oool0=@3oool20?oI0003
0?ooo`000?l0003o01`0oooo0P3o000?0?ooo`80003oA03oool20?l003X0oooo0P3of@0/0?ooo`80
omT02`3oool30000ob<0oooo0P000?l<0?ooo`4000000@3oool000D0oooo0P0000000`3oool00000
0000000a0?ooo`030000003oool0oooo07D0oooo0P3of@1N0?ooo`80omT0=`3oool30?oI00030?oo
o`000?l0oooo01`0oooo00<0o`000?ooo`3oool03@3oool20000od<0oooo0P3o000k0?ooo`030?oI
003oool0oooo02`0oooo00<0omT00?ooo`3oool02P3oool20000ob<0oooo0P000?l<0?ooo`400000
0@3oool000D0oooo0P0000000`3oool000000000000a0?ooo`030000003oool0oooo07H0oooo00<0
omT00?ooo`3oool0G03oool20?oI03P0oooo0P3of@000`3oool0003o0000o`0L0?ooo`80o`003@3o
ool30000od00oooo103o000k0?ooo`80omT0;P3oool20?oI00/0oooo0P000?lR0?ooo`<0003o303o
ool100000040oooo00050?ooo`80000000<0oooo000000000000<@3oool4000007D0oooo0P3of@1L
0?ooo`<0omT0>03oool30?oI00030?ooo`000?l0oooo01`0oooo00<0o`000?ooo`3oool02`3oool2
0000od00oooo1@3o000k0?ooo`030?oI003oool0oooo02h0oooo00<0omT00?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0P0?ooo`80003o2`3oool300000040oooo000k0?ooo`030000003oool0oooo
07H0oooo0P3of@1L0?ooo`80omT0>P3oool20?oI00030?ooo`000?l0003o01`0oooo0P3o000<0?oo
o`80003o?`3oool30?l003d0oooo0P3of@0`0?ooo`80omT02`3oool20000ob00oooo0`000?l=0?oo
o`4000000@3oool003/0oooo00<000000?ooo`3oool0MP3oool30?oI05/0oooo0P3of@0j0?ooo`80
omT00P3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0?03oool40?l003d0oooo0P3of@0b0?ooo`030?oI003oool0oooo00X0oooo00<0003o0?ooo`3o
ool07P3oool20000o`h0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`1g0?ooo`80omT0
F`3oool20?oI03X0oooo0P3of@020?ooo`80003o703oool20?l000X0oooo0P000?lm0?ooo`@0o`00
?P3oool00`3of@00oooo0?ooo`0a0?ooo`80omT02`3oool20000oal0oooo0P000?l>0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0N03oool00`3of@00oooo0?ooo`1I0?ooo`030?oI003o
ool0oooo03T0oooo0`3of@020?ooo`030000o`3oool0oooo01/0oooo0P3o00090?ooo`030000o`3o
ool0oooo03T0oooo1@3o000o0?ooo`80omT0=03oool20?oI00/0oooo00<0003o0?ooo`3oool0703o
ool30000o`h0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`1h0?ooo`80omT0F@3oool2
0?oI03`0oooo0P3of@020?ooo`80003o7@3oool00`3o0000oooo0?ooo`060?ooo`80003o>P3oool5
0?l00400oooo00<0omT00?ooo`3oool0=03oool00`3of@00oooo0?ooo`090?ooo`80003o7@3oool2
0000o`l0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`1i0?ooo`030?oI003oool0oooo
05L0oooo00<0omT00?ooo`3oool0>`3oool20?oI0080oooo0P000?lM0?ooo`80o`001`3oool00`00
0?l0oooo0?ooo`0h0?ooo`<0o`00@P3oool20?oI03H0oooo0P3of@0;0?ooo`030000o`3oool0oooo
01/0oooo0P000?l?0?ooo`4000000@3oool000@0oooo00L0hN7Q09ZJVP1=CDd0000004e=C@2JVYX0
hN7Q0300oooo00<000000?ooo`3oool0N@3oool20?oI05L0oooo0P3of@0n0?ooo`030?oI003oool0
oooo00<0003o7@3oool20?l000D0oooo0P000?lg0?ooo`D0o`00@`3oool20?oI03L0oooo0P3of@0:
0?ooo`80003o6`3oool30000o`l0oooo0@0000010?ooo`000`3oool00`2b/[800000000000050000
00030;:b/P3oool0oooo02d0oooo00<000000?ooo`3oool0NP3oool20?oI05H0oooo00<0omT00?oo
o`3oool0?@3oool20?oI0080oooo0P000?lN0?ooo`80o`00103oool00`000?l0oooo0?ooo`0d0?oo
o`H0o`00@`3oool30?oI03P0oooo0P3of@090?ooo`80003o6`3oool20000oa00oooo0@0000010?oo
o`000P3oool0103IfMT0000000000037alL20?ooo`050?3`l02m_Kd000000000003QhN40;P3oool0
0`000000oooo0?ooo`1k0?ooo`030?oI003oool0oooo05<0oooo0P3of@100?ooo`030?oI003oool0
oooo0080003o7`3oool0103o0000oooo0?ooo`3oool20000oc@0oooo1@3o00160?ooo`80omT0>P3o
ool00`3of@00oooo0?ooo`080?ooo`80003o6P3oool20000oa00oooo0@0000010?ooo`000P3oool0
0`2JVYX000000<O7a`050?ooo`030<O7a`000000VYZJ02h0oooo00<000000?ooo`3oool0N`3oool2
0?oI05@0oooo00<0omT00?ooo`3oool0?`3oool20?oI0080oooo00<0003o0?ooo`3oool07@3oool2
0?l00080oooo00<0003o0?ooo`3oool0<P3oool40?l004P0oooo0P3of@0j0?ooo`80omT02@3oool2
0000oaX0oooo0P000?l@0?ooo`4000000@3oool00080oooo0P0000070?ooo`800000;P3oool00`00
0000oooo0?ooo`1l0?ooo`030?oI003oool0oooo0540oooo0P3of@120?ooo`030?oI003oool0oooo
0080003o7`3oool0103o0000oooo0000o`000?l_0?ooo`L0o`00BP3oool00`3of@00oooo0?ooo`0i
0?ooo`80omT02@3oool30000oaP0oooo0`000?l@0?ooo`4000000@3oool00080oooo0P0000030?oo
o`8000000P3oool2000002h0oooo1000001k0?ooo`80omT0DP3oool20?oI0480oooo0P3of@020?oo
o`80003o7P3oool20?l000030000o`3oool0oooo02/0oooo2@3o001:0?ooo`80omT0?03oool20?oI
00T0oooo0P000?lH0?ooo`80003o3`3oool300000040oooo00020?ooo`0304e=C@000000hN7Q0080
oooo0P000000103oool0jNWY0000001XJ6P^0?ooo`030000003oool0oooo07d0oooo00<0omT00?oo
o`3oool0C`3oool20?oI04@0oooo00@0omT00?ooo`3oool0oooo0P000?lN0?ooo`80003o:`3oool6
0?l004h0oooo0P3of@0m0?ooo`80omT02@3oool30000oaH0oooo0`000?lA0?ooo`4000000@3oool0
0080oooo00D0VYZJ0000001lO7`0hN7Q0?ooo`02000000040?ooo`2m_Kd000000;fm_Bh0oooo00<0
00000?ooo`3oool0O@3oool20?oI0500oooo0P3of@140?ooo`80omT00`3oool00`000?l0oooo0?oo
o`0L0?ooo`030000o`3o0000oooo02@0oooo2@3o001A0?ooo`030?oI003oool0oooo03d0oooo00<0
omT00?ooo`3oool0203oool20000oaH0oooo0P000?lB0?ooo`4000000@3oool00080oooo00D0hN7Q
000000000000S8b<0?ooo`040000000304e=C@3oool0oooo02d0oooo00<000000?ooo`3oool0OP3o
ool00`3of@00oooo0?ooo`1=0?ooo`<0omT0A03oool20?oI00<0oooo0P000?lL0?ooo`80003o0P3o
000O0?ooo``0o`00DP3oool20?oI03l0oooo0P3of@090?ooo`80003o5P3oool20000oa80oooo0@00
00010?ooo`000`3oool0103IfMT0J6QX0>7Qh@3oool4000000030;fm_@3oool0oooo02d0oooo00<0
00000?ooo`3oool0OP3oool20?oI04h0oooo0P3of@150?ooo`80omT0103oool20000oa/0oooo0P00
0?l00`3oool0o`000?l0000L0?ooo`P0o`001P3of@1B0?ooo`030?oI003oool0oooo03l0oooo00<0
omT00?ooo`3oool01`3oool20000oaD0oooo0`000?lB0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool0OP3oool20?oI04d0oooo0`3of@150?ooo`<0omT0103oool20000oaT0oooo0`000?l2
0?ooo`80o`005@3oool90?l000<0omT0103oool50?oI0500oooo0P3of@110?ooo`80omT0203oool3
0000oa@0oooo0P000?lC0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0OP3oool30?oI
04`0oooo0P3of@170?ooo`80omT01@3oool00`000?l0oooo0?ooo`0G0?ooo`80003o0`3oool40?l0
00h0oooo303o000<0?ooo`<0omT0C`3oool00`3of@00oooo0?ooo`110?ooo`030?oI003oool0oooo
00L0oooo0P000?lC0?ooo`<0003o4`3oool100000040oooo00060?ooo`060=WIf@1lO7`000000000
001lO7`0fMWI;`3oool00`000000oooo0?ooo`1o0?ooo`80omT0C03oool20?oI04L0oooo0P3of@05
0?ooo`80003o603oool20000o`@0oooo1@3o00040?ooo`h0o`00103of@0?0?ooo`<0omT0C@3oool2
0?oI04<0oooo0P3of@080?ooo`80003o4`3oool20000oa@0oooo0@0000010?ooo`001@3oool00`3I
fMT0000000000004000000030=WIf@3oool0oooo02`0oooo00<000000?ooo`3oool0P03oool00`3o
f@00oooo0?ooo`190?ooo`<0omT0B03oool00`3of@00oooo0?ooo`040?ooo`80003o5`3oool00`00
0?l0oooo0?ooo`050?oooa00o`00103oool40?oI0140oooo103of@1;0?ooo`030?oI003oool0oooo
04<0oooo00<0omT00?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`<0003o503oool10000
0040oooo00050?ooo`0306QXJ0000000YjNW0080oooo00<0YjNW0000001XJ6P0;P3oool00`000000
oooo0?ooo`200?ooo`80omT0BP3oool20?oI04T0oooo0P3of@060?ooo`80003o5@3oool20000o`T0
oooo1P3o000<0?ooo`80omT0503oool40?oI04T0oooo0P3of@150?ooo`80omT0203oool20000oa40
oooo0P000?lE0?ooo`4000000@3oool000D0oooo0P0000040?ooo`800000;P3oool00`000000oooo
0?ooo`210?ooo`030?oI003oool0oooo04P0oooo0P3of@1:0?ooo`030?oI003oool0oooo00@0oooo
10000?lB0?ooo`80003o6`3oool20?oI01L0oooo0`3of@180?ooo`030?oI003oool0oooo04@0oooo
0P3of@090?ooo`030000o`3oool0oooo00l0oooo0P000?lE0?ooo`4000000@3oool000D0oooo00<0
J6QX0000002WYjL00P3oool00`2WYjL0000006QXJ00^0?ooo`@00000P03oool20?oI04P0oooo0`3o
f@1:0?ooo`80omT01P3oool50000o`l0oooo0P000?lK0?ooo`80omT06@3oool30?oI04H0oooo0P3o
f@160?ooo`<0omT0203oool20000o`l0oooo0`000?lC0?ooo`<000000@3oool000D0oooo00<0fMWI
000000000000100000000`3IfMT0oooo0?ooo`0/0?ooo`030000003oool0oooo0880oooo0P3of@17
0?ooo`80omT0C03oool20?oI00L0oooo1P000?l:0?ooo`<0003o6`3oool20?oI01/0oooo0`3of@15
0?ooo`80omT0A`3oool20?oI00T0oooo00<0003o0?ooo`3oool03@3oool20000oaH0oooo0@000001
0?ooo`001P3oool01P3IfMT0O7al000000000000O7al0>7QhBl0oooo00<000000?ooo`3oool0P`3o
ool00`3of@00oooo0?ooo`140?ooo`<0omT0C@3oool00`3of@00oooo0?ooo`070?ooo`L0003o1P3o
ool40000oaX0oooo0`3of@0L0?ooo`<0omT0@`3oool30?oI04P0oooo00<0omT00?ooo`3oool01`3o
ool20000o`d0oooo0`000?lF0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0P`3oool2
0?oI04D0oooo0P3of@1>0?ooo`80omT02`3oool60000o`80oooo10000?lK0?ooo`<0omT07P3oool3
0?oI0480oooo0P3of@190?ooo`80omT02@3oool00`000?l0oooo0?ooo`0;0?ooo`80003o5`3oool1
00000040oooo000k0?ooo`030000003oool0oooo08<0oooo0P3of@150?ooo`80omT0C`3oool00`3o
f@00oooo0?ooo`0<0?ooo`P0003o703oool20?oI0200oooo0`3of@110?ooo`80omT0BP3oool00`3o
f@00oooo0?ooo`070?ooo`80003o303oool20000oaL0oooo0@0000010?ooo`000P3oool;000002h0
oooo00<000000?ooo`3oool0Q03oool20?oI04<0oooo0`3of@1?0?ooo`80omT03`3oool40000oad0
oooo0P3of@0R0?ooo`<0omT0?`3oool30?oI04X0oooo0P3of@080?ooo`80003o2`3oool30000oaL0
oooo0@0000010?ooo`000P3oool;000002h0oooo00<000000?ooo`3oool0Q03oool20?oI04<0oooo
0P3of@1A0?ooo`80omT0;P3oool20?oI02@0oooo0P3of@0o0?ooo`80omT0C03oool20?oI00L0oooo
0`000?l:0?ooo`80003o603oool100000040oooo000K0?ooo`0304e=C@000000000000<000000P3o
ool0102JVYX000000000002WYjL30?ooo`0409ZJVP00000000000:NWY`d0oooo00<000000?ooo`3o
ool0Q@3oool00`3of@00oooo0?ooo`100?ooo`<0omT0DP3oool00`3of@00oooo0?ooo`0[0?ooo`80
omT09P3oool20?oI03d0oooo0`3of@1=0?ooo`030?oI003oool0oooo00H0oooo0P000?l:0?ooo`80
003o603oool100000040oooo000K0?ooo`030:NWY`000000alO700@0oooo00T0_Kfm00000037alL0
alO70000002b/[80oooo0;fm_@0000000P37alL00`000000/[:b0?ooo`0;0?ooo`030000003oool0
oooo08D0oooo0P3of@110?ooo`80omT0D`3oool20?oI02/0oooo0`3of@0W0?ooo`030?oI003oool0
oooo03/0oooo0P3of@1>0?ooo`80omT01`3oool20000o`X0oooo00<0003o0?ooo`3oool05`3oool1
00000040oooo00060?ooo`060=3@d01lO7`000000000001lO7`0fMWI3`3oool0103`l?00000004e=
C@3YjNT30?ooo`0907alO0000000oooo0?ooo`000000O7al0?ooo`1lO7`000000080oooo00<00000
07alO03oool02`3oool00`000000oooo0?ooo`260?ooo`030?oI003oool0oooo03l0oooo0P3of@1D
0?ooo`030?oI003oool0oooo02P0oooo0`3of@0X0?ooo`80omT0?03oool20?oI04h0oooo0P3of@08
0?ooo`030000o`3oool0oooo00L0oooo0P000?lI0?ooo`4000000@3oool000D0oooo00<0alO70000
00000000100000000`3@d=00oooo0?ooo`0=0?ooo`030<O7a`000000CDe=00<0oooo0P0000020?oo
o`80000000<0oooo0000000000000P3oool2000000`0oooo00<000000?ooo`3oool0QP3oool20?oI
03l0oooo0`3of@1D0?ooo`80omT0:@3oool20?oI02X0oooo00<0omT00?ooo`3oool0>@3oool30?oI
04l0oooo0P3of@070?ooo`80003o1`3oool20000oaX0oooo0@0000010?ooo`001@3oool0201=CDd0
00000;:b/P3`l?00oooo0:NWY`000000CDe=403oool00`2<S8`0000008b<S0020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P00000<0?ooo`D00000Q@3oool00`3of@00oooo0?oo
o`0m0?ooo`80omT0EP3oool20?oI02L0oooo0P3of@0[0?ooo`80omT0>P3oool20?oI0500oooo0P3o
f@080?ooo`80003o1@3oool20000oaP0oooo100000010?ooo`001@3oool00`1=CDd000000?ooo`03
0?ooo`030000001=CDd0oooo0100oooo00@0J6QX00000037alL0oooo0P0000020?ooo`80000000<0
oooo0000000000000P3oool2000000`0oooo00<000000?ooo`3oool0Q`3oool20?oI03h0oooo0P3o
f@1F0?ooo`<0omT09@3oool20?oI02d0oooo0P3of@0h0?ooo`<0omT0D03oool30?oI00P0oooo0P00
0?l30?ooo`80003o703oool100000040oooo00050?ooo`030=3@d0000000/[:b0080l?3`00<0YjNW
0000003@d=004@3oool0103QhN40000004e=C@3oool200000080oooo0P0000000`3oool000000000
00020?ooo`800000303oool00`000000oooo0?ooo`280?ooo`030?oI003oool0oooo03/0oooo0`3o
f@1G0?ooo`<0omT08`3oool20?oI02l0oooo0P3of@0g0?ooo`80omT0DP3oool20?oI00T0oooo1P00
0?lL0?ooo`4000000@3oool00080oooo2`0000000`3oool0hN7Q08b<S00?0?ooo`80000000<0oooo
07alO00000000P3oool01@000000O7al0?ooo`1lO7`000000080oooo00<0000007alO03oool02`3o
ool00`000000oooo0?ooo`280?ooo`80omT0?03oool20?oI05T0oooo0P3of@0S0?ooo`030?oI003o
ool0oooo02l0oooo00<0omT00?ooo`3oool0=@3oool20?oI0580oooo0`3of@080?ooo`D0003o7@3o
ool100000040oooo00020?ooo`/0000000<0J6QX0000000000002`3oool02@1XJ6P000000>WYj@3Y
jNT000000:NWY`3oool0/[:b000000020<O7a`050000002b/[80oooo0;:b/P0000000P37alL00`00
0000/[:b0?ooo`0;0?ooo`030000003oool0oooo08T0oooo00<0omT00?ooo`3oool0>@3oool30?oI
05X0oooo0P3of@0Q0?ooo`80omT0<@3oool20?oI03D0oooo0`3of@1C0?ooo`80omT02`3oool00`00
0?l0oooo0?ooo`0L0?ooo`4000000@3oool00080oooo00<0hN7Q08b<S00000002@0000000`2<S8`0
hN7Q0?ooo`0:0?ooo`050>WYj@1lO7`000000000002WYjL00`3oool0102WYjL000000000002WYjL3
0?ooo`040:NWY`00000000000:NWY`d0oooo00<000000?ooo`3oool0R@3oool20?oI03X0oooo0P3o
f@1L0?ooo`80omT0803oool00`3of@00oooo0?ooo`0a0?ooo`030?oI003oool0oooo03<0oooo0P3o
f@1D0?ooo`80omT0:P3oool100000040oooo00040?ooo`040?3`l037alL0S8b<04e=C@80000000@0
J6QX08b<S037alL0l?3`;@3oool00`000000oooo0?ooo`2:0?ooo`80omT0>@3oool20?oI05d0oooo
0P3of@0N0?ooo`80omT0<`3oool20?oI03@0oooo0P3of@1D0?ooo`<0omT0:@3oool100000040oooo
000k0?ooo`030000003oool0oooo08X0oooo0`3of@0g0?ooo`80omT0GP3oool30?oI01`0oooo0P3o
f@0e0?ooo`030?oI003oool0oooo0380oooo00<0omT00?ooo`3oool0E03oool20?oI02T0oooo0@00
00010?ooo`00>`3oool00`000000oooo0?ooo`2;0?ooo`80omT0=`3oool20?oI05l0oooo0`3of@0J
0?ooo`<0omT0=@3oool20?oI0380oooo0P3of@1F0?ooo`80omT0:@3oool100000040oooo000k0?oo
o`030000003oool0oooo08/0oooo0P3of@0g0?ooo`030?oI003oool0oooo05l0oooo0`3of@0H0?oo
o`<0omT0=`3oool20?oI0340oooo00<0omT00?ooo`3oool0E@3oool30?oI01/0oooo00<0omT00?oo
o`3oool02P3oool100000040oooo000k0?ooo`030000003oool0oooo08/0oooo0`3of@0e0?ooo`80
omT0HP3oool30?oI01L0oooo0P3of@0i0?ooo`80omT0;`3oool20?oI05P0oooo0P3of@0K0?ooo`03
0?oI003oool0oooo00X0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2<0?ooo`80omT0
=@3oool00`3of@00oooo0?ooo`1R0?ooo`<0omT05@3oool20?oI03/0oooo00<0omT00?ooo`3oool0
;@3oool00`3of@00oooo0?ooo`1G0?ooo`<0omT06@3oool20?oI00`0oooo0@0000010?ooo`00>`3o
ool4000008`0oooo00<0omT00?ooo`3oool0<P3oool20?oI06D0oooo0P3of@0E0?ooo`030?oI003o
ool0oooo03X0oooo0P3of@0]0?ooo`80omT0FP3oool20?oI01P0oooo0P3of@0;0?ooo`<000000@3o
ool003/0oooo00<000000?ooo`3oool0S@3oool20?oI03<0oooo00<0omT00?ooo`3oool0I@3oool2
0?oI01<0oooo0P3of@0m0?ooo`030?oI003oool0oooo02/0oooo00<0omT00?ooo`3oool0F@3oool2
0?oI01L0oooo0P3of@0>0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0SP3oool00`3o
f@00oooo0?ooo`0`0?ooo`80omT0J03oool20?oI0100oooo0`3of@0n0?ooo`80omT0:`3oool20?oI
05/0oooo0`3of@0F0?ooo`030?oI003oool0oooo00d0oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`2>0?ooo`80omT0<@3oool00`3of@00oooo0?ooo`1X0?ooo`80omT03P3oool40?oI03l0
oooo0P3of@0Z0?ooo`030?oI003oool0oooo05/0oooo0P3of@0E0?ooo`80omT03`3oool100000040
oooo000k0?ooo`030000003oool0oooo08l0oooo0P3of@0_0?ooo`80omT0JP3oool40?oI00X0oooo
103of@120?ooo`030?oI003oool0oooo02L0oooo0P3of@1M0?ooo`<0omT0503oool00`3of@00oooo
0?ooo`0>0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0T03oool00`3of@00oooo0?oo
o`0]0?ooo`80omT0J`3oool40?oI00P0oooo103of@130?ooo`80omT0:03oool00`3of@00oooo0?oo
o`1M0?ooo`80omT04`3oool20?oI0100oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2@
0?ooo`80omT0;@3oool30?oI06d0oooo0`3of@050?ooo`@0omT0AP3oool00`3of@00oooo0?ooo`0U
0?ooo`80omT0G`3oool20?oI01<0oooo00<0omT00?ooo`3oool03`3oool100000040oooo000k0?oo
o`030000003oool0oooo0900oooo0P3of@0]0?ooo`80omT0K`3oool:0?oI04L0oooo0P3of@0V0?oo
o`030?oI003oool0oooo05h0oooo0`3of@0A0?ooo`80omT04@3oool100000040oooo000k0?ooo`03
0000003oool0oooo0900oooo0`3of@0/0?ooo`80omT0L03oool70?oI04X0oooo00<0omT00?ooo`3o
ool08`3oool20?oI0640oooo0P3of@0@0?ooo`80omT04P3oool100000040oooo000k0?ooo`030000
003oool0oooo0940oooo0P3of@0/0?ooo`80omT0L`3oool00`3of@00oooo0?ooo`1;0?ooo`80omT0
903oool20?oI0640oooo0P3of@0?0?ooo`80omT04`3oool100000040oooo000k0?ooo`030000003o
ool0oooo0980oooo00<0omT00?ooo`3oool0:P3oool00`3of@00oooo0?ooo`310?ooo`030?oI003o
ool0oooo0240oooo0`3of@1R0?ooo`030?oI003oool0oooo00d0oooo00<0omT00?ooo`3oool04P3o
ool100000040oooo000k0?ooo`@00000T@3oool20?oI02X0oooo0P3of@330?ooo`80omT08P3oool2
0?oI06<0oooo0P3of@0=0?ooo`80omT04P3oool300000040oooo000k0?ooo`030000003oool0oooo
09<0oooo00<0omT00?ooo`3oool0:03oool00`3of@00oooo0?ooo`330?ooo`80omT08@3oool20?oI
06@0oooo00<0omT00?ooo`3oool02P3oool20?oI01D0oooo0@0000010?ooo`00>`3oool00`000000
oooo0?ooo`2C0?ooo`80omT0:03oool20?oI0<H0oooo00<0omT00?ooo`3oool07`3oool00`3of@00
oooo0?ooo`1S0?ooo`80omT02P3oool20?oI01H0oooo0@0000010?ooo`00>`3oool00`000000oooo
0?ooo`2D0?ooo`80omT09`3oool00`3of@00oooo0?ooo`350?ooo`80omT07`3oool20?oI06H0oooo
00<0omT00?ooo`3oool0203oool00`3of@00oooo0?ooo`0E0?ooo`4000000@3oool003/0oooo00<0
00000?ooo`3oool0U@3oool00`3of@00oooo0?ooo`0T0?ooo`80omT0a`3oool20?oI01l0oooo00<0
omT00?ooo`3oool0I@3oool20?oI00P0oooo0P3of@0G0?ooo`4000000@3oool003/0oooo00<00000
0?ooo`3oool0U@3oool20?oI02D0oooo00<0omT00?ooo`3oool0aP3oool30?oI01d0oooo0P3of@1X
0?ooo`80omT01P3oool20?oI01P0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2F0?oo
o`030?oI003oool0oooo0280oooo0P3of@390?ooo`80omT07@3oool00`3of@00oooo0?ooo`1W0?oo
o`<0omT00`3oool30?oI01T0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2F0?ooo`80
omT08`3oool20?oI0<X0oooo00<0omT00?ooo`3oool06P3oool20?oI06X0oooo0`3of@000`3oool0
omT00?oI00020?oI01T0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2G0?ooo`80omT0
8@3oool30?oI0<X0oooo0P3of@0K0?ooo`030?oI003oool0oooo06X0oooo1@3of@0K0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0V03oool00`3of@00oooo0?ooo`0O0?ooo`80omT0c03o
ool20?oI01T0oooo0P3of@1/0?ooo`@0omT0703oool100000040oooo000k0?ooo`030000003oool0
oooo09P0oooo0P3of@0P0?ooo`80omT0c@3oool20?oI01P0oooo0P3of@2<0?ooo`4000000@3oool0
03/0oooo1000002G0?ooo`80omT0803oool20?oI0<h0oooo00<0omT00?ooo`3oool05@3oool20?oI
08/0oooo0`0000010?ooo`00>`3oool00`000000oooo0?ooo`2H0?ooo`<0omT07P3oool30?oI0<h0
oooo0P3of@0F0?ooo`80omT0S@3oool100000040oooo000k0?ooo`030000003oool0oooo09T0oooo
0P3of@0N0?ooo`80omT0d03oool00`3of@00oooo0?ooo`0D0?ooo`030?oI003oool0oooo08`0oooo
0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2J0?ooo`030?oI003oool0oooo01/0oooo0`3o
f@3@0?ooo`80omT0503oool20?oI08h0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`2J
0?ooo`80omT0703oool20?oI0=80oooo0P3of@0B0?ooo`80omT0S`3oool100000040oooo000k0?oo
o`030000003oool0oooo09/0oooo0P3of@0K0?ooo`80omT0d`3oool00`3of@00oooo0?ooo`0?0?oo
o`80omT0T03oool100000040oooo000k0?ooo`030000003oool0oooo09`0oooo0P3of@0I0?ooo`80
omT0e03oool20?oI00l0oooo0P3of@2A0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
W@3oool00`3of@00oooo0?ooo`0G0?ooo`80omT0e@3oool20?oI00d0oooo0`3of@2A0?ooo`400000
0@3oool003/0oooo00<000000?ooo`3oool0W@3oool20?oI01P0oooo00<0omT00?ooo`3oool0e03o
ool30?oI00/0oooo0`3of@2B0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0W@3oool2
0?oI01L0oooo0P3of@3G0?ooo`<0omT02P3oool20?oI09<0oooo0@0000010?ooo`00>`3oool00`00
0000oooo0?ooo`2M0?ooo`<0omT05P3oool00`3of@00oooo0?ooo`3G0?ooo`<0omT0203oool20?oI
09@0oooo0@0000010?ooo`00>`3oool4000009d0oooo0P3of@0E0?ooo`80omT0fP3oool50?oI00@0
oooo0P3of@2C0?ooo`<000000@3oool003/0oooo00<000000?ooo`3oool0W`3oool00`3of@00oooo
0?ooo`0C0?ooo`030?oI003oool0oooo0=X0oooo2@3of@2F0?ooo`4000000@3oool003/0oooo00<0
00000?ooo`3oool0W`3oool20?oI01<0oooo0P3of@3O0?ooo`H0omT0UP3oool100000040oooo000k
0?ooo`030000003oool0oooo0:00oooo0P3of@0B0?ooo`030?oI003oool0oooo0>00oooo00<0omT0
0?ooo`3oool0U`3oool100000040oooo000k0?ooo`030000003oool0oooo0:40oooo0P3of@0@0?oo
o`80omT0o`3ooomm0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0XP3oool00`3of@00
oooo0?ooo`0>0?ooo`80omT0o`3ooomm0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
XP3oool20?oI00h0oooo0P3of@3o0?ooogh0oooo0@0000010?ooo`00>`3oool00`000000oooo0?oo
o`2S0?ooo`80omT03@3oool20?oI0?l0ooooOP3oool100000040oooo000K0?ooo`050>WYj@2<S8`0
000004e=C@2b/[800`3oool0102JVYX000000000002WYjL30?ooo`0409ZJVP00000000000:NWY`d0
oooo00<000000?ooo`3oool0Y03oool20?oI00`0oooo00<0omT00?ooo`3oool0o`3ooomm0?ooo`40
00000@3oool001/0oooo00T0S8b<0000003YjNT0alO70000002b/[80oooo0;fm_@0000000P37alL0
1@000000/[:b0?ooo`2m_Kd000000080alO700<000000;:b/P3oool02`3oool00`000000oooo0?oo
o`2U0?ooo`030?oI003oool0oooo00T0oooo0P3of@3o0?ooogl0oooo0@0000010?ooo`007`3oool0
1@000000CDe=0?ooo`1lO7`000000080oooo00D0000007alO03oool0O7al000000020?ooo`030000
001lO7`0oooo00/0oooo00<000000?ooo`3oool0Y@3oool20?oI00T0oooo0P3of@3o0?oooh00oooo
0@0000010?ooo`007`3oool2000000030?ooo`00000000000080oooo0P0000000`3oool000000000
00020?ooo`800000303oool00`000000oooo0?ooo`2V0?ooo`80omT01`3oool20?oI0?l0ooooP@3o
ool100000040oooo000N0?ooo`040<O7a`000000VYZJ0?ooo`8000000P3oool2000000030?ooo`00
000000000080oooo0P00000<0?ooo`D00000Y@3oool20?oI00D0oooo0P3of@3o0?ooogl0oooo1000
00010?ooo`007@3oool00`1XJ6P0000006QXJ0020?ooo`8000000P3oool2000000030?ooo`000000
00000080oooo0P00000<0?ooo`030000003oool0oooo0:L0oooo103of@020?ooo`<0omT0o`3ooon2
0?ooo`4000000@3oool001h0oooo00@0_Kfm0000002JVYX0oooo0P0000020?ooo`80000000<0oooo
0000000000000P3oool2000000`0oooo00<000000?ooo`3oool0Z03oool70?oI0?l0ooooP`3oool1
00000040oooo000O0?ooo`80000000<0oooo07alO00000000P3oool01@000000O7al0?ooo`1lO7`0
00000080oooo00<0000007alO03oool02`3oool00`000000oooo0?ooo`2Z0?ooo`@0omT0o`3ooon4
0?ooo`4000000@3oool001/0oooo00T0VYZJ0000003YjNT0hN7Q0000002<S8`0oooo0;:b/P000000
0P37alL01@000000/[:b0?ooo`2b/[8000000080alO700<000000;:b/P3oool02`3oool00`000000
oooo0?ooo`3o0?ooool0oooo<`3oool100000040oooo000K0?ooo`050>WYj@2JVYX000000000002J
VYX00`3oool0102WYjL000000000002WYjL30?ooo`040:NWY`00000000000:NWY`d0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooc<0oooo0@0000010?ooo`00>`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo<`3oool100000040oooo000k0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0P03oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool0P03oool00`000000oooo0?ooo`0L0?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`020?ooo`4000000@3oool003/0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`020?ooo`4000000@3oool003/0ooooo`00003o000003L000000@3oool0
0?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0ooooo`3o
oomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00
o`3ooooo0?ooog<0oooo003:0?ooo`030;fm_@1lO7`000000080000000<0VYZJ0>7Qh@3oool0o`3o
oonP0?ooo`00b@3oool00`2WYjL0000000000005000000030>7Qh@3oool0oooo0?l0ooooWP3oool0
0<T0oooo0`0000000`3YjNT0oooo0;fm_@020000000309ZJVP3oool0oooo0?l0ooooWP3oool00<l0
oooo0`00003o0?oooj00oooo002k0?ooo`0407alO000000000000>WYj@D0oooo00@0jNWY00000000
0000O7al0P3oool01@3YjNT0O7al0000002<S8`0jNWY00<00000103oool01P2WYjL0J6QX00000000
0000VYZJ0>WYj@<0oooo0`0000030?ooo`<000000P3oool01@3YjNT0O7al000000000000S8b<00P0
oooo00H0d=3@08b<S0000000000008b<S03@d=060?ooo`060:NWY`1XJ6P000000000002JVYX0jNWY
0`3oool3000000<0oooo0`0000020?ooo`050>WYj@1lO7`000000000002<S8`00`3oool01P2WYjL0
J6QX000000000000VYZJ0>WYj@<0oooo0`00000<0?ooo`050;:b/P1XJ6P0000006QXJ02m_Kd0103o
ool3000000T0oooo0`0000020?ooo`030;fm_@000000_Kfm0080oooo0`0000030?ooo`050:NWY`00
0000CDe=0:NWY`3YjNT00P0000001@2JVYX0oooo0?ooo`2m_Kd0O7al0080000000<0CDe=0;:b/P3o
ool00`3oool01P2m_Kd0O7al000000000000CDe=0;:b/PX0oooo00D0YjNW0000001=CDd0YjNW0>WY
j@020000000309ZJVP3oool00000008000000`3oool3000000<0oooo00D0jNWY06QXJ0000000O7al
0>WYj@03000000P0oooo1P0000000`1=CDd0YjNW0>7Qh@040?ooo`<000000`3oool01P2m_Kd0O7al
000000000000CDe=0;:b/P<0oooo00D0jNWY07alO0000000000008b<S0020?ooo`050:NWY`000000
CDe=0:NWY`3YjNT00P0000000`2JVYX0oooo00000002000000<0oooo0`0000030?ooo`060?3`l02J
VYX000000000001lO7`0fMWI1@3oool01P2WYjL0J6QX000000000000VYZJ0>WYjH<0oooo002k0?oo
o`040<O7a`00000000000;:b/PD0oooo00L0/[:b000000000000alO70?ooo`3`l?00CDe=00<00000
00@0J6QX00000000000000000`3oool00`1lO7`00000000000030000000404e=C@3YjNT0oooo0?oo
o`<000000`3oool300000080oooo00D0O7al000000000000000009ZJVP070?ooo`0307alO0000000
000000@0000000<0YjNW0?ooo`3oool00P3oool00`1lO7`00000000000030000000404e=C@3YjNT0
oooo0?ooo`<000000`3oool300000080oooo00D0O7al000000000000000009ZJVP020?ooo`0307al
O0000000000000<0000000@0CDe=0>WYj@3oool0oooo0`00000;0?ooo`0307alO0000000000000<0
000000@0O7al0?ooo`3oool0oooo0`0000090?ooo`<000000P3oool00`2<S8`0000008b<S0020?oo
o`<000000P3oool00`2WYjL00000000000020000000604e=C@00000000000>WYj@3oool0S8b<1P00
0000102b/[80oooo0?ooo`2<S8`6000000030;:b/P3oool0oooo00H0oooo00<0YjNW000000000000
0P0000001@1=CDd000000000003YjNT0oooo00<000000`3oool3000000<0oooo00D0CDe=00000000
0000000004e=C@03000000P0oooo2@000000102m_Kd0oooo0?ooo`3oool300000080oooo00<0S8b<
00000000000010000000102b/[80oooo0?ooo`1lO7`30000000309ZJVP3oool0YjNW00@0000000D0
CDe=000000000000jNWY0?ooo`03000000<0oooo0`0000030?ooo`0304e=C@000000000000<00000
00D0fMWI0?ooo`3oool0oooo07alO0050000000304e=C@3YjNT0oooo0840oooo002k0?ooo`040?3`
l0000000000006QXJ0D0oooo00H0J6QX000000000000l?3`0?ooo`2WYjL2000000030:NWY`3oool0
VYZJ00<000000P3oool01P2m_Kd000000000002m_Kd0oooo0=WIf@80000000<0S8b<0?ooo`3oool0
0`0000030?ooo`<000000P3oool3000000P0oooo00<0O7al0000000000001P000000103@d=00oooo
0?ooo`2m_Kd2000000030;fm_@3oool0fMWI0080000000<0S8b<0?ooo`3oool00`0000030?ooo`<0
00000P3oool3000000<0oooo00H0_Kfm000000000000_Kfm0?ooo`3IfMT20000000308b<S03oool0
oooo00<000002P3oool01P2b/[8000000000002JVYX0oooo09ZJVP80000000<0_Kfm0?ooo`3oool0
0`0000090?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0000000<0jNWY0<O7a`000000
0P0000020?ooo`<000000P3YjNT300000080oooo0`0000020>WYj@<00000203oool3000000030>WY
j@37alL00000008000000P3oool3000000<0oooo0`0000020?ooo`060;:b/P00000000000:NWY`3o
ool0YjNW0`0000080?ooo`X0000000<0l?3`0?ooo`3oool00`0000020?ooo`<000000P3YjNT30000
0080oooo0`0000030?ooo`<0000000<0jNWY0<O7a`0000000P0000020?ooo`<000000`3oool30000
0080oooo00P0YjNW000000000000YjNW0?ooo`2b/[80000006QXJ080oooo00H0_Kfm000000000000
_Kfm0?ooo`3IfMT20000000308b<S03oool0oooo0800oooo002l0?ooo`0307alO0000000000000L0
000000@0O7al0?ooo`3oool0J6QX0P0000000`3`l?00oooo0?3`l00300000080oooo00<0J6QX0000
00000000203oool3000000<0oooo0`0000020?ooo`<000001`3oool0203@d=0000000000001=CDd0
hN7Q0?ooo`3`l?00O7al0P000000101XJ6P0oooo0?ooo`1XJ6P2000000P0oooo0`0000030?ooo`<0
00000P3oool3000000<0oooo00<0J6QX000000000000203oool3000000X0oooo00H0J6QX00000000
0000jNWY0?ooo`3YjNT20000000306QXJ03oool0oooo00<000002@3oool3000000030?ooo`3QhN40
00000080000000<0hN7Q0?ooo`0000000P0000020?ooo`<000000P3oool3000000H0oooo00@0alO7
000000000000CDe=1P3oool01037alL000000000001=CDd80?ooo`<000000P3oool300000080oooo
0`0000030?ooo`<000000P3oool01P1lO7`000000000003`l?00oooo0?3`l0<00000203oool30000
00<0oooo00D0jNWY07alO000000000000;:b/P020?ooo`<000001P3oool01037alL000000000001=
CDd20?ooo`<000000`3oool300000080oooo0`0000020?ooo`<000000`3oool300000080oooo00P0
J6QX000000000000l?3`0?ooo`3`l?00S8b<0>7Qh@80oooo00<0J6QX000000000000R03oool00;`0
oooo00<0d=3@0000000000001`0000000`3@d=00oooo0?ooo`03000000<0oooo0`0000020?ooo`T0
00000P3oool3000000<0oooo0`0000020?ooo`<000001`3oool0102<S8`000000000003IfMT40?oo
o`030:NWY`2<S8`0hN7Q0080oooo2@0000020?ooo`<000000`3oool300000080oooo0`0000030?oo
o`T000000P3oool3000000X0oooo0`0000030?ooo`<000000P3oool3000000T0oooo0`0000001`3o
ool0_Kfm0000002<S8`000000;fm_@3oool00`0000020?ooo`050=3@d0000000000009ZJVP3YjNT0
0`0000030?ooo`030>7Qh@2JVYX0000000<0000000H0d=3@0?ooo`3oool0oooo0>7Qh@2JVYX40000
00030=3@d03oool0oooo00H0oooo00D0d=3@000000000000VYZJ0>WYj@0300000080oooo0`000003
0?ooo`<000000P3oool3000000<0oooo0`0000080?ooo`<00000103oool0103IfMT000000000001l
O7`20?ooo`<000000`3oool00`3QhN40VYZJ00000003000000030=3@d03oool0oooo00<000000`3o
ool01@3@d=0000000000002JVYX0jNWY00<000000P3oool3000000<0oooo0`0000020?ooo`<00000
1`3oool900000880oooo002m0?ooo`T000000`3oool3000000<0oooo0`0000020?ooo`T000000P3o
ool3000000<0oooo0`0000020?ooo`<000001`3oool00`1=CDd000000000000:0?ooo`T000000P3o
ool3000000<0oooo0`0000020?ooo`<000000`3oool900000080oooo0`00000:0?ooo`<000000`3o
ool300000080oooo0`0000090?ooo`<0000000L0oooo08b<S0000000hN7Q0000002<S8`0oooo00<0
00000`3oool00`3YjNT0J6QX0000000400000080oooo00<0_Kfm0000000000000P0000000`2<S8`0
hN7Q0?ooo`020?ooo`030;fm_@00000000000080000000<0S8b<0>7Qh@3oool02@3oool00`3YjNT0
J6QX0000000400000080oooo0`0000030?ooo`<000000P3oool3000000<0oooo0`0000080?ooo`<0
00001@3oool300000080oooo0`0000020?ooo`030;fm_@00000000000080000000<0S8b<0>7Qh@3o
ool00P3oool3000000@0oooo00<0jNWY06QXJ0000000100000020?ooo`<000000`3oool300000080
oooo0`0000070?ooo`T00000PP3oool00;d0oooo00H0VYZJ000000000000hN7Q0?ooo`3YjNT20000
000509ZJVP3oool0oooo0?ooo`1XJ6P00P0000000`3`l?00oooo0?3`l00300000080oooo00<0J6QX
0000000000000`3oool20000000308b<S03oool0oooo00<0000000<0l?3`0?ooo`3oool00`000002
0?ooo`<000001`3oool3000000X0oooo00<0J6QX0000000000000`3oool20000000308b<S03oool0
oooo00<0000000<0l?3`0?ooo`3oool00`0000020?ooo`<000000`3oool00`1XJ6P0000000000003
0?ooo`80000000<0S8b<0?ooo`3oool00`0000000`3YjNT0oooo0?ooo`070?ooo`0607alO0000000
00000>WYj@3oool0jNWY0P0000000`1XJ6P0oooo0?ooo`03000000T0oooo0`0000001`3oool00000
06QXJ03oool0J6QX0000003oool00`0000050?ooo`030<O7a`1lO7`00000008000000P3oool01@1=
CDd000000000002JVYX0l?3`00D0oooo00D0CDe=000000000000VYZJ0?3`l00>0?ooo`030<O7a`1l
O7`00000008000000P3oool3000000030?3`l03oool0oooo00<000000P3oool01P2<S8`000000000
003`l?00oooo0?3`l0<00000203oool3000000D0oooo0`0000020?ooo`<000000P3oool01@1=CDd0
00000000002JVYX0l?3`00D0oooo0`0000060?ooo`030<O7a`1lO7`00000008000000P3oool30000
00030?3`l03oool0oooo00<000000P3oool0201XJ6P000000000003`l?00oooo0?3`l02<S8`0hN7Q
0P3oool00`1XJ6P00000000000030?ooo`80000000<0S8b<0?ooo`3oool0P03oool00;d0oooo00H0
d=3@000000000000YjNW0?ooo`2WYjL2000000050=3@d03oool0oooo0?ooo`2WYjL00P0000000`2W
YjL0oooo0:NWY`0300000080oooo00H0YjNW000000000000/[:b0?ooo`2m_Kd2000000030;fm_@3o
ool0oooo00<0000000<0YjNW0?ooo`37alL00P0000000`1=CDd0oooo0?ooo`03000000L0oooo0`00
000:0?ooo`060:NWY`00000000000;:b/P3oool0_Kfm0P0000000`2m_Kd0oooo0?ooo`0300000003
0:NWY`3oool0alO70080000000<0CDe=0?ooo`3oool00`0000030?ooo`060:NWY`00000000000;:b
/P3oool0_Kfm0P0000000`2m_Kd0oooo0?ooo`03000000030:NWY`3oool0l?3`00L0oooo00H0_Kfm
000000000000VYZJ0?ooo`2JVYX2000000030;fm_@3oool0oooo00<000002@3oool3000000070=WI
f@000000/[:b0?ooo`2b/[8000000=WIf@0300000080oooo00D0J6QX0000003IfMT0oooo0>WYj@03
00000080oooo0`0000000`3oool0jNWY0000000200000080oooo0`0000000`3oool0jNWY00000002
000000P0oooo00D0J6QX0000003IfMT0oooo0>WYj@0300000080oooo0`0000000`2WYjL0oooo0<O7
a`020000000404e=C@3oool0oooo0;:b/P80000000<0YjNW0?ooo`2WYjL00`0000080?ooo`<00000
1@3oool300000080oooo0`0000020?ooo`<0000000<0oooo0>WYj@0000000P0000020?ooo`<00000
0`3oool01@1XJ6P000000=WIf@3oool0jNWY00<000000P3oool3000000030:NWY`3oool0alO70080
000000@0CDe=0?ooo`3oool0YjNW0P0000001@2WYjL0oooo0;fm_@000000J6QX0080oooo00H0YjNW
000000000000/[:b0?ooo`2m_Kd2000000030;fm_@3oool0oooo0800oooo002n0?ooo`0704e=C@00
0000CDe=0?ooo`1=CDd0000004e=C@040?ooo`030?3`l01=CDd000000080000000@0J6QX00000000
000000000`3oool00`1=CDd00000000000030000000404e=C@3oool0oooo0?ooo`<0000000<0CDe=
0000000000000P0000000`2WYjL0oooo00000005000000D0oooo00@0S8b<000000000000fMWI0`3o
ool0103`l?00J6QX0;:b/P3YjNT30?ooo`0304e=C@000000000000<0000000@0CDe=0?ooo`3oool0
oooo0`0000000`1=CDd0000000000002000000030:NWY`3oool0000000D000000P3oool00`1=CDd0
0000000000030000000404e=C@3oool0oooo0?ooo`D0000000<0S8b<0?ooo`3oool01P3oool00`1l
O7`00000000000030000000307alO03oool0oooo00H000001`3oool3000000070;:b/P000000fMWI
0?ooo`3IfMT000000;:b/P0300000080oooo00<0fMWI00000000000010000000102JVYX0oooo0?oo
o`2b/[86000000040:NWY`3oool0oooo0;:b/PH0000000<0YjNW0?ooo`3oool01P3oool00`3IfMT0
0000000000040000000309ZJVP3oool0oooo00<0000000<0CDe=0000000000000P0000001@2WYjL0
oooo0?ooo`3`l?00CDe=00<0000000@0CDe=0000000000000000203oool3000000@0oooo00@0fMWI
000000000000O7al0P3oool300000080oooo00<0/[:b000000000000100000000`2WYjL0oooo0000
0005000000030?ooo`3IfMT0000000D0000000<0VYZJ0?ooo`3oool00`0000000`1=CDd000000000
0002000000050:NWY`3oool0oooo0?ooo`1=CDd01@0000001@3IfMT0oooo0?ooo`3oool0CDe=00D0
000000<0CDe=0?ooo`3oool0P@3oool00;h0oooo00@0YjNW000000000000YjNW0P0000000`2WYjL0
oooo0?ooo`030?ooo`050>WYj@1lO7`0000006QXJ03YjNT00`0000040?ooo`050:NWY`1=CDd00000
04e=C@2WYjL0103oool3000000050>WYj@2JVYX000000000002WYjL00P3oool6000000D0oooo00P0
alO7000000000000CDe=0>7Qh@3oool0l?3`07alO080000000<0J6QX0?ooo`3oool00P3oool01@2W
YjL0CDe=0000001=CDd0YjNW00@0oooo0`0000001@3YjNT0VYZJ000000000000YjNW0080oooo1P00
00030?ooo`050:NWY`1=CDd0000004e=C@2WYjL0103oool3000000030=3@d0000000J6QX00T0oooo
00D0YjNW06QXJ0000000J6QX0;fm_@030?ooo`H000001`3oool30000000307alO0000000oooo0080
oooo00<0000007alO00000000P0000030?ooo`060=WIf@1lO7`000000000001=CDd0YjNW103oool0
1P2m_Kd0J6QX000000000000CDe=0;fm_@@0oooo00H0_Kfm06QXJ0000000000004e=C@2m_Kd:0?oo
o`060=WIf@1lO7`000000000001=CDd0YjNW0`3oool3000000050>WYj@2JVYX000000000002WYjL0
103oool01@3QhN40J6QX0000001XJ6P0jNWY00<00000203oool3000000<0oooo00D0hN7Q04e=C@00
000000000:NWY`020?ooo`<000000`3oool01P2m_Kd0J6QX000000000000CDe=0;fm_@80oooo1P00
00020?ooo`060=WIf@1lO7`000000000001=CDd0YjNW0`3oool3000000050>WYj@2JVYX000000000
002WYjL0103oool01P3`l?00VYZJ000000000000O7al0=WIf@D0oooo00D0YjNW04e=C@000000CDe=
0:NWY`240?ooo`00_P3oool00`3IfMT0000000000003000000030=WIf@3oool0oooo02<0oooo0`00
00080?ooo`0306QXJ0000000000000H0000000<0d=3@0?ooo`3oool05P3oool3000002H0oooo0`00
00090?ooo`@0000000D0S8b<0?ooo`3oool0oooo08b<S00400000440oooo0`0000080?ooo`X00000
00<0jNWY0?ooo`3oool03`3oool300000:d0oooo002o0?ooo`0504e=C@00000000000000001=CDd0
9P3oool3000000P0oooo00<0jNWY06QXJ00000001@0000000`2WYjL0oooo0?ooo`0G0?ooo`<00000
9P3oool00`1XJ6P00000000000020000000309ZJVP3oool0oooo00@0oooo100000001@37alL0oooo
0?ooo`3oool0alO700@00000@@3oool3000000P0oooo2@0000001037alL0oooo0?ooo`3oool30000
00`0oooo0`00002]0?ooo`00_`3oool01@2WYjL00000000000000000YjNW02H0oooo00<0jNWY0;:b
/P1XJ6P02P3oool01P37alL0O7al000000000000O7al0=3@d1X0oooo00<0jNWY0;:b/P1XJ6P09P3o
ool00`3YjNT0VYZJ000000020000000309ZJVP3oool0oooo00@0oooo100000001@3YjNT0oooo0?oo
o`3oool0jNWY00@00000@@3oool3000000P0oooo1P0000000`1=CDd0VYZJ0>7Qh@040?ooo`<00000
303oool00`3YjNT0/[:b06QXJ02]0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0ooooL`3oool0
0?l0ooooo`3ooomc0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 624}, {411.5, 0}} -> {-27.1462, -362.11, 0.479482, \
2.22177}},
  CellTags->"run simulation"],

Cell[BoxData[
    InterpretationBox[\("Mean Center of Mass: \
"\[InvisibleSpace]{\(-17.92863052903524`\), \(-28.3466710763563`\)}\),
      SequenceForm[ 
      "Mean Center of Mass: ", {-17.928630529035239, -28.346671076356301}],
      Editable->False]], "Print",
  CellTags->"run simulation"],

Cell[BoxData[
    InterpretationBox[\("S.D. Center of Mass: \
"\[InvisibleSpace]{111.8019890898371`, 135.68778572433433`}\),
      SequenceForm[ 
      "S.D. Center of Mass: ", {111.80198908983709, 135.68778572433433}],
      Editable->False]], "Print",
  CellTags->"run simulation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export Simulation Graphics", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      EXPORT\ graphic\ based\ on\ time\ series\ from\ simulation\ *) \)\(\
\[IndentingNewLine]\)\( (*\ 
      Set\ global\ option\ for\ Mathemtica\ NOT\ to\ substitute\ its\ \
operator\ fonts\ for\ standard\ characters\ present\ on\ the\ keyboard\ \
\(\((via\ John\ Fultz, \ 
            10 - 07 - 
              05)\)\(.\)\)\ \
*) \)\(\[IndentingNewLine]\)\(SetOptions[$FrontEnd, 
      PrivateFontOptions \[Rule] {"\<OperatorSubstitution\>" \[Rule] 
            False}]\[IndentingNewLine]\[IndentingNewLine]
    \(Show[g1];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      export\ EPS\ of\ graphic\ with\ embedded\ fonts\ *) \[IndentingNewLine]
    \(fileExport = "\<test-EPS-Export-embedded.eps\>";\)\[IndentingNewLine]
    \(Print["\<Exported file: \>", \[IndentingNewLine]Export[
          ToFileName[{dirmyMathematica, "\<ExportedExpressions\>"}, 
            fileExport], g1, 
          ConversionOptions \[Rule] {"\<IncludeSpecialFonts\>" \[Rule] 
                True}]];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      export\ PDF\ *) \[IndentingNewLine]
    \(fileExport = "\<test-EPS-Export-embedded.pdf\>";\)\[IndentingNewLine]
    \(Print["\<Exported file: \>", 
        Export[ToFileName[{dirmyMathematica, "\<ExportedExpressions\>"}, 
            fileExport], g1, "\<PDF\>"]];\)\)\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(Show::"gtype"\), \(\(:\)\(\ \)\), "\<\"\\!\\(Symbol\\) is not a \
type of graphics. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\
\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Show::gtype\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    InterpretationBox[\("Exported file: "\[InvisibleSpace]"C:\\Documents and \
Settings\\macal.DIS\\My \
Documents\\_myMathematica\\ExportedExpressions\\test-EPS-Export-embedded.eps"\
\),
      SequenceForm[ 
      "Exported file: ", 
        "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\ExportedExpressions\\test-EPS-Export-embedded.eps"]\
,
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{\(Export::"type"\), \(\(:\)\(\ \)\), "\<\"\\!\\(g1\\) cannot be \
exported to the \\!\\(\\\"PDF\\\"\\) format. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Export::type\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    InterpretationBox[\("Exported file: "\[InvisibleSpace]$Failed\),
      SequenceForm[ "Exported file: ", $Failed],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Time Series Analysis of Simulation Results", "Section"],

Cell[CellGroupData[{

Cell["Open and init TS notebook", "Subsubsection"],

Cell[BoxData[{
    \(\(fileAuto = "\<autoCorrelation-11-30-02-AM.nb\>";\)\), "\n", 
    \(\(OpenInitial[
        ToFileName[{dirmyMathematica, "\<SupplyChain\>", "\<ProjectO\>"}, 
          fileAuto]];\)\), "\n", 
    \(\(SetSelectedNotebook[EvaluationNotebook[]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyze TS", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      StyleBox["analyzeTimeSeries",
        FontColor->RGBColor[0, 0, 1]], 
      "[", \(tsCMPrey\[LeftDoubleBracket]1\[RightDoubleBracket], 
      displayPlots \[Rule] True\), "]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["analyzeTimeSeries",
        FontColor->RGBColor[0, 0, 1]], 
      "[", \(tsCMPrey\[LeftDoubleBracket]2\[RightDoubleBracket], 
      displayPlots \[Rule] True\), "]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["analyzeTimeSeries",
        FontColor->RGBColor[0, 0, 1]], 
      "[", \(MapThread[Sqrt[#1\^2 + #2\^2] &, tsCMPrey], 
      displayPlots \[Rule] True\), "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.249242 0.000896761 [
[.17532 .23674 -6 -9 ]
[.17532 .23674 6 0 ]
[.32993 .23674 -9 -9 ]
[.32993 .23674 9 0 ]
[.48454 .23674 -9 -9 ]
[.48454 .23674 9 0 ]
[.63915 .23674 -9 -9 ]
[.63915 .23674 9 0 ]
[.79375 .23674 -9 -9 ]
[.79375 .23674 9 0 ]
[.94836 .23674 -9 -9 ]
[.94836 .23674 9 0 ]
[.00822 .06989 -24 -4.5 ]
[.00822 .06989 0 4.5 ]
[.00822 .15957 -24 -4.5 ]
[.00822 .15957 0 4.5 ]
[.00822 .33892 -18 -4.5 ]
[.00822 .33892 0 4.5 ]
[.00822 .42859 -18 -4.5 ]
[.00822 .42859 0 4.5 ]
[.00822 .51827 -18 -4.5 ]
[.00822 .51827 0 4.5 ]
[.00822 .60795 -18 -4.5 ]
[.00822 .60795 0 4.5 ]
[.5 .63053 -159.688 0 ]
[.5 .63053 159.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .24924 m
.17532 .25549 L
s
[(50)] .17532 .23674 0 1 Mshowa
.32993 .24924 m
.32993 .25549 L
s
[(100)] .32993 .23674 0 1 Mshowa
.48454 .24924 m
.48454 .25549 L
s
[(150)] .48454 .23674 0 1 Mshowa
.63915 .24924 m
.63915 .25549 L
s
[(200)] .63915 .23674 0 1 Mshowa
.79375 .24924 m
.79375 .25549 L
s
[(250)] .79375 .23674 0 1 Mshowa
.94836 .24924 m
.94836 .25549 L
s
[(300)] .94836 .23674 0 1 Mshowa
.125 Mabswid
.05164 .24924 m
.05164 .25299 L
s
.08256 .24924 m
.08256 .25299 L
s
.11348 .24924 m
.11348 .25299 L
s
.1444 .24924 m
.1444 .25299 L
s
.20625 .24924 m
.20625 .25299 L
s
.23717 .24924 m
.23717 .25299 L
s
.26809 .24924 m
.26809 .25299 L
s
.29901 .24924 m
.29901 .25299 L
s
.36085 .24924 m
.36085 .25299 L
s
.39177 .24924 m
.39177 .25299 L
s
.4227 .24924 m
.4227 .25299 L
s
.45362 .24924 m
.45362 .25299 L
s
.51546 .24924 m
.51546 .25299 L
s
.54638 .24924 m
.54638 .25299 L
s
.5773 .24924 m
.5773 .25299 L
s
.60823 .24924 m
.60823 .25299 L
s
.67007 .24924 m
.67007 .25299 L
s
.70099 .24924 m
.70099 .25299 L
s
.73191 .24924 m
.73191 .25299 L
s
.76283 .24924 m
.76283 .25299 L
s
.82468 .24924 m
.82468 .25299 L
s
.8556 .24924 m
.8556 .25299 L
s
.88652 .24924 m
.88652 .25299 L
s
.91744 .24924 m
.91744 .25299 L
s
.97928 .24924 m
.97928 .25299 L
s
.25 Mabswid
0 .24924 m
1 .24924 L
s
.02072 .06989 m
.02697 .06989 L
s
[(-200)] .00822 .06989 1 0 Mshowa
.02072 .15957 m
.02697 .15957 L
s
[(-100)] .00822 .15957 1 0 Mshowa
.02072 .33892 m
.02697 .33892 L
s
[(100)] .00822 .33892 1 0 Mshowa
.02072 .42859 m
.02697 .42859 L
s
[(200)] .00822 .42859 1 0 Mshowa
.02072 .51827 m
.02697 .51827 L
s
[(300)] .00822 .51827 1 0 Mshowa
.02072 .60795 m
.02697 .60795 L
s
[(400)] .00822 .60795 1 0 Mshowa
.125 Mabswid
.02072 .08782 m
.02447 .08782 L
s
.02072 .10576 m
.02447 .10576 L
s
.02072 .1237 m
.02447 .1237 L
s
.02072 .14163 m
.02447 .14163 L
s
.02072 .1775 m
.02447 .1775 L
s
.02072 .19544 m
.02447 .19544 L
s
.02072 .21337 m
.02447 .21337 L
s
.02072 .23131 m
.02447 .23131 L
s
.02072 .26718 m
.02447 .26718 L
s
.02072 .28511 m
.02447 .28511 L
s
.02072 .30305 m
.02447 .30305 L
s
.02072 .32098 m
.02447 .32098 L
s
.02072 .35685 m
.02447 .35685 L
s
.02072 .37479 m
.02447 .37479 L
s
.02072 .39272 m
.02447 .39272 L
s
.02072 .41066 m
.02447 .41066 L
s
.02072 .44653 m
.02447 .44653 L
s
.02072 .46446 m
.02447 .46446 L
s
.02072 .4824 m
.02447 .4824 L
s
.02072 .50033 m
.02447 .50033 L
s
.02072 .53621 m
.02447 .53621 L
s
.02072 .55414 m
.02447 .55414 L
s
.02072 .57208 m
.02447 .57208 L
s
.02072 .59001 m
.02447 .59001 L
s
.02072 .05195 m
.02447 .05195 L
s
.02072 .03402 m
.02447 .03402 L
s
.02072 .01608 m
.02447 .01608 L
s
.25 Mabswid
.02072 0 m
.02072 .61803 L
s
gsave
.5 .63053 -220.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Time) show
111.000 14.000 moveto
(Series) show
147.000 14.000 moveto
0.000 0.000 rmoveto
147.000 14.000 moveto
(,) show
156.563 14.000 moveto
(12) show
168.563 14.000 moveto
(,) show
178.125 14.000 moveto
(RGBColor) show
226.125 14.000 moveto
([) show
232.125 14.000 moveto
(0) show
238.125 14.000 moveto
(,) show
247.688 14.000 moveto
(0) show
253.688 14.000 moveto
(,) show
263.250 14.000 moveto
(0) show
269.250 14.000 moveto
(]) show
275.250 14.000 moveto
(,) show
284.813 14.000 moveto
0.000 0.000 rmoveto
284.813 14.000 moveto
(Helvetica) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(,) show
348.375 14.000 moveto
0.000 0.000 rmoveto
348.375 14.000 moveto
(Bold) show
372.375 14.000 moveto
0.000 0.000 rmoveto
372.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .60332 m
.0269 .25151 L
.02999 .25456 L
.03309 .25741 L
.03618 .26106 L
.03927 .26532 L
.04236 .27009 L
.04545 .2745 L
.04855 .27921 L
.05164 .28333 L
.05473 .2874 L
.05782 .29114 L
.06092 .29439 L
.06401 .2966 L
.0671 .29812 L
.07019 .29834 L
.07328 .29874 L
.07638 .2983 L
.07947 .29749 L
.08256 .29569 L
.08565 .29411 L
.08874 .29119 L
.09184 .28871 L
.09493 .28591 L
.09802 .28271 L
.10111 .27931 L
.10421 .27709 L
.1073 .2756 L
.11039 .27465 L
.11348 .27365 L
.11657 .27265 L
.11967 .27134 L
.12276 .27008 L
.12585 .26845 L
.12894 .26659 L
.13203 .26441 L
.13513 .26186 L
.13822 .25872 L
.14131 .25532 L
.1444 .25162 L
.1475 .24773 L
.15059 .24342 L
.15368 .23865 L
.15677 .23313 L
.15986 .22721 L
.16296 .22099 L
.16605 .21448 L
.16914 .20764 L
.17223 .20041 L
.17532 .1925 L
Mistroke
.17842 .18445 L
.18151 .1764 L
.1846 .16844 L
.18769 .16048 L
.19079 .15253 L
.19388 .14468 L
.19697 .13684 L
.20006 .12883 L
.20315 .12117 L
.20625 .1135 L
.20934 .10582 L
.21243 .09731 L
.21552 .08843 L
.21861 .07897 L
.22171 .06989 L
.2248 .06156 L
.22789 .05521 L
.23098 .05004 L
.23408 .04583 L
.23717 .04154 L
.24026 .03817 L
.24335 .03488 L
.24644 .03205 L
.24954 .02965 L
.25263 .02732 L
.25572 .02478 L
.25881 .02234 L
.2619 .01939 L
.265 .01742 L
.26809 .01593 L
.27118 .01496 L
.27427 .01472 L
.27737 .01498 L
.28046 .01529 L
.28355 .01662 L
.28664 .01779 L
.28973 .01867 L
.29283 .01911 L
.29592 .01967 L
.29901 .02002 L
.3021 .01999 L
.30519 .01929 L
.30829 .01883 L
.31138 .01848 L
.31447 .01844 L
.31756 .02031 L
.32066 .02486 L
.32375 .03057 L
.32684 .03717 L
.32993 .04491 L
Mistroke
.33302 .05357 L
.33612 .06281 L
.33921 .07223 L
.3423 .08147 L
.34539 .09027 L
.34848 .09863 L
.35158 .10662 L
.35467 .11435 L
.35776 .12191 L
.36085 .12947 L
.36395 .13707 L
.36704 .14474 L
.37013 .15264 L
.37322 .16061 L
.37631 .16859 L
.37941 .17656 L
.3825 .1845 L
.38559 .19233 L
.38868 .20006 L
.39177 .20766 L
.39487 .21523 L
.39796 .22278 L
.40105 .2303 L
.40414 .23769 L
.40724 .24483 L
.41033 .25143 L
.41342 .25755 L
.41651 .26325 L
.4196 .26879 L
.4227 .27429 L
.42579 .28008 L
.42888 .28618 L
.43197 .29222 L
.43506 .29824 L
.43816 .30394 L
.44125 .30931 L
.44434 .31454 L
.44743 .31933 L
.45053 .32397 L
.45362 .3286 L
.45671 .3333 L
.4598 .33844 L
.46289 .34347 L
.46599 .34887 L
.46908 .35383 L
.47217 .35896 L
.47526 .3643 L
.47835 .37009 L
.48145 .37671 L
.48454 .38477 L
Mistroke
.48763 .39416 L
.49072 .40383 L
.49382 .41161 L
.49691 .41681 L
.5 .41933 L
.50309 .41916 L
.50618 .41731 L
.50928 .41402 L
.51237 .40954 L
.51546 .40431 L
.51855 .39857 L
.52165 .39273 L
.52474 .38696 L
.52783 .38133 L
.53092 .37573 L
.53401 .37046 L
.53711 .36531 L
.5402 .3602 L
.54329 .35508 L
.54638 .35002 L
.54947 .34514 L
.55257 .3404 L
.55566 .3358 L
.55875 .33133 L
.56184 .32699 L
.56494 .32303 L
.56803 .31921 L
.57112 .31548 L
.57421 .3117 L
.5773 .30827 L
.5804 .30456 L
.58349 .30095 L
.58658 .2975 L
.58967 .29423 L
.59276 .29183 L
.59586 .29001 L
.59895 .28921 L
.60204 .28808 L
.60513 .2879 L
.60823 .28722 L
.61132 .28578 L
.61441 .28295 L
.6175 .27845 L
.62059 .27232 L
.62369 .26523 L
.62678 .25749 L
.62987 .24892 L
.63296 .23999 L
.63605 .23071 L
.63915 .22132 L
Mistroke
.64224 .21183 L
.64533 .20256 L
.64842 .19323 L
.65152 .18392 L
.65461 .17452 L
.6577 .16508 L
.66079 .15577 L
.66388 .14657 L
.66698 .13758 L
.67007 .12879 L
.67316 .12087 L
.67625 .11483 L
.67934 .11143 L
.68244 .10951 L
.68553 .10969 L
.68862 .11087 L
.69171 .1125 L
.69481 .11402 L
.6979 .11522 L
.70099 .11606 L
.70408 .11658 L
.70717 .11685 L
.71027 .11735 L
.71336 .11802 L
.71645 .11882 L
.71954 .11973 L
.72263 .12073 L
.72573 .12172 L
.72882 .12245 L
.73191 .12309 L
.735 .12367 L
.7381 .1241 L
.74119 .12447 L
.74428 .12477 L
.74737 .12508 L
.75046 .12495 L
.75356 .12468 L
.75665 .12435 L
.75974 .12329 L
.76283 .12213 L
.76592 .12064 L
.76902 .11899 L
.77211 .11709 L
.7752 .11483 L
.77829 .11232 L
.78139 .10964 L
.78448 .10672 L
.78757 .10377 L
.79066 .10124 L
.79375 .09982 L
Mistroke
.79685 .09918 L
.79994 .09906 L
.80303 .09999 L
.80612 .102 L
.80921 .10612 L
.81231 .11272 L
.8154 .11889 L
.81849 .12501 L
.82158 .13197 L
.82468 .13987 L
.82777 .14841 L
.83086 .15624 L
.83395 .1649 L
.83704 .17332 L
.84014 .1819 L
.84323 .18988 L
.84632 .19664 L
.84941 .20215 L
.8525 .20593 L
.8556 .20896 L
.85869 .21152 L
.86178 .21402 L
.86487 .21636 L
.86797 .21865 L
.87106 .22093 L
.87415 .22318 L
.87724 .22515 L
.88033 .22691 L
.88343 .22851 L
.88652 .23009 L
.88961 .23137 L
.8927 .23286 L
.89579 .23458 L
.89889 .23635 L
.90198 .23811 L
.90507 .23985 L
.90816 .24153 L
.91126 .243 L
.91435 .24428 L
.91744 .24548 L
.92053 .24673 L
.92362 .24798 L
.92672 .24945 L
.92981 .25102 L
.9329 .25272 L
.93599 .25405 L
.93908 .25516 L
.94218 .25648 L
.94527 .2578 L
.94836 .25917 L
Mistroke
.95145 .26077 L
.95455 .2625 L
.95764 .2646 L
.96073 .26718 L
.96382 .27091 L
.96691 .27556 L
.97001 .28137 L
.9731 .28807 L
.97619 .29593 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00=@3oool00`000000oooo0?oo
o`3o0?oooc40oooo000e0?ooo`030000003oool0oooo0?l0oooo<@3oool003D0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`00=@3oool00`000000oooo0?ooo`3o0?oooc40oooo000e0?ooo`800000
?`3oool50000ond0oooo000e0?ooo`030000003oool0oooo03`0oooo0P000?l50?ooo`T0003oi03o
ool003D0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo0>80oooo000e0?ooo`030000003oool0oooo03X0oooo0P000?l@0?ooo`030000o`3oool0oooo
0>40oooo000e0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`3P0?ooo`00=@3oool2000003P0oooo0P000?lD0?ooo`030000o`3oool0oooo0>00oooo
000e0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?oo
o`3P0?ooo`00=@3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?ooo`3oool0h03oool003D0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0F0?oo
o`030000o`3oool0oooo0=l0oooo000e0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`3O0?ooo`00=@3oool2000003@0oooo00<0003o0?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`3N0?ooo`00=@3oool00`000000oooo0?ooo`0c0?ooo`030000o`3o
ool0oooo01T0oooo00<0003o0?ooo`3oool0gP3oool001/0oooo1@0000040?ooo`@00000103oool4
000000D0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo0=d0oooo000K0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0c0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0g@3oool001`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo01/0oooo00<0
003o0?ooo`3oool0g@3oool001<0oooo1P0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0`00
000b0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0g03oool001h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo01d0oooo00<0
003o0?ooo`3oool0g03oool001l0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000
o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0f`3oool001/0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool07`3oool00`000?l0
oooo0?ooo`3K0?ooo`00703oool3000000D0oooo100000040?ooo`@000001@3oool200000340oooo
00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`3K0?ooo`00=@3oool00`000000oooo0?oo
o`0`0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0f`3oool003D0oooo00<00000
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo0=/0oooo000e0?oo
o`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`1b0?oo
o`@0003oI03oool003D0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo0740oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1Q0?ooo`00
=@3oool200000300oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`1_0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0H@3oool003D0oooo00<000000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo05<0oooo10000?lG0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0H@3oool003D0oooo00<000000?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo0540oooo00@0003o0?ooo`3oool0oooo0`00
0?lC0?ooo`80003o203oool00`000?l0oooo0?ooo`1P0?ooo`00=@3oool00`000000oooo0?ooo`0]
0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`04
0?ooo`D0003o3@3oool20000o`X0oooo00<0003o0?ooo`3oool0G`3oool003D0oooo00<000000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo0500oooo00<0003o0?oo
o`3oool02@3oool40000o`L0oooo0P000?l<0?ooo`030000o`3oool0oooo05l0oooo000e0?ooo`80
0000;@3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3o
ool03P3oool70000o`l0oooo00<0003o0?ooo`3oool0GP3oool003D0oooo00<000000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool0
903oool00`000?l0oooo0?ooo`1N0?ooo`00=@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo02P0oooo00<0003o0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3o
ool0oooo05d0oooo000e0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0G@3oool0
03D0oooo0P00000[0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0C@3oool00`00
0?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo05d0oooo000e0?ooo`030000003oool0oooo02X0
oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`1;0?ooo`030000o`3oool0oooo02L0
oooo00<0003o0?ooo`3oool0G@3oool001`0oooo1@0000030?ooo`@00000103oool4000000D0oooo
00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo04/0oooo
00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`1L0?ooo`007P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo
0?ooo`190?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0G03oool001h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02d0oooo
00<0003o0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo05/0oooo
000C0?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<00000:@3oool00`000?l0oooo
0?ooo`0^0?ooo`030000o`3oool0oooo04P0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`1K0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo02`0oooo
00<0003o0?ooo`3oool0FP3oool001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0X0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo
0?ooo`0/0?ooo`030000o`3oool0oooo05X0oooo000L0?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0X0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo
0?ooo`0]0?ooo`030000o`3oool0oooo05T0oooo000N0?ooo`030000003oool0oooo00<0oooo1000
00040?ooo`@000001@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0340oooo00<0
003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo05T0oooo000e
0?ooo`800000:03oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo04H0oooo00<0003o
0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`1I0?ooo`00=@3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0^0?oo
o`030000o`3oool0oooo05T0oooo000e0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3o
ool0<`3oool00`000?l0oooo0?ooo`140?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3o
ool0F@3oool003D0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0c0?ooo`030000
o`3oool0oooo04<0oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`1H0?ooo`00=@3o
ool00`000000oooo0?ooo`0P0?ooo`@000000P3oool00`000?l0oooo00000003000001P0oooo1@00
00030?ooo`@00000103oool4000000D0oooo00<0003o0?ooo`3oool03@3oool5000000<0oooo1000
00040?ooo`@00000503oool5000000@0oooo1000000010000?l0oooo0?ooo`3oool4000001<0oooo
1@0000040?ooo`@00000103oool4000000<0oooo00<0003o0?ooo`3oool03`3oool3000000D0oooo
100000040?ooo`@00000=@3oool003D0oooo0P00000P0?ooo`030000003oool0oooo0080oooo00@0
00000000o`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo
0?ooo`0000000`3oool01P000000oooo0?ooo`3oool0003o00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000o`0?
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0<P3oool003D0oooo00<000000?ooo`3oool0903o
ool010000000003o0?ooo`0000040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00H000000?oo
o`3oool0oooo0000o`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0380oooo000e0?ooo`030000003oool0oooo02@0
oooo00@0003o0?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`060000003o
ool0oooo0?ooo`000?l000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0P
0?ooo`@0000000@0003o0?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`@00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
0P3oool01P000000oooo0?ooo`000?l0oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<P3oool0
03D0oooo0P00000Q0?ooo`040000003oool0oooo0000o`<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000?l0oooo
000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`80003o3`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0P0?ooo`04
0000003oool0oooo0000o`<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?oo
o`<00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`<000001@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00H000000?ooo`3oool0003o0?ooo`0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0003o0?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0380oooo000e0?ooo`030000003oool0
oooo0200oooo0P0000000`000?l00000000000030?ooo`@000006P3oool00`000000oooo0?ooo`03
0?ooo`@00000103oool4000000L0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`D000000`3oool4000001D0oooo0`0000050?ooo`80000000<0003o0000003oool00`3oool4
000001@0oooo0`0000050?ooo`D000000`3oool4000000X0oooo0P000?l90?ooo`<000001@3oool4
000000@0oooo1000000e0?ooo`00=@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
03/0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0j0?ooo`80003oD@3oool003D0
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo03`0
oooo00<0003o0?ooo`3oool0?@3oool20000odl0oooo000e0?ooo`8000008P3oool00`000?l0oooo
0?ooo`0m0?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool0?`3oool20000odd0oooo
000e0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo0?oo
o`0j0?ooo`030000o`3oool0oooo0480oooo0P000?m;0?ooo`00=@3oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`14
0?ooo`80003oB@3oool003D0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`100?oo
o`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool0A@3oool30000odL0oooo000e0?ooo`03
0000003oool0oooo01h0oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000o`3oool0oooo04T0oooo0P000?m50?ooo`00;`3oool8000000030000o`000000000001/00000
00<0003o000000000000@`0000000`000?l000000000000g000000030000o`000000000004/00000
0P000?lC00000300oooo000e0?ooo`030000003oool0003o00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000?l00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0`000?l00`3oool000000?ooo`060?oo
o`030000003oool0oooo03@0oooo000e0?ooo`040000003oool0003o0000oa/0oooo00<0003o0?oo
o`3oool0A@3oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo0500oooo0`000?ln0?oo
o`00=@3oool01@000000oooo0000o`3oool0003o01T0oooo00<0003o0?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo05<0oooo0P000?ll0?ooo`00=@3oool200000004
0000o`3oool0oooo0000oaH0oooo0P000?m:0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?oo
o`3oool0E03oool20000oc/0oooo000e0?ooo`030000003oool0003o00<0oooo00<0003o0?ooo`3o
ool04P3oool20000od`0oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`1G0?ooo`03
0000o`3oool0oooo03P0oooo000e0?ooo`030000003oool0003o00<0oooo00<0003o0?ooo`3oool0
3P3oool40000odl0oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`1G0?ooo`030000
o`3oool0oooo03P0oooo000e0?ooo`030000003oool0003o00<0oooo00<0003o0?ooo`3oool03@3o
ool20000oe80oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3o
ool0oooo03L0oooo000e0?ooo`030000003oool0003o00@0oooo00<0003o0?ooo`3oool02P3oool2
0000oe@0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1K0?ooo`030000o`3oool0
oooo03H0oooo000e0?ooo`80000000<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool0;@3oool20000oed0oooo00<0003o0?oo
o`3oool0=P3oool003D0oooo00<000000?ooo`000?l01P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool0:@3oool40000oel0oooo00<0003o0?ooo`3o
ool0=P3oool003D0oooo00<000000?ooo`000?l01`3oool00`000?l0oooo0?ooo`040?ooo`80003o
F@3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo0640oooo00<0003o0?ooo`3oool0
=P3oool003D0oooo00<000000?ooo`000?l01`3oool20000o`<0oooo0P000?mK0?ooo`030000o`3o
ool0oooo02H0oooo0P000?mT0?ooo`030000o`3oool0oooo03D0oooo000e0?ooo`030000003oool0
003o00T0oooo10000?mM0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0W03oool0
03D0oooo0P0000000`000?l0oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0280oooo00<0003o0?oo
o`3oool0W@3oool003D0oooo00<000000?ooo`000?l0K03oool00`000?l0oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo09h0oooo000e0?ooo`030000003oool0003o06`0oooo00<0003o0?ooo`3oool0
803oool00`000?l0oooo0?ooo`2N0?ooo`00=@3oool00`000000oooo0000o`1/0?ooo`030000o`3o
ool0oooo01l0oooo00<0003o0?ooo`3oool0W`3oool003D0oooo00<000000?ooo`000?l0K@3oool0
0`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo0:00oooo000e0?ooo`80000000<0003o0?oo
o`3oool0K03oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo0:40oooo000L0?ooo`D0
00000`3oool4000000@0oooo100000050?ooo`030000003oool0003o06h0oooo00<0003o0?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`2R0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0003o06l0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`2S0?ooo`00
7P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0003o0700oooo00<0003o0?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`2S0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80
000000<0003o0?ooo`3oool0KP3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo0:@0
oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000?l0L@3oool00`000?l0
oooo0?ooo`0E0?ooo`030000o`3oool0oooo0:@0oooo000N0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000?l0L@3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0:D0
oooo000L0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000o`1b0?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool0YP3oool001h0oooo00<000000?ooo`3oool00`3oool4000000@0oooo
100000050?ooo`030000003oool0003o07<0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`2W0?ooo`00=@3oool2000000030000o`3oool0oooo0740oooo00<0003o0?ooo`3oool0403o
ool00`000?l0oooo0?ooo`2W0?ooo`00=@3oool00`000000oooo0000o`1d0?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool0Y`3oool003D0oooo00<000000?ooo`000?l0M03oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0:P0oooo000e0?ooo`030000003oool0003o07D0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`2Y0?ooo`00=@3oool00`000000oooo
0000o`1e0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0Z@3oool003D0oooo0P00
00000`000?l0oooo0?ooo`1d0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0ZP3o
ool003D0oooo00<000000?ooo`000?l0MP3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo0:/0oooo000e0?ooo`030000003oool0003o07L0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`2[0?ooo`00=@3oool00`000000oooo0000o`1g0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool0Z`3oool003D0oooo0P0000000`000?l0oooo0?ooo`1f0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0[03oool003D0oooo00<000000?ooo`000?l0N03o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0:d0oooo000e0?ooo`030000003oool0
003o07P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`2]0?ooo`00=@3oool00`00
0000oooo0000o`1i0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0[P3oool003D0
oooo00<000000?ooo`000?l0N@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0:l0
oooo000e0?ooo`80000000<0003o0?ooo`3oool0M`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0:l0oooo000e0?ooo`030000003oool0003o07T0oooo00D0003o0?ooo`3oool0oooo
0000o`2b0?ooo`006`3oool5000000@0oooo100000040?ooo`@000001@3oool00`000000oooo0000
o`1j0?ooo`@0003o/P3oool001/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0003o0?l0oooo<@3oool001`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0000o`3o0?oooc40oooo000M0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000000o`000000
o`3ooola0?ooo`007P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03000000000?l0oooo0?l0oooo
<@3oool001l0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000000003o0?ooo`3o0?oooc40oooo000K0?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool00`000000003o0?ooo`3o0?oooc40oooo000L0?ooo`<0
00001@3oool4000000@0oooo100000050?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo
00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e
0?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?oo
o`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo
<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o
0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3o
ool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e0?ooo`0300000000
0?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`00
0000003o0?ooo`3o0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo<@3oool001`0oooo
0`0000050?ooo`@00000103oool4000000D0oooo00<000000000o`3oool0o`3ooola0?ooo`006`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000000o`3oool0o`3ooola0?ooo`00
7`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`03000000000?l0oooo0?l0oooo<@3oool001l0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000003o0000003o0?oooc40oooo000M0?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o0?ooo`3o
0?oooc40oooo000O0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00<000000000o`3oool0o`3ooola0?ooo`006`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00<000000000o`3oool0o`3ooola0?ooo`00703o
ool3000000D0oooo100000040?ooo`@000001@3oool00`000000003o0?ooo`3o0?oooc40oooo000e
0?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?oo
o`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo
<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o
0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3o
ool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e0?ooo`0300000000
0?l0oooo0?l0oooo<@3oool003D0oooo00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`00
0000003o0?ooo`3o0?oooc40oooo000e0?ooo`03000000000?l0oooo0?l0oooo<@3oool003D0oooo
00<000000000o`3oool0o`3ooola0?ooo`00=@3oool00`000000003o0?ooo`3o0?oooc40oooo000e
0?ooo`03000000000?l0oooo0?l0oooo<@3oool001h0oooo0`0000030?ooo`@00000103oool40000
00D0oooo00<000000000o`3oool0o`3ooola0?ooo`007`3oool01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03000000000?l0
oooo0?l0oooo<@3oool001l0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o0?ooo`3o0?oooc40oooo000K
0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool300000?l0oooo<@3oool001`0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?oooc40oooo000L0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0o`3ooola0?ooo`007@3oool00`000000oooo000000030?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo<@3oool001h0oooo0P0000040?ooo`@00000103oool400000?l0oooo
>@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0oooo
J@3oool000<00000EP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04H0oooo0`00
000;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool3000000D0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0L0?ooo`0000<000000?ooo`3oool0EP3oool2
000001T0oooo0P0000170?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`8000004`3oool0
0`000000oooo0?ooo`030?ooo`800000CP3oool2000001d0oooo00000`000000oooo0?ooo`040?oo
o`<00000103oool5000000050?ooo`00000000000000003oool00P000000103oool000000?ooo`3o
ool5000000P0oooo00<000000?ooo`0000000P0000040?ooo`D000000P3oool5000000@0oooo1@00
00030?ooo`D000000P3oool500000080oooo00<000000?ooo`3oool0203oool500000080oooo1@00
00040?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`040000003oool0oooo0?ooo`<00000
0`3oool5000000D0oooo0`0000040?ooo`@00000103oool5000000<0oooo100000030?ooo`D00000
00<0oooo0000003oool0103oool4000000D0oooo00<000000?ooo`3oool0203oool4000000@0oooo
00<000000?ooo`3oool0203oool4000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`<0000000@0oooo00000000000000000P3oool5000000<0oooo1@0000040?ooo`80
00001@3oool5000000@0oooo0`0000040?ooo`D000000`3oool4000000@0oooo0`0000000`3oool0
0000000000090?ooo`D00000103oool4000000@0oooo0`00000000030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`0000003@3oool2000000<0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool00000000000/0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool2000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000030?ooo`@000002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool000000180oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000D000003@3oool00`000000oooo0?ooo`060000
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`H000000`3oool40000
00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`@000000`3oool01000
0000oooo0?ooo`3oool300000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000P3oool6000000D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?oo
o`H000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool5000000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0000001`3oool000000000003oool0
00000?ooo`000000103oool00`000000oooo0?ooo`070?ooo`@000000`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01P3oool4000000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00l0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool3000000<0oooo
0P0000001@3oool000000?ooo`3oool0000000<0oooo100000090?ooo`030000003oool0oooo00H0
oooo100000030?ooo`80000000@0oooo00000000000000000`3oool3000000D0oooo100000040?oo
o`D000003P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00H0oooo100000060?ooo`030000003oool0oooo00<0oooo1000
00030?ooo`80000000<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`@000001P3oool010000000oooo0?ooo`3oool300000080
oooo0`0000020?ooo`@000000`3oool5000000@0oooo0`0000050?ooo`<0000000<0oooo0000003o
ool00P3oool4000000`0oooo00D000000?ooo`3oool0oooo000000030?ooo`@000001P3oool10000
000000<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01d0oooo00@000000?ooo`3oool0oooo0P00000d0?ooo`<00000103oool01@000000oooo0?ooo`3o
ool0000000l0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000=
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02D0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`400000000300000080oooo1`00
00040?ooo`030000003oool0oooo01T0oooo0`0000000`3oool000000?ooo`0D0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool00`3oool3000000l0oooo1@0000050?ooo`@000000P3o
ool5000000D0oooo1000000<0?ooo`8000004P3oool3000000<0oooo1000000@0?ooo`@000003`3o
ool4000000<0oooo0`00000@0?ooo`<0000000@0oooo00000000000000002`3oool2000001l0oooo
00<000000?ooo`3oool06P3oool5000000d0oooo0P0000000?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-65.6372, -358.424, 1.53647, \
5.29795}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00308214 0.309017 0.309017 [
[.17792 .29652 -6 -9 ]
[.17792 .29652 6 0 ]
[.33202 .29652 -9 -9 ]
[.33202 .29652 9 0 ]
[.48613 .29652 -9 -9 ]
[.48613 .29652 9 0 ]
[.64024 .29652 -9 -9 ]
[.64024 .29652 9 0 ]
[.79434 .29652 -9 -9 ]
[.79434 .29652 9 0 ]
[.94845 .29652 -9 -9 ]
[.94845 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -174.688 0 ]
[.5 .63053 174.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17792 .30902 m
.17792 .31527 L
s
[(50)] .17792 .29652 0 1 Mshowa
.33202 .30902 m
.33202 .31527 L
s
[(100)] .33202 .29652 0 1 Mshowa
.48613 .30902 m
.48613 .31527 L
s
[(150)] .48613 .29652 0 1 Mshowa
.64024 .30902 m
.64024 .31527 L
s
[(200)] .64024 .29652 0 1 Mshowa
.79434 .30902 m
.79434 .31527 L
s
[(250)] .79434 .29652 0 1 Mshowa
.94845 .30902 m
.94845 .31527 L
s
[(300)] .94845 .29652 0 1 Mshowa
.125 Mabswid
.05463 .30902 m
.05463 .31277 L
s
.08545 .30902 m
.08545 .31277 L
s
.11627 .30902 m
.11627 .31277 L
s
.1471 .30902 m
.1471 .31277 L
s
.20874 .30902 m
.20874 .31277 L
s
.23956 .30902 m
.23956 .31277 L
s
.27038 .30902 m
.27038 .31277 L
s
.3012 .30902 m
.3012 .31277 L
s
.36284 .30902 m
.36284 .31277 L
s
.39367 .30902 m
.39367 .31277 L
s
.42449 .30902 m
.42449 .31277 L
s
.45531 .30902 m
.45531 .31277 L
s
.51695 .30902 m
.51695 .31277 L
s
.54777 .30902 m
.54777 .31277 L
s
.57859 .30902 m
.57859 .31277 L
s
.60942 .30902 m
.60942 .31277 L
s
.67106 .30902 m
.67106 .31277 L
s
.70188 .30902 m
.70188 .31277 L
s
.7327 .30902 m
.7327 .31277 L
s
.76352 .30902 m
.76352 .31277 L
s
.82517 .30902 m
.82517 .31277 L
s
.85599 .30902 m
.85599 .31277 L
s
.88681 .30902 m
.88681 .31277 L
s
.91763 .30902 m
.91763 .31277 L
s
.97927 .30902 m
.97927 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -235.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Autocorrellagram) show
177.000 14.000 moveto
0.000 0.000 rmoveto
177.000 14.000 moveto
(,) show
186.563 14.000 moveto
(12) show
198.563 14.000 moveto
(,) show
208.125 14.000 moveto
(RGBColor) show
256.125 14.000 moveto
([) show
262.125 14.000 moveto
(0) show
268.125 14.000 moveto
(,) show
277.688 14.000 moveto
(0) show
283.688 14.000 moveto
(,) show
293.250 14.000 moveto
(0) show
299.250 14.000 moveto
(]) show
305.250 14.000 moveto
(,) show
314.813 14.000 moveto
0.000 0.000 rmoveto
314.813 14.000 moveto
(Helvetica) show
368.813 14.000 moveto
0.000 0.000 rmoveto
368.813 14.000 moveto
(,) show
378.375 14.000 moveto
0.000 0.000 rmoveto
378.375 14.000 moveto
(Bold) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02689 .60522 m
.02997 .60392 L
.03306 .602 L
.03614 .59951 L
.03922 .59645 L
.0423 .59284 L
.04538 .58869 L
.04847 .58403 L
.05155 .57887 L
.05463 .57326 L
.05771 .5672 L
.0608 .56073 L
.06388 .55385 L
.06696 .54659 L
.07004 .53896 L
.07312 .53104 L
.07621 .52282 L
.07929 .51432 L
.08237 .50555 L
.08545 .49656 L
.08853 .48731 L
.09162 .47789 L
.0947 .46827 L
.09778 .45847 L
.10086 .4485 L
.10395 .43841 L
.10703 .4282 L
.11011 .41786 L
.11319 .40738 L
.11627 .39676 L
.11936 .38602 L
.12244 .37518 L
.12552 .36422 L
.1286 .35318 L
.13168 .34206 L
.13477 .33087 L
.13785 .31963 L
.14093 .30835 L
.14401 .29705 L
.1471 .28575 L
.15018 .27447 L
.15326 .26324 L
.15634 .25208 L
.15942 .24105 L
.16251 .23018 L
.16559 .21951 L
.16867 .20906 L
.17175 .19887 L
.17483 .18894 L
.17792 .17935 L
Mistroke
.181 .1701 L
.18408 .16124 L
.18716 .15278 L
.19025 .14476 L
.19333 .1372 L
.19641 .13011 L
.19949 .1235 L
.20257 .11737 L
.20566 .11173 L
.20874 .10657 L
.21182 .10185 L
.2149 .09759 L
.21798 .09375 L
.22107 .09036 L
.22415 .08742 L
.22723 .08495 L
.23031 .0829 L
.23339 .08127 L
.23648 .07999 L
.23956 .07911 L
.24264 .07859 L
.24572 .07842 L
.24881 .07861 L
.25189 .07914 L
.25497 .08 L
.25805 .08119 L
.26113 .0827 L
.26422 .08457 L
.2673 .08677 L
.27038 .0893 L
.27346 .09218 L
.27654 .09538 L
.27963 .09889 L
.28271 .10273 L
.28579 .10687 L
.28887 .1113 L
.29196 .116 L
.29504 .121 L
.29812 .12627 L
.3012 .1318 L
.30428 .13759 L
.30737 .14367 L
.31045 .15001 L
.31353 .15664 L
.31661 .16357 L
.31969 .17083 L
.32278 .17834 L
.32586 .18604 L
.32894 .19393 L
.33202 .20196 L
Mistroke
.33511 .21008 L
.33819 .21827 L
.34127 .22649 L
.34435 .2347 L
.34743 .24289 L
.35052 .25104 L
.3536 .25913 L
.35668 .26715 L
.35976 .27507 L
.36284 .28288 L
.36593 .29056 L
.36901 .29809 L
.37209 .30546 L
.37517 .31265 L
.37826 .31964 L
.38134 .32644 L
.38442 .33304 L
.3875 .33945 L
.39058 .34568 L
.39367 .35174 L
.39675 .35763 L
.39983 .36336 L
.40291 .36893 L
.40599 .37433 L
.40908 .37955 L
.41216 .38459 L
.41524 .38944 L
.41832 .3941 L
.42141 .39857 L
.42449 .40286 L
.42757 .40695 L
.43065 .41083 L
.43373 .41449 L
.43682 .41791 L
.4399 .42109 L
.44298 .42402 L
.44606 .4267 L
.44914 .42911 L
.45223 .43127 L
.45531 .43316 L
.45839 .43479 L
.46147 .43615 L
.46456 .43723 L
.46764 .43802 L
.47072 .43854 L
.4738 .43877 L
.47688 .43874 L
.47997 .43844 L
.48305 .43791 L
.48613 .43713 L
Mistroke
.48921 .43608 L
.49229 .43469 L
.49538 .43297 L
.49846 .43092 L
.50154 .42857 L
.50462 .42599 L
.50771 .42321 L
.51079 .42027 L
.51387 .41721 L
.51695 .41406 L
.52003 .41082 L
.52312 .40751 L
.5262 .40413 L
.52928 .40067 L
.53236 .39717 L
.53544 .39361 L
.53853 .39002 L
.54161 .38639 L
.54469 .38272 L
.54777 .37904 L
.55086 .37533 L
.55394 .37161 L
.55702 .36787 L
.5601 .36411 L
.56318 .36036 L
.56627 .35659 L
.56935 .35283 L
.57243 .34905 L
.57551 .34528 L
.57859 .34149 L
.58168 .3377 L
.58476 .33392 L
.58784 .33015 L
.59092 .32642 L
.59401 .32272 L
.59709 .31908 L
.60017 .31546 L
.60325 .31192 L
.60633 .30841 L
.60942 .30495 L
.6125 .30152 L
.61558 .29814 L
.61866 .29481 L
.62174 .29158 L
.62483 .28846 L
.62791 .28545 L
.63099 .28259 L
.63407 .27987 L
.63716 .27731 L
.64024 .2749 L
Mistroke
.64332 .27267 L
.6464 .2706 L
.64948 .26869 L
.65257 .26695 L
.65565 .26537 L
.65873 .26397 L
.66181 .26275 L
.66489 .2617 L
.66798 .26084 L
.67106 .26017 L
.67414 .25971 L
.67722 .25949 L
.68031 .25944 L
.68339 .25958 L
.68647 .25984 L
.68955 .26018 L
.69263 .26058 L
.69572 .26104 L
.6988 .26154 L
.70188 .26209 L
.70496 .2627 L
.70804 .26338 L
.71113 .26412 L
.71421 .26492 L
.71729 .26578 L
.72037 .26671 L
.72346 .26769 L
.72654 .26872 L
.72962 .26979 L
.7327 .27091 L
.73578 .27207 L
.73887 .27327 L
.74195 .27451 L
.74503 .27579 L
.74811 .27709 L
.75119 .27844 L
.75428 .27984 L
.75736 .28126 L
.76044 .28271 L
.76352 .28421 L
.76661 .28573 L
.76969 .28728 L
.77277 .28885 L
.77585 .29043 L
.77893 .29199 L
.78202 .29354 L
.7851 .29505 L
.78818 .29655 L
.79126 .29805 L
.79434 .29953 L
Mistroke
.79743 .30099 L
.80051 .30243 L
.80359 .30385 L
.80667 .30527 L
.80975 .3067 L
.81284 .30802 L
.81592 .30927 L
.819 .31046 L
.82208 .31159 L
.82517 .31265 L
.82825 .31361 L
.83133 .3145 L
.83441 .31532 L
.83749 .31606 L
.84058 .3167 L
.84366 .31725 L
.84674 .31769 L
.84982 .31802 L
.8529 .3183 L
.85599 .31851 L
.85907 .3187 L
.86215 .31884 L
.86523 .31895 L
.86832 .31903 L
.8714 .31909 L
.87448 .31911 L
.87756 .31911 L
.88064 .31908 L
.88373 .31904 L
.88681 .31898 L
.88989 .31891 L
.89297 .31884 L
.89605 .31875 L
.89914 .31864 L
.90222 .3185 L
.9053 .31832 L
.90838 .31811 L
.91147 .31787 L
.91455 .3176 L
.91763 .3173 L
.92071 .31699 L
.92379 .31666 L
.92688 .31631 L
.92996 .31596 L
.93304 .31558 L
.93612 .31518 L
.9392 .3148 L
.94229 .31441 L
.94537 .31404 L
.94845 .3137 L
Mistroke
.95153 .31336 L
.95462 .31306 L
.9577 .31279 L
.96078 .31257 L
.96386 .3124 L
.96694 .31226 L
.97003 .31215 L
.97311 .31208 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`004`3oool500000?l0ooooD@3oool001D0oooo00<0
00000?ooo`3oool0o`3ooomA0?ooo`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo000:0?oo
o`H000001@3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooom90?ooo`005@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB@3oool001D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000C0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooodT0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`007@3oool200000?l0ooooBP3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo
000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?oo
o`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool000@0
oooo0P0000070?ooo`030000003oool0oooo00<0oooo100000060?ooo`030000003oool0oooo0?l0
ooooB@3oool000@0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB@3oool000d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB@3o
ool000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`<00000@P3oool3
0?l00?l0oooo103oool000h0oooo00<000000?ooo`3oool00P3oool4000000H0oooo00<000000?oo
o`3oool0?`3oool30?l000<0oooo0`3o003o0?ooo`40oooo000?0?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`0m0?ooo`80o`002@3oool20?l00?h0oooo000:0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
03`0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3k0?ooo`002P3oool6000000<0
oooo1@0000050?ooo`030000003oool0oooo03/0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`3j0?ooo`007@3oool2000003/0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo
0?ooo`3i0?ooo`007@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo0140oooo00<0
o`000?ooo`3oool0n03oool001d0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0C
0?ooo`030?l0003oool0oooo0?L0oooo000M0?ooo`030000003oool0oooo03P0oooo00<0o`000?oo
o`3oool0503oool00`3o0000oooo0?ooo`3f0?ooo`007@3oool00`000000oooo0?ooo`0g0?ooo`03
0?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0m@3oool001d0oooo0P00000g0?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool0m@3oool001d0oooo00<000000?ooo`3oool0=P3o
ool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0?@0oooo000M0?ooo`030000003oool0
oooo03D0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3c0?ooo`007@3oool00`00
0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0l`3oool001d0
oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0?80
oooo000M0?ooo`800000=P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0?40oooo
000M0?ooo`030000003oool0oooo03@0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`3a0?ooo`007@3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo01d0oooo00<0o`00
0?ooo`3oool0l@3oool001d0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0oooo0?40oooo000M0?ooo`800000=03oool00`3o0000oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo0?00oooo000M0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool0
803oool00`3o0000oooo0?ooo`3`0?ooo`000`3oool4000000D0oooo0P0000050?ooo`@000001P3o
ool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0k`3o
ool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0>l0oooo00020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0340oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3^0?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool300000340
oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`3^0?ooo`000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo100000060?ooo`030000003oool0oooo0300oooo
00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`3]0?ooo`000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0`0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0k@3oool00080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo0>`0oooo00030?oo
o`@00000303oool5000000D0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0W0?oo
o`030?l0003oool0oooo0>`0oooo000M0?ooo`800000<03oool00`3o0000oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo0>/0oooo000M0?ooo`030000003oool0oooo02l0oooo00<0o`000?ooo`3oool0
:03oool00`3o0000oooo0?ooo`3[0?ooo`007@3oool00`000000oooo0?ooo`0^0?ooo`030?l0003o
ool0oooo02X0oooo00<0o`000?ooo`3oool0jP3oool001d0oooo00<000000?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo0>X0oooo000M0?ooo`030000003oool0oooo
02h0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`3Z0?ooo`007@3oool2000002h0
oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`3Y0?ooo`007@3oool00`000000oooo
0?ooo`0]0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0j@3oool001d0oooo00<0
00000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo0>P0oooo000M
0?ooo`030000003oool0oooo02`0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`3X
0?ooo`007@3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?oo
o`3oool0j03oool001d0oooo0P00000]0?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3o
ool0i`3oool001d0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0`0?ooo`030?l0
003oool0oooo0>L0oooo000M0?ooo`030000003oool0oooo02/0oooo00<0o`000?ooo`3oool0<@3o
ool00`3o0000oooo0?ooo`3V0?ooo`007@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0
oooo0340oooo00<0o`000?ooo`3oool0iP3oool001d0oooo00<000000?ooo`3oool0:P3oool00`3o
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo0>H0oooo000M0?ooo`800000:`3oool00`3o0000
oooo0?ooo`0c0?ooo`030?l0003oool0oooo0>D0oooo000M0?ooo`030000003oool0oooo02X0oooo
00<0o`000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`3U0?ooo`00103oool2000000@0oooo1@00
00040?ooo`@000001P3oool00`000000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo03@0oooo00<0
o`000?ooo`3oool0i03oool000@0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo0>@0oooo000;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo03D0oooo00<0o`000?ooo`3oool0i03oool000`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`<00000:@3oool00`3o0000oooo0?ooo`0f0?ooo`030?l0003oool0oooo
0><0oooo000=0?ooo`030000003oool0oooo00<0oooo100000060?ooo`030000003oool0oooo02P0
oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`3S0?ooo`003P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0g0?ooo`030?l0003oool0oooo0><0oooo000:0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool0
>03oool00`3o0000oooo0?ooo`3R0?ooo`002`3oool3000000D0oooo1@0000050?ooo`800000:@3o
ool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0>80oooo000M0?ooo`030000003oool0
oooo02L0oooo00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`3Q0?ooo`007@3oool00`00
0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo03X0oooo00<0o`000?ooo`3oool0h@3oool001d0
oooo00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0>40
oooo000M0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo
0?ooo`1R0?ooo`D0o`00N@3oool001d0oooo0P00000W0?ooo`030?l0003oool0000000<00000103o
ool400000200oooo1@0000030?ooo`@00000103oool010000000o`0000000000000M0?ooo`D00000
0`3oool4000000@0oooo1000000K0?ooo`D00000103oool4000000@0oooo00<000000?l0003o0000
0P3o00050?ooo`D0o`004@3oool5000000@0oooo100000040?ooo`@00000703oool3000000D0oooo
100000040?ooo`@000007P3oool001d0oooo00<000000?ooo`3oool09P3oool00`3o000000000?oo
o`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`3o0000
oooo0000000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o00030?ooo`030000003oool0
oooo00P0oooo103o000=0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<0o`00
0?ooo`0000007P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?l0003o00000000103oool00`000000oooo0?ooo`0<0?ooo`<0o`002`3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K
0?ooo`007@3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030?l0003oool0000001h0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20?l00080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`<0o`002@3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`007@3oool0
0`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo00@000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00<0o`000000003oool07@3oool00`000000oooo0?oo
o`030?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool00P3oool01P000000oooo0?ooo`3o0000oooo00000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0B0?ooo`<0o`001`3oool00`000000oooo0?ooo`030?ooo`@0
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?oo
o`007@3oool2000002H0oooo00@0o`000?ooo`3oool000001P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo00<0o`000000003oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`070000003oool0oooo0?ooo`000000oooo0?l000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool05@3oool20?l000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K
0?ooo`007@3oool00`000000oooo0?ooo`0T0?ooo`050?l0003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo0`0000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`3o0000oooo0?ooo`0J0?ooo`<000001@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?l0003oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01L0oooo0P3o00001@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01P0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`0T
0?ooo`040?l0003oool0oooo0?ooo`D000000`3oool400000280oooo00<000000?ooo`3oool00`3o
ool4000000@0oooo100000000`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo1@00
00030?ooo`@00000703oool3000000<0oooo0P3o0004000000@0oooo1000000L0?ooo`80o`000P00
00050?ooo`D000000`3oool4000001`0oooo0`0000050?ooo`@00000103oool4000001h0oooo000M
0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`1?
0?ooo`030?l0003oool0oooo02X0oooo0P3o001O0?ooo`007@3oool00`000000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo0480oooo00<0o`000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0]0?oo
o`80o`00G@3oool001d0oooo0P00000T0?ooo`030?l0003oool0oooo04<0oooo00<0o`000?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`0`0?ooo`80o`00F`3oool001d0oooo00<000000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo04X0oooo00<0o`000?ooo`3oool0
<`3oool30?l005P0oooo000M0?ooo`030000003oool0oooo02<0oooo00<0o`000?ooo`3oool0A03o
ool00`3o0000oooo0?ooo`190?ooo`030?l0003oool0oooo03L0oooo0P3o001F0?ooo`007@3oool0
0`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo04H0oooo00<0o`000?ooo`3oool0B03oool0
0`3o0000oooo0?ooo`0h0?ooo`80o`00E@3oool001d0oooo00<000000?ooo`3oool08P3oool00`3o
0000oooo0?ooo`160?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool0>`3oool20?l0
05<0oooo000F0?ooob`0000000<0o`00000000000000AP0000000`3o000000000000001600000003
0?l000000000000003h000000`3o000a000000030?l000000000000000D000005`3oool001d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`3o0000oooo000000090?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`3o
00001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0000000T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0`3o00080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`X0
o`0000<0oooo0000003oool0703oool001d0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool02P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00P0oooo1@3o000G0?ooo`P0o`0000<0oooo0000003oool0
9P3oool001d0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`190?ooo`030?l0003o
ool0oooo0480oooo00<0o`000?ooo`3oool0B`3ooolG0?l00340oooo000M0?ooo`030000003oool0
oooo0240oooo00<0o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`110?ooo`030?l0003oool0
oooo09@0oooo000M0?ooo`8000008@3oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo
03l0oooo00<0o`000?ooo`3oool0U@3oool001d0oooo00<000000?ooo`3oool0803oool00`3o0000
oooo0?ooo`1;0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool0UP3oool001d0oooo
00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`1<0?ooo`030?l0003oool0oooo03d0oooo
00<0o`000?ooo`3oool0UP3oool001d0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?oo
o`1<0?ooo`030?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool0U`3oool001d0oooo00<00000
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`1>0?ooo`030?l0003oool0oooo03X0oooo00<0o`00
0?ooo`3oool0V03oool001d0oooo0P00000P0?ooo`030?l0003oool0oooo04h0oooo00<0o`000?oo
o`3oool0>@3oool00`3o0000oooo0?ooo`2I0?ooo`007@3oool00`000000oooo0?ooo`0O0?ooo`03
0?l0003oool0oooo04l0oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`2J0?ooo`00
7@3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0500oooo00<0o`000?ooo`3oool0
=P3oool00`3o0000oooo0?ooo`2K0?ooo`007@3oool00`000000oooo0?ooo`0N0?ooo`030?l0003o
ool0oooo0540oooo00<0o`000?ooo`3oool0=03oool00`3o0000oooo0?ooo`2L0?ooo`007@3oool2
000001l0oooo00<0o`000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0
oooo09`0oooo000M0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0DP3oool00`3o
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo09d0oooo000M0?ooo`030000003oool0oooo01d0
oooo00<0o`000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo09h0
oooo000M0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo
0?ooo`0_0?ooo`030?l0003oool0oooo09l0oooo000M0?ooo`030000003oool0oooo01d0oooo00<0
o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0:00oooo000M
0?ooo`8000007@3oool00`3o0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo02d0oooo00<0o`00
0?ooo`3oool0X@3oool001d0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`1F0?oo
o`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0X@3oool000@0oooo0P0000040?ooo`D0
0000103oool4000000H0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`1F0?ooo`03
0?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool0XP3oool000@0oooo0P0000040?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`1G0?ooo`030?l0003oool0oooo02T0
oooo00<0o`000?ooo`3oool0X`3oool000/0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0F03oool00`3o0000oooo
0?ooo`0X0?ooo`030?l0003oool0oooo0:@0oooo000<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool3000001/0oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?oo
o`0V0?ooo`030?l0003oool0oooo0:D0oooo000=0?ooo`030000003oool0oooo00<0oooo10000006
0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0FP3oool00`3o0000oooo0?ooo`0T
0?ooo`030?l0003oool0oooo0:H0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo05/0oooo00<0o`000?oo
o`3oool08`3oool00`3o0000oooo0?ooo`2W0?ooo`002P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo
05`0oooo00<0o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`2W0?ooo`002`3oool3000000D0
oooo1@0000050?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool0G@3oool00`3o0000
oooo0?ooo`0P0?ooo`030?l0003oool0oooo0:P0oooo000M0?ooo`8000006P3oool00`3o0000oooo
0?ooo`1O0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0Z@3oool001d0oooo00<0
00000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1O0?ooo`030?l0003oool0oooo01d0oooo00<0
o`000?ooo`3oool0ZP3oool001d0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1P
0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0Z`3oool001d0oooo00<000000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?oo
o`3oool0[03oool001d0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`1S0?ooo`03
0?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0[@3oool001d0oooo0P00000I0?ooo`030?l0
003oool0oooo06@0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`2^0?ooo`007@3o
ool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo06D0oooo00<0o`000?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`2_0?ooo`007@3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo06L0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`2`0?ooo`007@3oool00`00
0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo06P0oooo00<0o`000?ooo`3oool03P3oool20?l0
0;<0oooo000M0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0J@3oool20?l000h0
oooo00<0o`000?ooo`3oool0/P3oool001d0oooo0P00000G0?ooo`030?l0003oool0oooo06`0oooo
0P3o000:0?ooo`80o`00]@3oool001d0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`1^0?ooo`<0o`00103oool30?l00;L0oooo000M0?ooo`030000003oool0oooo01H0oooo00<0o`00
0?ooo`3oool0L@3oool40?l00;X0oooo000M0?ooo`030000003oool0oooo01H0oooo00<0o`000?oo
o`3oool0o`3oool`0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0?l0
oooo<03oool001d0oooo0P00000G0?ooo`030?l0003oool0oooo0?l0oooo<03oool000<0oooo1000
00050?ooo`8000001@3oool4000000H0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`3o0?oooc00oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01D0oooo00<0o`000?ooo`3oool0o`3ooola0?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo0?l0oooo<@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0`00000E0?ooo`030?l0003oool0oooo0?l0
oooo<@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`@00000
1P3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0oooo<P3oool00080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0503oool00`3o0000oooo0?ooo`3o0?oooc80oooo00020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01@0oooo00<0o`000?ooo`3oool0o`3ooolb0?ooo`000`3oool4000000`0oooo1@0000050?oo
o`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0o`3ooolc0?ooo`007@3oool2000001@0
oooo00<0o`000?ooo`3oool0o`3ooolc0?ooo`007@3oool00`000000oooo0?ooo`0C0?ooo`030?l0
003oool0oooo0?l0oooo<`3oool001d0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?oo
o`3o0?oooc@0oooo000M0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool0o`3ooold
0?ooo`007@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0?l0oooo=03oool001d0
oooo0P00000B0?ooo`030?l0003oool0oooo0?l0oooo=@3oool001d0oooo00<000000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`3o0?ooocD0oooo000M0?ooo`030000003oool0oooo0140oooo00<0
o`000?ooo`3oool0o`3ooole0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0?l0oooo=P3oool001d0oooo00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`3o0?oo
ocH0oooo000M0?ooo`800000403oool00`3o0000oooo0?ooo`3o0?ooocL0oooo000M0?ooo`030000
003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolg0?ooo`007@3oool00`000000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0?l0oooo=`3oool001d0oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`3o0?ooocP0oooo000M0?ooo`030000003oool0oooo00h0oooo00<0o`000?oo
o`3oool0o`3ooolh0?ooo`007@3oool2000000l0oooo00<0o`000?ooo`3oool0o`3ooolh0?ooo`00
7@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo>@3oool000@0oooo0P00
00070?ooo`030000003oool0oooo00<0oooo100000060?ooo`030000003oool0oooo00d0oooo00<0
o`000?ooo`3oool0o`3oooli0?ooo`00103oool2000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`3o0?ooocX0oooo000=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?l0oooo>P3oool000h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`<00000303oool00`3o0000
oooo0?ooo`3o0?ooocX0oooo000>0?ooo`030000003oool0oooo0080oooo100000060?ooo`030000
003oool0oooo00/0oooo00<0o`000?ooo`3oool0o`3ooolk0?ooo`003`3oool01@000000oooo0?oo
o`3oool0000000T0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo
000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000
003oool0oooo00X0oooo00<0o`000?ooo`3oool0o`3oooll0?ooo`002P3oool6000000<0oooo1@00
00050?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0o`3oooll0?ooo`007@3oool2
000000X0oooo00<0o`000?ooo`3oool0o`3ooolm0?ooo`007@3oool00`000000oooo0?ooo`090?oo
o`030?l0003oool0oooo0?l0oooo?@3oool001d0oooo00<000000?ooo`3oool0203oool00`3o0000
oooo0?ooo`3o0?oooch0oooo000M0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0
o`3oooln0?ooo`007@3oool2000000P0oooo00<0o`000?ooo`3oool0o`3ooolo0?ooo`007@3oool0
0`000000oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0oooo?`3oool001d0oooo00<000000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`3o0?oood00oooo000M0?ooo`030000003oool0oooo00H0
oooo00<0o`000?ooo`3oool0o`3ooom00?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo0?l0oooo@@3oool001d0oooo0P0000050?ooo`030?l0003oool0oooo0?l0oooo@P3o
ool001d0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?oood80oooo000M0?oo
o`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom30?ooo`007@3oool00`000000
oooo0?ooo`020?ooo`030?l0003oool0oooo0?l0ooooA03oool001d0oooo00D000000?ooo`3oool0
oooo0?l0003o0?ooodL0oooo000M0?ooo`80000000<0oooo0?l0003oool0o`3ooom70?ooo`007@3o
ool00`000000o`000?l0003o0?ooodT0oooo000C0?ooo`D000001@3oool00`000000oooo0?ooo`3o
0?ooodT0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom90?oo
o`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB@3oool001D0oooo
00<000000?ooo`3oool01@3oool300000?l0ooooB@3oool001D0oooo00<000000?ooo`3oool0o`3o
oomA0?ooo`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo000C0?ooo`<00000o`3ooomC0?oo
o`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo003o0?ooofT0oooo003o0?ooofT0oooo003o
0?ooofT0oooo001D0?ooo`@00000503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
04H0oooo0`00000;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool30000
00D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0:0?ooo`00F03oool00`000000
oooo0?ooo`0A0?ooo`8000006@3oool2000004L0oooo00<000000?ooo`3oool02`3oool200000140
oooo0P00000C0?ooo`030000003oool0oooo00<0oooo0P00001=0?ooo`8000002`3oool000800000
0`3oool3000000@0oooo100000040?ooo`@00000103oool4000000<0oooo1@0000030?ooo`D00000
103oool5000000<0oooo1@0000030?ooo`D000000`3oool3000000030?ooo`00000000000080oooo
0`000000103oool000000?ooo`3oool5000000@0oooo0`0000000`3oool000000000000600000003
0?ooo`000000oooo00D0oooo1@0000020?ooo`D00000103oool00`000000oooo0?ooo`070?ooo`<0
00000`3oool010000000oooo0?ooo`3oool3000000<0oooo1@0000050?ooo`<00000103oool40000
00@0oooo1@0000030?ooo`@000000`3oool5000000030?ooo`000000oooo00@0oooo100000050?oo
o`030000003oool0oooo00P0oooo100000040?ooo`030000003oool0oooo00P0oooo100000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool3000000040?ooo`0000000000
00000080oooo1@0000030?ooo`D00000103oool2000000D0oooo1@0000040?ooo`<00000103oool5
000000<0oooo100000040?ooo`<0000000<0oooo000000000000203oool20000000000D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`3o
ool2000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool200000080oooo
00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`8000002@3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`8000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool3000000T0oooo0@00000000050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool10000000000D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`040?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
1@0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000070?ooo`D0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0?0?ooo`@000000`3oool010000000oooo0?ooo`3oool3
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool6000000D0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`H000000`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool50000
00X0oooo0@00000000050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P0000060?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool2000000<0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000001@3oool000000000003oool0000000P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`060?ooo`@000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool500000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo0@00000000030000003oool0oooo00D00000103oool4000000@0oooo
0`0000000`3oool000000?ooo`020?ooo`@000000`3oool2000000040?ooo`000000000000000080
oooo0P000000103oool000000000000000030?ooo`@000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo100000040?ooo`<0000000@0oooo000000000000oooo0P000000
103oool000000000000000030?ooo`@000000P3oool2000000050?ooo`000000oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00H0oooo100000060?ooo`030000003oool0oooo00<0oooo100000030?oo
o`80000000<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D000000?oo
o`3oool0oooo000000030?ooo`@000001P3oool010000000oooo0?ooo`3oool300000080oooo0`00
00020?ooo`@000000`3oool5000000@0oooo0`0000050?ooo`<0000000<0oooo0000003oool00P3o
ool4000000/0oooo0@00000000@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02l0oooo0`0000040?ooo`050000003oool0oooo0?ooo`0000003`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D00000
0?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903o
ool100000000?@3oool2000000H0oooo0P00000c0?ooo`030000003oool0oooo00<0oooo0`00000?
0?ooo`D000001@3oool400000080oooo1@0000050?ooo`@00000303oool200000180oooo0`000003
0?ooo`@00000403oool4000000l0oooo100000030?ooo`<00000403oool3000000040?ooo`000000
0000000000/0oooo0P00000O0?ooo`030000003oool0oooo01T0oooo0P0000000?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.729, -1.0579, 1.2899, \
0.0128654}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00649351 0.00649351 0.0101058 0.000345305 [
[.12338 -0.00239 -6 -9 ]
[.12338 -0.00239 6 0 ]
[.25325 -0.00239 -6 -9 ]
[.25325 -0.00239 6 0 ]
[.38312 -0.00239 -6 -9 ]
[.38312 -0.00239 6 0 ]
[.51299 -0.00239 -6 -9 ]
[.51299 -0.00239 6 0 ]
[.64286 -0.00239 -9 -9 ]
[.64286 -0.00239 9 0 ]
[.77273 -0.00239 -9 -9 ]
[.77273 -0.00239 9 0 ]
[.9026 -0.00239 -9 -9 ]
[.9026 -0.00239 9 0 ]
[-0.01899 .07917 -18 -4.5 ]
[-0.01899 .07917 0 4.5 ]
[-0.01899 .14823 -18 -4.5 ]
[-0.01899 .14823 0 4.5 ]
[-0.01899 .21729 -18 -4.5 ]
[-0.01899 .21729 0 4.5 ]
[-0.01899 .28635 -18 -4.5 ]
[-0.01899 .28635 0 4.5 ]
[-0.01899 .35541 -24 -4.5 ]
[-0.01899 .35541 0 4.5 ]
[-0.01899 .42447 -24 -4.5 ]
[-0.01899 .42447 0 4.5 ]
[-0.01899 .49353 -24 -4.5 ]
[-0.01899 .49353 0 4.5 ]
[.5 .5125 -186.688 0 ]
[.5 .5125 186.688 14 ]
[ -0.00649 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12338 .01011 m
.12338 .01636 L
s
[(20)] .12338 -0.00239 0 1 Mshowa
.25325 .01011 m
.25325 .01636 L
s
[(40)] .25325 -0.00239 0 1 Mshowa
.38312 .01011 m
.38312 .01636 L
s
[(60)] .38312 -0.00239 0 1 Mshowa
.51299 .01011 m
.51299 .01636 L
s
[(80)] .51299 -0.00239 0 1 Mshowa
.64286 .01011 m
.64286 .01636 L
s
[(100)] .64286 -0.00239 0 1 Mshowa
.77273 .01011 m
.77273 .01636 L
s
[(120)] .77273 -0.00239 0 1 Mshowa
.9026 .01011 m
.9026 .01636 L
s
[(140)] .9026 -0.00239 0 1 Mshowa
.125 Mabswid
.02597 .01011 m
.02597 .01386 L
s
.05844 .01011 m
.05844 .01386 L
s
.09091 .01011 m
.09091 .01386 L
s
.15584 .01011 m
.15584 .01386 L
s
.18831 .01011 m
.18831 .01386 L
s
.22078 .01011 m
.22078 .01386 L
s
.28571 .01011 m
.28571 .01386 L
s
.31818 .01011 m
.31818 .01386 L
s
.35065 .01011 m
.35065 .01386 L
s
.41558 .01011 m
.41558 .01386 L
s
.44805 .01011 m
.44805 .01386 L
s
.48052 .01011 m
.48052 .01386 L
s
.54545 .01011 m
.54545 .01386 L
s
.57792 .01011 m
.57792 .01386 L
s
.61039 .01011 m
.61039 .01386 L
s
.67532 .01011 m
.67532 .01386 L
s
.70779 .01011 m
.70779 .01386 L
s
.74026 .01011 m
.74026 .01386 L
s
.80519 .01011 m
.80519 .01386 L
s
.83766 .01011 m
.83766 .01386 L
s
.87013 .01011 m
.87013 .01386 L
s
.93506 .01011 m
.93506 .01386 L
s
.96753 .01011 m
.96753 .01386 L
s
.25 Mabswid
0 .01011 m
1 .01011 L
s
-0.00649 .07917 m
-0.00024 .07917 L
s
[(200)] -0.01899 .07917 1 0 Mshowa
-0.00649 .14823 m
-0.00024 .14823 L
s
[(400)] -0.01899 .14823 1 0 Mshowa
-0.00649 .21729 m
-0.00024 .21729 L
s
[(600)] -0.01899 .21729 1 0 Mshowa
-0.00649 .28635 m
-0.00024 .28635 L
s
[(800)] -0.01899 .28635 1 0 Mshowa
-0.00649 .35541 m
-0.00024 .35541 L
s
[(1000)] -0.01899 .35541 1 0 Mshowa
-0.00649 .42447 m
-0.00024 .42447 L
s
[(1200)] -0.01899 .42447 1 0 Mshowa
-0.00649 .49353 m
-0.00024 .49353 L
s
[(1400)] -0.01899 .49353 1 0 Mshowa
.125 Mabswid
-0.00649 .02737 m
-0.00274 .02737 L
s
-0.00649 .04464 m
-0.00274 .04464 L
s
-0.00649 .0619 m
-0.00274 .0619 L
s
-0.00649 .09643 m
-0.00274 .09643 L
s
-0.00649 .1137 m
-0.00274 .1137 L
s
-0.00649 .13096 m
-0.00274 .13096 L
s
-0.00649 .16549 m
-0.00274 .16549 L
s
-0.00649 .18276 m
-0.00274 .18276 L
s
-0.00649 .20002 m
-0.00274 .20002 L
s
-0.00649 .23455 m
-0.00274 .23455 L
s
-0.00649 .25182 m
-0.00274 .25182 L
s
-0.00649 .26908 m
-0.00274 .26908 L
s
-0.00649 .30362 m
-0.00274 .30362 L
s
-0.00649 .32088 m
-0.00274 .32088 L
s
-0.00649 .33815 m
-0.00274 .33815 L
s
-0.00649 .37268 m
-0.00274 .37268 L
s
-0.00649 .38994 m
-0.00274 .38994 L
s
-0.00649 .40721 m
-0.00274 .40721 L
s
-0.00649 .44174 m
-0.00274 .44174 L
s
-0.00649 .459 m
-0.00274 .459 L
s
-0.00649 .47627 m
-0.00274 .47627 L
s
.25 Mabswid
-0.00649 0 m
-0.00649 .5 L
s
gsave
.5 .5125 -247.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Fourier) show
129.000 14.000 moveto
(Coefficients) show
201.000 14.000 moveto
0.000 0.000 rmoveto
201.000 14.000 moveto
(,) show
210.563 14.000 moveto
(12) show
222.563 14.000 moveto
(,) show
232.125 14.000 moveto
(RGBColor) show
280.125 14.000 moveto
([) show
286.125 14.000 moveto
(0) show
292.125 14.000 moveto
(,) show
301.688 14.000 moveto
(0) show
307.688 14.000 moveto
(,) show
317.250 14.000 moveto
(0) show
323.250 14.000 moveto
(]) show
329.250 14.000 moveto
(,) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(Helvetica) show
392.813 14.000 moveto
0.000 0.000 rmoveto
392.813 14.000 moveto
(,) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(Bold) show
426.375 14.000 moveto
0.000 0.000 rmoveto
426.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 .502 r
.5 Mabswid
0 .29905 m
.00649 .11802 L
.01299 .4881 L
.01948 .12082 L
.02597 .04218 L
.03247 .02824 L
.03896 .01442 L
.04545 .03433 L
.05195 .06134 L
.05844 .02904 L
.06494 .01252 L
.07143 .01889 L
.07792 .01464 L
.08442 .0119 L
.09091 .02923 L
.0974 .01848 L
.1039 .02014 L
.11039 .01741 L
.11688 .02263 L
.12338 .01452 L
.12987 .02074 L
.13636 .02062 L
.14286 .01785 L
.14935 .01574 L
.15584 .02129 L
.16234 .01662 L
.16883 .01863 L
.17532 .01814 L
.18182 .01846 L
.18831 .01771 L
.19481 .01949 L
.2013 .01789 L
.20779 .01768 L
.21429 .01702 L
.22078 .01821 L
.22727 .01736 L
.23377 .01797 L
.24026 .01796 L
.24675 .01745 L
.25325 .01754 L
.25974 .01781 L
.26623 .01784 L
.27273 .01762 L
.27922 .01761 L
.28571 .01769 L
.29221 .01775 L
.2987 .0175 L
.30519 .0176 L
.31169 .01729 L
.31818 .01748 L
Mistroke
.32468 .01753 L
.33117 .01763 L
.33766 .01751 L
.34416 .01757 L
.35065 .01744 L
.35714 .01744 L
.36364 .01723 L
.37013 .0175 L
.37662 .01751 L
.38312 .01742 L
.38961 .0173 L
.3961 .01735 L
.4026 .01725 L
.40909 .01749 L
.41558 .01745 L
.42208 .01748 L
.42857 .01732 L
.43506 .01737 L
.44156 .01738 L
.44805 .01743 L
.45455 .01745 L
.46104 .0173 L
.46753 .01727 L
.47403 .01738 L
.48052 .01738 L
.48701 .01733 L
.49351 .0174 L
.5 .01736 L
.50649 .0173 L
.51299 .01734 L
.51948 .01741 L
.52597 .01732 L
.53247 .01737 L
.53896 .01739 L
.54545 .0173 L
.55195 .01723 L
.55844 .01736 L
.56494 .01737 L
.57143 .01731 L
.57792 .0173 L
.58442 .01736 L
.59091 .0173 L
.5974 .01734 L
.6039 .01738 L
.61039 .01732 L
.61688 .01732 L
.62338 .0173 L
.62987 .0173 L
.63636 .01732 L
.64286 .0173 L
Mistroke
.64935 .01729 L
.65584 .01726 L
.66234 .01733 L
.66883 .01734 L
.67532 .01731 L
.68182 .01734 L
.68831 .01734 L
.69481 .0173 L
.7013 .01732 L
.70779 .01733 L
.71429 .01735 L
.72078 .01731 L
.72727 .0173 L
.73377 .01731 L
.74026 .01733 L
.74675 .01731 L
.75325 .01729 L
.75974 .01728 L
.76623 .01732 L
.77273 .0173 L
.77922 .01731 L
.78571 .01732 L
.79221 .01728 L
.7987 .0173 L
.80519 .0173 L
.81169 .01733 L
.81818 .01731 L
.82468 .0173 L
.83117 .01729 L
.83766 .01727 L
.84416 .01728 L
.85065 .01732 L
.85714 .01731 L
.86364 .01732 L
.87013 .01729 L
.87662 .01728 L
.88312 .01731 L
.88961 .01729 L
.8961 .01734 L
.9026 .01729 L
.90909 .01732 L
.91558 .0173 L
.92208 .01725 L
.92857 .01731 L
.93506 .01729 L
.94156 .0173 L
.94805 .0173 L
.95455 .01727 L
.96104 .01725 L
.96753 .01728 L
Mistroke
.97403 .01732 L
.98052 .01732 L
.98701 .01727 L
.99351 .01733 L
1 .01737 L
Mfstroke
1 .01737 m
1 .01737 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003oo`3ooomY
0?ooo`00?P3oool5000000@0oooo1000000L0?ooo`<000000`3oool4000001/0oooo0`0000040?oo
o`@000006P3oool4000000@0oooo1000000F0?ooo`D000000`3oool4000000@0oooo1000000B0?oo
o`D000000P3oool5000000@0oooo1000000A0?ooo`D000001@3oool3000000<0oooo1000000f0?oo
o`00?P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0<`3oool003l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0<`3oool00400oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo1P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool05`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03<0oooo00110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<`3oool00480oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01L0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0
oooo000n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01<0oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`<00000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`<000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<`3o
ool003l0oooo0`0000050?ooo`@00000703oool2000000@0oooo1000000L0?ooo`<000000`3oool4
000001X0oooo100000040?ooo`@00000603oool00`000000oooo0?ooo`030?ooo`@00000103oool4
000001@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo1000000C0?ooo`030000003oool0
oooo00D0oooo0P0000040?ooo`@00000=P3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0oooo
J@3oool001l0oooo00<000000?ooo`3oool0o`3ooom70?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooodL0oooo000O0?ooo`030000003oool0oooo0?l0ooooA`3oool001l0oooo00<000000?ooo`00
0000o`00000U00000280oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0000P0050?ooo`030000P03oool0000000P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo000O0?ooo`030000003o
ool0oooo00X0oooo00<000200?ooo`3oool01@3oool20000P080oooo0`00080:0?ooo`030000P03o
ool0oooo00D0oooo00@000200?ooo`3oool000203`3oool00`000800oooo0?ooo`080?ooo`030000
003oool0oooo00h0oooo00<000200?ooo`3oool0303oool00`000800oooo0?ooo`030?ooo`030000
003oool0002000<0oooo00<000200?ooo`3oool03P3oool30000P0X0oooo00<000200?ooo`000000
203oool30000P0D0oooo0`0008030?ooo`030000P03oool0oooo00H0oooo0`0008030?ooo`@00020
1@3oool00`000800oooo0?ooo`030?ooo`030000P03oool0oooo00@0oooo1@0008030?ooo`D00020
0`3oool20000P0<0oooo1@0008030?ooo`P000200`3oool010000800oooo0?ooo`3oool70000P080
oooo00@000200?ooo`3oool0oooo400008050?ooo`050000P03oool0oooo0?ooo`0008008P3oool0
01l0oooo00<000000?ooo`3oool02P3oool00`000800oooo0?ooo`040?ooo`030000P03oool0oooo
008000200`3oool00`000800oooo0?ooo`040000P080oooo00<000200?ooo`0008001P000800103o
ool000200000P03oool?0000P0030?ooo`000800002001T0002000<0oooo0000P000080030000800
0`3oool000200000P0050000P0050?ooo`00080000200000P03oool0400008030?ooo`X0002000<0
oooo0000P0000800200008030?ooo`D000200`3oool30000P0030?ooo`000800002000H000200`3o
ool30000P0@0oooo1@0008000`3oool000200000P0030000P0030?ooo`000800002000@000201@3o
ool30000P0D0oooo0`0008020?ooo`<000201@3oool30000P0P0oooo0`000800103oool000200000
P00008070?ooo`80002000@0oooo0000P00008000020403oool50000P0030?ooo`00080000200080
00208P3oool001l0oooo00<000000?ooo`3oool02@3oool00`000800oooo0000P0050?ooo`030000
P03oool0oooo00D0oooo00<000200?ooo`000800103oool20000P0/0oooo00<000200?ooo`3oool0
o`3ooolG0?ooo`007`3oool2000000X0oooo00<000200?ooo`000800103oool00`000800oooo0?oo
o`070?ooo`800020o`3oool[0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`040000P03oool0
oooo0000P0<0oooo00<000200?ooo`3oool01`3oool00`000800oooo0?ooo`3o0?ooobX0oooo000O
0?ooo`030000003oool0oooo00P0oooo00D000200?ooo`3oool0oooo0000P0030?ooo`030000P03o
ool0oooo0?l0oooo=03oool001l0oooo00<000000?ooo`3oool0203oool01@000800oooo0?ooo`3o
ool0002000<0oooo00<000200?ooo`3oool0o`3ooold0?ooo`007`3oool00`000000oooo0?ooo`07
0?ooo`030000P03oool0oooo0080oooo00@000200?ooo`3oool00020o`3ooolg0?ooo`007`3oool2
000000P0oooo00<000200?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocL0oooo000O0?oo
o`030000003oool0oooo00L0oooo00<000200?ooo`3oool00`3oool00`000800oooo0000P03o0?oo
ocL0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000200?ooo`3oool00`3oool00`000800
oooo0000P03o0?ooocL0oooo000O0?ooo`030000003oool0oooo00L0oooo00<000200?ooo`3oool0
0`3oool20000P?l0oooo>03oool001l0oooo00<000000?ooo`3oool01`3oool00`000800oooo0?oo
o`040?ooo`030000P03oool0oooo0?l0oooo=P3oool001l0oooo00<000000?ooo`3oool01`3oool0
0`000800oooo0?ooo`040?ooo`030000P03oool0oooo0?l0oooo=P3oool001l0oooo0P0000070?oo
o`030000P03oool0oooo0?l0oooo?P3oool001l0oooo00<000000?ooo`3oool01P3oool00`000800
oooo0?ooo`3o0?oooch0oooo00050?ooo`D00000103oool4000000@0oooo100000050?ooo`030000
003oool0oooo00H0oooo00<000200?ooo`3oool0o`3oooln0?ooo`001@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000800oooo0?ooo`3o0?oooch0
oooo00060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000800
oooo0?ooo`3o0?oooch0oooo00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0`0000060?ooo`03
0000P03oool0oooo0?l0oooo?P3oool000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000P03oool0oooo0?l0oooo?P3oool000T0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000P03oool0oooo0?l0oooo?P3oool000D0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000200?ooo`3oool0o`3oooln
0?ooo`001P3oool3000000D0oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`060?oo
o`030000P03oool0oooo0?l0oooo?P3oool001l0oooo0P0000070?ooo`030000P03oool0oooo0?l0
oooo?P3oool001l0oooo00<000000?ooo`3oool01P3oool00`000800oooo0?ooo`3o0?oooch0oooo
000O0?ooo`030000003oool0oooo00D0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool0
0`000000oooo0?ooo`050?ooo`030000P03oool0oooo0?l0oooo?`3oool001l0oooo00<000000?oo
o`3oool01@3oool00`000800oooo0?ooo`3o0?ooocl0oooo000O0?ooo`8000001P3oool00`000800
oooo0?ooo`3o0?ooocl0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3oool00`000800
oooo0?ooo`3o0?ooocl0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3oool00`000800
oooo0?ooo`3o0?ooocl0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3oool00`000800
oooo0?ooo`3o0?ooocl0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3oool00`000800
oooo0?ooo`3o0?ooocl0oooo000O0?ooo`8000000P3oool01@000800oooo0?ooo`3oool000200?l0
oooo@@3oool001l0oooo00D000000?ooo`3oool0oooo0000P0030?ooo`030000P03oool0oooo0?l0
oooo?`3oool000P0oooo0`0000030?ooo`@00000103oool4000000D0oooo00D000000?ooo`3oool0
oooo0000P0030?ooo`030000P03oool0oooo0?l0oooo?`3oool000T0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0002000<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`002@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0008000`3oool00`000800oooo0?ooo`3o0?ooocl0oooo
00050?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool3000000030?ooo`000800oooo0080oooo00<000200?ooo`3oool0
o`3ooolo0?ooo`001P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0008000`3oool00`000800oooo0?ooo`3o0?ooocl0oooo00060?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo0000P0030?ooo`030000P03oool0oooo0?l0oooo?`3o
ool000L0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0002000<0oooo
00<000200?ooo`3oool0o`3ooolo0?ooo`00203oool2000000@0oooo100000040?ooo`@000001@3o
ool01@000000oooo0?ooo`3oool0002000<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3o
ool2000000030?ooo`000800002000<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool0
0`000000oooo0?ooo`020000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`00
0000oooo0?ooo`020000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000
oooo0?ooo`020000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo
0?ooo`020000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool2000000030?ooo`00
0800002000<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo0?ooo`02
0000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo0?ooo`020000
P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo0?ooo`020000P0<0
oooo00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo0?ooo`020000P0<0oooo
00<000200?ooo`3oool0o`3ooolo0?ooo`007`3oool2000000030?ooo`000800002000<0oooo00<0
00200?ooo`3oool0o`3ooolo0?ooo`007`3oool00`000000oooo0?ooo`020000P0<0oooo00<00020
0?ooo`3oool0o`3ooolo0?ooo`001`3oool3000000@0oooo100000040?ooo`@000001@3oool00`00
0000oooo0?ooo`020000P0<0oooo00<000200?ooo`3oool0o`3ooolo0?ooo`001P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0008030?ooo`030000P03oool0
oooo0?l0oooo?`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`080000003o
ool0oooo0000P03oool000200?ooo`00083o0?oood80oooo00060?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool3000000050000P03oool000200?ooo`000800o`3ooom20?ooo`001P3oool4
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00P000000?ooo`3oool000200?ooo`000800oooo0000P?l0oooo@P3oool000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`000800oooo0000P03oool00020
o`3ooom20?ooo`001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`080000003oool0oooo0000P03o
ool000200?ooo`00083o0?oood80oooo00080?ooo`<000000`3oool4000000@0oooo100000050?oo
o`080000003oool0oooo0000P03oool000200?ooo`00083o0?oood80oooo000O0?ooo`80000000H0
oooo0000P03oool000200?ooo`00083o0?oood80oooo000O0?ooo`080000003oool0oooo0000P03o
ool000200?ooo`00083o0?oood80oooo000O0?ooo`080000003oool0oooo0000P03oool000200?oo
o`00083o0?oood80oooo000O0?ooo`080000003oool0oooo0000P03oool000200?ooo`00083o0?oo
od80oooo000O0?ooo`080000003oool0oooo0000P03oool000200?ooo`00083o0?oood80oooo000O
0?ooo`80000000H0oooo0000P03oool000200?ooo`00083o0?oood80oooo000O0?ooo`030000003o
ool000200080oooo00<000200?ooo`000800o`3ooom20?ooo`007`3oool00`000000oooo0000P002
0?ooo`030000P03oool000200?l0oooo@P3oool001l0oooo00<000000?ooo`0008000P3oool00`00
0800oooo0000P03o0?oood80oooo000O0?ooo`030000003oool000200080oooo00<000200?ooo`00
0800o`3ooom20?ooo`007`3oool2000000060000P03oool0oooo0000P03oool00020o`3ooom20?oo
o`007`3oool00`000000oooo0000P0020?ooo`030000P03oool000200?l0oooo@P3oool000H0oooo
100000040?ooo`@00000103oool4000000D0oooo00<000000?ooo`0008000P3oool00`000800oooo
0000P03o0?oood80oooo00050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
08000P3oool00`000800oooo0000P03o0?oood80oooo00050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0008000P3oool00`000800oooo0000P03o0?oood80oooo00050?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo0P0000001P000800oooo0?ooo`000800oooo0000P?l0oooo
@P3oool000H0oooo100000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool000200080oooo00<000200?ooo`000800
o`3ooom20?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool000200080
oooo00<000200?ooo`000800o`3ooom20?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool000200080oooo00<000200?ooo`000800o`3ooom20?ooo`001P3oool4000000@0
oooo100000040?ooo`@000001@3oool00`000000oooo0000P0020?ooo`030000P03oool000200?l0
oooo@P3oool001l0oooo0P0000030?ooo`030000P03oool000200?l0oooo@P3oool001l0oooo00<0
00000?ooo`3oool00P3oool00`000800oooo0000P03o0?oood80oooo000O0?ooo`030000003oool0
oooo0080oooo00<000200?ooo`000800o`3ooom20?ooo`007`3oool00`000000oooo0?ooo`020?oo
o`030000P03oool000200?l0oooo@P3oool001l0oooo00<000000?ooo`3oool00P3oool00`000800
oooo0000P03o0?oood80oooo000O0?ooo`8000000`3oool00`000800oooo0000P03o0?oood80oooo
000O0?ooo`030000003oool0oooo0080oooo00<000200?ooo`000800o`3ooom20?ooo`007`3oool0
0`000000oooo0?ooo`020?ooo`030000P03oool000200?l0oooo@P3oool001l0oooo00<000000?oo
o`3oool00P3oool00`000800oooo0000P03o0?oood80oooo000O0?ooo`030000003oool0oooo0080
oooo00<000200?ooo`000800o`3ooom20?ooo`007`3oool2000000<0oooo00<000200?ooo`000800
o`3ooom20?ooo`007`3oool00`000000oooo0?ooo`020?ooo`030000P03oool000200?l0oooo@P3o
ool000<000000`3oool4000000@0oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`02
0?ooo`030000P03oool000200?l0oooo@P3oool000030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000P03oool000200?l0oooo@P3o
ool000030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000P03oool000200?l0oooo@P3oool000030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool300000080oooo00<000200?ooo`000800o`3ooom20?ooo`00
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000200?ooo`000800o`3ooom20?ooo`0000<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000200?ooo`000800o`3ooom2
0?ooo`0000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000200?ooo`000800o`3ooom20?ooo`0000<000000?ooo`3oool00`3oool4
000000@0oooo100000040?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`030000P03oool0
00200?l0oooo@P3oool001l0oooo0P0000030?ooo`030000P03oool000200?l0oooo@P3oool001l0
oooo00<000000?ooo`3oool00P3oool00`000800oooo0000P03o0?oood80oooo000O0?ooo`030000
003oool0oooo0080oooo00<000200?ooo`000800o`3ooom20?ooo`007`3oool00`000000oooo0?oo
o`020?ooo`030000P03oool000200?l0oooo@P3oool001l0oooo00<000000?ooo`3oool00P3oool0
0`000800oooo0000P03o0?oood80oooo000O0?ooo`8000000`3oool00`000800oooo0000P03o0?oo
od80oooo000O0?ooo`030000003oool0oooo0080oooo00<000200?ooo`000800o`3ooom20?ooo`00
7`3oool00`000000oooo0?ooo`020?ooo`030000P03oool000200?l0oooo@P3oool001l0oooo00<0
00000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0
oooo00<0oooo00<000200?ooo`3oool0o`3ooom10?ooo`007`3oool2000000@0oooo00<000200?oo
o`3oool0o`3ooom10?ooo`007`3oool00`000000oooo0?ooo`030?ooo`030000P03oool0oooo0?l0
oooo@@3oool000<000000P3oool5000000@0oooo100000040?ooo`@000001@3oool00`000000oooo
0?ooo`030?ooo`030000P03oool0oooo0?l0oooo@@3oool000030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000200?ooo`3o
ool0o`3ooom10?ooo`0000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000200?ooo`3oool0o`3ooom10?ooo`0000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000800oooo0?ooo`3o0?oood40
oooo00000`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000800oooo0?ooo`3o0?oood40oooo00000`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40oooo00000`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000P03oool0oooo0?l0oooo@@3oool000030000003oool0oooo00<0oooo0`0000050?oo
o`@00000103oool4000000D0oooo00<000000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oo
od40oooo000O0?ooo`800000103oool00`000800oooo0?ooo`3o0?oood40oooo000O0?ooo`030000
003oool0oooo00<0oooo00<000200?ooo`3oool0o`3ooom10?ooo`007`3oool00`000000oooo0?oo
o`030?ooo`030000P03oool0oooo0?l0oooo@@3oool001l0oooo00<000000?ooo`3oool00`3oool0
0`000800oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0oooo00<0oooo00<000200?oo
o`3oool0o`3ooom10?ooo`007`3oool2000000@0oooo00<000200?ooo`3oool0o`3ooom10?ooo`00
7`3oool00`000000oooo0?ooo`030?ooo`030000P03oool0oooo0?l0oooo@@3oool001l0oooo00<0
00000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40oooo000O0?ooo`030000003oool0
oooo00<0oooo00<000200?ooo`3oool0o`3ooom10?ooo`007`3oool00`000000oooo0?ooo`030?oo
o`030000P03oool0oooo0?l0oooo@@3oool001l0oooo0P0000040?ooo`030000P03oool0oooo0?l0
oooo@@3oool001l0oooo00<000000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40oooo
0003000000D0oooo0`0000030?ooo`@00000103oool4000000D0oooo00<000000?ooo`3oool00`3o
ool00`000800oooo0?ooo`3o0?oood40oooo00000`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40oooo00000`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000800oooo0?ooo`3o0?oood40
oooo00000`000000oooo0?ooo`020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool300000?l0ooooA`3oool000030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oo
odL0oooo00000`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooom70?ooo`0000<000000?ooo`3oool0103oool00`000000oooo000000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o
0?oood`0oooo00000`000000oooo0?ooo`050?ooo`800000103oool4000000@0oooo1000003o0?oo
odl0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo001k0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool3000000/0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000
oooo0?ooo`1:0?ooo`00N`3oool2000001T0oooo0P0000170?ooo`030000003oool0oooo00/0oooo
0P00000A0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`800000B`3oool000030000003o
ool0oooo0080oooo1@0000030?ooo`D000000P3oool5000000T0oooo0`0000040?ooo`@00000103o
ool500000080oooo1P0000020?ooo`H000000`3oool5000000<0oooo100000040?ooo`D000000`3o
ool500000080oooo0`000000103oool000000000000000030?ooo`<000000`3oool5000000X0oooo
1@0000020?ooo`D00000103oool00`000000oooo0?ooo`070?ooo`<000000`3oool010000000oooo
0?ooo`3oool3000000<0oooo1@0000050?ooo`<00000103oool4000000@0oooo1@0000030?ooo`@0
00000`3oool5000000030?ooo`000000oooo00@0oooo100000050?ooo`030000003oool0oooo00P0
oooo100000040?ooo`030000003oool0oooo00P0oooo100000050?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01`3oool3000000040?ooo`000000000000000080oooo1@0000030?oo
o`D00000103oool2000000D0oooo1@0000040?ooo`<00000103oool5000000<0oooo100000040?oo
o`40000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`80
00002`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool20000
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool2000000@0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000040
oooo00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`001`3oool00`000000oooo0?ooo`020?ooo`H000000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060000
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`H000000`3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3oool4000000`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`@000000`3oool010000000oooo0?ooo`3o
ool300000080oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000P3oool60000
00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`H000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool1
000000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`3oool200000080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo10000003
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3o
ool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`D000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`4000000@3oool0008000000`3oool3000000D0oooo100000030?ooo`80000000@0oooo00000000
000000001P3oool00`000000oooo0?ooo`060?ooo`@00000103oool4000000<0oooo1P0000020?oo
o`H000000`3oool3000000D0oooo0`0000000`3oool000000?ooo`020?ooo`<000001@3oool40000
00<0oooo0P0000000`3oool00000000000030?ooo`D00000103oool5000000/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`@000000`3oool2000000030?ooo`00
0000000000800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`000000
0`3oool4000000H0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<000000P3oool4000000<0
oooo1@0000040?ooo`<000001@3oool3000000030?ooo`000000oooo0080oooo0@0000000240oooo
00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0C0?ooo`<00000103oool01@000000oooo0?ooo`3oool00000
00l0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01H0oooo00070?ooo`030000003oool0oooo01P0oooo1000000E0?ooo`<000001@3oool3000000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0
oooo0`00000?0?ooo`D000001@3oool400000080oooo1@0000050?ooo`@00000303oool200000180
oooo0`0000030?ooo`@00000403oool4000000l0oooo100000030?ooo`<00000403oool300000004
0?ooo`0000000000000000/0oooo0P00000O0?ooo`030000003oool0oooo00`0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-16.7304, -147.844, 0.659682, \
12.4054}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.201641 0.000725495 [
[.17532 .18914 -6 -9 ]
[.17532 .18914 6 0 ]
[.32993 .18914 -9 -9 ]
[.32993 .18914 9 0 ]
[.48454 .18914 -9 -9 ]
[.48454 .18914 9 0 ]
[.63915 .18914 -9 -9 ]
[.63915 .18914 9 0 ]
[.79375 .18914 -9 -9 ]
[.79375 .18914 9 0 ]
[.94836 .18914 -9 -9 ]
[.94836 .18914 9 0 ]
[.00822 .05654 -24 -4.5 ]
[.00822 .05654 0 4.5 ]
[.00822 .12909 -24 -4.5 ]
[.00822 .12909 0 4.5 ]
[.00822 .27419 -18 -4.5 ]
[.00822 .27419 0 4.5 ]
[.00822 .34674 -18 -4.5 ]
[.00822 .34674 0 4.5 ]
[.00822 .41929 -18 -4.5 ]
[.00822 .41929 0 4.5 ]
[.00822 .49184 -18 -4.5 ]
[.00822 .49184 0 4.5 ]
[.5 .5125 -234.688 0 ]
[.5 .5125 234.688 14 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .20164 m
.17532 .20789 L
s
[(50)] .17532 .18914 0 1 Mshowa
.32993 .20164 m
.32993 .20789 L
s
[(100)] .32993 .18914 0 1 Mshowa
.48454 .20164 m
.48454 .20789 L
s
[(150)] .48454 .18914 0 1 Mshowa
.63915 .20164 m
.63915 .20789 L
s
[(200)] .63915 .18914 0 1 Mshowa
.79375 .20164 m
.79375 .20789 L
s
[(250)] .79375 .18914 0 1 Mshowa
.94836 .20164 m
.94836 .20789 L
s
[(300)] .94836 .18914 0 1 Mshowa
.125 Mabswid
.05164 .20164 m
.05164 .20539 L
s
.08256 .20164 m
.08256 .20539 L
s
.11348 .20164 m
.11348 .20539 L
s
.1444 .20164 m
.1444 .20539 L
s
.20625 .20164 m
.20625 .20539 L
s
.23717 .20164 m
.23717 .20539 L
s
.26809 .20164 m
.26809 .20539 L
s
.29901 .20164 m
.29901 .20539 L
s
.36085 .20164 m
.36085 .20539 L
s
.39177 .20164 m
.39177 .20539 L
s
.4227 .20164 m
.4227 .20539 L
s
.45362 .20164 m
.45362 .20539 L
s
.51546 .20164 m
.51546 .20539 L
s
.54638 .20164 m
.54638 .20539 L
s
.5773 .20164 m
.5773 .20539 L
s
.60823 .20164 m
.60823 .20539 L
s
.67007 .20164 m
.67007 .20539 L
s
.70099 .20164 m
.70099 .20539 L
s
.73191 .20164 m
.73191 .20539 L
s
.76283 .20164 m
.76283 .20539 L
s
.82468 .20164 m
.82468 .20539 L
s
.8556 .20164 m
.8556 .20539 L
s
.88652 .20164 m
.88652 .20539 L
s
.91744 .20164 m
.91744 .20539 L
s
.97928 .20164 m
.97928 .20539 L
s
.25 Mabswid
0 .20164 m
1 .20164 L
s
.02072 .05654 m
.02697 .05654 L
s
[(-200)] .00822 .05654 1 0 Mshowa
.02072 .12909 m
.02697 .12909 L
s
[(-100)] .00822 .12909 1 0 Mshowa
.02072 .27419 m
.02697 .27419 L
s
[(100)] .00822 .27419 1 0 Mshowa
.02072 .34674 m
.02697 .34674 L
s
[(200)] .00822 .34674 1 0 Mshowa
.02072 .41929 m
.02697 .41929 L
s
[(300)] .00822 .41929 1 0 Mshowa
.02072 .49184 m
.02697 .49184 L
s
[(400)] .00822 .49184 1 0 Mshowa
.125 Mabswid
.02072 .07105 m
.02447 .07105 L
s
.02072 .08556 m
.02447 .08556 L
s
.02072 .10007 m
.02447 .10007 L
s
.02072 .11458 m
.02447 .11458 L
s
.02072 .1436 m
.02447 .1436 L
s
.02072 .15811 m
.02447 .15811 L
s
.02072 .17262 m
.02447 .17262 L
s
.02072 .18713 m
.02447 .18713 L
s
.02072 .21615 m
.02447 .21615 L
s
.02072 .23066 m
.02447 .23066 L
s
.02072 .24517 m
.02447 .24517 L
s
.02072 .25968 m
.02447 .25968 L
s
.02072 .2887 m
.02447 .2887 L
s
.02072 .30321 m
.02447 .30321 L
s
.02072 .31772 m
.02447 .31772 L
s
.02072 .33223 m
.02447 .33223 L
s
.02072 .36125 m
.02447 .36125 L
s
.02072 .37576 m
.02447 .37576 L
s
.02072 .39027 m
.02447 .39027 L
s
.02072 .40478 m
.02447 .40478 L
s
.02072 .4338 m
.02447 .4338 L
s
.02072 .44831 m
.02447 .44831 L
s
.02072 .46282 m
.02447 .46282 L
s
.02072 .47733 m
.02447 .47733 L
s
.02072 .04203 m
.02447 .04203 L
s
.02072 .02752 m
.02447 .02752 L
s
.02072 .01301 m
.02447 .01301 L
s
.25 Mabswid
.02072 0 m
.02072 .5 L
s
gsave
.5 .5125 -295.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Originial) show
141.000 14.000 moveto
(Series) show
183.000 14.000 moveto
(vs) show
195.000 14.000 moveto
(.) show
207.000 14.000 moveto
(Inverse) show
255.000 14.000 moveto
(Fourier) show
297.000 14.000 moveto
0.000 0.000 rmoveto
297.000 14.000 moveto
(,) show
306.563 14.000 moveto
(12) show
318.563 14.000 moveto
(,) show
328.125 14.000 moveto
(RGBColor) show
376.125 14.000 moveto
([) show
382.125 14.000 moveto
(0) show
388.125 14.000 moveto
(,) show
397.688 14.000 moveto
(0) show
403.688 14.000 moveto
(,) show
413.250 14.000 moveto
(0) show
419.250 14.000 moveto
(]) show
425.250 14.000 moveto
(,) show
434.813 14.000 moveto
0.000 0.000 rmoveto
434.813 14.000 moveto
(Helvetica) show
488.813 14.000 moveto
0.000 0.000 rmoveto
488.813 14.000 moveto
(,) show
498.375 14.000 moveto
0.000 0.000 rmoveto
498.375 14.000 moveto
(Bold) show
522.375 14.000 moveto
0.000 0.000 rmoveto
522.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
1 0 0 r
.001 w
.02381 .4881 m
.0269 .20348 L
.02999 .20595 L
.03309 .20825 L
.03618 .2112 L
.03927 .21465 L
.04236 .21851 L
.04545 .22208 L
.04855 .22588 L
.05164 .22921 L
.05473 .23251 L
.05782 .23554 L
.06092 .23817 L
.06401 .23996 L
.0671 .24119 L
.07019 .24136 L
.07328 .24169 L
.07638 .24133 L
.07947 .24067 L
.08256 .23922 L
.08565 .23794 L
.08874 .23558 L
.09184 .23357 L
.09493 .23131 L
.09802 .22872 L
.10111 .22596 L
.10421 .22417 L
.1073 .22296 L
.11039 .2222 L
.11348 .22138 L
.11657 .22058 L
.11967 .21952 L
.12276 .2185 L
.12585 .21718 L
.12894 .21567 L
.13203 .21392 L
.13513 .21185 L
.13822 .20931 L
.14131 .20655 L
.1444 .20356 L
.1475 .20042 L
.15059 .19693 L
.15368 .19307 L
.15677 .18861 L
.15986 .18382 L
.16296 .17879 L
.16605 .17352 L
.16914 .16798 L
.17223 .16213 L
.17532 .15574 L
Mistroke
.17842 .14923 L
.18151 .14271 L
.1846 .13627 L
.18769 .12983 L
.19079 .1234 L
.19388 .11705 L
.19697 .1107 L
.20006 .10423 L
.20315 .09803 L
.20625 .09182 L
.20934 .08561 L
.21243 .07873 L
.21552 .07154 L
.21861 .06389 L
.22171 .05655 L
.2248 .04981 L
.22789 .04466 L
.23098 .04048 L
.23408 .03708 L
.23717 .03361 L
.24026 .03088 L
.24335 .02822 L
.24644 .02593 L
.24954 .02399 L
.25263 .0221 L
.25572 .02005 L
.25881 .01808 L
.2619 .01569 L
.265 .01409 L
.26809 .01289 L
.27118 .0121 L
.27427 .0119 L
.27737 .01212 L
.28046 .01237 L
.28355 .01344 L
.28664 .01439 L
.28973 .0151 L
.29283 .01546 L
.29592 .01591 L
.29901 .0162 L
.3021 .01617 L
.30519 .01561 L
.30829 .01524 L
.31138 .01495 L
.31447 .01492 L
.31756 .01643 L
.32066 .02011 L
.32375 .02473 L
.32684 .03007 L
.32993 .03633 L
Mistroke
.33302 .04334 L
.33612 .05081 L
.33921 .05843 L
.3423 .06591 L
.34539 .07303 L
.34848 .07979 L
.35158 .08626 L
.35467 .09251 L
.35776 .09863 L
.36085 .10474 L
.36395 .11089 L
.36704 .11709 L
.37013 .12349 L
.37322 .12993 L
.37631 .13639 L
.37941 .14284 L
.3825 .14927 L
.38559 .1556 L
.38868 .16186 L
.39177 .168 L
.39487 .17412 L
.39796 .18023 L
.40105 .18632 L
.40414 .1923 L
.40724 .19807 L
.41033 .20341 L
.41342 .20836 L
.41651 .21297 L
.4196 .21745 L
.4227 .22191 L
.42579 .22659 L
.42888 .23152 L
.43197 .23641 L
.43506 .24128 L
.43816 .24589 L
.44125 .25023 L
.44434 .25447 L
.44743 .25834 L
.45053 .2621 L
.45362 .26585 L
.45671 .26965 L
.4598 .27381 L
.46289 .27788 L
.46599 .28224 L
.46908 .28625 L
.47217 .2904 L
.47526 .29473 L
.47835 .29941 L
.48145 .30477 L
.48454 .31129 L
Mistroke
.48763 .31888 L
.49072 .32671 L
.49382 .333 L
.49691 .33721 L
.5 .33924 L
.50309 .33911 L
.50618 .33761 L
.50928 .33495 L
.51237 .33132 L
.51546 .32709 L
.51855 .32245 L
.52165 .31772 L
.52474 .31306 L
.52783 .3085 L
.53092 .30397 L
.53401 .29971 L
.53711 .29554 L
.5402 .2914 L
.54329 .28727 L
.54638 .28317 L
.54947 .27923 L
.55257 .27539 L
.55566 .27167 L
.55875 .26805 L
.56184 .26454 L
.56494 .26134 L
.56803 .25825 L
.57112 .25523 L
.57421 .25217 L
.5773 .2494 L
.5804 .2464 L
.58349 .24347 L
.58658 .24068 L
.58967 .23804 L
.59276 .23609 L
.59586 .23462 L
.59895 .23398 L
.60204 .23306 L
.60513 .23292 L
.60823 .23237 L
.61132 .2312 L
.61441 .22891 L
.6175 .22527 L
.62059 .22031 L
.62369 .21458 L
.62678 .20831 L
.62987 .20138 L
.63296 .19416 L
.63605 .18665 L
.63915 .17905 L
Mistroke
.64224 .17137 L
.64533 .16387 L
.64842 .15633 L
.65152 .14879 L
.65461 .14119 L
.6577 .13355 L
.66079 .12602 L
.66388 .11857 L
.66698 .11131 L
.67007 .1042 L
.67316 .09779 L
.67625 .0929 L
.67934 .09015 L
.68244 .08859 L
.68553 .08874 L
.68862 .0897 L
.69171 .09101 L
.69481 .09225 L
.6979 .09322 L
.70099 .09389 L
.70408 .09431 L
.70717 .09454 L
.71027 .09494 L
.71336 .09548 L
.71645 .09612 L
.71954 .09686 L
.72263 .09767 L
.72573 .09847 L
.72882 .09907 L
.73191 .09958 L
.735 .10005 L
.7381 .1004 L
.74119 .1007 L
.74428 .10094 L
.74737 .10119 L
.75046 .10108 L
.75356 .10087 L
.75665 .1006 L
.75974 .09974 L
.76283 .0988 L
.76592 .0976 L
.76902 .09626 L
.77211 .09473 L
.7752 .0929 L
.77829 .09087 L
.78139 .0887 L
.78448 .08634 L
.78757 .08395 L
.79066 .0819 L
.79375 .08075 L
Mistroke
.79685 .08024 L
.79994 .08014 L
.80303 .08089 L
.80612 .08252 L
.80921 .08586 L
.81231 .09119 L
.8154 .09618 L
.81849 .10114 L
.82158 .10677 L
.82468 .11316 L
.82777 .12007 L
.83086 .1264 L
.83395 .13341 L
.83704 .14022 L
.84014 .14716 L
.84323 .15361 L
.84632 .15908 L
.84941 .16354 L
.8525 .1666 L
.8556 .16905 L
.85869 .17112 L
.86178 .17315 L
.86487 .17504 L
.86797 .17689 L
.87106 .17874 L
.87415 .18056 L
.87724 .18215 L
.88033 .18357 L
.88343 .18487 L
.88652 .18614 L
.88961 .18718 L
.8927 .18839 L
.89579 .18978 L
.89889 .19121 L
.90198 .19263 L
.90507 .19405 L
.90816 .1954 L
.91126 .19659 L
.91435 .19763 L
.91744 .1986 L
.92053 .19961 L
.92362 .20062 L
.92672 .20181 L
.92981 .20308 L
.9329 .20446 L
.93599 .20553 L
.93908 .20643 L
.94218 .2075 L
.94527 .20856 L
.94836 .20967 L
Mistroke
.95145 .21097 L
.95455 .21237 L
.95764 .21406 L
.96073 .21615 L
.96382 .21917 L
.96691 .22293 L
.97001 .22764 L
.9731 .23306 L
.97619 .23941 L
Mfstroke
0 0 1 r
.02381 .27895 m
.0269 .27886 L
.02999 .27858 L
.03309 .27812 L
.03618 .27748 L
.03927 .27665 L
.04236 .27564 L
.04545 .27445 L
.04855 .27309 L
.05164 .27154 L
.05473 .26983 L
.05782 .26795 L
.06092 .2659 L
.06401 .26368 L
.0671 .26131 L
.07019 .25878 L
.07328 .2561 L
.07638 .25327 L
.07947 .2503 L
.08256 .24719 L
.08565 .24395 L
.08874 .24058 L
.09184 .23709 L
.09493 .23349 L
.09802 .22978 L
.10111 .22596 L
.10421 .22204 L
.1073 .21804 L
.11039 .21394 L
.11348 .20978 L
.11657 .20554 L
.11967 .20124 L
.12276 .19688 L
.12585 .19247 L
.12894 .18802 L
.13203 .18353 L
.13513 .17902 L
.13822 .17449 L
.14131 .16995 L
.1444 .1654 L
.1475 .16085 L
.15059 .15632 L
.15368 .1518 L
.15677 .14731 L
.15986 .14285 L
.16296 .13843 L
.16605 .13406 L
.16914 .12974 L
.17223 .12549 L
.17532 .1213 L
Mistroke
.17842 .11719 L
.18151 .11316 L
.1846 .10922 L
.18769 .10538 L
.19079 .10164 L
.19388 .09801 L
.19697 .09449 L
.20006 .09109 L
.20315 .08782 L
.20625 .08468 L
.20934 .08167 L
.21243 .07881 L
.21552 .07609 L
.21861 .07352 L
.22171 .07111 L
.2248 .06885 L
.22789 .06676 L
.23098 .06484 L
.23408 .06308 L
.23717 .06149 L
.24026 .06008 L
.24335 .05885 L
.24644 .0578 L
.24954 .05692 L
.25263 .05623 L
.25572 .05573 L
.25881 .0554 L
.2619 .05526 L
.265 .05531 L
.26809 .05554 L
.27118 .05596 L
.27427 .05656 L
.27737 .05734 L
.28046 .0583 L
.28355 .05945 L
.28664 .06077 L
.28973 .06227 L
.29283 .06394 L
.29592 .06578 L
.29901 .06779 L
.3021 .06996 L
.30519 .07229 L
.30829 .07478 L
.31138 .07743 L
.31447 .08022 L
.31756 .08316 L
.32066 .08623 L
.32375 .08944 L
.32684 .09277 L
.32993 .09623 L
Mistroke
.33302 .09981 L
.33612 .1035 L
.33921 .10729 L
.3423 .11118 L
.34539 .11517 L
.34848 .11924 L
.35158 .12339 L
.35467 .12761 L
.35776 .13189 L
.36085 .13624 L
.36395 .14064 L
.36704 .14508 L
.37013 .14955 L
.37322 .15406 L
.37631 .15859 L
.37941 .16313 L
.3825 .16767 L
.38559 .17222 L
.38868 .17676 L
.39177 .18128 L
.39487 .18578 L
.39796 .19025 L
.40105 .19468 L
.40414 .19906 L
.40724 .20339 L
.41033 .20767 L
.41342 .21187 L
.41651 .216 L
.4196 .22005 L
.4227 .22401 L
.42579 .22788 L
.42888 .23165 L
.43197 .23531 L
.43506 .23885 L
.43816 .24228 L
.44125 .24559 L
.44434 .24876 L
.44743 .2518 L
.45053 .2547 L
.45362 .25746 L
.45671 .26006 L
.4598 .26252 L
.46289 .26481 L
.46599 .26694 L
.46908 .26891 L
.47217 .27071 L
.47526 .27234 L
.47835 .27379 L
.48145 .27507 L
.48454 .27617 L
Mistroke
.48763 .27709 L
.49072 .27782 L
.49382 .27838 L
.49691 .27874 L
.5 .27893 L
.50309 .27893 L
.50618 .27874 L
.50928 .27838 L
.51237 .27782 L
.51546 .27709 L
.51855 .27617 L
.52165 .27507 L
.52474 .27379 L
.52783 .27234 L
.53092 .27071 L
.53401 .26891 L
.53711 .26694 L
.5402 .26481 L
.54329 .26252 L
.54638 .26006 L
.54947 .25746 L
.55257 .2547 L
.55566 .2518 L
.55875 .24876 L
.56184 .24559 L
.56494 .24228 L
.56803 .23885 L
.57112 .23531 L
.57421 .23165 L
.5773 .22788 L
.5804 .22401 L
.58349 .22005 L
.58658 .216 L
.58967 .21187 L
.59276 .20767 L
.59586 .20339 L
.59895 .19906 L
.60204 .19468 L
.60513 .19025 L
.60823 .18578 L
.61132 .18128 L
.61441 .17676 L
.6175 .17222 L
.62059 .16767 L
.62369 .16313 L
.62678 .15859 L
.62987 .15406 L
.63296 .14955 L
.63605 .14508 L
.63915 .14064 L
Mistroke
.64224 .13624 L
.64533 .13189 L
.64842 .12761 L
.65152 .12339 L
.65461 .11924 L
.6577 .11517 L
.66079 .11118 L
.66388 .10729 L
.66698 .1035 L
.67007 .09981 L
.67316 .09623 L
.67625 .09277 L
.67934 .08944 L
.68244 .08623 L
.68553 .08316 L
.68862 .08022 L
.69171 .07743 L
.69481 .07478 L
.6979 .07229 L
.70099 .06996 L
.70408 .06779 L
.70717 .06578 L
.71027 .06394 L
.71336 .06227 L
.71645 .06077 L
.71954 .05945 L
.72263 .0583 L
.72573 .05734 L
.72882 .05656 L
.73191 .05596 L
.735 .05554 L
.7381 .05531 L
.74119 .05526 L
.74428 .0554 L
.74737 .05573 L
.75046 .05623 L
.75356 .05692 L
.75665 .0578 L
.75974 .05885 L
.76283 .06008 L
.76592 .06149 L
.76902 .06308 L
.77211 .06484 L
.7752 .06676 L
.77829 .06885 L
.78139 .07111 L
.78448 .07352 L
.78757 .07609 L
.79066 .07881 L
.79375 .08167 L
Mistroke
.79685 .08468 L
.79994 .08782 L
.80303 .09109 L
.80612 .09449 L
.80921 .09801 L
.81231 .10164 L
.8154 .10538 L
.81849 .10922 L
.82158 .11316 L
.82468 .11719 L
.82777 .1213 L
.83086 .12549 L
.83395 .12974 L
.83704 .13406 L
.84014 .13843 L
.84323 .14285 L
.84632 .14731 L
.84941 .1518 L
.8525 .15632 L
.8556 .16085 L
.85869 .1654 L
.86178 .16995 L
.86487 .17449 L
.86797 .17902 L
.87106 .18353 L
.87415 .18802 L
.87724 .19247 L
.88033 .19688 L
.88343 .20124 L
.88652 .20554 L
.88961 .20978 L
.8927 .21394 L
.89579 .21804 L
.89889 .22204 L
.90198 .22596 L
.90507 .22978 L
.90816 .23349 L
.91126 .23709 L
.91435 .24058 L
.91744 .24395 L
.92053 .24719 L
.92362 .2503 L
.92672 .25327 L
.92981 .2561 L
.9329 .25878 L
.93599 .26131 L
.93908 .26368 L
.94218 .2659 L
.94527 .26795 L
.94836 .26983 L
Mistroke
.95145 .27154 L
.95455 .27309 L
.95764 .27445 L
.96073 .27564 L
.96382 .27665 L
.96691 .27748 L
.97001 .27812 L
.9731 .27858 L
.97619 .27886 L
Mfstroke
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003o703oool0
0`000000oooo0?ooo`3o0?ooodX0oooo000L0?ooo`030000003oool0oooo0?l0ooooBP3oool001`0
oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00703oool00`000000oooo0?ooo`3o0?ooodX0oooo
000L0?ooo`030000003oool0oooo04`0oooo103o003i0?ooo`00703oool2000004X0oooo0`3o0004
0?ooo`@0o`000`3oool40?l00>h0oooo000L0?ooo`030000003oool0oooo04P0oooo00<0o`000?oo
o`3oool02@3oool30?l000@0oooo00<0o`000?ooo`3oool0j`3oool001`0oooo00<000000?ooo`3o
ool0AP3oool20?l001<0oooo00<0o`000?ooo`3oool0j`3oool001`0oooo00<000000?ooo`3oool0
A@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0>X0oooo000L0?ooo`800000A03o
ool20?l001L0oooo00<0o`000?ooo`3oool0jP3oool001`0oooo00<000000?ooo`3oool0@P3oool0
0`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0>T0oooo000L0?ooo`030000003oool0oooo
0440oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`3Y0?ooo`00703oool00`000000
oooo0?ooo`100?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0j03oool001`0oooo
00<000000?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0>P0oooo
000L0?ooo`800000?`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0>L0oooo0000
0`3oool0000000000003000000@0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`0n
0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0i`3oool000030?ooo`000000oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`030?l0003oool0oooo0200oooo00<0
o`000?ooo`3oool0iP3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0l0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0iP3oool000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool3000003`0oooo00<0o`000?ooo`3oool01P3oool90000oa80oooo00<0
o`000?ooo`3oool0N@3oool90000of@0oooo00040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0?03oool00`3o0000oooo0?ooo`030?ooo`<0003o2@3oool30000oa00oooo00<0
o`000?ooo`3oool0M@3oool30000o`T0oooo0`000?mQ0?ooo`001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo03/0oooo00<0o`000?ooo`3oool00P3oool20000o`l0oooo0P000?l>0?ooo`030?l0
003oool0oooo07<0oooo0P000?l?0?ooo`80003oG`3oool000030?ooo`000000oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0k0?ooo`050?l0003oool0oooo0?ooo`000?l04`3oool20000
o`d0oooo00<0o`000?ooo`3oool0L03oool20000oa<0oooo00<0003o0?ooo`3oool0G03oool00080
oooo0`0000050?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0>P3oool00`3o0000
oooo0?ooo`020000oaH0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`1_0?ooo`03
0000o`3oool0oooo01@0oooo0P000?mL0?ooo`00703oool2000003/0oooo00<0o`000?ooo`000?l0
6@3oool20000o`/0oooo00<0o`000?ooo`3oool0K03oool20000oaT0oooo00<0003o0?ooo`3oool0
F@3oool001`0oooo00<000000?ooo`3oool0>@3oool00`3o0000003o0000o`0L0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0J0?ooo`80003oF@3o
ool001`0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0
oooo05H0oooo000L0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo06P0oooo00<0003o0?ooo`3oool07P3oool0103o
0000003o0?l0003o001E0?ooo`00703oool2000003P0oooo00<0003o0?l0003oool08@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo06L0oooo00<0003o0?ooo`3oool07P3oool01P3o
0000oooo0?ooo`000?l0oooo0?l005@0oooo000L0?ooo`030000003oool0oooo03H0oooo00<0003o
0?l0003oool08P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo06D0oooo00<0003o
0?l0003oool07@3oool20?l000@0oooo00<0003o0?ooo`3o0000D`3oool001`0oooo00<000000?oo
o`3oool0=@3oool00`000?l0oooo0?l0000T0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0I@3oool010000?l0oooo0?l0003o000K0?ooo`030?l0003oool0oooo00@0oooo00@0003o
0?ooo`3oool0o`00DP3oool001`0oooo00<000000?ooo`3oool0=@3oool00`000?l0o`000?ooo`0U
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`02
0?ooo`H0o`004`3oool20?l000P0oooo00<0003o0?ooo`3o0000DP3oool001`0oooo00<000000?oo
o`3oool0=03oool00`000?l0oooo0?l0000W0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0HP3oool00`000?l0oooo0?ooo`090?ooo`@0o`003@3oool20?l000/0oooo00<0003o0?oo
o`3o0000D@3oool001`0oooo0P00000d0?ooo`030000o`3oool0o`0002T0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`1P0?ooo`030000o`3oool0oooo00h0oooo3@3o000=0?ooo`04
0000o`3oool0oooo0?l00500oooo000L0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3o
0000:P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo05l0oooo00<0003o0?l0003o
ool0:P3oool00`000?l0oooo0?l0001@0?ooo`00703oool00`000000oooo0?ooo`0b0?ooo`040000
o`3oool0oooo0?l002/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`1M0?ooo`03
0000o`3oool0o`0002`0oooo00<0003o0?ooo`3o0000C`3oool001`0oooo00<000000?ooo`3oool0
<@3oool01@000?l0oooo0?ooo`3oool0o`0002/0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`1K0?ooo`030000o`3oool0o`0002h0oooo00<0003o0?l0003oool0CP3oool001`0oooo
00<000000?ooo`3oool0<03oool01@000?l0oooo0?ooo`3oool0o`0002d0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`1K0?ooo`030000o`3oool0o`0002l0oooo00<0003o0?l0003o
ool0C@3oool001`0oooo0P00000`0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
;03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo05T0oooo00<0003o0?ooo`3o0000
<@3oool00`000?l0oooo0?ooo`1<0?ooo`000P3oool5000000<0oooo100000040?ooo`@000001P3o
ool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo05P0oooo00@0003o0?ooo`3oool0o`00
<@3oool00`000?l0o`000?ooo`1<0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02h0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0_0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0EP3oool010000?l0oooo0?ooo`3o000c0?ooo`03
0000o`3oool0oooo04/0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0300oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`1E0?ooo`050000o`3oool0oooo0?ooo`3o0000=03oool00`00
0?l0oooo0?ooo`1:0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`<00000;03oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1D0?ooo`050000o`3oool0oooo0?ooo`3o0000=03oool00`3o0000003o0?ooo`1:
0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool0D`3oool01@000?l0oooo0?ooo`3oool0o`0003H0oooo00<0003o0?ooo`3oool0B@3o
ool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0=03oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0540oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0d0?ooo`030?l00000
0?l0oooo04T0oooo00020?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0500oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0e0?ooo`030?l0003o
ool0003o04T0oooo00040?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000001P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0=P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo04l0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0f0?ooo`030?l000000?l0oooo04P0oooo000L0?ooo`800000:P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo03L0oooo00D0003o0?ooo`3oool0oooo0?l0001@
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0000o`18
0?ooo`00703oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0>03oool01@000?l0oooo0?ooo`3oool0o`0004l0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0003o04L0oooo000L0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0i0?ooo`050000o`3oool0oooo
0?ooo`3o0000CP3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo03P0oooo00@0o`00
0?ooo`3oool0003oAP3oool001`0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo00000003
00000080oooo00<0o`000?ooo`0000000`00000P0?ooo`D000000`3oool4000000@0oooo10000004
0?ooo`040000o`3oool0oooo0?l001D0oooo1@0000030?ooo`@00000103oool4000001`0oooo1@00
00030?ooo`030000o`00000000000080000000@0oooo0?l0003oool0oooo1000000L0?ooo`D00000
103oool4000000@0oooo100000050?ooo`030?l0003oool0003o01@0oooo0`0000050?ooo`@00000
103oool4000001h0oooo000L0?ooo`8000009`3oool00`000?l000000?ooo`030?ooo`040000003o
ool0o`00000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`04
0000o`3oool0oooo0?l001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<0003o0000003oool00`3oool010000000o`000?ooo`0000040?ooo`030000
003oool0oooo01T0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`040?l0003oool0oooo
0000oa80oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo00@0oooo00@000000?l0003oool00000103oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo00@0003o0?ooo`3oool0o`005P3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`020?ooo`030000o`3oool0000000@0oooo00@0o`000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`040?l0003oool0oooo0000oaD0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool0
01`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`050?ooo`040000003o0000oooo
000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000o`3o
ool0oooo0?l001D0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01/0oooo00L000000?ooo`3oool0oooo0000o`3oool0000000@0oooo00@0o`00
0?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030?l0003oool0003o01D0oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool06`3oool001`0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`3oool40000
00040?l0003oool0oooo000000@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`040?ooo`040000o`3oool0oooo0?l001@0oooo00<000000?ooo`3oool00`3oool4000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0003o0080oooo
00<000000?ooo`3oool00P3oool0103o0000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030?l0003oool0003o0180oooo0P0000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo00@000000?ooo`3oool0o`000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool0
10000?l0oooo0?ooo`3o000D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00D0003o0?ooo`3oool0oooo
000000030?ooo`050?l000000000oooo0?ooo`000000103oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo0P3o00000`000?l0oooo0?ooo`0A0?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo000L0?oo
o`8000008`3oool00`000?l0oooo0?ooo`030?ooo`040000003oool0oooo0?l000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3o000A0?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool0003o00<0oooo00H000000?ooo`3o
ool0oooo0?l0000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<0o`000000o`3oool03@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
103oool2000000030?l000000000000000<0oooo1000000R0?ooo`030000003oool0oooo00<0oooo
100000040?ooo`@000002@3oool00`000?l0oooo0?l0000C0?ooo`030000003oool0oooo00<0oooo
1@0000030?ooo`@000007@3oool2000000030000o`3oool0oooo00<0oooo0P0000000`3o00000000
0?ooo`030?ooo`@000007@3oool3000000D0oooo1@0000030?ooo`@00000303oool00`000?l0o`00
0?ooo`0=0?ooo`<000001@3oool4000000@0oooo1000000N0?ooo`00703oool00`000000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0A03oool010000?l0oooo0?oo
o`3o00120?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0A@3oool00`000?l0o`00
0?l0000n0?ooo`00703oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0AP3oool00`000?l0oooo0?l000120?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0A`3oool010000?l0oooo0?l0003o000l0?ooo`00703oool200000200oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`180?ooo`030000o`3oool0o`000400oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`170?ooo`040000o`3oool0oooo0?ooo`<0o`00
>@3oool001`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo04T0oooo00<0003o0?l0003oool0?P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo04P0oooo00<0003o0?ooo`3oool00`3oool20?l003L0oooo000L0?ooo`030000003oool0
oooo01h0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`1:0?ooo`030000o`3oool0
o`0003d0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`1:0?ooo`030000o`3oool0
oooo00@0oooo0P3o000e0?ooo`00703oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0C03oool00`000?l0o`000?ooo`0l0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`060?ooo`<0o`00<P3oool001`0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo04d0
oooo00<0003o0?l0003oool0>P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo04`0
oooo00<0003o0?ooo`3oool0203oool30?l002l0oooo000E0?ooobH0000000<0003o000000000000
1P0000000`3o000000000000001>000000030000o`3o0000000003T0000000<0003o000000000000
200000000`3o000000000000001=000000030000o`000000000000T000000`3o000G000001H0oooo
000L0?ooo`040000003oool0o`000?l000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`070?ooo`03000000000?l0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00<0003o0?l0003oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0000000D0oooo00D0o`000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool010000000oooo0?ooo`3oool20?l000<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`00703oool01@000000oooo0?l0003oool0
o`0001P0oooo00<0003o0?ooo`3oool01@3oool20?l000X0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0G0?ooo`030000o`3o0000oooo01@0oooo00<000000?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`080?ooo`050?l0003oool0oooo0?ooo`000000<03oool00`000000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00d0oooo0`3o00000`000000oooo0?ooo`0U0?ooo`00703oool0
0`000000oooo0?l000020?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`1E0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`1A0?ooo`030000o`3oool0oooo00l0oooo0`3o000U0?ooo`00703oool00`00
0000oooo0?l000030?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool20?l0
05P0oooo00<0003o0?l0003oool0<`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
0580oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0R0?ooo`00703oool200000003
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`020?ooo`80
o`00F`3oool00`000?l0o`000?ooo`0b0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0E03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0240oooo000L0?ooo`030000
003oool0o`0000D0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`030?l005h0oooo
00<0003o0?l0003oool0<03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo05D0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0P0?ooo`00703oool00`000000oooo0?l0
00050?ooo`030?l0003oool0oooo00h0oooo00@0003o0?l0003o0000o`00HP3oool00`000?l0oooo
0?ooo`0^0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0EP3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01l0oooo000L0?ooo`030000003oool0o`0000H0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1T0?ooo`030000o`3oool0oooo02`0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`1H0?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool07P3oool001`0oooo0P0000000`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00X0oooo00<0o`000000o`3oool0I`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0
oooo00T0oooo0P3o001K0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool07P3oool0
01`0oooo00<000000?ooo`3o0000203oool00`3o0000oooo0?ooo`080?ooo`030?l000000?l0oooo
06P0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`D0o`00GP3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01d0oooo000L0?ooo`030000003oool0o`0000T0
oooo00<0o`000?ooo`3oool01@3oool20?l000030000o`3oool0oooo06T0oooo00<0003o0?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0680oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0M0?ooo`00703oool00`000000oooo0?l0000:0?ooo`80o`00
0`3oool20?l000030?ooo`000?l0oooo06/0oooo00<0o`000000o`3oool09`3oool00`000?l0oooo
0?ooo`030?ooo`80o`00IP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01`0oooo
000L0?ooo`030000003oool0o`0000`0oooo103o00000`3oool0003o0?ooo`1]0?ooo`030?l00000
0?l0oooo02D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1W0?ooo`030000o`3o
ool0oooo02h0oooo000L0?ooo`80000000<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1^
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo02d0oooo000L0?ooo`030000003oool0o`0000l0oooo00<0003o0?oo
o`3oool0K`3oool00`3o0000003o0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`0]0?ooo`00703oool00`000000oooo0?l0000?0?ooo`03
0000o`3oool0oooo06l0oooo00<0o`000?ooo`000?l08P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo06`0oooo00<0003o0?ooo`3oool0;03oool001`0oooo00<000000?ooo`3o0000
3P3oool00`000?l0oooo0?ooo`1a0?ooo`030?l0003oool0003o0200oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`1^0?ooo`030000o`3oool0oooo02/0oooo000L0?ooo`80000000<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1c0?ooo`040?l0003oool0003o0000oa`0oooo
0P000?l40?ooo`030?l0003oool0oooo0700oooo00<0003o0?ooo`3oool0:P3oool001`0oooo00<0
00000?ooo`3o0000303oool00`000?l0oooo0?ooo`1e0?ooo`040?l0003oool0oooo0000oaX0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1b0?ooo`030000o`3oool0oooo02T0oooo
00020?ooo`D000000`3oool4000000@0oooo100000060?ooo`030000003oool0o`0000X0oooo0P00
0?mi0?ooo`040?l0003oool0oooo0000oaP0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`1d0?ooo`80003o:@3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?l000090?ooo`030000o`3oool0oooo07X0oooo00<0o`000?ooo`3oool00P000?lD0?ooo`80003o
1P3oool00`3o0000oooo0?ooo`1f0?ooo`030000o`3oool0oooo02H0oooo00040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3o00001`3oool20000ogd0oooo00<0o`000?ooo`3oool0
0P3oool20000oa00oooo0P000?l70?ooo`030?l0003oool0oooo07P0oooo0P000?lV0?ooo`00103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`80000000<0o`000?ooo`3oool00P3oool30000oh00oooo
00<0o`000?ooo`3oool00`3oool20000o``0oooo0P000?l80?ooo`030?l0003oool0oooo07/0oooo
0`000?lS0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03000000000?l0003o00@0003o
Q03oool00`3o0000oooo0?ooo`040?ooo``0003o2@3oool00`3o0000oooo0?ooo`1o0?ooo`D0003o
7P3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?l000290?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool0X`3oool00080oooo0`0000040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0o`0008T0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`2S0?ooo`00103o
ool00`000000oooo0?ooo`030?ooo`@00000103oool4000000H0oooo0P0000000`3o0000oooo0?oo
o`280?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0Y03oool001`0oooo00<00000
0?ooo`3o0000R`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0:D0oooo000L0?oo
o`030000003oool0o`0008`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`2V0?oo
o`00703oool00`000000oooo0?l0002<0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3o
ool0YP3oool001`0oooo00<000000?ooo`3o0000S@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0:L0oooo000L0?ooo`80000000<0o`000?ooo`3oool0R`3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo0:P0oooo000L0?ooo`030000003oool0o`0008h0oooo00<0o`00
0?ooo`3oool0303oool00`3o0000oooo0?ooo`2Y0?ooo`00703oool00`000000oooo0?l0002>0?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0Z@3oool001`0oooo00<000000?ooo`3o
0000S`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0:X0oooo000L0?ooo`030000
003oool0o`0008l0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`2[0?ooo`00703o
ool2000000030?l0003oool0oooo08h0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`2[0?ooo`00703oool00`000000oooo0?l0002@0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0[03oool001`0oooo00<000000?ooo`3o0000T@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo0:d0oooo000L0?ooo`030000003oool0o`000940oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`2]0?ooo`00703oool2000000030?l0003oool0oooo0900oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2^0?ooo`00703oool00`000000oooo0?l0
002B0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0[`3oool000030?ooo`000000
000000<00000103oool4000000@0oooo100000060?ooo`030000003oool0o`0009<0oooo103o002b
0?ooo`0000<0oooo0000003oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0o`000?l0ooooBP3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?l0003o0?ooodX0oooo0003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?l000000000o`3ooom:0?ooo`00103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003o0000oooo0?l0ooooBP3oool000D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000o`000?ooo`3o0?ooodX0oooo00000`3oool000000?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000?l0003oool0o`3ooom:0?ooo`000P3oool3000000D0oooo100000040?ooo`@00000
1P3oool00`000000o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000003o0000oooo0?l0ooooBP3o
ool001`0oooo00<000000?l0003oool0o`3ooom:0?ooo`00703oool00`000000o`000?ooo`3o0?oo
odX0oooo000L0?ooo`030000003o0000oooo0?l0ooooBP3oool001`0oooo00<000000?l0003oool0
o`3ooom:0?ooo`00703oool00`000000o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000003o0000
oooo0?l0ooooBP3oool001`0oooo00<000000?l0003oool0o`3ooom:0?ooo`00703oool00`000000
o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000003o0000oooo0?l0ooooBP3oool001`0oooo00<0
00000?l0003oool0o`3ooom:0?ooo`00703oool00`000000o`000?ooo`3o0?ooodX0oooo000L0?oo
o`030000003o0000oooo0?l0ooooBP3oool001`0oooo00<000000?l0003oool0o`3ooom:0?ooo`00
703oool00`000000o`000?ooo`3o0?ooodX0oooo00020?ooo`<000001@3oool4000000@0oooo1000
00060?ooo`030000003o0000oooo0?l0ooooBP3oool000030?ooo`000000oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000o`000?ooo`3o0?ooodX0oooo00050?ooo`050000003oool0oooo0?ooo`000000
103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?l0003o
ool0o`3ooom:0?ooo`001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003o000000000?l0ooooBP3oool000<0
oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003o0000oooo0?l0ooooBP3oool000D0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000o`000?ooo`3o0?ooodX0oooo00000`3oool000000?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?l0003oool0o`3ooom:0?ooo`000P3oool3000000D0oooo100000040?ooo`@000001P3oool0
0`000000o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000003o0000oooo0?l0ooooBP3oool001`0
oooo00<000000?l0003oool0o`3ooom:0?ooo`00703oool00`000000o`000?ooo`3o0?ooodX0oooo
000L0?ooo`030000003o0000oooo0?l0ooooBP3oool001`0oooo00<000000?l0003oool0o`3ooom:
0?ooo`00703oool00`000000o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000003o0000oooo0?l0
ooooBP3oool001`0oooo00<000000?l0003oool0o`3ooom:0?ooo`00703oool00`000000o`000?oo
o`3o0?ooodX0oooo000L0?ooo`030000003o0000oooo0?l0ooooBP3oool001`0oooo00<000000?l0
003oool0o`3ooom:0?ooo`00703oool00`000000o`000?ooo`3o0?ooodX0oooo000L0?ooo`030000
003o0000oooo0?l0ooooBP3oool001`0oooo00<000000?l0003oool0o`3ooom:0?ooo`00103oool3
000000<0oooo100000040?ooo`@000001P3oool00`000000o`000?ooo`3o0?ooodX0oooo00050?oo
o`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?l0003oool0o`3ooom:0?ooo`001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003o0000oooo0?l0ooooBP3oool000030?ooo`000000000000@000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool300000?l0oooo
BP3oool00080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodX0
oooo00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom:0?oo
o`000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooBP3oool000@0
oooo0P0000040?ooo`@00000103oool400000?l0ooooD`3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00;L0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0100oooo0`0000050?ooo`030000003oool0oooo00h0oooo002g
0?ooo`8000006@3oool2000004L0oooo00<000000?ooo`3oool02`3oool200000140oooo0P00000C
0?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`0000<000000?ooo`3oool01@0000040?oo
o`D000000`3oool500000080oooo1@0000090?ooo`800000103oool5000000@0oooo0P00000<0?oo
o`D000000P3oool3000000040?ooo`0000000000000000<0oooo0P0000050?ooo`D000000P3oool5
000000<0oooo1@0000040?ooo`D000001P3oool3000000H0oooo100000050?ooo`80000000@0oooo
000000000000oooo1@0000040?ooo`D000000`3oool500000080oooo1@0000020?ooo`030000003o
ool0oooo00P0oooo1@0000020?ooo`D00000103oool00`000000oooo0?ooo`070?ooo`<000000`3o
ool010000000oooo0?ooo`3oool3000000<0oooo1@0000050?ooo`<00000103oool4000000@0oooo
1@0000030?ooo`@000000`3oool5000000030?ooo`000000oooo00@0oooo100000050?ooo`030000
003oool0oooo00P0oooo100000040?ooo`030000003oool0oooo00P0oooo100000050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool300000040oooo0@00000100000000103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`800000103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000080oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`8000002@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`8000002@3oool010000000oooo0?ooo`3oool100000000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
10000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`40
000000001@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool6000000<0
oooo100000080?ooo`040000003oool0oooo000000@0oooo1000000D0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo1P00
00030?ooo`030000003oool0oooo00D0oooo100000030?ooo`H000001`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`H000000`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool4000000<0
oooo00@000000?ooo`3oool0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?oo
o`3oool10000000000@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool00`3oool200000080oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool3000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool200000140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`@00000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool500000000
0`3oool2000000040?ooo`0000000000000000<0oooo0`0000050?ooo`@00000103oool5000000D0
oooo0`0000020?ooo`<000000P3oool5000001<0oooo00<000000?ooo`3oool00P3oool200000003
0?ooo`00000000000080oooo0`0000020?ooo`<000000P3oool4000000<0oooo0P000000103oool0
00000000000000030?ooo`D000000`3oool4000000P0oooo00<000000?ooo`0000001@3oool40000
00<0oooo0P0000020?ooo`8000000P3oool2000000040?ooo`0000000000000000<0oooo0`000005
0?ooo`@000000`3oool2000000040?ooo`0000000000000000h0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`@0
00001P3oool00`000000oooo0?ooo`030?ooo`@000000`3oool2000000030?ooo`00000000000080
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`40000000180?ooo`03
0000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`<00000103oool01@00
0000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo0000000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`400000000>0?ooo`030000003oool0oooo
03D0oooo1@00000f0?ooo`H000007@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00<0oooo0`00000?0?ooo`D000001@3oool400000080oooo1@0000050?ooo`@00000303oool20000
0180oooo0`0000030?ooo`@00000403oool4000000l0oooo100000030?ooo`<00000403oool30000
0040oooo0@00000100000000o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-29.2172, -277.939, 1.28285, \
5.46766}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Series classified as chaotic.\"\>",
            FontFamily->"Helvetica",
            FontSize->14,
            FontWeight->"Bold",
            FontColor->GrayLevel[0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> GrayLevel[ 0], 
            FontSize -> 14, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\n    Autocorrelation Analysis:   Period: 146   \
Autocorrelation: 0.419891   Bounds:            9871\\n{-261.527, ----}\\n     \
       25\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\n    Fourier Analysis:   Frequency: {308, 3, 1, \
0}\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Series classified as chaotic.", FontWeight -> "Bold", FontColor -> 
          GrayLevel[ 0], FontSize -> 14, FontFamily -> "Helvetica"], 
        StyleForm[ 
        "\n    Autocorrelation Analysis:   Period: 146   Autocorrelation: \
0.419891   Bounds:            9871\n{-261.527, ----}\n            25", 
          FontSize -> 12, FontFamily -> "Helvetica"], 
        StyleForm[ 
        "\n    Fourier Analysis:   Frequency: {308, 3, 1, 0}", FontSize -> 12,
           FontFamily -> "Helvetica"]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({"chaotic", 309}\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.263216 0.00147023 [
[.17532 .25072 -6 -9 ]
[.17532 .25072 6 0 ]
[.32993 .25072 -9 -9 ]
[.32993 .25072 9 0 ]
[.48454 .25072 -9 -9 ]
[.48454 .25072 9 0 ]
[.63915 .25072 -9 -9 ]
[.63915 .25072 9 0 ]
[.79375 .25072 -9 -9 ]
[.79375 .25072 9 0 ]
[.94836 .25072 -9 -9 ]
[.94836 .25072 9 0 ]
[.00822 .11619 -24 -4.5 ]
[.00822 .11619 0 4.5 ]
[.00822 .41024 -18 -4.5 ]
[.00822 .41024 0 4.5 ]
[.00822 .55726 -18 -4.5 ]
[.00822 .55726 0 4.5 ]
[.5 .63053 -159.688 0 ]
[.5 .63053 159.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .26322 m
.17532 .26947 L
s
[(50)] .17532 .25072 0 1 Mshowa
.32993 .26322 m
.32993 .26947 L
s
[(100)] .32993 .25072 0 1 Mshowa
.48454 .26322 m
.48454 .26947 L
s
[(150)] .48454 .25072 0 1 Mshowa
.63915 .26322 m
.63915 .26947 L
s
[(200)] .63915 .25072 0 1 Mshowa
.79375 .26322 m
.79375 .26947 L
s
[(250)] .79375 .25072 0 1 Mshowa
.94836 .26322 m
.94836 .26947 L
s
[(300)] .94836 .25072 0 1 Mshowa
.125 Mabswid
.05164 .26322 m
.05164 .26697 L
s
.08256 .26322 m
.08256 .26697 L
s
.11348 .26322 m
.11348 .26697 L
s
.1444 .26322 m
.1444 .26697 L
s
.20625 .26322 m
.20625 .26697 L
s
.23717 .26322 m
.23717 .26697 L
s
.26809 .26322 m
.26809 .26697 L
s
.29901 .26322 m
.29901 .26697 L
s
.36085 .26322 m
.36085 .26697 L
s
.39177 .26322 m
.39177 .26697 L
s
.4227 .26322 m
.4227 .26697 L
s
.45362 .26322 m
.45362 .26697 L
s
.51546 .26322 m
.51546 .26697 L
s
.54638 .26322 m
.54638 .26697 L
s
.5773 .26322 m
.5773 .26697 L
s
.60823 .26322 m
.60823 .26697 L
s
.67007 .26322 m
.67007 .26697 L
s
.70099 .26322 m
.70099 .26697 L
s
.73191 .26322 m
.73191 .26697 L
s
.76283 .26322 m
.76283 .26697 L
s
.82468 .26322 m
.82468 .26697 L
s
.8556 .26322 m
.8556 .26697 L
s
.88652 .26322 m
.88652 .26697 L
s
.91744 .26322 m
.91744 .26697 L
s
.97928 .26322 m
.97928 .26697 L
s
.25 Mabswid
0 .26322 m
1 .26322 L
s
.02072 .11619 m
.02697 .11619 L
s
[(-100)] .00822 .11619 1 0 Mshowa
.02072 .41024 m
.02697 .41024 L
s
[(100)] .00822 .41024 1 0 Mshowa
.02072 .55726 m
.02697 .55726 L
s
[(200)] .00822 .55726 1 0 Mshowa
.125 Mabswid
.02072 .1456 m
.02447 .1456 L
s
.02072 .175 m
.02447 .175 L
s
.02072 .20441 m
.02447 .20441 L
s
.02072 .23381 m
.02447 .23381 L
s
.02072 .29262 m
.02447 .29262 L
s
.02072 .32203 m
.02447 .32203 L
s
.02072 .35143 m
.02447 .35143 L
s
.02072 .38083 m
.02447 .38083 L
s
.02072 .43964 m
.02447 .43964 L
s
.02072 .46905 m
.02447 .46905 L
s
.02072 .49845 m
.02447 .49845 L
s
.02072 .52786 m
.02447 .52786 L
s
.02072 .08679 m
.02447 .08679 L
s
.02072 .05738 m
.02447 .05738 L
s
.02072 .02798 m
.02447 .02798 L
s
.02072 .58667 m
.02447 .58667 L
s
.02072 .61607 m
.02447 .61607 L
s
.25 Mabswid
.02072 0 m
.02072 .61803 L
s
gsave
.5 .63053 -220.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Time) show
111.000 14.000 moveto
(Series) show
147.000 14.000 moveto
0.000 0.000 rmoveto
147.000 14.000 moveto
(,) show
156.563 14.000 moveto
(12) show
168.563 14.000 moveto
(,) show
178.125 14.000 moveto
(RGBColor) show
226.125 14.000 moveto
([) show
232.125 14.000 moveto
(0) show
238.125 14.000 moveto
(,) show
247.688 14.000 moveto
(0) show
253.688 14.000 moveto
(,) show
263.250 14.000 moveto
(0) show
269.250 14.000 moveto
(]) show
275.250 14.000 moveto
(,) show
284.813 14.000 moveto
0.000 0.000 rmoveto
284.813 14.000 moveto
(Helvetica) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(,) show
348.375 14.000 moveto
0.000 0.000 rmoveto
348.375 14.000 moveto
(Bold) show
372.375 14.000 moveto
0.000 0.000 rmoveto
372.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .59173 m
.0269 .26207 L
.02999 .25837 L
.03309 .25511 L
.03618 .25079 L
.03927 .24675 L
.04236 .24346 L
.04545 .24016 L
.04855 .23655 L
.05164 .23298 L
.05473 .22908 L
.05782 .22469 L
.06092 .22097 L
.06401 .21681 L
.0671 .21316 L
.07019 .20906 L
.07328 .20262 L
.07638 .19655 L
.07947 .1911 L
.08256 .18725 L
.08565 .18499 L
.08874 .18467 L
.09184 .18536 L
.09493 .18861 L
.09802 .19264 L
.10111 .19893 L
.10421 .20544 L
.1073 .21345 L
.11039 .22134 L
.11348 .22954 L
.11657 .23793 L
.11967 .2459 L
.12276 .25369 L
.12585 .26126 L
.12894 .2691 L
.13203 .27692 L
.13513 .28453 L
.13822 .29214 L
.14131 .29998 L
.1444 .30746 L
.1475 .31494 L
.15059 .32252 L
.15368 .33034 L
.15677 .33874 L
.15986 .3475 L
.16296 .35668 L
.16605 .36637 L
.16914 .37613 L
.17223 .386 L
.17532 .39613 L
Mistroke
.17842 .40612 L
.18151 .41619 L
.1846 .42655 L
.18769 .43689 L
.19079 .44639 L
.19388 .45635 L
.19697 .46544 L
.20006 .47511 L
.20315 .48404 L
.20625 .49259 L
.20934 .4994 L
.21243 .50565 L
.21552 .50831 L
.21861 .50909 L
.22171 .50603 L
.2248 .49962 L
.22789 .49132 L
.23098 .48261 L
.23408 .47275 L
.23717 .46132 L
.24026 .44928 L
.24335 .43639 L
.24644 .42258 L
.24954 .40802 L
.25263 .39293 L
.25572 .37714 L
.25881 .36065 L
.2619 .34346 L
.265 .32536 L
.26809 .30707 L
.27118 .28869 L
.27427 .27034 L
.27737 .25194 L
.28046 .23361 L
.28355 .21557 L
.28664 .19746 L
.28973 .17968 L
.29283 .16226 L
.29592 .14548 L
.29901 .12883 L
.3021 .11271 L
.30519 .09744 L
.30829 .08363 L
.31138 .07182 L
.31447 .06314 L
.31756 .05731 L
.32066 .05406 L
.32375 .05194 L
.32684 .04987 L
.32993 .04798 L
Mistroke
.33302 .0479 L
.33612 .05049 L
.33921 .05597 L
.3423 .06377 L
.34539 .07379 L
.34848 .08509 L
.35158 .09731 L
.35467 .10999 L
.35776 .12319 L
.36085 .13647 L
.36395 .1496 L
.36704 .16262 L
.37013 .17586 L
.37322 .18891 L
.37631 .20183 L
.37941 .21471 L
.3825 .22747 L
.38559 .24022 L
.38868 .25297 L
.39177 .26578 L
.39487 .27861 L
.39796 .29144 L
.40105 .30429 L
.40414 .3174 L
.40724 .33097 L
.41033 .34504 L
.41342 .35927 L
.41651 .37337 L
.4196 .38763 L
.4227 .40237 L
.42579 .4178 L
.42888 .43296 L
.43197 .4474 L
.43506 .46115 L
.43816 .47338 L
.44125 .48415 L
.44434 .49406 L
.44743 .50201 L
.45053 .50971 L
.45362 .51694 L
.45671 .52452 L
.4598 .53257 L
.46289 .54119 L
.46599 .54966 L
.46908 .55945 L
.47217 .56967 L
.47526 .57955 L
.47835 .58877 L
.48145 .59647 L
.48454 .60208 L
Mistroke
.48763 .60332 L
.49072 .59761 L
.49382 .58595 L
.49691 .57116 L
.5 .55508 L
.50309 .53847 L
.50618 .52183 L
.50928 .5061 L
.51237 .49154 L
.51546 .47797 L
.51855 .46509 L
.52165 .45232 L
.52474 .43965 L
.52783 .42677 L
.53092 .41449 L
.53401 .40109 L
.53711 .38732 L
.5402 .37321 L
.54329 .35887 L
.54638 .34425 L
.54947 .32935 L
.55257 .31422 L
.55566 .29898 L
.55875 .28366 L
.56184 .26829 L
.56494 .2532 L
.56803 .23811 L
.57112 .22478 L
.57421 .2127 L
.5773 .20057 L
.5804 .18682 L
.58349 .17174 L
.58658 .15675 L
.58967 .14141 L
.59276 .12785 L
.59586 .11494 L
.59895 .10359 L
.60204 .09242 L
.60513 .08447 L
.60823 .08062 L
.61132 .07962 L
.61441 .08033 L
.6175 .08199 L
.62059 .08371 L
.62369 .08535 L
.62678 .08707 L
.62987 .0892 L
.63296 .09176 L
.63605 .09432 L
.63915 .09764 L
Mistroke
.64224 .10113 L
.64533 .10547 L
.64842 .10997 L
.65152 .11488 L
.65461 .12009 L
.6577 .12567 L
.66079 .13062 L
.66388 .13513 L
.66698 .13872 L
.67007 .14118 L
.67316 .14155 L
.67625 .13986 L
.67934 .13755 L
.68244 .13707 L
.68553 .13872 L
.68862 .14263 L
.69171 .14927 L
.69481 .15799 L
.6979 .16838 L
.70099 .18015 L
.70408 .19263 L
.70717 .20542 L
.71027 .21834 L
.71336 .23156 L
.71645 .24486 L
.71954 .25817 L
.72263 .2714 L
.72573 .28453 L
.72882 .29671 L
.73191 .30836 L
.735 .31921 L
.7381 .32969 L
.74119 .33949 L
.74428 .34885 L
.74737 .35851 L
.75046 .36833 L
.75356 .37822 L
.75665 .38847 L
.75974 .39917 L
.76283 .41101 L
.76592 .42253 L
.76902 .4338 L
.77211 .4442 L
.7752 .45371 L
.77829 .46182 L
.78139 .46894 L
.78448 .47607 L
.78757 .4832 L
.79066 .49067 L
.79375 .49733 L
Mistroke
.79685 .50349 L
.79994 .51021 L
.80303 .51757 L
.80612 .52457 L
.80921 .53075 L
.81231 .53268 L
.8154 .53177 L
.81849 .52873 L
.82158 .52531 L
.82468 .52057 L
.82777 .5148 L
.83086 .50816 L
.83395 .50153 L
.83704 .4953 L
.84014 .48989 L
.84323 .48564 L
.84632 .48272 L
.84941 .48075 L
.8525 .47924 L
.8556 .47714 L
.85869 .47478 L
.86178 .47251 L
.86487 .46999 L
.86797 .46739 L
.87106 .46489 L
.87415 .46243 L
.87724 .45925 L
.88033 .45503 L
.88343 .4491 L
.88652 .44163 L
.88961 .43212 L
.8927 .42071 L
.89579 .40716 L
.89889 .39201 L
.90198 .37602 L
.90507 .35928 L
.90816 .34208 L
.91126 .32458 L
.91435 .30675 L
.91744 .28874 L
.92053 .27064 L
.92362 .25255 L
.92672 .23471 L
.92981 .21742 L
.9329 .2009 L
.93599 .1855 L
.93908 .17047 L
.94218 .15597 L
.94527 .14147 L
.94836 .12708 L
Mistroke
.95145 .11277 L
.95455 .09869 L
.95764 .0849 L
.96073 .07097 L
.96382 .05763 L
.96691 .04521 L
.97001 .03361 L
.9731 .02309 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00=@3oool00`000000oooo0?oo
o`3o0?oooc40oooo000e0?ooo`030000003oool0oooo0?l0oooo<@3oool003D0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`00=@3oool00`000000oooo0?ooo`3o0?oooc40oooo000e0?ooo`030000
003oool0oooo0?P0oooo00<0003o0?ooo`3oool0=@3oool003D0oooo00<000000?ooo`3oool0m`3o
ool00`000?l0oooo0?ooo`0f0?ooo`00=@3oool00`000000oooo0?ooo`3g0?ooo`030000o`3oool0
oooo03H0oooo000e0?ooo`800000n03oool00`000?l0oooo0?ooo`0f0?ooo`00=@3oool00`000000
oooo0?ooo`3g0?ooo`030000o`3oool0oooo03H0oooo000e0?ooo`030000003oool0oooo0?L0oooo
00<0003o0?ooo`3oool0=P3oool003D0oooo00<000000?ooo`3oool0m`3oool00`000?l0oooo0?oo
o`0f0?ooo`00=@3oool00`000000oooo0?ooo`3f0?ooo`030000o`3oool0oooo03L0oooo000e0?oo
o`030000003oool0oooo0?H0oooo00<0003o0?ooo`3oool0=`3oool003D0oooo00<000000?ooo`3o
ool0C@3oool40000ojD0oooo00<0003o0?ooo`3oool0=`3oool003D0oooo00<000000?ooo`3oool0
C03oool20000o`80oooo00<0003o0?ooo`3oool0XP3oool00`000?l0oooo0?ooo`0h0?ooo`00=@3o
ool2000004`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`2Q0?ooo`030000o`3o
ool0oooo03P0oooo000e0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`2Q0?ooo`030000o`3oool0oooo03P0oooo000e0?ooo`030000003oool0oooo
04X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`2O0?ooo`030000o`3oool0oooo
03T0oooo000e0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`2O0?ooo`030000o`3oool0oooo03T0oooo000e0?ooo`030000003oool0oooo04T0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2O0?ooo`030000o`3oool0oooo03T0oooo
000e0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`2O0?ooo`030000o`3oool0oooo03T0oooo000e0?ooo`030000003oool0oooo04T0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`120?ooo`<0003oF@3oool00`000?l0oooo0?ooo`0j
0?ooo`00=@3oool00`000000oooo0?ooo`190?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`020000oeL0oooo00<0003o0?ooo`3oool0>P3oool003D0
oooo0P00001:0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0@03oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo05@0oooo00<0003o0?ooo`3oool0>P3oool003D0oooo
00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0400oooo
00<0003o0?ooo`3oool0103oool20000oe@0oooo00<0003o0?ooo`3oool0>P3oool003D0oooo00<0
00000?ooo`3oool0B03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo03l0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo03X0oooo000e
0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0n
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0D03oool00`000?l0oooo0?ooo`0j
0?ooo`00=@3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo00T0oooo00<0003o0?oo
o`3oool0?P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0500oooo00<0003o0?oo
o`3oool0>P3oool001`0oooo1@0000030?ooo`@00000103oool4000000D0oooo00<000000?ooo`3o
ool0A`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`1>0?ooo`030000o`3oool0oooo03/0oooo000N0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo03`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1=0?ooo`03
0000o`3oool0oooo03/0oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0A`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03`0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1<0?ooo`030000o`3oool0oooo03/0oooo000C0?ooo`H00000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`<00000A`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo03`0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1<0?ooo`03
0000o`3oool0oooo03/0oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3oool0oooo03`0oooo000N0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`1:0?ooo`03
0000o`3oool0oooo03`0oooo000L0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`160?ooo`03
0000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo04T0oooo00<0003o0?ooo`3oool0?03oool001h0oooo00<000000?ooo`3oool0
0`3oool4000000@0oooo100000050?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
B@3oool00`000?l0oooo0?ooo`0l0?ooo`00=@3oool00`000000oooo0?ooo`150?ooo`030000o`3o
ool0oooo00h0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0@0?ooo`040000o`3o
ool0oooo0?ooo`80003oA03oool00`000?l0oooo0?ooo`0m0?ooo`00=@3oool00`000000oooo0?oo
o`150?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?oo
o`0A0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo03d0oooo000e
0?ooo`800000AP3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo03T0oooo00<0003o
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0oooo03d0oooo000e0?oo
o`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0h0?oo
o`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0n0?oo
o`00=@3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3o
ool0>03oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3o
ool0?P3oool003D0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo03P0oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0n0?ooo`030000
o`3oool0oooo03h0oooo000e0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`0n0?ooo`00=@3oool00`000000oooo0?ooo`140?ooo`030000o`3oool0
oooo0140oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo03h0oooo00<0003o0?ooo`3oool0?P3oool003D0oooo00<000000?ooo`3oool0A03oool00`00
0?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo03h0oooo000e0?ooo`030000003oool0oooo04@0
oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo01/0
oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0n0?ooo`00=@3oool2000004D0oooo
00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo01/0oooo
00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0n0?ooo`00=@3oool00`000000oooo0?oo
o`140?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo0?oo
o`0M0?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool0?`3oool003D0oooo00<00000
0?ooo`3oool0A03oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo03@0oooo00<0003o
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0k0?ooo`030000o`3oool0oooo03l0oooo000e0?oo
o`030000003oool0oooo00d0oooo10000?lc0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo03/0oooo00<0003o0?oo
o`3oool0?`3oool003D0oooo00<000000?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0003o
0380oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo
01h0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0o0?ooo`00=@3oool00`000000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool07`3oool00`000?l0
oooo0?ooo`0i0?ooo`030000o`3oool0oooo0400oooo000e0?ooo`030000003oool0oooo00`0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo03T0oooo
00<0003o0?ooo`3oool0@03oool003D0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?oo
o`0b0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?oo
o`100?ooo`00=@3oool2000000/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0]
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0P
0?ooo`030000o`3oool0oooo03P0oooo00<0003o0?ooo`3oool0@03oool003D0oooo00<000000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo100000040?oo
o`@000005P3oool00`000?l0oooo00000004000000<0oooo100000040?ooo`@000000P3oool00`00
0?l0oooo0?ooo`0@0?ooo`D000000`3oool4000000@0oooo1000000>0?ooo`030000o`3oool0oooo
00<0oooo1@0000040?ooo`@00000103oool4000000P0oooo00<0003o0?ooo`3oool0203oool50000
00@0oooo100000040?ooo`@000005@3oool300000080oooo00<0003o0?ooo`3oool0100000040?oo
o`@00000=@3oool003D0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01<0oooo00D0003o0?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000?lC0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00D0oooo00<0003o0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo
00T000000?ooo`3oool0oooo0000003oool0003o0?ooo`000000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0380oooo000e0?ooo`030000003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool04`3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000oa<0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00/0oooo00<0003o
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo
00D000000?ooo`000?l0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0<P3oool003D0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0C0?oo
o`050000o`3oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool0003o4`3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05@3oool01@000000oooo0000o`3o
ool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0b0?ooo`00=@3o
ool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`050000o`3o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo0000o`0B0?ooo`030000003oool0oooo00<0oooo100000030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo0P000002
0?ooo`030000o`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0b0?ooo`00=@3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00`0oooo00<0003o
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000?l0
4P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00D000000?ooo`3oool0
oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00D000000000o`3oool0oooo00000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<P3oool003D0oooo00<00000
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<0003o
0?ooo`3oool00`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool01@000000oooo0?ooo`3oool0003o0100oooo0`0000050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0A0?ooo`060000003oool0oooo0?ooo`000000003o0P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0<P3oool003D0oooo
0P0000050?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool5000000<0oooo
1000000E0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool00`3oool4000000@0oooo
100000050?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool00`3oool5000000<0oooo
1000000<0?ooo`030000o`3oool0oooo00H0oooo0`0000050?ooo`@00000103oool4000000T0oooo
00<0003o0?ooo`3oool0203oool3000000D0oooo1@0000030?ooo`@000005@3oool3000000030?oo
o`000?l0oooo0080oooo100000040?ooo`@00000=@3oool003D0oooo00<000000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`120?ooo`00=@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0
oooo02d0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0
oooo0480oooo000e0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0;03oool00`00
0?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0@`3oool003D0
oooo00D000000?ooo`3oool0oooo0000o`0E0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`130?ooo`00=@3oool010000000oooo0?ooo`000?lG0?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0[0?oo
o`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`130?oo
o`00=@3oool00`000000oooo0000o`0H0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool06`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3o
ool0<P3oool00`000?l0oooo0?ooo`130?ooo`00;`3oool8000000030000o`000000000001L00000
00<0003o000000000000900000000`000?l000000000000L000000030000o`000000000002T00000
00<0003o0000000000009`0000000`000?l000000000000b000000030000o`000000000001<00000
<03oool003D0oooo00<000000?ooo`000?l01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`000?l01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool010000?l0oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000003o0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0=03oool003D0oooo00<000000?ooo`000?l06@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000003oool0oooo01L0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo01D0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0B0?ooo`03
0000003oool0oooo01<0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo00@0oooo00<000000?ooo`3oool0?03oool003D0oooo00<000000?ooo`000?l0
6@3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool0
@`3oool003D0oooo00<000000?ooo`000?l06P3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo01`0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo0340oooo00<0003o0?ooo`3oool0@`3oool003D0oooo00<000000?ooo`000?l06P3oool0
0`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool0A03oool0
03D0oooo00<000000?ooo`000?l06`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
01d0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo
0300oooo00<0003o0?ooo`3oool0A03oool003D0oooo00<000000?ooo`000?l06`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool09`3oool00`000?l0
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool0A03oool003D0oooo
0P0000000`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`140?ooo`00=@3oool00`000000oooo0000o`0L0?ooo`030000o`3o
ool0oooo0200oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo02X0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`140?ooo`00=@3oool0
0`000000oooo0000o`0M0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0803oool0
0`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0;P3oool0
0`000?l0oooo0?ooo`150?ooo`00=@3oool00`000000oooo0000o`0M0?ooo`030000o`3oool0oooo
01h0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo
02/0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`150?ooo`00=@3oool00`000000
oooo0000o`0M0?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0803oool00`000?l0
oooo0?ooo`0U0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0
oooo0?ooo`150?ooo`00=@3oool00`000000oooo0000o`0M0?ooo`030000o`3oool0oooo01h0oooo
00<0003o0?ooo`3oool0803oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo02`0oooo
00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`150?ooo`00=@3oool00`000000oooo0000
o`0N0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0T0?ooo`030000o`3oool0oooo02d0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?oo
o`150?ooo`00=@3oool00`000000oooo0000o`0N0?ooo`030000o`3oool0oooo01`0oooo00<0003o
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo02d0oooo00<0003o
0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`160?ooo`00=@3oool2000000030000o`3oool0oooo
01d0oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo
02<0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo
04H0oooo000e0?ooo`030000003oool0003o01l0oooo00<0003o0?ooo`3oool06`3oool00`000?l0
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04H0oooo000e0?ooo`030000003oool0003o0200oooo
00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo0280oooo
00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04H0oooo
000e0?ooo`030000003oool0003o0200oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0T0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo04L0oooo000e0?ooo`030000003oool0003o0240oooo00<0003o
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo0240oooo00<0003o
0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo04L0oooo000e0?oo
o`030000003oool0003o0240oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0T0?oo
o`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo04L0oooo000e0?ooo`030000003oool0003o0280oooo00<0003o0?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3o
ool0<@3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0oooo04L0oooo000e0?ooo`030000
003oool0003o0280oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0240oooo00<0003o0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0X0?ooo`030000
o`3oool0oooo04L0oooo000e0?ooo`80000000<0003o0?ooo`3oool0803oool00`000?l0oooo0?oo
o`0G0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo0?oo
o`0b0?ooo`030000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool0A`3oool003D0oooo00<00000
0?ooo`000?l08P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo02D0oooo00<0003o
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo02L0oooo00<0003o
0?ooo`3oool0A`3oool003D0oooo00<000000?ooo`000?l08P3oool00`000?l0oooo0?ooo`0G0?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0c0?oo
o`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0A`3oool003D0oooo00<000000?ooo`00
0?l08`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3o
ool0A`3oool003D0oooo00<000000?ooo`000?l08`3oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo02L0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0d0?ooo`030000
o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0B03oool003D0oooo00<000000?ooo`000?l08`3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool0B03o
ool003D0oooo00<000000?ooo`000?l0903oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo02L0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0
oooo02@0oooo00<0003o0?ooo`3oool0B03oool003D0oooo0P0000000`000?l0oooo0?ooo`0R0?oo
o`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0M0?oo
o`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`180?oo
o`00=@3oool00`000000oooo0000o`0U0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o
ool0:@3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`190?ooo`00=@3oool00`000000oooo0000o`0U0?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0L0?ooo`030000
o`3oool0oooo03L0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`190?ooo`00=@3o
ool00`000000oooo0000o`0U0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo03L0oooo00<0003o0?ooo`3oool08P3o
ool00`000?l0oooo0?ooo`190?ooo`00=@3oool00`000000oooo0000o`0V0?ooo`030000o`3oool0
oooo0140oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
oooo03P0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`190?ooo`00703oool50000
00<0oooo100000040?ooo`@000001@3oool00`000000oooo0000o`0V0?ooo`030000o`3oool0oooo
0100oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo
03P0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`1:0?ooo`007P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0003o02H0oooo00<0003o0?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool0>03oool00`00
0?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo04X0oooo000N0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000?l09P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo
02/0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0i0?ooo`030000o`3oool0oooo
0200oooo00<0003o0?ooo`3oool0BP3oool001h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool20000
00030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0[0?oo
o`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0P0?oo
o`030000o`3oool0oooo04X0oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000?l09`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?oo
o`3oool06@3oool00`000?l0oooo0?ooo`0j0?ooo`030000o`3oool0oooo01l0oooo00<0003o0?oo
o`3oool0B`3oool001h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000o`0W0?oo
o`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0I0?oo
o`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`1;0?oo
o`00703oool3000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`000?l09`3oool00`000?l0oooo0?ooo`0>0?oo
o`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0l0?oo
o`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3oool0B`3oool001h0oooo00<000000?ooo`3o
ool00`3oool4000000@0oooo100000050?ooo`030000003oool0003o02P0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3o
ool0?03oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo04/0oooo000e0?ooo`030000
00000?l0oooo02P0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0^0?ooo`030000
o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0M0?ooo`030000
o`3oool0oooo04/0oooo000e0?ooo`03000000000?l0oooo02T0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0?@3o
ool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo04/0oooo000e0?ooo`03000000000?l0
oooo02T0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0
oooo01L0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0
oooo04`0oooo000e0?ooo`03000000000?l0oooo02T0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo04`0oooo000e0?ooo`03000000000?l0oooo02X0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo01H0
oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo04d0
oooo000e0?ooo`03000000000?l0oooo02X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0_0?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo
0?ooo`0J0?ooo`030000o`3oool0oooo04d0oooo000e0?ooo`03000000000?l0oooo02X0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0_0?ooo`030000o`3oool0oooo01D0oooo00<0
003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo04h0oooo000e
0?ooo`03000000000?l0oooo02X0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0a
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0I
0?ooo`030000o`3oool0oooo04h0oooo000e0?ooo`03000000000?l0oooo02X0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo04l0oooo000e0?ooo`03
000000000?l0oooo02/0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0a0?ooo`03
0000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo0500oooo000e0?ooo`03000000000?l0oooo02/0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0
@P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0540oooo000e0?ooo`0300000000
0?l0oooo02/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0c0?ooo`030000o`3o
ool0oooo0140oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0B0?ooo`80003oE03o
ool003D0oooo00<000000000o`3oool0;03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo03<0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`140?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool0E03oool003D0oooo00<000000000o`3oool0;03oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`140?ooo`030000o`3oool0oooo00l0oooo0P000?mF0?ooo`00=@3oool00`000000
003o0?ooo`0]0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=@3oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0303oool20000oeP0
oooo000e0?ooo`03000000000?l0oooo02d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0f0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo05P0oooo000e0?ooo`03000000000?l0oooo02h0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo05T0oooo000e
0?ooo`03000000000?l0oooo02h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0f
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo05T0oooo000e0?ooo`03000000000?l0oooo02h0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?oo
o`3oool0B03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05X0oooo000e0?ooo`03
000000000?l0oooo02l0oooo00D0003o0?ooo`3oool0oooo0000o`0i0?ooo`030000o`3oool0oooo
00d0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
05X0oooo000e0?ooo`03000000000?l0oooo02l0oooo00@0003o0?ooo`3oool0003o>P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo04T0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`1K0?ooo`00=@3oool00`000000003o0?ooo`0`0?ooo`80003o?03oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`1K0?ooo`00=@3oool00`000000003o0?ooo`1^0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05`0oooo
000e0?ooo`03000000000?l0oooo06l0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`1;0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0G03oool003D0oooo00<00000
0000o`3oool0K`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04/0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1M0?ooo`00=@3oool00`000000003o0?ooo`1`0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0C03oool01@000?l0oooo0?ooo`3oool0
003o05l0oooo000e0?ooo`03000000000?l0oooo0700oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`1<0?ooo`040000o`3oool0oooo0000of00oooo000e0?ooo`03000000000?l0oooo
0700oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1=0?ooo`<0003oH@3oool003D0
oooo00<000000000o`3oool0L03oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0;40
oooo000e0?ooo`03000000000?l0oooo0740oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`2a0?ooo`00=@3oool00`000000003o0?ooo`1a0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool0/@3oool001/0oooo1@0000040?ooo`@00000103oool4000000D0oooo00<00000
0000o`3oool0L@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0;80oooo000K0?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o0?ooo`1b0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0/P3oool001`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000003o0?ooo`1b0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0/P3o
ool001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000003o0000001c0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0/P3oool001h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000003o0?ooo`1c0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0/`3o
ool001l0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000003o0?ooo`1d0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0/`3oool001/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
000000000?l0oooo07@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`2c0?ooo`00
703oool3000000D0oooo100000040?ooo`@000001@3oool00`000000003o0?ooo`1d0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0/`3oool003D0oooo00<000000000o`3oool0M03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0;@0oooo000e0?ooo`03000000000?l0
oooo07@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2d0?ooo`00=@3oool00`00
0000003o0?ooo`1d0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0]03oool003D0
oooo00<000000000o`3oool0M@3oool01@000?l0oooo0?ooo`3oool0003o0;H0oooo000e0?ooo`03
000000000?l0oooo07D0oooo00D0003o0?ooo`3oool0oooo0000o`2f0?ooo`00=@3oool00`000000
oooo0?ooo`1f0?ooo`040000o`3oool0oooo0000okH0oooo000e0?ooo`030000003oool0oooo07H0
oooo00<0003o0?ooo`000?l0]`3oool003D0oooo00<000000?ooo`3oool0M`3oool20000okL0oooo
000e0?ooo`030000003oool0oooo0?l0oooo<@3oool003D0oooo00<000000?ooo`3oool0o`3ooola
0?ooo`00=@3oool200000?l0oooo<P3oool003D0oooo00<000000?ooo`3oool0o`3ooola0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`000`00001F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3o
ool3000000/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000001@3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01`0oooo00000`000000oooo0?ooo`1F
0?ooo`8000006@3oool2000004L0oooo00<000000?ooo`3oool02`3oool200000140oooo0P00000C
0?ooo`030000003oool0oooo00<0oooo0P00001>0?ooo`8000007@3oool000030000003oool0oooo
00@0oooo0`0000040?ooo`D0000000D0oooo00000000000000000?ooo`02000000040?ooo`000000
oooo0?ooo`D00000203oool00`000000oooo00000002000000@0oooo1@0000020?ooo`D00000103o
ool5000000<0oooo1@0000020?ooo`D000000P3oool00`000000oooo0?ooo`080?ooo`D000000P3o
ool5000000@0oooo00<000000?ooo`3oool01`3oool3000000<0oooo00@000000?ooo`3oool0oooo
0`0000030?ooo`D000001@3oool3000000@0oooo100000040?ooo`D000000`3oool4000000<0oooo
1@0000000`3oool000000?ooo`040?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`@00000
103oool00`000000oooo0?ooo`080?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo0`000000103oool000000000000000020?ooo`D000000`3oool5000000@0
oooo0P0000050?ooo`D00000103oool3000000@0oooo1@0000030?ooo`@00000103oool300000003
0?ooo`000000000000T0oooo1@0000040?ooo`@00000103oool30000000000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0000000=0?ooo`8000000`3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00@000000?ooo`00000000002`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool2000000T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool2000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo100000090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0@00
000000030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000004P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0@0000000003
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000001@00000=0?ooo`030000003oool0oooo
00H000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo1P0000030?oo
o`@000003`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo100000030?oo
o`040000003oool0oooo0?ooo`<000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`H000001@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo1P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`D000002`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000070?ooo`0000000000
0?ooo`000000oooo000000040?ooo`030000003oool0oooo00L0oooo100000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`060?ooo`@000000`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool500000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool2000000050?ooo`000000oooo0?ooo`0000000`3oool4000000T0oooo00<000000?ooo`3o
ool01P3oool4000000<0oooo0P000000103oool000000000000000030?ooo`<000001@3oool40000
00@0oooo1@00000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01P3oool4000000H0oooo00<000000?ooo`3oool00`3o
ool4000000<0oooo0P0000000`3oool0000000000002000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo100000060?ooo`040000003oool0oooo0?ooo`<0
00000P3oool300000080oooo100000030?ooo`D00000103oool3000000D0oooo0`0000000`3oool0
00000?ooo`020?ooo`@00000303oool01@000000oooo0?ooo`3oool0000000<0oooo100000060?oo
o`40000000000`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool07@3oool010000000oooo0?ooo`3oool2000003@0oooo0`0000040?ooo`050000003oool0
oooo0?ooo`0000003`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0000000d0oooo0@00000000<000000P3o
ool7000000@0oooo00<000000?ooo`3oool06@3oool3000000030?ooo`000000oooo01@0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`<000003`3oool5000000D0oooo1000
00020?ooo`D000001@3oool4000000`0oooo0P00000B0?ooo`<000000`3oool400000100oooo1000
000?0?ooo`@000000`3oool300000100oooo0`000000103oool0000000000000000;0?ooo`800000
7`3oool00`000000oooo0?ooo`0J0?ooo`D000003@3oool200000000o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-65.6372, -228.124, 1.53647, \
3.23146}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00308214 0.309017 0.309017 [
[.17792 .29652 -6 -9 ]
[.17792 .29652 6 0 ]
[.33202 .29652 -9 -9 ]
[.33202 .29652 9 0 ]
[.48613 .29652 -9 -9 ]
[.48613 .29652 9 0 ]
[.64024 .29652 -9 -9 ]
[.64024 .29652 9 0 ]
[.79434 .29652 -9 -9 ]
[.79434 .29652 9 0 ]
[.94845 .29652 -9 -9 ]
[.94845 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -174.688 0 ]
[.5 .63053 174.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17792 .30902 m
.17792 .31527 L
s
[(50)] .17792 .29652 0 1 Mshowa
.33202 .30902 m
.33202 .31527 L
s
[(100)] .33202 .29652 0 1 Mshowa
.48613 .30902 m
.48613 .31527 L
s
[(150)] .48613 .29652 0 1 Mshowa
.64024 .30902 m
.64024 .31527 L
s
[(200)] .64024 .29652 0 1 Mshowa
.79434 .30902 m
.79434 .31527 L
s
[(250)] .79434 .29652 0 1 Mshowa
.94845 .30902 m
.94845 .31527 L
s
[(300)] .94845 .29652 0 1 Mshowa
.125 Mabswid
.05463 .30902 m
.05463 .31277 L
s
.08545 .30902 m
.08545 .31277 L
s
.11627 .30902 m
.11627 .31277 L
s
.1471 .30902 m
.1471 .31277 L
s
.20874 .30902 m
.20874 .31277 L
s
.23956 .30902 m
.23956 .31277 L
s
.27038 .30902 m
.27038 .31277 L
s
.3012 .30902 m
.3012 .31277 L
s
.36284 .30902 m
.36284 .31277 L
s
.39367 .30902 m
.39367 .31277 L
s
.42449 .30902 m
.42449 .31277 L
s
.45531 .30902 m
.45531 .31277 L
s
.51695 .30902 m
.51695 .31277 L
s
.54777 .30902 m
.54777 .31277 L
s
.57859 .30902 m
.57859 .31277 L
s
.60942 .30902 m
.60942 .31277 L
s
.67106 .30902 m
.67106 .31277 L
s
.70188 .30902 m
.70188 .31277 L
s
.7327 .30902 m
.7327 .31277 L
s
.76352 .30902 m
.76352 .31277 L
s
.82517 .30902 m
.82517 .31277 L
s
.85599 .30902 m
.85599 .31277 L
s
.88681 .30902 m
.88681 .31277 L
s
.91763 .30902 m
.91763 .31277 L
s
.97927 .30902 m
.97927 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -235.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Autocorrellagram) show
177.000 14.000 moveto
0.000 0.000 rmoveto
177.000 14.000 moveto
(,) show
186.563 14.000 moveto
(12) show
198.563 14.000 moveto
(,) show
208.125 14.000 moveto
(RGBColor) show
256.125 14.000 moveto
([) show
262.125 14.000 moveto
(0) show
268.125 14.000 moveto
(,) show
277.688 14.000 moveto
(0) show
283.688 14.000 moveto
(,) show
293.250 14.000 moveto
(0) show
299.250 14.000 moveto
(]) show
305.250 14.000 moveto
(,) show
314.813 14.000 moveto
0.000 0.000 rmoveto
314.813 14.000 moveto
(Helvetica) show
368.813 14.000 moveto
0.000 0.000 rmoveto
368.813 14.000 moveto
(,) show
378.375 14.000 moveto
0.000 0.000 rmoveto
378.375 14.000 moveto
(Bold) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02689 .61173 m
.02997 .60787 L
.03306 .60275 L
.03614 .5964 L
.03922 .58888 L
.0423 .58028 L
.04538 .57064 L
.04847 .56003 L
.05155 .5485 L
.05463 .53613 L
.05771 .52297 L
.0608 .50909 L
.06388 .49454 L
.06696 .4794 L
.07004 .46374 L
.07312 .4476 L
.07621 .43109 L
.07929 .41431 L
.08237 .39733 L
.08545 .38024 L
.08853 .36311 L
.09162 .34601 L
.0947 .32901 L
.09778 .31217 L
.10086 .29557 L
.10395 .27925 L
.10703 .26327 L
.11011 .24766 L
.11319 .23247 L
.11627 .21772 L
.11936 .20346 L
.12244 .18972 L
.12552 .17655 L
.1286 .16399 L
.13168 .15207 L
.13477 .14086 L
.13785 .13041 L
.14093 .12074 L
.14401 .1119 L
.1471 .10392 L
.15018 .09682 L
.15326 .09062 L
.15634 .08533 L
.15942 .08097 L
.16251 .07757 L
.16559 .07515 L
.16867 .07371 L
.17175 .07326 L
.17483 .07379 L
.17792 .07529 L
Mistroke
.181 .07774 L
.18408 .08111 L
.18716 .08538 L
.19025 .09051 L
.19333 .09644 L
.19641 .10309 L
.19949 .11043 L
.20257 .11842 L
.20566 .12703 L
.20874 .13622 L
.21182 .14596 L
.2149 .15617 L
.21798 .16682 L
.22107 .17787 L
.22415 .18926 L
.22723 .20097 L
.23031 .21294 L
.23339 .2251 L
.23648 .23738 L
.23956 .24973 L
.24264 .26209 L
.24572 .27442 L
.24881 .28666 L
.25189 .29877 L
.25497 .3107 L
.25805 .3224 L
.26113 .33383 L
.26422 .34495 L
.2673 .35572 L
.27038 .36611 L
.27346 .37606 L
.27654 .38555 L
.27963 .39453 L
.28271 .40298 L
.28579 .41087 L
.28887 .41817 L
.29196 .42488 L
.29504 .43097 L
.29812 .43642 L
.3012 .44124 L
.30428 .44542 L
.30737 .44899 L
.31045 .45197 L
.31353 .4544 L
.31661 .45633 L
.31969 .45777 L
.32278 .45874 L
.32586 .45926 L
.32894 .45933 L
.33202 .45896 L
Mistroke
.33511 .45813 L
.33819 .45685 L
.34127 .4551 L
.34435 .45289 L
.34743 .4502 L
.35052 .44705 L
.3536 .44345 L
.35668 .43941 L
.35976 .43495 L
.36284 .43009 L
.36593 .42485 L
.36901 .41926 L
.37209 .41333 L
.37517 .40708 L
.37826 .40054 L
.38134 .39373 L
.38442 .38665 L
.3875 .37932 L
.39058 .37177 L
.39367 .36404 L
.39675 .35617 L
.39983 .34824 L
.40291 .3403 L
.40599 .3324 L
.40908 .32457 L
.41216 .31684 L
.41524 .30924 L
.41832 .30181 L
.42141 .29456 L
.42449 .28749 L
.42757 .28059 L
.43065 .27387 L
.43373 .26735 L
.43682 .26106 L
.4399 .25501 L
.44298 .24922 L
.44606 .24371 L
.44914 .23849 L
.45223 .23359 L
.45531 .22903 L
.45839 .22482 L
.46147 .22099 L
.46456 .21753 L
.46764 .21448 L
.47072 .21183 L
.4738 .20958 L
.47688 .20774 L
.47997 .20631 L
.48305 .2053 L
.48613 .20468 L
Mistroke
.48921 .20445 L
.49229 .20462 L
.49538 .20526 L
.49846 .2064 L
.50154 .20807 L
.50462 .21025 L
.50771 .21297 L
.51079 .21617 L
.51387 .21979 L
.51695 .22372 L
.52003 .22791 L
.52312 .23229 L
.5262 .23685 L
.52928 .24155 L
.53236 .24636 L
.53544 .25128 L
.53853 .25629 L
.54161 .2614 L
.54469 .26659 L
.54777 .27185 L
.55086 .27718 L
.55394 .28256 L
.55702 .28798 L
.5601 .29342 L
.56318 .29885 L
.56627 .30424 L
.56935 .30959 L
.57243 .31486 L
.57551 .32003 L
.57859 .32506 L
.58168 .32993 L
.58476 .33467 L
.58784 .33925 L
.59092 .34367 L
.59401 .34793 L
.59709 .35202 L
.60017 .35592 L
.60325 .35964 L
.60633 .36319 L
.60942 .36655 L
.6125 .36966 L
.61558 .37252 L
.61866 .37509 L
.62174 .37734 L
.62483 .37927 L
.62791 .38087 L
.63099 .38212 L
.63407 .38301 L
.63716 .38354 L
.64024 .38369 L
Mistroke
.64332 .38346 L
.6464 .38285 L
.64948 .38185 L
.65257 .38045 L
.65565 .37868 L
.65873 .37652 L
.66181 .37399 L
.66489 .37113 L
.66798 .36794 L
.67106 .36446 L
.67414 .36071 L
.67722 .3567 L
.68031 .35247 L
.68339 .34805 L
.68647 .34348 L
.68955 .33882 L
.69263 .3341 L
.69572 .32938 L
.6988 .32466 L
.70188 .31999 L
.70496 .31537 L
.70804 .31083 L
.71113 .3064 L
.71421 .30209 L
.71729 .29793 L
.72037 .29394 L
.72346 .29015 L
.72654 .28655 L
.72962 .28318 L
.7327 .28005 L
.73578 .27718 L
.73887 .27459 L
.74195 .27228 L
.74503 .27026 L
.74811 .26855 L
.75119 .26714 L
.75428 .26604 L
.75736 .26525 L
.76044 .26479 L
.76352 .26462 L
.76661 .26474 L
.76969 .26514 L
.77277 .26579 L
.77585 .2667 L
.77893 .26784 L
.78202 .26919 L
.7851 .2707 L
.78818 .27236 L
.79126 .2741 L
.79434 .27592 L
Mistroke
.79743 .27782 L
.80051 .27977 L
.80359 .28177 L
.80667 .2838 L
.80975 .28581 L
.81284 .28781 L
.81592 .28978 L
.819 .29175 L
.82208 .2937 L
.82517 .29562 L
.82825 .29752 L
.83133 .29938 L
.83441 .30122 L
.83749 .30303 L
.84058 .30481 L
.84366 .30657 L
.84674 .3083 L
.84982 .30999 L
.8529 .31162 L
.85599 .3132 L
.85907 .31471 L
.86215 .31614 L
.86523 .31748 L
.86832 .31874 L
.8714 .31991 L
.87448 .32096 L
.87756 .32188 L
.88064 .32267 L
.88373 .32331 L
.88681 .32377 L
.88989 .32407 L
.89297 .32418 L
.89605 .32411 L
.89914 .32388 L
.90222 .32349 L
.9053 .32297 L
.90838 .32233 L
.91147 .3216 L
.91455 .32079 L
.91763 .31994 L
.92071 .31906 L
.92379 .31817 L
.92688 .31731 L
.92996 .31647 L
.93304 .31564 L
.93612 .3148 L
.9392 .31398 L
.94229 .31315 L
.94537 .31233 L
.94845 .31152 L
Mistroke
.95153 .31072 L
.95462 .30993 L
.9577 .30914 L
.96078 .30837 L
.96386 .30763 L
.96694 .30693 L
.97003 .30625 L
.97311 .30563 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`004`3oool500000?l0ooooD@3oool001D0oooo00<0
00000?ooo`3oool0o`3ooomA0?ooo`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo000:0?oo
o`H000001@3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooom90?ooo`005@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB@3oool001D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000C0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooodT0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`007@3oool200000?l0ooooBP3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo
000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?oo
o`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool000@0
oooo0P0000070?ooo`030000003oool0oooo00<0oooo100000060?ooo`030000003oool0oooo0?l0
ooooB@3oool000@0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB@3oool000d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo1@3o
003o0?oooaX0oooo000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool3
000002T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?oooaL0oooo000>0?oo
o`030000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo02P0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`3o0?oooaH0oooo000?0?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0o`3ooolF0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool0o`3ooolE0?ooo`002P3oool6000000<0oooo1@0000050?ooo`030000003oool0oooo02H0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?oooa@0oooo000M0?ooo`800000
9P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0?l0oooo503oool001d0oooo00<0
00000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0oooo4`3o
ool001d0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo0?l0oooo4`3oool001d0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?ooo`0=0?oo
o`030?l0003oool0oooo0?l0oooo4P3oool001d0oooo00<000000?ooo`3oool0903oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0oooo4P3oool001d0oooo0P00000T0?ooo`030?l0
003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolA0?ooo`007@3oool00`000000oooo0?oo
o`0S0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolA0?ooo`007@3oool0
0`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolA
0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool0o`3ooolA0?ooo`007@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`3oool0o`3ooolA0?ooo`007@3oool2000002<0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`3o0?oooa00oooo000M0?ooo`030000003oool0oooo0240oooo00<0
o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`3o0?oooa00oooo000M0?ooo`030000003oool0
oooo0240oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`3o0?oooa00oooo000M0?oo
o`030000003oool0oooo0240oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`3o0?oo
o`l0oooo000M0?ooo`8000008@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0?l0
oooo3`3oool001d0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo0?l0oooo3`3oool000<0oooo100000050?ooo`8000001@3oool4000000H0oooo00<0
00000?ooo`3oool0803oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0?l0oooo3P3o
ool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool0
0`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0?l0oooo3P3oool00080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0?l0oooo3P3oool00080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo0`00000O0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool0o`3oool=0?ooo`00
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo100000060?ooo`030000
003oool0oooo01l0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`3o0?ooo`d0oooo
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?oo
o`3o0?ooo`d0oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`3o0?ooo``0oooo00030?ooo`@00000303oool5000000D0oooo00<000000?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0?l0oooo303oool001d0
oooo0P00000N0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0o`3oool<0?ooo`00
7@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0
o`3oool<0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo01/0oooo00<0
o`000?ooo`3oool0o`3oool;0?ooo`007@3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo01/0oooo00<0o`000?ooo`3oool0o`3oool;0?ooo`007@3oool00`000000oooo0?ooo`0L0?oo
o`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0o`3oool;0?ooo`007@3oool2000001d0
oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo000M0?ooo`030000
003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`3o0?ooo`X0oooo
000M0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`3o0?ooo`X0oooo000M0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`3o0?ooo`X0oooo000M0?ooo`030000003oool0oooo01/0oooo00<0o`000?oo
o`3oool07`3oool00`3o0000oooo0?ooo`3o0?ooo`T0oooo000M0?ooo`800000703oool00`3o0000
oooo0?ooo`0O0?ooo`030?l0003oool0oooo0?l0oooo2@3oool001d0oooo00<000000?ooo`3oool0
6`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo04h0oooo1@3o002e0?ooo`007@3o
ool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0C03o
ool20?l000D0oooo00<0o`000?ooo`3oool0/P3oool001d0oooo00<000000?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo04T0oooo0P3o00080?ooo`030?l0003oool0
oooo0;40oooo000M0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool08@3oool00`3o
0000oooo0?ooo`180?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0/03oool001d0
oooo0P00000K0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0A`3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0:l0oooo000M0?ooo`030000003oool0oooo01X0oooo
00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`160?ooo`030?l0003oool0oooo00d0oooo
00<0o`000?ooo`3oool0[P3oool000@0oooo0P0000040?ooo`D00000103oool4000000H0oooo00<0
00000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo04@0oooo00<0
o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`2]0?ooo`00103oool2000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0@`3o
ool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0:`0oooo000;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0
oooo02<0oooo00<0o`000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0:`0oooo000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool30000
01T0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`110?ooo`030?l0003oool0oooo
01<0oooo00<0o`000?ooo`3oool0Z`3oool000d0oooo00<000000?ooo`3oool00`3oool4000000H0
oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0400
oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`2Z0?ooo`003P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0T0?ooo`030?l0003oool0oooo0400oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo
0?ooo`2Z0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0
?`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0:T0oooo000;0?ooo`<000001@3o
ool5000000D0oooo0P00000I0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool0?@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo0:P0oooo000M0?ooo`030000003oool0
oooo01P0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0m0?ooo`030?l0003oool0
oooo01T0oooo00<0o`000?ooo`3oool0Z03oool001d0oooo00<000000?ooo`3oool0603oool00`3o
0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool06`3oool00`3o
0000oooo0?ooo`2W0?ooo`007@3oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo02H0
oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0:H0
oooo000M0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo
0?ooo`0j0?ooo`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0YP3oool001d0oooo0P00
000H0?ooo`030?l0003oool0oooo00h0oooo100000040?ooo`@000003P3oool00`3o0000oooo0?oo
o`0?0?ooo`D000000`3oool4000000@0oooo1000000G0?ooo`030?l0003oool0oooo00<0oooo1@00
00030?ooo`@00000103oool4000000L0oooo00<0o`000?ooo`3oool04@3oool5000000@0oooo1000
00040?ooo`@00000703oool5000000@0oooo100000040?ooo`@00000703oool3000000D0oooo1000
00040?ooo`@000007P3oool001d0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01L0oooo1`3o00030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool06`3oool001d0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo01D0oooo0P3o00030?ooo`040000003oool0oooo0?ooo`<0o`00
1@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool0
01d0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0180oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0A0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01<0oooo0P3o00060?ooo`030000003oool0oooo00<0oooo0P3o00030?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`007@3oool0
0`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00l0oooo100000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0180oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`@000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool04P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool010000000o`000000000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06P3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01/0oooo000M0?ooo`8000005`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?l0003o00030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`000000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool3000000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0140oooo00<0o`000?ooo`3oool01P3oool3000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3o00020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo000M0?ooo`03
0000003oool0oooo01H0oooo00<0o`000?ooo`3oool03`3oool5000000<0oooo1000000@0?ooo`03
0?l0003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool4000000@0oooo1000000C0?ooo`03
0?l0003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool5000000<0oooo1000000;0?ooo`03
0?l0003oool0oooo00h0oooo0`0000050?ooo`@00000103oool400000180oooo00<0o`000?ooo`3o
ool0203oool3000000D0oooo1@0000000`3o0000oooo0?ooo`04000001`0oooo0`0000050?ooo`@0
0000103oool4000001h0oooo000M0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0
:`3oool00`3o0000oooo0?ooo`0d0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool0
<P3oool00`3o0000oooo0?ooo`0G0?ooo`80o`00DP3oool001d0oooo00<000000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0[0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0:03o
ool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo01X0oooo0P3o001@0?ooo`007@3oool2
000001L0oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0
oooo02T0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0
oooo04d0oooo000M0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool0;03oool00`3o
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool0;P3oool00`3o
0000oooo0?ooo`0O0?ooo`80o`00C@3oool001d0oooo00<000000?ooo`3oool05P3oool00`3o0000
oooo0?ooo`0/0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`0/0?ooo`030?l0003oool0oooo0280oooo0P3o001;0?ooo`007@3oool00`000000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0<@3oool00`3o0000oooo
0?ooo`0/0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo
0?ooo`180?ooo`007@3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02h0oooo00<0
o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo02X0oooo00<0
o`000?ooo`3oool09P3oool20?l002D0oooo103o000O0?ooo`005P3ooolO000000030?l000000000
000002h0000000<0o`00000000000000;`0000000`3o000000000000000^000000030?l000000000
000002P0000000<0o`00000000000000:@0000020?l001l00000103o0004000000030?l000000000
000000D000005`3oool001d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`050000003oool0oooo0?ooo`3o0000103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00@0
o`000?ooo`3oool00000203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3oool00`000000o`000?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
0P3o00090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool40?l000T0oooo
00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo01D0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?oo
o`0B0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool06P3oool00`000000oooo0?oo
o`0A0?ooo`80o`00503oool30?l000<0oooo00<000000?ooo`3oool09@3oool001d0oooo00<00000
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo02d0oooo00<0o`00
0?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0340oooo0`3o000=
0?ooo`@0o`00;P3oool001d0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0`0?oo
o`030?l0003oool0oooo02`0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0T0?oo
o`030?l0003oool0oooo03@0oooo103o00040?ooo`D0o`00<P3oool001d0oooo0P00000E0?ooo`03
0?l0003oool0oooo0300oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`0c0?ooo`03
0?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0>03oool40?l003L0oooo000M0?ooo`030000
003oool0oooo01@0oooo00<0o`000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0[0?ooo`030?l0
003oool0oooo03D0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`1d0?ooo`007@3o
ool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0M@3o
ool001d0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0
oooo02X0oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0
oooo07D0oooo000M0?ooo`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0<P3oool00`3o
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo03P0oooo00<0o`000?ooo`3oool07@3oool00`3o
0000oooo0?ooo`1f0?ooo`007@3oool2000001@0oooo00<0o`000?ooo`3oool0<`3oool00`3o0000
oooo0?ooo`0X0?ooo`030?l0003oool0oooo03P0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`1g0?ooo`007@3oool00`000000oooo0?ooo`0C0?ooo`030?l0003oool0oooo03<0oooo
00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0i0?ooo`030?l0003oool0oooo01/0oooo
00<0o`000?ooo`3oool0M`3oool001d0oooo00<000000?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0c0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?oo
o`0I0?ooo`030?l0003oool0oooo07P0oooo000M0?ooo`030000003oool0oooo01<0oooo00<0o`00
0?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0oooo03/0oooo00<0o`00
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`1i0?ooo`007@3oool2000001@0oooo00<0o`000?oo
o`3oool0=03oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo03`0oooo00<0o`000?oo
o`3oool05`3oool00`3o0000oooo0?ooo`1i0?ooo`007@3oool00`000000oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo03D0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0l0?ooo`03
0?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0NP3oool001d0oooo00<000000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo02D0oooo00<0o`000?ooo`3oool0
?P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo07/0oooo000M0?ooo`030000003o
ool0oooo0180oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo03l0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`1l0?ooo`007@3oool0
0`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool0903oool0
0`3o0000oooo0?ooo`100?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0O@3oool0
01d0oooo0P00000C0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool08`3oool00`3o
0000oooo0?ooo`120?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0OP3oool001d0
oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo0280
oooo00<0o`000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo07l0
oooo00040?ooo`800000103oool5000000@0oooo100000060?ooo`030000003oool0oooo0140oooo
00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo04D0oooo
0P3o000;0?ooo`030?l0003oool0oooo0800oooo00040?ooo`800000103oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo04L0oooo00<0o`000?ooo`3oool01P3oool20?l008<0oooo000;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo03T0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`190?ooo`P0o`00Q@3o
ool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`<000004@3oool0
0`3o0000oooo0?ooo`0i0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0eP3oool0
00d0oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3oool0403oool00`3o
0000oooo0?ooo`0j0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0eP3oool000h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100
oooo00<0o`000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0=L0
oooo000:0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0100oooo00<0o`000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0M0?ooo`03
0?l0003oool0oooo0=L0oooo000;0?ooo`<000001@3oool5000000D0oooo00<000000?ooo`3oool0
403oool00`3o0000oooo0?ooo`0k0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0
f03oool001d0oooo0P00000A0?ooo`030?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool06`3o
ool00`3o0000oooo0?ooo`3H0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo03`0oooo00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`3I0?ooo`007@3oool00`00
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`3I0?ooo`007@3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo03h0
oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`3J0?ooo`007@3oool00`000000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo
0?ooo`3J0?ooo`007@3oool200000100oooo00<0o`000?ooo`3oool0?`3oool00`3o0000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo0=/0oooo000M0?ooo`030000003oool0oooo00l0oooo00<0o`00
0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo0=/0oooo000M0?oo
o`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0=`0oooo000M0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3o
ool0@@3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo0=d0oooo000M0?ooo`030000
003oool0oooo00h0oooo00<0o`000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0
003oool0oooo0=d0oooo000M0?ooo`8000003`3oool00`3o0000oooo0?ooo`120?ooo`030?l0003o
ool0oooo0140oooo00<0o`000?ooo`3oool0gP3oool001d0oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`130?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0gP3oool0
01d0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo
00l0oooo00<0o`000?ooo`3oool0g`3oool001d0oooo00<000000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`140?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0h03oool001d0oooo
00<000000?ooo`3oool03@3oool00`3o0000oooo0?ooo`150?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool0h@3oool001d0oooo0P00000>0?ooo`030?l0003oool0oooo04H0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`3R0?ooo`000`3oool4000000D0oooo0P000005
0?ooo`@000001P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo04L0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`3S0?ooo`000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo04T0oooo0P3o00060?oo
o`80o`00iP3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`1;0?ooo`H0
o`00j03oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo0`00000<0?ooo`030?l0003oool0oooo0?l0oooo>P3oool00080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`@000001P3oool00`000000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo0?l0oooo>P3oool00080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`3o0?ooocX0oooo00020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<0o`000?oo
o`3oool0o`3ooolk0?ooo`000`3oool4000000`0oooo1@0000050?ooo`030000003oool0oooo00/0
oooo00<0o`000?ooo`3oool0o`3ooolk0?ooo`007@3oool2000000`0oooo00<0o`000?ooo`3oool0
o`3ooolk0?ooo`007@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0oooo>`3o
ool001d0oooo00<000000?ooo`3oool02`3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo000M0?oo
o`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0o`3oooll0?ooo`007@3oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo0?l0oooo?03oool001d0oooo0P00000;0?ooo`030?l0
003oool0oooo0?l0oooo?03oool001d0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`3o0?oooc`0oooo000M0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0o`3oooll
0?ooo`007@3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0?l0oooo?@3oool001d0
oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo000M0?ooo`800000
2P3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo000M0?ooo`030000003oool0oooo00T0oooo00<0
o`000?ooo`3oool0o`3ooolm0?ooo`007@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0
oooo0?l0oooo?P3oool001d0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`3o0?oo
och0oooo000M0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0o`3oooln0?ooo`00
7@3oool2000000T0oooo00<0o`000?ooo`3oool0o`3oooln0?ooo`007@3oool00`000000oooo0?oo
o`070?ooo`030?l0003oool0oooo0?l0oooo?`3oool000@0oooo0P0000070?ooo`030000003oool0
oooo00<0oooo100000060?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool0o`3ooolo
0?ooo`00103oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?oo
ocl0oooo000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030?l0003oool0oooo0?l0oooo?`3oool000h0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`<000001P3oool00`3o0000oooo0?ooo`3o0?oood00oooo
000>0?ooo`030000003oool0oooo0080oooo100000060?ooo`030000003oool0oooo00H0oooo00<0
o`000?ooo`3oool0o`3ooom00?ooo`003`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<0
00000?ooo`3oool01P3oool00`3o0000oooo0?ooo`3o0?oood00oooo000:0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00H0oooo00<0
o`000?ooo`3oool0o`3ooom00?ooo`002P3oool6000000<0oooo1@0000050?ooo`030000003oool0
oooo00D0oooo00<0o`000?ooo`3oool0o`3ooom10?ooo`007@3oool2000000H0oooo00<0o`000?oo
o`3oool0o`3ooom10?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0
oooo@@3oool001d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oood40oooo
000M0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0o`3ooom20?ooo`007@3oool2
000000D0oooo00<0o`000?ooo`3oool0o`3ooom20?ooo`007@3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo0?l0oooo@P3oool001d0oooo00<000000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`3o0?oood<0oooo000M0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0
o`3ooom30?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo@`3o
ool001d0oooo0P0000030?ooo`030?l0003oool0oooo0?l0ooooA03oool001d0oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`3o0?oood@0oooo000M0?ooo`050000003oool0oooo0?oo
o`3o0000o`3ooom70?ooo`007@3oool01@000000oooo0?ooo`3oool0o`000?l0ooooA`3oool001d0
oooo00@000000?ooo`3oool0o`00o`3ooom80?ooo`007@3oool2000000030?ooo`3o0000oooo0?l0
ooooA`3oool001d0oooo00<000000?ooo`3o0000o`3ooom90?ooo`004`3oool5000000D0oooo00<0
00000?ooo`3o0000o`3ooom90?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003o0000
oooo0?l0ooooB@3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
odT0oooo000E0?ooo`030000003oool0oooo00D0oooo0`00003o0?ooodT0oooo000E0?ooo`030000
003oool0oooo0?l0ooooD@3oool001D0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`004`3oool3
00000?l0ooooD`3oool001D0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00E03oool4000001@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo0`0000050?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02P3oool0
05P0oooo00<000000?ooo`3oool04@3oool2000001T0oooo0P0000170?ooo`030000003oool0oooo
00/0oooo0P00000A0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`800000C@3oool20000
00/0oooo0002000000<0oooo0`0000040?ooo`@00000103oool4000000@0oooo100000030?ooo`D0
00000`3oool5000000@0oooo1@0000030?ooo`D000000`3oool5000000<0oooo0`0000000`3oool0
0000000000020?ooo`<0000000@0oooo0000003oool0oooo1@0000040?ooo`<0000000<0oooo0000
000000001P0000000`3oool000000?ooo`050?ooo`D000000P3oool5000000@0oooo00<000000?oo
o`3oool01`3oool3000000<0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`D000001@3oool3
000000@0oooo100000040?ooo`D000000`3oool4000000<0oooo1@0000000`3oool000000?ooo`04
0?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`@00000103oool00`000000oooo0?ooo`08
0?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0`000000
103oool000000000000000020?ooo`D000000`3oool5000000@0oooo0P0000050?ooo`D00000103o
ool3000000@0oooo1@0000030?ooo`@00000103oool3000000030?ooo`000000000000P0oooo0P00
000000050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0
000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool2000000T0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool2000000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000@0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0`0000090?oo
o`40000000001@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0@00
000000050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool0103oool6000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000001`3oool500000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool4000000<0oooo00@00000
0?ooo`3oool0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool00000
0080oooo1P0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool6
000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo1@00000:0?ooo`40000000001@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`8000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`8000001P3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000D0oooo00000000
0000oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool4000000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo1@0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`40000000000`000000oooo0?ooo`05000000@0
oooo100000040?ooo`<0000000<0oooo0000003oool00P3oool4000000<0oooo0P000000103oool0
00000000000000020?ooo`80000000@0oooo00000000000000000`3oool4000000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`@00000103oool3000000040?ooo`000000
00000?ooo`80000000@0oooo00000000000000000`3oool400000080oooo0P0000001@3oool00000
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`@000001P3oool00`000000oooo0?ooo`03
0?ooo`@000000`3oool2000000030?ooo`000000000000800000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000H0oooo00@000000?ooo`3oool0oooo
0`0000020?ooo`<000000P3oool4000000<0oooo1@0000040?ooo`<000001@3oool3000000030?oo
o`000000oooo0080oooo1000000;0?ooo`40000000040?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`<00000103oool01@000000oooo0?oo
o`3oool0000000l0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo02@0oooo0@00000003d0oooo0P0000060?ooo`800000<`3oool00`000000oooo0?oo
o`030?ooo`<000003`3oool5000000D0oooo100000020?ooo`D000001@3oool4000000`0oooo0P00
000B0?ooo`<000000`3oool400000100oooo1000000?0?ooo`@000000`3oool300000100oooo0`00
0000103oool0000000000000000;0?ooo`8000007`3oool00`000000oooo0?ooo`0I0?ooo`800000
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.729, -1.0579, 1.2899, \
0.0128654}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00649351 0.00649351 0.00466734 0.000417857 [
[.12338 -0.00783 -6 -9 ]
[.12338 -0.00783 6 0 ]
[.25325 -0.00783 -6 -9 ]
[.25325 -0.00783 6 0 ]
[.38312 -0.00783 -6 -9 ]
[.38312 -0.00783 6 0 ]
[.51299 -0.00783 -6 -9 ]
[.51299 -0.00783 6 0 ]
[.64286 -0.00783 -9 -9 ]
[.64286 -0.00783 9 0 ]
[.77273 -0.00783 -9 -9 ]
[.77273 -0.00783 9 0 ]
[.9026 -0.00783 -9 -9 ]
[.9026 -0.00783 9 0 ]
[-0.01899 .08824 -18 -4.5 ]
[-0.01899 .08824 0 4.5 ]
[-0.01899 .17181 -18 -4.5 ]
[-0.01899 .17181 0 4.5 ]
[-0.01899 .25538 -18 -4.5 ]
[-0.01899 .25538 0 4.5 ]
[-0.01899 .33895 -18 -4.5 ]
[-0.01899 .33895 0 4.5 ]
[-0.01899 .42252 -24 -4.5 ]
[-0.01899 .42252 0 4.5 ]
[.5 .5125 -186.688 0 ]
[.5 .5125 186.688 14 ]
[ -0.00649 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12338 .00467 m
.12338 .01092 L
s
[(20)] .12338 -0.00783 0 1 Mshowa
.25325 .00467 m
.25325 .01092 L
s
[(40)] .25325 -0.00783 0 1 Mshowa
.38312 .00467 m
.38312 .01092 L
s
[(60)] .38312 -0.00783 0 1 Mshowa
.51299 .00467 m
.51299 .01092 L
s
[(80)] .51299 -0.00783 0 1 Mshowa
.64286 .00467 m
.64286 .01092 L
s
[(100)] .64286 -0.00783 0 1 Mshowa
.77273 .00467 m
.77273 .01092 L
s
[(120)] .77273 -0.00783 0 1 Mshowa
.9026 .00467 m
.9026 .01092 L
s
[(140)] .9026 -0.00783 0 1 Mshowa
.125 Mabswid
.02597 .00467 m
.02597 .00842 L
s
.05844 .00467 m
.05844 .00842 L
s
.09091 .00467 m
.09091 .00842 L
s
.15584 .00467 m
.15584 .00842 L
s
.18831 .00467 m
.18831 .00842 L
s
.22078 .00467 m
.22078 .00842 L
s
.28571 .00467 m
.28571 .00842 L
s
.31818 .00467 m
.31818 .00842 L
s
.35065 .00467 m
.35065 .00842 L
s
.41558 .00467 m
.41558 .00842 L
s
.44805 .00467 m
.44805 .00842 L
s
.48052 .00467 m
.48052 .00842 L
s
.54545 .00467 m
.54545 .00842 L
s
.57792 .00467 m
.57792 .00842 L
s
.61039 .00467 m
.61039 .00842 L
s
.67532 .00467 m
.67532 .00842 L
s
.70779 .00467 m
.70779 .00842 L
s
.74026 .00467 m
.74026 .00842 L
s
.80519 .00467 m
.80519 .00842 L
s
.83766 .00467 m
.83766 .00842 L
s
.87013 .00467 m
.87013 .00842 L
s
.93506 .00467 m
.93506 .00842 L
s
.96753 .00467 m
.96753 .00842 L
s
.25 Mabswid
0 .00467 m
1 .00467 L
s
-0.00649 .08824 m
-0.00024 .08824 L
s
[(200)] -0.01899 .08824 1 0 Mshowa
-0.00649 .17181 m
-0.00024 .17181 L
s
[(400)] -0.01899 .17181 1 0 Mshowa
-0.00649 .25538 m
-0.00024 .25538 L
s
[(600)] -0.01899 .25538 1 0 Mshowa
-0.00649 .33895 m
-0.00024 .33895 L
s
[(800)] -0.01899 .33895 1 0 Mshowa
-0.00649 .42252 m
-0.00024 .42252 L
s
[(1000)] -0.01899 .42252 1 0 Mshowa
.125 Mabswid
-0.00649 .02556 m
-0.00274 .02556 L
s
-0.00649 .04645 m
-0.00274 .04645 L
s
-0.00649 .06735 m
-0.00274 .06735 L
s
-0.00649 .10913 m
-0.00274 .10913 L
s
-0.00649 .13002 m
-0.00274 .13002 L
s
-0.00649 .15092 m
-0.00274 .15092 L
s
-0.00649 .1927 m
-0.00274 .1927 L
s
-0.00649 .2136 m
-0.00274 .2136 L
s
-0.00649 .23449 m
-0.00274 .23449 L
s
-0.00649 .27627 m
-0.00274 .27627 L
s
-0.00649 .29717 m
-0.00274 .29717 L
s
-0.00649 .31806 m
-0.00274 .31806 L
s
-0.00649 .35985 m
-0.00274 .35985 L
s
-0.00649 .38074 m
-0.00274 .38074 L
s
-0.00649 .40163 m
-0.00274 .40163 L
s
-0.00649 .44342 m
-0.00274 .44342 L
s
-0.00649 .46431 m
-0.00274 .46431 L
s
-0.00649 .4852 m
-0.00274 .4852 L
s
.25 Mabswid
-0.00649 0 m
-0.00649 .5 L
s
gsave
.5 .5125 -247.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Fourier) show
129.000 14.000 moveto
(Coefficients) show
201.000 14.000 moveto
0.000 0.000 rmoveto
201.000 14.000 moveto
(,) show
210.563 14.000 moveto
(12) show
222.563 14.000 moveto
(,) show
232.125 14.000 moveto
(RGBColor) show
280.125 14.000 moveto
([) show
286.125 14.000 moveto
(0) show
292.125 14.000 moveto
(,) show
301.688 14.000 moveto
(0) show
307.688 14.000 moveto
(,) show
317.250 14.000 moveto
(0) show
323.250 14.000 moveto
(]) show
329.250 14.000 moveto
(,) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(Helvetica) show
392.813 14.000 moveto
0.000 0.000 rmoveto
392.813 14.000 moveto
(,) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(Bold) show
426.375 14.000 moveto
0.000 0.000 rmoveto
426.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 .502 r
.5 Mabswid
0 .21882 m
.00649 .02652 L
.01299 .15323 L
.01948 .4881 L
.02597 .1442 L
.03247 .09847 L
.03896 .07011 L
.04545 .05048 L
.05195 .03839 L
.05844 .04986 L
.06494 .02765 L
.07143 .04778 L
.07792 .02098 L
.08442 .01857 L
.09091 .0157 L
.0974 .023 L
.1039 .01417 L
.11039 .02259 L
.11688 .01503 L
.12338 .02015 L
.12987 .0119 L
.13636 .02277 L
.14286 .01503 L
.14935 .01822 L
.15584 .01565 L
.16234 .01593 L
.16883 .0151 L
.17532 .01628 L
.18182 .01418 L
.18831 .01593 L
.19481 .01386 L
.2013 .0153 L
.20779 .0138 L
.21429 .01414 L
.22078 .0136 L
.22727 .01427 L
.23377 .01327 L
.24026 .01377 L
.24675 .01344 L
.25325 .01381 L
.25974 .01355 L
.26623 .0136 L
.27273 .01326 L
.27922 .01315 L
.28571 .01326 L
.29221 .01379 L
.2987 .01299 L
.30519 .01302 L
.31169 .01283 L
.31818 .01285 L
Mistroke
.32468 .01314 L
.33117 .01273 L
.33766 .01284 L
.34416 .01257 L
.35065 .01266 L
.35714 .01278 L
.36364 .01263 L
.37013 .01269 L
.37662 .01256 L
.38312 .01251 L
.38961 .01267 L
.3961 .01246 L
.4026 .0127 L
.40909 .01245 L
.41558 .01257 L
.42208 .01238 L
.42857 .01254 L
.43506 .0124 L
.44156 .01252 L
.44805 .01234 L
.45455 .01236 L
.46104 .01229 L
.46753 .01238 L
.47403 .01232 L
.48052 .01236 L
.48701 .01229 L
.49351 .01231 L
.5 .01226 L
.50649 .01232 L
.51299 .01225 L
.51948 .01233 L
.52597 .01228 L
.53247 .01224 L
.53896 .0123 L
.54545 .01221 L
.55195 .01225 L
.55844 .01222 L
.56494 .01223 L
.57143 .01226 L
.57792 .01215 L
.58442 .01223 L
.59091 .01221 L
.5974 .0122 L
.6039 .01215 L
.61039 .01212 L
.61688 .01215 L
.62338 .01217 L
.62987 .01216 L
.63636 .01215 L
.64286 .0121 L
Mistroke
.64935 .01216 L
.65584 .01216 L
.66234 .01215 L
.66883 .01212 L
.67532 .0121 L
.68182 .01213 L
.68831 .01213 L
.69481 .01216 L
.7013 .01207 L
.70779 .01208 L
.71429 .01204 L
.72078 .01209 L
.72727 .01207 L
.73377 .0121 L
.74026 .01204 L
.74675 .01203 L
.75325 .01206 L
.75974 .01203 L
.76623 .01205 L
.77273 .01203 L
.77922 .01203 L
.78571 .01205 L
.79221 .01206 L
.7987 .01207 L
.80519 .01208 L
.81169 .01202 L
.81818 .01205 L
.82468 .01203 L
.83117 .01206 L
.83766 .01203 L
.84416 .01201 L
.85065 .01202 L
.85714 .01204 L
.86364 .01203 L
.87013 .01203 L
.87662 .01202 L
.88312 .01207 L
.88961 .01202 L
.8961 .01199 L
.9026 .01198 L
.90909 .01198 L
.91558 .01204 L
.92208 .01196 L
.92857 .012 L
.93506 .01195 L
.94156 .01202 L
.94805 .01208 L
.95455 .01204 L
.96104 .01203 L
.96753 .01197 L
Mistroke
.97403 .01198 L
.98052 .01206 L
.98701 .01204 L
.99351 .01198 L
1 .01196 L
Mfstroke
1 .01196 m
1 .01196 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003oo`3ooomY
0?ooo`00?`3oool5000000@0oooo1000000L0?ooo`<000000`3oool4000001X0oooo0`0000040?oo
o`@000006P3oool4000000@0oooo1000000E0?ooo`D000000`3oool4000000@0oooo1000000B0?oo
o`D000000P3oool5000000@0oooo1000000A0?ooo`D000001@3oool3000000<0oooo1000000g0?oo
o`00?`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0F
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0=03oool00400oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0=03oool00440oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo1P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool05P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03@0oooo00120?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0=03oool004<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01L0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0
oooo000o0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0180oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`<00000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`<000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=03o
ool00400oooo0`0000050?ooo`@00000703oool2000000@0oooo1000000K0?ooo`<000000`3oool4
000001X0oooo100000040?ooo`@000005`3oool00`000000oooo0?ooo`030?ooo`@00000103oool4
000001@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo1000000C0?ooo`030000003oool0
oooo00D0oooo0P0000040?ooo`@00000=`3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0oooo
J@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?oo
o`008@3oool00`000000oooo0000003o000002400000903oool00240oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:`3oool00240oooo00<000000?ooo`3oool08P3oool00`000000oooo0000P00S0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00h0oooo1@0008030?ooo`030000P03oool0oooo04`00020903oool00240oooo00<00000
0?ooo`3oool07@3oool010000800oooo0?ooo`0008020?ooo`8000200`3oool00`000800oooo0?oo
o`040?ooo`050000P03oool0oooo0?ooo`0008000`3ooonB0000P0D0oooo0`0008000`3oool00020
0000P01`0?ooo`008@3oool00`000000oooo0?ooo`0G0?ooo`<000200P3oool20000P00;0?ooo`00
0800oooo0000P03oool000200?ooo`000800oooo0000P03oool01P0008001@3oool000200000P000
0800oooo00<00020o`3oool>0?ooo`008@3oool00`000000oooo0?ooo`0E0?ooo`8000200`3oool0
10000800oooo0000P03oool20000P080oooo00H000200?ooo`3oool000200?ooo`00083o0?oooad0
oooo000Q0?ooo`8000005P3oool00`000800oooo0?ooo`030?ooo`040000P03oool0oooo0000P0L0
oooo00<000200?ooo`3oool0o`3ooolL0?ooo`008@3oool010000000oooo0?ooo`00080@0?ooo`04
0000P03oool0oooo0000P?l0oooo<03oool00240oooo00@000000?ooo`3oool00020403oool01000
0800oooo0?ooo`00083o0?oooc00oooo000Q0?ooo`040000003oool0oooo0000P0l0oooo00D00020
0?ooo`000800oooo0000P03o0?oooc00oooo000Q0?ooo`040000003oool0oooo0000P0d0oooo00L0
00200?ooo`000800oooo0000P03oool000200?l0oooo<03oool00240oooo00@000000?ooo`3oool0
0020303oool20000P0030?ooo`000800oooo00800020o`3ooola0?ooo`008@3oool2000000030?oo
o`000800oooo00/0oooo00<000200?ooo`0008000`3oool00`000800oooo0?ooo`3o0?ooobl0oooo
000Q0?ooo`040000003oool0oooo0000P0/0oooo00@000200?ooo`3oool000200`3oool00`000800
oooo0?ooo`3o0?ooobl0oooo000Q0?ooo`040000003oool0oooo0000P0/0oooo00<000200?ooo`3o
ool0o`3ooolf0?ooo`008@3oool010000000oooo0?ooo`00080;0?ooo`030000P03oool0oooo0?l0
oooo=P3oool00240oooo00@000000?ooo`3oool000202P3oool00`000800oooo0?ooo`3o0?ooocL0
oooo000Q0?ooo`030000003oool0oooo008000202@3oool00`000800oooo0?ooo`3o0?ooocL0oooo
000Q0?ooo`80000000<0oooo0000P0000800203oool00`000800oooo0?ooo`3o0?ooocP0oooo000Q
0?ooo`030000003oool0oooo00800020203oool00`000800oooo0?ooo`3o0?ooocP0oooo000Q0?oo
o`030000003oool0oooo00800020203oool00`000800oooo0?ooo`3o0?ooocP0oooo00060?ooo`D0
0000103oool4000000@0oooo100000060?ooo`030000003oool0oooo008000201`3oool00`000800
oooo0?ooo`3o0?ooocT0oooo00060?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020000P0L0oooo00<000200?ooo`3oool0o`3oooli0?ooo`001`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000201`3oool00`000800oooo0?ooo`3o0?oo
ocT0oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0`0000020000P0L0oooo00<000200?oo
o`3oool0o`3oooli0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
008000201P3oool00`000800oooo0?ooo`3o0?ooocX0oooo000:0?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P0008060?ooo`030000P03oool0oooo0?l0oooo>P3oool000H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000201P3oool00`000800oooo0?oo
o`3o0?ooocX0oooo00070?ooo`<000001@3oool4000000@0oooo100000060?ooo`030000003oool0
oooo008000201P3oool00`000800oooo0?ooo`3o0?ooocX0oooo000Q0?ooo`030000003oool0oooo
008000201P3oool00`000800oooo0?ooo`3o0?ooocX0oooo000Q0?ooo`030000003oool0oooo0080
00201P3oool00`000800oooo0?ooo`3o0?ooocX0oooo000Q0?ooo`80000000<0oooo0000P0000800
1@3oool00`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003oool0oooo008000201@3o
ool00`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003oool0oooo008000201@3oool0
0`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003oool0oooo008000201@3oool00`00
0800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003oool000200080oooo00<000200?ooo`3o
ool00P3oool00`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003oool000200080oooo
00<000200?ooo`3oool00P3oool00`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`80000000@0
00200?ooo`3oool00020103oool00`000800oooo0?ooo`3o0?oooc/0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`80000000@0
00200?ooo`3oool000200`3oool00`000800oooo0?ooo`3o0?oooc`0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo000Q0?ooo`030000003o
ool000200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo00090?ooo`<000000`3o
ool4000000@0oooo100000060?ooo`030000003oool000200080oooo00D000200?ooo`3oool0oooo
0000P03o0?oooch0oooo000:0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0008000P3oool01@000800
oooo0?ooo`3oool000200?l0oooo?P3oool000X0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000P002
0?ooo`050000P03oool0oooo0?ooo`000800o`3oooln0?ooo`001P3oool600000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P00
000010000800oooo0?ooo`0008030?ooo`030000P03oool0oooo0?l0oooo?03oool000L0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0000P0020?ooo`050000P03oool0oooo0?oo
o`000800o`3oooln0?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
00200080oooo00D000200?ooo`3oool0oooo0000P03o0?oooch0oooo00080?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0008000P3oool01@000800oooo0?ooo`3oool000200?l0oooo
?P3oool000T0oooo0P0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo0P00000010000800oooo0?oo
o`0008030?ooo`030000P03oool0oooo0?l0oooo?03oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo0P00000010000800oooo0?oo
o`0008030?ooo`030000P03oool0oooo0?l0oooo?03oool00240oooo00<000000?ooo`0008000P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`3oool00P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`3oool00P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`3oool00P3o
ool01@000800oooo0?ooo`3oool000200?l0oooo?P3oool00240oooo00<000000?ooo`3oool00P3o
ool010000800oooo0?ooo`00083o0?ooocl0oooo000Q0?ooo`8000000`3oool010000800oooo0?oo
o`00083o0?ooocl0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3o
oolo0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool0
00P0oooo0`0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool00`3oool00`00
0800oooo0000P03o0?ooocl0oooo00070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool000L0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3o
oolo0?ooo`001`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`030000
P03oool000200?l0oooo?`3oool000L0oooo100000030?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000200?ooo`000800o`3ooolo0?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`00203oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`002@3o
ool3000000<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`030000P03o
ool000200?l0oooo?`3oool00240oooo00<000000?ooo`3oool00`3oool00`000800oooo0000P03o
0?ooocl0oooo000Q0?ooo`800000103oool00`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`03
0000003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`008@3oool00`000000oooo
0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool00240oooo00<000000?ooo`3oool00`3o
ool00`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<00020
0?ooo`000800o`3ooolo0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000P03oool00020
0?l0oooo?`3oool00240oooo0P0000040?ooo`030000P03oool000200?l0oooo?`3oool00240oooo
00<000000?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`030000003o
ool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`008@3oool00`000000oooo0?ooo`03
0?ooo`030000P03oool000200?l0oooo?`3oool00240oooo00<000000?ooo`3oool00`3oool00`00
0800oooo0000P03o0?ooocl0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000200?ooo`00
0800o`3ooolo0?ooo`008@3oool2000000@0oooo00<000200?ooo`000800o`3ooolo0?ooo`008@3o
ool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool00240oooo00<00000
0?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocl0oooo00070?ooo`@00000103oool40000
00@0oooo100000060?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?oo
o`001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00020
0?ooo`000800o`3ooolo0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`001P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`<000000`3oool00`000800oooo0000P03o0?ooocl0oooo00070?ooo`@000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool000H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0
oooo?`3oool000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000P03oool000200?l0oooo?`3oool000L0oooo100000040?ooo`@00000103oool4000000H0
oooo00<000000?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`030000
003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`008@3oool2000000@0oooo00<0
00200?ooo`000800o`3ooolo0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000P03oool0
00200?l0oooo?`3oool00240oooo00<000000?ooo`3oool00`3oool00`000800oooo0000P03o0?oo
ocl0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`00
8@3oool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool00240oooo00<0
00000?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`800000103oool0
0`000800oooo0000P03o0?ooocl0oooo000Q0?ooo`030000003oool0oooo00<0oooo00<000200?oo
o`000800o`3ooolo0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000P03oool000200?l0
oooo?`3oool00240oooo00<000000?ooo`3oool00`3oool00`000800oooo0000P03o0?ooocl0oooo
000Q0?ooo`030000003oool0oooo00<0oooo00<000200?ooo`000800o`3ooolo0?ooo`008@3oool0
0`000000oooo0?ooo`030?ooo`030000P03oool000200?l0oooo?`3oool00240oooo0P0000040?oo
o`030000P03oool000200?l0oooo?`3oool00240oooo00<000000?ooo`3oool0103oool00`000800
oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000200?ooo`3oool0
o`3oooln0?ooo`00100000030?ooo`@00000103oool4000000@0oooo100000060?ooo`030000003o
ool0oooo00@0oooo00<000200?ooo`3oool0o`3oooln0?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000200?ooo`3oool0
o`3oooln0?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000200?ooo`3oool0o`3oooln0?ooo`0000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000800oooo0?ooo`3o0?oo
och0oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000800oooo0?ooo`3o0?oooch0oooo00000`3oool000000?ooo`030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000800oooo0?oo
o`3o0?oooch0oooo0002000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000P03oool0oooo0?l0oooo?P3oool000030?ooo`000000oooo00@0oooo1000
00040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool0103oool00`000800oooo0?oo
o`3o0?oooch0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000200?ooo`3oool0o`3oooln
0?ooo`008@3oool2000000D0oooo00<000200?ooo`3oool0o`3oooln0?ooo`008@3oool00`000000
oooo0?ooo`040?ooo`030000P03oool0oooo0?l0oooo?P3oool00240oooo00<000000?ooo`3oool0
103oool00`000800oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<0
00200?ooo`3oool0o`3oooln0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000P03oool0
oooo0?l0oooo?P3oool00240oooo00<000000?ooo`3oool0103oool00`000800oooo0?ooo`3o0?oo
och0oooo000Q0?ooo`8000001@3oool00`000800oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000
003oool0oooo00@0oooo00<000200?ooo`3oool0o`3oooln0?ooo`008@3oool00`000000oooo0?oo
o`040?ooo`030000P03oool0oooo0?l0oooo?P3oool00240oooo00<000000?ooo`3oool0103oool0
0`000800oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000003oool0oooo00@0oooo00<000200?oo
o`3oool0o`3oooln0?ooo`008@3oool00`000000oooo0?ooo`040?ooo`030000P03oool0oooo0?l0
oooo?P3oool00240oooo0P0000050?ooo`030000P03oool0oooo0?l0oooo?P3oool00240oooo00<0
00000?ooo`3oool0103oool00`000800oooo0?ooo`3o0?oooch0oooo000Q0?ooo`030000003oool0
oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?ooo`008@3oool00`000000
oooo0?ooo`3o0?ooodD0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo001k0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0AP3oool3000000/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000oooo0?ooo`1:0?ooo`00N`3oool20000
01T0oooo0P0000170?ooo`030000003oool0oooo00/0oooo0P00000A0?ooo`8000004`3oool00`00
0000oooo0?ooo`030?ooo`800000B`3oool000030000003oool0oooo0080oooo1@0000030?ooo`D0
00000P3oool5000000T0oooo0`0000040?ooo`@00000103oool500000080oooo1P0000020?ooo`H0
00000`3oool5000000<0oooo100000040?ooo`D000000`3oool500000080oooo0`000000103oool0
00000000000000030?ooo`<000000`3oool5000000X0oooo1@0000020?ooo`D00000103oool00`00
0000oooo0?ooo`070?ooo`<000000`3oool010000000oooo0?ooo`3oool3000000<0oooo1@000005
0?ooo`<00000103oool4000000@0oooo1@0000030?ooo`@000000`3oool5000000030?ooo`000000
oooo00@0oooo100000050?ooo`030000003oool0oooo00P0oooo100000040?ooo`030000003oool0
oooo00P0oooo100000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool3
000000040?ooo`000000000000000080oooo1@0000030?ooo`D00000103oool2000000D0oooo1@00
00040?ooo`<00000103oool5000000<0oooo100000040?ooo`40000000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000002`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`000000103oool2000000T0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool2000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000040oooo00070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`001`3oool00`000000oooo0?oo
o`020?ooo`H000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`06000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`H000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01@3oool4000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0?0?ooo`@000000`3oool010000000oooo0?ooo`3oool300000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`050000003oool0oooo0?ooo`0000000P3oool6000000D0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000030?ooo`H000000`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool1000000001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00H0oooo100000030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`4000000@3oool0008000000`3oool3
000000D0oooo100000030?ooo`80000000@0oooo00000000000000001P3oool00`000000oooo0?oo
o`060?ooo`@00000103oool4000000<0oooo1P0000020?ooo`H000000`3oool3000000D0oooo0`00
00000`3oool000000?ooo`020?ooo`<000001@3oool4000000<0oooo0P0000000`3oool000000000
00030?ooo`D00000103oool5000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`@000001P3oool00`000000
oooo0?ooo`030?ooo`@000000`3oool2000000030?ooo`000000000000800000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000H0oooo00@000000?oo
o`3oool0oooo0`0000020?ooo`<000000P3oool4000000<0oooo1@0000040?ooo`<000001@3oool3
000000030?ooo`000000oooo0080oooo0@0000000240oooo00D000000?ooo`3oool0oooo0000000D
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C
0?ooo`<00000103oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01H0oooo00070?ooo`030000003oool0
oooo01P0oooo1000000E0?ooo`<000001@3oool3000000D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo0`00000?0?ooo`D000001@3oool4
00000080oooo1@0000050?ooo`@00000303oool200000180oooo0`0000030?ooo`@00000403oool4
000000l0oooo100000030?ooo`<00000403oool3000000040?ooo`0000000000000000/0oooo0P00
000O0?ooo`030000003oool0oooo00`0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-17.7313, -123.153, 0.666652, \
10.3598}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.212946 0.00118944 [
[.17532 .20045 -6 -9 ]
[.17532 .20045 6 0 ]
[.32993 .20045 -9 -9 ]
[.32993 .20045 9 0 ]
[.48454 .20045 -9 -9 ]
[.48454 .20045 9 0 ]
[.63915 .20045 -9 -9 ]
[.63915 .20045 9 0 ]
[.79375 .20045 -9 -9 ]
[.79375 .20045 9 0 ]
[.94836 .20045 -9 -9 ]
[.94836 .20045 9 0 ]
[.00822 .094 -24 -4.5 ]
[.00822 .094 0 4.5 ]
[.00822 .33189 -18 -4.5 ]
[.00822 .33189 0 4.5 ]
[.00822 .45084 -18 -4.5 ]
[.00822 .45084 0 4.5 ]
[.5 .5125 -234.688 0 ]
[.5 .5125 234.688 14 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .21295 m
.17532 .2192 L
s
[(50)] .17532 .20045 0 1 Mshowa
.32993 .21295 m
.32993 .2192 L
s
[(100)] .32993 .20045 0 1 Mshowa
.48454 .21295 m
.48454 .2192 L
s
[(150)] .48454 .20045 0 1 Mshowa
.63915 .21295 m
.63915 .2192 L
s
[(200)] .63915 .20045 0 1 Mshowa
.79375 .21295 m
.79375 .2192 L
s
[(250)] .79375 .20045 0 1 Mshowa
.94836 .21295 m
.94836 .2192 L
s
[(300)] .94836 .20045 0 1 Mshowa
.125 Mabswid
.05164 .21295 m
.05164 .2167 L
s
.08256 .21295 m
.08256 .2167 L
s
.11348 .21295 m
.11348 .2167 L
s
.1444 .21295 m
.1444 .2167 L
s
.20625 .21295 m
.20625 .2167 L
s
.23717 .21295 m
.23717 .2167 L
s
.26809 .21295 m
.26809 .2167 L
s
.29901 .21295 m
.29901 .2167 L
s
.36085 .21295 m
.36085 .2167 L
s
.39177 .21295 m
.39177 .2167 L
s
.4227 .21295 m
.4227 .2167 L
s
.45362 .21295 m
.45362 .2167 L
s
.51546 .21295 m
.51546 .2167 L
s
.54638 .21295 m
.54638 .2167 L
s
.5773 .21295 m
.5773 .2167 L
s
.60823 .21295 m
.60823 .2167 L
s
.67007 .21295 m
.67007 .2167 L
s
.70099 .21295 m
.70099 .2167 L
s
.73191 .21295 m
.73191 .2167 L
s
.76283 .21295 m
.76283 .2167 L
s
.82468 .21295 m
.82468 .2167 L
s
.8556 .21295 m
.8556 .2167 L
s
.88652 .21295 m
.88652 .2167 L
s
.91744 .21295 m
.91744 .2167 L
s
.97928 .21295 m
.97928 .2167 L
s
.25 Mabswid
0 .21295 m
1 .21295 L
s
.02072 .094 m
.02697 .094 L
s
[(-100)] .00822 .094 1 0 Mshowa
.02072 .33189 m
.02697 .33189 L
s
[(100)] .00822 .33189 1 0 Mshowa
.02072 .45084 m
.02697 .45084 L
s
[(200)] .00822 .45084 1 0 Mshowa
.125 Mabswid
.02072 .11779 m
.02447 .11779 L
s
.02072 .14158 m
.02447 .14158 L
s
.02072 .16537 m
.02447 .16537 L
s
.02072 .18916 m
.02447 .18916 L
s
.02072 .23674 m
.02447 .23674 L
s
.02072 .26052 m
.02447 .26052 L
s
.02072 .28431 m
.02447 .28431 L
s
.02072 .3081 m
.02447 .3081 L
s
.02072 .35568 m
.02447 .35568 L
s
.02072 .37947 m
.02447 .37947 L
s
.02072 .40326 m
.02447 .40326 L
s
.02072 .42705 m
.02447 .42705 L
s
.02072 .07021 m
.02447 .07021 L
s
.02072 .04642 m
.02447 .04642 L
s
.02072 .02264 m
.02447 .02264 L
s
.02072 .47462 m
.02447 .47462 L
s
.02072 .49841 m
.02447 .49841 L
s
.25 Mabswid
.02072 0 m
.02072 .5 L
s
gsave
.5 .5125 -295.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Originial) show
141.000 14.000 moveto
(Series) show
183.000 14.000 moveto
(vs) show
195.000 14.000 moveto
(.) show
207.000 14.000 moveto
(Inverse) show
255.000 14.000 moveto
(Fourier) show
297.000 14.000 moveto
0.000 0.000 rmoveto
297.000 14.000 moveto
(,) show
306.563 14.000 moveto
(12) show
318.563 14.000 moveto
(,) show
328.125 14.000 moveto
(RGBColor) show
376.125 14.000 moveto
([) show
382.125 14.000 moveto
(0) show
388.125 14.000 moveto
(,) show
397.688 14.000 moveto
(0) show
403.688 14.000 moveto
(,) show
413.250 14.000 moveto
(0) show
419.250 14.000 moveto
(]) show
425.250 14.000 moveto
(,) show
434.813 14.000 moveto
0.000 0.000 rmoveto
434.813 14.000 moveto
(Helvetica) show
488.813 14.000 moveto
0.000 0.000 rmoveto
488.813 14.000 moveto
(,) show
498.375 14.000 moveto
0.000 0.000 rmoveto
498.375 14.000 moveto
(Bold) show
522.375 14.000 moveto
0.000 0.000 rmoveto
522.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
1 0 0 r
.001 w
.02381 .47872 m
.0269 .21202 L
.02999 .20902 L
.03309 .20639 L
.03618 .20289 L
.03927 .19962 L
.04236 .19697 L
.04545 .1943 L
.04855 .19138 L
.05164 .18849 L
.05473 .18533 L
.05782 .18178 L
.06092 .17877 L
.06401 .1754 L
.0671 .17245 L
.07019 .16914 L
.07328 .16392 L
.07638 .15901 L
.07947 .1546 L
.08256 .15149 L
.08565 .14966 L
.08874 .1494 L
.09184 .14996 L
.09493 .15259 L
.09802 .15585 L
.10111 .16093 L
.10421 .1662 L
.1073 .17269 L
.11039 .17907 L
.11348 .1857 L
.11657 .19249 L
.11967 .19893 L
.12276 .20524 L
.12585 .21136 L
.12894 .21771 L
.13203 .22403 L
.13513 .23019 L
.13822 .23635 L
.14131 .24269 L
.1444 .24874 L
.1475 .25479 L
.15059 .26092 L
.15368 .26725 L
.15677 .27404 L
.15986 .28113 L
.16296 .28856 L
.16605 .2964 L
.16914 .3043 L
.17223 .31228 L
.17532 .32048 L
Mistroke
.17842 .32856 L
.18151 .33671 L
.1846 .34508 L
.18769 .35345 L
.19079 .36114 L
.19388 .3692 L
.19697 .37655 L
.20006 .38437 L
.20315 .3916 L
.20625 .39852 L
.20934 .40402 L
.21243 .40908 L
.21552 .41123 L
.21861 .41187 L
.22171 .40938 L
.2248 .4042 L
.22789 .39749 L
.23098 .39044 L
.23408 .38247 L
.23717 .37322 L
.24026 .36347 L
.24335 .35305 L
.24644 .34187 L
.24954 .3301 L
.25263 .31789 L
.25572 .30511 L
.25881 .29178 L
.2619 .27786 L
.265 .26322 L
.26809 .24843 L
.27118 .23356 L
.27427 .21871 L
.27737 .20382 L
.28046 .189 L
.28355 .1744 L
.28664 .15975 L
.28973 .14536 L
.29283 .13127 L
.29592 .11769 L
.29901 .10422 L
.3021 .09119 L
.30519 .07883 L
.30829 .06766 L
.31138 .0581 L
.31447 .05108 L
.31756 .04636 L
.32066 .04373 L
.32375 .04202 L
.32684 .04035 L
.32993 .03881 L
Mistroke
.33302 .03875 L
.33612 .04085 L
.33921 .04528 L
.3423 .05159 L
.34539 .05969 L
.34848 .06884 L
.35158 .07873 L
.35467 .08899 L
.35776 .09966 L
.36085 .1104 L
.36395 .12103 L
.36704 .13156 L
.37013 .14227 L
.37322 .15283 L
.37631 .16329 L
.37941 .1737 L
.3825 .18403 L
.38559 .19435 L
.38868 .20466 L
.39177 .21502 L
.39487 .2254 L
.39796 .23578 L
.40105 .24617 L
.40414 .25678 L
.40724 .26776 L
.41033 .27914 L
.41342 .29065 L
.41651 .30206 L
.4196 .3136 L
.4227 .32552 L
.42579 .33801 L
.42888 .35027 L
.43197 .36196 L
.43506 .37308 L
.43816 .38297 L
.44125 .39169 L
.44434 .39971 L
.44743 .40613 L
.45053 .41236 L
.45362 .41821 L
.45671 .42435 L
.4598 .43086 L
.46289 .43783 L
.46599 .44468 L
.46908 .45261 L
.47217 .46088 L
.47526 .46887 L
.47835 .47633 L
.48145 .48255 L
.48454 .48709 L
Mistroke
.48763 .4881 L
.49072 .48348 L
.49382 .47404 L
.49691 .46208 L
.5 .44907 L
.50309 .43563 L
.50618 .42217 L
.50928 .40944 L
.51237 .39766 L
.51546 .38668 L
.51855 .37626 L
.52165 .36593 L
.52474 .35569 L
.52783 .34526 L
.53092 .33533 L
.53401 .32448 L
.53711 .31335 L
.5402 .30193 L
.54329 .29034 L
.54638 .2785 L
.54947 .26645 L
.55257 .25421 L
.55566 .24188 L
.55875 .22948 L
.56184 .21705 L
.56494 .20485 L
.56803 .19263 L
.57112 .18185 L
.57421 .17208 L
.5773 .16226 L
.5804 .15114 L
.58349 .13894 L
.58658 .12682 L
.58967 .11441 L
.59276 .10343 L
.59586 .09299 L
.59895 .08381 L
.60204 .07477 L
.60513 .06833 L
.60823 .06523 L
.61132 .06442 L
.61441 .06499 L
.6175 .06633 L
.62059 .06772 L
.62369 .06905 L
.62678 .07044 L
.62987 .07217 L
.63296 .07423 L
.63605 .0763 L
.63915 .07899 L
Mistroke
.64224 .08182 L
.64533 .08533 L
.64842 .08897 L
.65152 .09294 L
.65461 .09715 L
.6577 .10167 L
.66079 .10568 L
.66388 .10932 L
.66698 .11222 L
.67007 .11422 L
.67316 .11451 L
.67625 .11315 L
.67934 .11128 L
.68244 .11089 L
.68553 .11223 L
.68862 .11539 L
.69171 .12076 L
.69481 .12782 L
.6979 .13622 L
.70099 .14574 L
.70408 .15584 L
.70717 .16619 L
.71027 .17664 L
.71336 .18734 L
.71645 .1981 L
.71954 .20886 L
.72263 .21957 L
.72573 .23019 L
.72882 .24004 L
.73191 .24947 L
.735 .25825 L
.7381 .26672 L
.74119 .27465 L
.74428 .28223 L
.74737 .29004 L
.75046 .29799 L
.75356 .30599 L
.75665 .31428 L
.75974 .32294 L
.76283 .33251 L
.76592 .34183 L
.76902 .35095 L
.77211 .35937 L
.7752 .36706 L
.77829 .37362 L
.78139 .37938 L
.78448 .38515 L
.78757 .39092 L
.79066 .39696 L
.79375 .40235 L
Mistroke
.79685 .40734 L
.79994 .41277 L
.80303 .41872 L
.80612 .42439 L
.80921 .42939 L
.81231 .43095 L
.8154 .43021 L
.81849 .42775 L
.82158 .42499 L
.82468 .42115 L
.82777 .41648 L
.83086 .41111 L
.83395 .40574 L
.83704 .40071 L
.84014 .39633 L
.84323 .39289 L
.84632 .39053 L
.84941 .38893 L
.8525 .38771 L
.8556 .38602 L
.85869 .38411 L
.86178 .38227 L
.86487 .38023 L
.86797 .37813 L
.87106 .37611 L
.87415 .37412 L
.87724 .37154 L
.88033 .36812 L
.88343 .36333 L
.88652 .35729 L
.88961 .34959 L
.8927 .34036 L
.89579 .3294 L
.89889 .31714 L
.90198 .30421 L
.90507 .29066 L
.90816 .27675 L
.91126 .26259 L
.91435 .24816 L
.91744 .23359 L
.92053 .21895 L
.92362 .20432 L
.92672 .18988 L
.92981 .1759 L
.9329 .16253 L
.93599 .15007 L
.93908 .13792 L
.94218 .12619 L
.94527 .11445 L
.94836 .10281 L
Mistroke
.95145 .09123 L
.95455 .07984 L
.95764 .06869 L
.96073 .05741 L
.96382 .04662 L
.96691 .03658 L
.97001 .02719 L
.9731 .01868 L
.97619 .0119 L
Mfstroke
0 0 1 r
.02381 .09182 m
.0269 .09017 L
.02999 .0891 L
.03309 .08862 L
.03618 .08872 L
.03927 .08939 L
.04236 .09063 L
.04545 .09243 L
.04855 .09478 L
.05164 .09766 L
.05473 .10107 L
.05782 .10499 L
.06092 .10939 L
.06401 .11426 L
.0671 .11958 L
.07019 .12532 L
.07328 .13146 L
.07638 .13797 L
.07947 .14483 L
.08256 .15201 L
.08565 .15947 L
.08874 .16719 L
.09184 .17513 L
.09493 .18326 L
.09802 .19156 L
.10111 .19998 L
.10421 .2085 L
.1073 .21707 L
.11039 .22568 L
.11348 .23427 L
.11657 .24282 L
.11967 .2513 L
.12276 .25967 L
.12585 .2679 L
.12894 .27596 L
.13203 .28382 L
.13513 .29145 L
.13822 .29881 L
.14131 .30589 L
.1444 .31265 L
.1475 .31907 L
.15059 .32512 L
.15368 .3308 L
.15677 .33606 L
.15986 .3409 L
.16296 .34529 L
.16605 .34923 L
.16914 .35269 L
.17223 .35567 L
.17532 .35816 L
Mistroke
.17842 .36014 L
.18151 .36162 L
.1846 .36259 L
.18769 .36305 L
.19079 .36299 L
.19388 .36243 L
.19697 .36136 L
.20006 .35979 L
.20315 .35774 L
.20625 .3552 L
.20934 .3522 L
.21243 .34875 L
.21552 .34486 L
.21861 .34055 L
.22171 .33584 L
.2248 .33075 L
.22789 .32531 L
.23098 .31953 L
.23408 .31345 L
.23717 .30708 L
.24026 .30046 L
.24335 .29362 L
.24644 .28658 L
.24954 .27937 L
.25263 .27203 L
.25572 .26459 L
.25881 .25707 L
.2619 .24952 L
.265 .24195 L
.26809 .23441 L
.27118 .22693 L
.27427 .21953 L
.27737 .21225 L
.28046 .20513 L
.28355 .19818 L
.28664 .19145 L
.28973 .18495 L
.29283 .17872 L
.29592 .17279 L
.29901 .16718 L
.3021 .16191 L
.30519 .15701 L
.30829 .1525 L
.31138 .14839 L
.31447 .14472 L
.31756 .14149 L
.32066 .13872 L
.32375 .13642 L
.32684 .13461 L
.32993 .13329 L
Mistroke
.33302 .13248 L
.33612 .13217 L
.33921 .13237 L
.3423 .13308 L
.34539 .1343 L
.34848 .13604 L
.35158 .13827 L
.35467 .14101 L
.35776 .14423 L
.36085 .14793 L
.36395 .1521 L
.36704 .15672 L
.37013 .16177 L
.37322 .16724 L
.37631 .17311 L
.37941 .17935 L
.3825 .18594 L
.38559 .19286 L
.38868 .20009 L
.39177 .20759 L
.39487 .21533 L
.39796 .22329 L
.40105 .23144 L
.40414 .23975 L
.40724 .24818 L
.41033 .2567 L
.41342 .26527 L
.41651 .27388 L
.4196 .28247 L
.4227 .29102 L
.42579 .29949 L
.42888 .30786 L
.43197 .31608 L
.43506 .32412 L
.43816 .33195 L
.44125 .33955 L
.44434 .34687 L
.44743 .35389 L
.45053 .36058 L
.45362 .36691 L
.45671 .37285 L
.4598 .37838 L
.46289 .38348 L
.46599 .38812 L
.46908 .39228 L
.47217 .39595 L
.47526 .3991 L
.47835 .40172 L
.48145 .40379 L
.48454 .40531 L
Mistroke
.48763 .40627 L
.49072 .40665 L
.49382 .40646 L
.49691 .40569 L
.5 .40433 L
.50309 .40239 L
.50618 .39988 L
.50928 .39679 L
.51237 .39314 L
.51546 .38893 L
.51855 .38418 L
.52165 .3789 L
.52474 .3731 L
.52783 .36681 L
.53092 .36004 L
.53401 .35282 L
.53711 .34516 L
.5402 .3371 L
.54329 .32865 L
.54638 .31986 L
.54947 .31074 L
.55257 .30132 L
.55566 .29165 L
.55875 .28175 L
.56184 .27165 L
.56494 .2614 L
.56803 .25102 L
.57112 .24055 L
.57421 .23003 L
.5773 .21949 L
.5804 .20898 L
.58349 .19853 L
.58658 .18817 L
.58967 .17795 L
.59276 .16789 L
.59586 .15804 L
.59895 .14843 L
.60204 .13909 L
.60513 .13006 L
.60823 .12138 L
.61132 .11306 L
.61441 .10515 L
.6175 .09767 L
.62059 .09065 L
.62369 .08411 L
.62678 .07809 L
.62987 .0726 L
.63296 .06766 L
.63605 .06329 L
.63915 .05951 L
Mistroke
.64224 .05634 L
.64533 .05378 L
.64842 .05186 L
.65152 .05056 L
.65461 .04991 L
.6577 .04991 L
.66079 .05055 L
.66388 .05185 L
.66698 .05378 L
.67007 .05636 L
.67316 .05957 L
.67625 .06341 L
.67934 .06785 L
.68244 .0729 L
.68553 .07852 L
.68862 .08471 L
.69171 .09144 L
.69481 .0987 L
.6979 .10645 L
.70099 .11468 L
.70408 .12336 L
.70717 .13245 L
.71027 .14192 L
.71336 .15175 L
.71645 .16191 L
.71954 .17235 L
.72263 .18305 L
.72573 .19396 L
.72882 .20505 L
.73191 .21629 L
.735 .22764 L
.7381 .23905 L
.74119 .25049 L
.74428 .26192 L
.74737 .2733 L
.75046 .28459 L
.75356 .29576 L
.75665 .30677 L
.75974 .31758 L
.76283 .32815 L
.76592 .33846 L
.76902 .34845 L
.77211 .35811 L
.7752 .3674 L
.77829 .37629 L
.78139 .38474 L
.78448 .39273 L
.78757 .40024 L
.79066 .40724 L
.79375 .4137 L
Mistroke
.79685 .41961 L
.79994 .42495 L
.80303 .4297 L
.80612 .43384 L
.80921 .43736 L
.81231 .44026 L
.8154 .44252 L
.81849 .44413 L
.82158 .4451 L
.82468 .44542 L
.82777 .44509 L
.83086 .44412 L
.83395 .44251 L
.83704 .44027 L
.84014 .4374 L
.84323 .43392 L
.84632 .42985 L
.84941 .42519 L
.8525 .41997 L
.8556 .41421 L
.85869 .40793 L
.86178 .40115 L
.86487 .3939 L
.86797 .3862 L
.87106 .37808 L
.87415 .36958 L
.87724 .36071 L
.88033 .35153 L
.88343 .34205 L
.88652 .33231 L
.88961 .32236 L
.8927 .31221 L
.89579 .30191 L
.89889 .2915 L
.90198 .28102 L
.90507 .27049 L
.90816 .25996 L
.91126 .24946 L
.91435 .23903 L
.91744 .22871 L
.92053 .21853 L
.92362 .20852 L
.92672 .19873 L
.92981 .18918 L
.9329 .17991 L
.93599 .17095 L
.93908 .16233 L
.94218 .15407 L
.94527 .14621 L
.94836 .13877 L
Mistroke
.95145 .13177 L
.95455 .12523 L
.95764 .11919 L
.96073 .11365 L
.96382 .10863 L
.96691 .10415 L
.97001 .10022 L
.9731 .09685 L
.97619 .09404 L
Mfstroke
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003o703oool0
0`000000oooo0?ooo`3o0?ooodX0oooo000L0?ooo`030000003oool0oooo0?l0ooooBP3oool001`0
oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00703oool00`000000oooo0?ooo`3o0?ooodX0oooo
000L0?ooo`030000003oool0oooo0?l0oooo:`3oool00`3o0000oooo0?ooo`0L0?ooo`00703oool0
0`000000oooo0?ooo`3o0?ooobX0oooo00<0o`000?ooo`3oool07@3oool001`0oooo00<000000?oo
o`3oool0o`3ooolZ0?ooo`030?l0003oool0oooo01d0oooo000L0?ooo`030000003oool0oooo0?l0
oooo:P3oool00`3o0000oooo0?ooo`0M0?ooo`00703oool200000?l0oooo:P3oool00`3o0000oooo
0?ooo`0N0?ooo`00703oool00`000000oooo0?ooo`3o0?ooobT0oooo00<0o`000?ooo`3oool07P3o
ool001`0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`030?l0003oool0oooo01h0oooo000L0?oo
o`030000003oool0oooo0?l0oooo:03oool00`3o0000oooo0?ooo`0O0?ooo`00703oool00`000000
oooo0?ooo`3o0?ooobP0oooo00<0o`000?ooo`3oool07`3oool001`0oooo00<000000?ooo`3oool0
G@3oool40?l00<H0oooo00<0o`000?ooo`3oool07`3oool001`0oooo00<000000?ooo`3oool0F`3o
ool20?l000<0oooo00<0o`000?ooo`3oool0``3oool00`3o0000oooo0?ooo`0P0?ooo`00703oool2
000005`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`320?ooo`030?l0003oool0
oooo0200oooo000L0?ooo`030000003oool0oooo05X0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`1P0?ooo`@0003oGP3oool00`3o0000oooo0?ooo`0P0?ooo`00703oool00`000000
oooo0?ooo`1J0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0G@3oool20000o`@0
oooo0P000?mK0?ooo`030?l0003oool0oooo0240oooo000L0?ooo`030000003oool0oooo05T0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`1L0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool0F03oool00`3o0000oooo0?ooo`0Q0?ooo`00703oool00`000000oooo0?oo
o`1I0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0FP3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo05L0oooo00<0o`000?ooo`3oool08@3oool001`0oooo00<00000
0?ooo`3oool0F@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo05T0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003oool0oooo0240oooo000L0?oo
o`030000003oool0oooo05P0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`1?0?oo
o`@0o`00103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo05D0oooo00<0o`000?oo
o`3oool08P3oool001`0oooo00<000000?ooo`3oool0F03oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo04h0oooo00<0o`000?ooo`3oool00P3oool20?l00080oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1D0?ooo`030?l0003oool0oooo0280oooo000L0?ooo`800000
F@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo04d0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000003o0?ooo`0>0?ooo`030000o`3oool0oooo05@0oooo00<0o`000?ooo`3oool0
8P3oool001`0oooo00<000000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo04`0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?l0000>0?ooo`030000o`3o
ool0oooo05<0oooo00<0o`000?ooo`3oool08`3oool001`0oooo00<000000?ooo`3oool0E`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo04`0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?l000d0oooo00<0003o0?ooo`3oool0DP3oool00`3o0000oooo0?ooo`0S
0?ooo`00703oool00`000000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool0B`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`1B0?ooo`030?l0003oool0oooo02<0oooo00020?ooo`D0
00000`3oool4000000@0oooo100000060?ooo`030000003oool0oooo05H0oooo00<0o`000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`1;0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0540oooo00<0o`000?ooo`3o
ool08`3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20000
oe<0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0500oooo00<0o`000?ooo`3oool0903oool000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01000
0000003o0000o`000?l20?ooo`80003oD@3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo04T0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`0T0?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`<000001@3oool20000odl0oooo00<0o`000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`190?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo04l0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0L0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<0003o0?ooo`3oool0B`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo04P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0C@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo01d0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`1:0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0A`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`1=0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool07P3oool0
0080oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0BP3oool0
0`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0C@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo01l0oooo00040?ooo`030000003oool0oooo
00<0oooo100000040?ooo`@000001P3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
04T0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`160?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
04`0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0P0?ooo`00703oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo04P0oooo00<0o`000?ooo`3oool0403oool00`3o0000
oooo0?ooo`150?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0B`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0200oooo000L0?ooo`030000003oool0oooo00X0oooo
00<0003o0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo04D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?ooo`80o`0000@0oooo0?l0003o0000
o`00103oool00`000?l0oooo0?ooo`1:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool08@3oool001`0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`160?ooo`030?l0
003oool0oooo0140oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0140oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo04X0
oooo00D0o`000?ooo`3oool0oooo0000o`0T0?ooo`00703oool2000000d0oooo00<0003o0?ooo`3o
ool0A@3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0F0?ooo`050?l0003oool0oooo0?ooo`000?l0C03oool01@3o
0000oooo0?ooo`3oool0003o02@0oooo000L0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool0A@3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`000?l0BP3oool0
1@3o0000oooo0?ooo`3oool0003o02D0oooo000L0?ooo`030000003oool0oooo00d0oooo00<0003o
0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo04<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`000?l0BP3o
ool01@3o0000oooo0?ooo`3oool0003o02D0oooo000L0?ooo`030000003oool0oooo00d0oooo00<0
003o0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0480oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0I0?ooo`050?l0003oool0oooo0?ooo`000?l0
B@3oool0103o0000oooo0?ooo`000?lV0?ooo`00703oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo0480oooo00<0o`000?ooo`3oool02@3oool40000o`L0oooo00<0o`000?ooo`3oool0
@@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo01T0oooo00D0o`000?ooo`3oool0
oooo0000o`180?ooo`050?l0003oool0oooo0?ooo`000?l09P3oool001`0oooo00<000000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`120?ooo`030?l0003oool0oooo00H0oooo0`000?l40?ooo`80
003o1@3oool00`3o0000oooo0?ooo`110?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool06`3oool0103o0000oooo0?ooo`000?m80?ooo`040?l0003oool0oooo0000obL0oooo000L0?oo
o`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool0@03oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`100?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0
003o04L0oooo00@0o`000?ooo`3oool0003o9`3oool001`0oooo0P00000@0?ooo`030000o`3oool0
oooo0400oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool0@03oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo01`0oooo00@0o`000?ooo`3oool0003oA`3oool0103o0000oooo0?ooo`000?lW0?ooo`00703o
ool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0400oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo0?ooo`3o0000@@3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo01d0oooo00@0o`000?ooo`3oool0003oAP3oool0103o0000
oooo0?ooo`000?lX0?ooo`00703oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0400
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l0
0440oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0M0?ooo`050?l0003oool0oooo
0?ooo`000?l0A@3oool0103o0000oooo0?ooo`000?lX0?ooo`00703oool00`000000oooo0?ooo`0@
0?ooo`040000o`3o0000o`000?l003h0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0>0?ooo`040000o`3oool0oooo0?l00400oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0M0?ooo`050?l0003oool0oooo0?ooo`000?l0A@3oool00`3o0000oooo0000o`0Y0?ooo`00
703oool00`000000oooo0?ooo`0?0?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool0
>P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo00@0003o0?ooo`3oool0
o`00@03oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01l0oooo00@0o`000?ooo`3o
ool0003oA@3oool00`3o0000oooo0000o`0Y0?ooo`00703oool00`000000oooo0?ooo`0?0?ooo`03
0?l0003oool0003o00<0oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0100oooo00<0003o0?ooo`3o0000?`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo01l0oooo00@0o`000?ooo`3oool0003oA03oool0103o0000oooo0?ooo`000?lY
0?ooo`00703oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0003o00@0oooo00<0o`000?oo
o`3oool0>03oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00<0003o0?oo
o`3o0000?P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo01l0oooo00D0o`000?oo
o`3oool0oooo0000o`130?ooo`030?l0003oool0003o02X0oooo000L0?ooo`030000003oool0oooo
00h0oooo00@0o`000?ooo`3oool0003o103oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?l0000n0?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool08@3oool0103o0000oooo0?ooo`000?m30?ooo`030?l0003o
ool0003o02X0oooo000L0?ooo`8000003P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool03P3oool4000000@0oooo1000000L0?ooo`060?l0003oool0
oooo0?ooo`000000003o0`0000030?ooo`@00000103oool4000000@0oooo00<0003o0?l0003oool0
5P3oool5000000<0oooo100000040?ooo`@000004`3oool00`3o0000oooo0?ooo`020?ooo`040000
o`3oool0oooo0?ooo`D00000103oool4000000@0oooo1000000;0?ooo`040?l0003oool0oooo0000
o`d0oooo1@0000040?ooo`@00000103oool4000001`0oooo0`0000020?ooo`030?l000000?l0oooo
00@00000103oool4000001h0oooo000L0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01T0oooo00L0o`000?oo
o`3oool0oooo0000o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`070000003oool0oooo0?ooo`000?l0oooo0?l0000H0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00l0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0203oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0H0?ooo`090000003oool0oooo0?ooo`000000o`000?ooo`000?l0000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0A0?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06@3oool01`3o0000oooo0?ooo`3o
ool0003o0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000?l0o`000?ooo`0G0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`040?l0003oool0
oooo0000o`d0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01`0oooo00D000000?l0003oool0003o000000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool04@3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01T0oooo00@0o`000?ooo`3oool0003o0P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`020?ooo`030000o`3o0000oooo01L0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00@0o`000?ooo`3o
ool0003o3P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0703oool01@000000o`000000o`3oool0000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0<0?ooo`@000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00@0o`000?ooo`3oool0003o
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000o`3o0000oooo01H0oooo00<000000?ooo`3o
ool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?oo
o`050?l0003oool0oooo0?ooo`000?l03P3oool00`000000oooo0?ooo`030?ooo`@000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo0P0000001@3oool0o`000000o`3o
ool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`00703o
ool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0H0?ooo`040?l0003oool0oooo0000o`<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000?l0o`000?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0000
o`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01`0oooo00D0o`000?ooo`000?l0oooo000000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
603oool01@3o0000oooo0?ooo`000?l0oooo00<00000103oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?oo
o`<000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000o`/0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0H0?ooo`060000003oool0oooo0?ooo`3o0000003o0P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool001`0oooo0P000008
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;
0?ooo`D000000`3oool4000001/0oooo00<0o`000?ooo`000?l0103oool00`000000oooo0?ooo`03
0?ooo`@00000103oool4000000L0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`03
0?ooo`D000000`3oool400000100oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`<000001@3oool4000000@0oooo1000000=0?ooo`040?l0003oool0oooo0000o``0oooo0`00
00050?ooo`D000000`3oool4000001`0oooo0`0000000`3o0000003o0?ooo`020?ooo`@00000103o
ool4000001h0oooo000L0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`000?l07P3oool0
0`000?l0oooo0?ooo`0f0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool09@3oool0
1@3o0000oooo0?ooo`3oool0003o03h0oooo00<0o`000000o`3oool0;03oool001`0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0<@3oool00`3o0000003o0?ooo`0N0?ooo`030000o`3oool0oooo03H0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0W0?ooo`040?l0003oool0oooo0000och0oooo00<0
003o0?ooo`3oool0;03oool001`0oooo00<000000?ooo`3oool00`3oool20?l00140oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0_0?ooo`030?l0003oool0003o01l0oooo00<0o`00
0000o`3oool0=@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo02L0oooo00@0o`00
0?ooo`3oool0003o?@3oool00`3o0000003o0?ooo`0]0?ooo`00703oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0_
0?ooo`030?l000000?l0oooo0200oooo00<0003o0?ooo`3oool0=03oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo02L0oooo00D0o`000?ooo`3oool0oooo0000o`0l0?ooo`030?l00000
0?l0oooo02d0oooo000L0?ooo`050000003oool0oooo0?ooo`3o0000503oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo02h0oooo00<0o`000000o`3oool0803oool00`000?l0oooo0?oo
o`0d0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0:@3oool0103o0000oooo0?oo
o`000?ll0?ooo`030000o`3oool0oooo02d0oooo000L0?ooo`030000003oool0oooo0080o`005@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3oool0803o
ool00`3o0000003o0?ooo`0d0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0:@3o
ool0103o0000oooo0?ooo`000?ll0?ooo`030000o`3oool0oooo02d0oooo000L0?ooo`030000003o
ool0o`0001L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0/0?ooo`030?l00000
0?l0oooo0280oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo02T0oooo00@0o`000?ooo`3oool0003o?03oool00`000?l0oooo0?ooo`0]0?ooo`005@3o
ool9000000030?l000000000000001H0000000<0003o0000000000000`0000000`3o000000000000
000/000000030?l000000?l000000280000000<0o`000000o`000000<P0000000`3o000000000000
0002000000030000o`000000000002X0000000D0o`0000000000000000000000o`0k000000030000
o`000000000001L000005P3oool001`0oooo00<000000?ooo`3o00001`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`000000103oool00`3o0000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000?l01`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`3o0000003o0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`000?l90?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000003o0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3o0000
603oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0
703oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`000?l0
6P3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
4@3oool00`000000oooo0?ooo`0G0?ooo`040?l0003oool0oooo0000oa<0oooo00<000000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo000L0?ooo`030000
003oool0o`0001T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0Y0?ooo`030000
o`3o0000oooo02@0oooo00<0o`000000o`3oool0<@3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo02/0oooo00D0o`000?ooo`3oool0oooo0000o`0i0?ooo`030000o`3o0000oooo02h0
oooo000L0?ooo`030000003oool0o`0001T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`0Y0?ooo`030000o`3oool0oooo02@0oooo00<0o`000000o`3oool0<@3oool01@3o0000oooo
0?ooo`3oool0003o02l0oooo00@0o`000?ooo`3oool0003o>@3oool00`000?l0oooo0?ooo`0^0?oo
o`00703oool00`000000oooo0?l0000I0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool09`3oool00`000?l0o`000?ooo`0U0?ooo`030?l0003oool0003o0340oooo00D0o`000?ooo`3o
ool0oooo0000o`0_0?ooo`040?l0003oool0oooo0000ocT0oooo00<0003o0?ooo`3oool0;P3oool0
01`0oooo00<000000?ooo`3o00006P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
02L0oooo00<0003o0?l0003oool09P3oool00`3o0000003o0?ooo`0`0?ooo`050?l0003oool0oooo
0?ooo`000?l0;`3oool0103o0000oooo0?ooo`000?li0?ooo`030000o`3oool0oooo02h0oooo000L
0?ooo`80000000<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo02H0oooo00<0003o0?l0003oool09P3oool00`3o0000oooo0000o`0_0?ooo`050?l0003oool0
oooo0?ooo`000?l0<@3oool0103o0000oooo0?ooo`000?lg0?ooo`030000o`3o0000oooo02l0oooo
000L0?ooo`030000003oool0o`0001/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`0U0?ooo`030000o`3oool0o`0002L0oooo00<0o`000?ooo`000?l0;`3oool01@3o0000oooo0?oo
o`3oool0003o0340oooo00@0o`000?ooo`3oool0003o=`3oool00`000?l0o`000?ooo`0_0?ooo`00
703oool00`000000oooo0?l0000K0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
903oool00`000?l0o`000?ooo`0X0?ooo`030?l000000?l0oooo02h0oooo00D0o`000?ooo`3oool0
oooo0000o`0a0?ooo`040?l0003oool0oooo0000ocL0oooo00<0003o0?ooo`3oool0;`3oool001`0
oooo00<000000?ooo`3o00006`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo02<0
oooo00<0003o0?ooo`3o0000:@3oool00`3o0000oooo0000o`0^0?ooo`040?l0003oool0oooo0000
oc<0oooo00@0o`000?ooo`3oool0003o=@3oool00`000?l0o`000?ooo`0`0?ooo`00703oool00`00
0000oooo0?l0000L0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?l0000Y0?ooo`030?l0003oool0003o02d0oooo00D0o`000?ooo`3oool0oooo0000o`0c
0?ooo`040?l0003oool0oooo0000ocD0oooo00<0003o0?l0003oool0<03oool001`0oooo00<00000
0?ooo`3o0000703oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0280oooo00<0003o
0?ooo`3o0000:P3oool00`3o0000003o0?ooo`0/0?ooo`050?l0003oool0oooo0?ooo`000?l0<`3o
ool0103o0000oooo0?ooo`000?le0?ooo`030000o`3o0000oooo0300oooo000L0?ooo`030000003o
ool0o`0001`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3o
ool0o`0002/0oooo00<0o`000?ooo`000?l0;03oool01@3o0000oooo0?ooo`3oool0003o03@0oooo
00<0o`000?ooo`000?l0=03oool00`000?l0o`000?ooo`0a0?ooo`00703oool00`000000oooo0?l0
000M0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?l0
000[0?ooo`030?l0003oool0003o02`0oooo00@0o`000?ooo`3oool0003o=@3oool0103o0000oooo
0?ooo`000?lc0?ooo`030000o`3o0000oooo0340oooo000L0?ooo`80000000<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo01h0oooo00@0003o0?ooo`3oool0
o`00:`3oool0103o0000oooo0?ooo`000?lZ0?ooo`050?l0003oool0oooo0?ooo`000?l0=@3oool0
103o0000oooo0?ooo`000?lc0?ooo`030000o`3o0000oooo0340oooo000L0?ooo`030000003oool0
o`0001h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0N0?ooo`040000o`3oool0
oooo0?l002`0oooo00<0o`000?ooo`000?l0:P3oool01@3o0000oooo0?ooo`3oool0003o03H0oooo
00<0o`000?ooo`000?l0<P3oool00`000?l0oooo0?l0000b0?ooo`00703oool00`000000oooo0?l0
000N0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0703oool01@000?l0oooo0?oo
o`3oool0o`0002`0oooo00<0o`000?ooo`000?l0:P3oool0103o0000oooo0?ooo`000?lg0?ooo`03
0?l0003oool0003o0380oooo00<0003o0?ooo`3o0000<P3oool001`0oooo00<000000?ooo`3o0000
7P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo01`0oooo00@0003o0?ooo`3oool0
o`00;@3oool0103o0000oooo0?ooo`000?lX0?ooo`050?l0003oool0oooo0?ooo`000?l0=`3oool0
103o0000oooo0?ooo`000?la0?ooo`030000o`3o0000oooo0380oooo000L0?ooo`030000003oool0
o`0001l0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0K0?ooo`040000o`3oool0
oooo0?l002h0oooo00<0o`000?ooo`000?l0:03oool01@3o0000oooo0?ooo`3oool0003o03P0oooo
00<0o`000?ooo`000?l0<@3oool00`000?l0o`000?ooo`0b0?ooo`00703oool00`000000oooo0?l0
000O0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool06P3oool01@000?l0oooo0?oo
o`3oool0o`0002h0oooo00<0o`000?ooo`000?l0:03oool01@3o0000oooo0?ooo`3oool0003o03P0
oooo00<0o`000?ooo`000?l0<03oool00`000?l0oooo0?l0000c0?ooo`00703oool00`000000oooo
0?l0000P0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool06@3oool01@000?l0oooo
0?ooo`3oool0o`0002h0oooo00@0o`000?ooo`3oool0003o9`3oool01@3o0000oooo0?ooo`3oool0
003o03T0oooo00<0o`000?ooo`000?l0;`3oool00`000?l0oooo0?l0000c0?ooo`00703oool20000
00030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0H0?oo
o`050000o`3oool0oooo0?ooo`3o0000;`3oool0103o0000oooo0?ooo`000?lV0?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0=`3oool00`3o0000oooo0000o`0_0?ooo`030000o`3o
0000oooo03<0oooo000L0?ooo`030000003oool0o`000200oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0G0?ooo`050000o`3oool0oooo0?ooo`3o0000<03oool00`3o0000oooo0000
o`0V0?ooo`050?l0003oool0oooo0?ooo`000?l0>`3oool00`3o0000003o0?ooo`0]0?ooo`030000
o`3oool0o`0003@0oooo000L0?ooo`030000003oool0o`000240oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0;P3o
ool0103o0000oooo0?ooo`000?lU0?ooo`050?l0003oool0oooo0?ooo`000?l0>`3oool00`3o0000
003o0?ooo`0]0?ooo`030000o`3oool0o`0003@0oooo000L0?ooo`030000003oool0o`000240oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool0;P3oool0103o0000oooo0?ooo`000?lU0?ooo`050?l0003oool0oooo0?oo
o`000?l0>`3oool00`3o0000oooo0000o`0]0?ooo`030000o`3oool0o`0003@0oooo000L0?ooo`03
0000003oool0o`000280oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool01@3o0000oooo0?ooo`3oool0003o
02<0oooo00D0o`000?ooo`3oool0oooo0000o`0m0?ooo`030?l000000?l0oooo02/0oooo00<0003o
0?ooo`3o0000=@3oool001`0oooo00<000000?ooo`3o00008P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0`0?oo
o`040?l0003oool0oooo0000ob<0oooo00D0o`000?ooo`3oool0oooo0000o`0m0?ooo`030?l00000
0?l0oooo02/0oooo00<0003o0?ooo`3o0000=@3oool001`0oooo00<000000?ooo`3o00008P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0`0?ooo`040?l0003oool0oooo0000ob<0oooo00D0o`000?ooo`3oool0oooo
0000o`0n0?ooo`030?l000000?l0oooo02X0oooo00<0003o0?ooo`3o0000=@3oool001`0oooo00<0
00000?ooo`3o00008`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0`0?ooo`050?l0003oool0oooo0?ooo`000?l0
8P3oool0103o0000oooo0?ooo`000?lo0?ooo`030?l000000?l0oooo02X0oooo00<0003o0?ooo`3o
0000=@3oool001`0oooo0P0000000`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0340oooo
00@0o`000?ooo`3oool0003o8@3oool01@3o0000oooo0?ooo`3oool0003o03l0oooo00<0o`000000
o`3oool0:@3oool00`000?l0oooo0?l0000f0?ooo`00703oool00`000000oooo0?l0000T0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0380oooo00@0o`000?ooo`3oool0003o8@3oool01@3o0000oooo0?ooo`3oool0
003o0400oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?l0000f0?ooo`00703oool00`00
0000oooo0?l0000T0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0380oooo00D0o`000?ooo`3oool0oooo0000o`0P
0?ooo`040?l0003oool0oooo0000od40oooo00<0o`000000o`3oool0:03oool00`000?l0oooo0?l0
000f0?ooo`00703oool00`000000oooo0?l0000U0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0380oooo00D0o`00
0?ooo`3oool0oooo0000o`0O0?ooo`050?l0003oool0oooo0?ooo`000?l0@@3oool00`3o0000003o
0?ooo`0W0?ooo`040000o`3oool0oooo0?l003H0oooo00020?ooo`D000000`3oool4000000@0oooo
100000060?ooo`030000003oool0o`0002D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0<`3oool01@3o0000oooo
0?ooo`3oool0003o01h0oooo00D0o`000?ooo`3oool0oooo0000o`120?ooo`030000o`3oool0oooo
02H0oooo00<0003o0?ooo`3o0000=`3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?l0000V0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo03@0oooo00D0o`000?ooo`3oool0oooo0000o`0N
0?ooo`040?l0003oool0oooo0000od<0oooo00<0o`000000o`3oool09P3oool00`000?l0oooo0?l0
000g0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0o`0002H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0=03oool01@3o0000oooo0?ooo`3oool0003o01h0oooo00@0o`000?ooo`3oool0
003oA03oool00`000?l0oooo0?ooo`0T0?ooo`040000o`3oool0oooo0?l003L0oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo0P0000000`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
03@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0J0?ooo`050?l0003oool0oooo
0?ooo`000?l0A03oool00`000?l0oooo0?ooo`0T0?ooo`040000o`3oool0oooo0?l003L0oooo0004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o0000:03oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0e0?ooo`050?l0003oool0oooo0?ooo`000?l0703oool0103o0000oooo0?ooo`000?m50?ooo`03
0?l000000?l0oooo02@0oooo00<0003o0?ooo`3o0000>03oool000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?l0000X0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo03H0oooo00D0o`000?ooo`3o
ool0oooo0000o`0L0?ooo`040?l0003oool0oooo0000odH0oooo00<0003o0?ooo`3oool08P3oool0
10000?l0oooo0?ooo`3o000h0?ooo`000P3oool3000000@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o0000:@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0f0?ooo`050?l0003oool0oooo0?ooo`000?l06`3oool0103o0000oooo
0?ooo`000?m70?ooo`030000o`3oool0oooo0280oooo00@0003o0?ooo`3oool0o`00>03oool000@0
oooo00<000000?ooo`3oool00`3oool4000000@0oooo100000060?ooo`030000003o0000oooo02X0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01P0
oooo00@0o`000?ooo`3oool0003oA`3oool00`3o0000003o0?ooo`0R0?ooo`040000o`3oool0oooo
0?l003P0oooo000L0?ooo`030000003o0000oooo02X0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0>03oool01@3o
0000oooo0?ooo`3oool0003o01X0oooo00@0o`000?ooo`3oool0003oB03oool00`000?l0oooo0?oo
o`0P0?ooo`040000o`3oool0oooo0?l003T0oooo000L0?ooo`030000003o0000oooo02/0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0>03oool01@3o0000oooo0?ooo`3oool0003o01T0oooo00@0o`000?ooo`3oool0
003oB@3oool00`000?l0oooo0?ooo`0P0?ooo`040000o`3oool0oooo0?l003T0oooo000L0?ooo`03
0000003o0000oooo02`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0>03oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo01H0oooo00@0o`000?ooo`3oool0003oB@3oool00`3o0000003o0?ooo`0P0?oo
o`030000o`3oool0o`0003X0oooo000L0?ooo`030000003o0000oooo02d0oooo0P000?l30?ooo`05
0?l0003oool0oooo0?ooo`000?l0303oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0000o`1;0?ooo`030000o`3oool0oooo
01h0oooo00@0003o0?ooo`3oool0o`00>P3oool001`0oooo00<000000?l0003oool0;`3oool20000
o`80oooo00<0o`000?ooo`000?l0303oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0000o`1;0?ooo`030000o`3oool0oooo
01h0oooo00<0003o0?ooo`3o0000>`3oool001`0oooo00<000000?l0003oool0<@3oool40000o`d0
oooo00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`000?l0C03oool00`3o0000003o0?ooo`0N0?ooo`030000o`3oool0o`0003/0
oooo000L0?ooo`030000003o0000oooo03@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0j0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0000o`1=0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3o0000?03oool001`0oooo00<0
00000?l0003oool0=03oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo03`0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l000000?l0oooo04d0oooo00<0
003o0?ooo`3oool0703oool00`000?l0oooo0?l0000l0?ooo`00703oool00`000000o`000?ooo`0d
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0?03oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`000?l0C`3oool00`000?l0oooo0?ooo`0K
0?ooo`030000o`3o0000oooo03`0oooo000L0?ooo`030000003o0000oooo03D0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0l0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000003o0?ooo`1?0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?oo
o`3oool0?@3oool001`0oooo00<000000?l0003oool0=@3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo03h0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l000000?l0oooo04l0oooo00<0003o0?l0003oool0603oool20?l000030000o`3oool0oooo03d0
oooo000L0?ooo`030000003o0000oooo03D0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0n0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000003o
0?ooo`1A0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`000?l0@03oool001`0oooo00<0
00000?l0003oool0=@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo03h0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`030?l000000?l0oooo0540oooo00<0
003o0?l0003oool0503oool20?l00080oooo00<0003o0?ooo`3oool0?P3oool001`0oooo00<00000
0?l0003oool0=@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo03l0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0540oooo00<0003o
0?l0003oool04P3oool20?l000@0oooo00<0003o0?ooo`3oool0?P3oool001`0oooo00<000000?l0
003oool0=P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo03l0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo05<0oooo00<0003o0?l0
003oool03`3oool20?l000D0oooo00<0003o0?ooo`3oool0?`3oool001`0oooo00<000000?l0003o
ool0=P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0400oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000oooo05@0oooo00<0003o0?l0003o
ool03P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo03l0oooo000L0?ooo`030000
003o0000oooo03L0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`110?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000?l0o`000?ooo`1E0?ooo`030000
o`3o0000oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`100?ooo`00703o
ool00`000000o`000?ooo`0g0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0@P3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0o`000?oo
o`1E0?ooo`030000o`3oool0o`0000`0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`100?ooo`00703oool00`000000o`000?ooo`0h0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`080?ooo`80003o0`3oool20000o`80oooo00<0o`00
0?ooo`3oool0E@3oool00`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0@@3oool001`0oooo00<000000?l0003oool0>@3oool0103o0000oooo0?ooo`3o0016
0?ooo`030?l0003oool0oooo00X0oooo0`000?l40?ooo`030?l0003oool0oooo05H0oooo00<0003o
0?ooo`3o00002@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0440oooo000L0?oo
o`030000003o0000oooo03X0oooo0`3o00170?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool0EP3oool00`000?l0oooo0?l000090?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0@P3oool001`0oooo00<000000?l0003oool0Q03oool00`3o0000oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo05L0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo0480oooo000L0?ooo`030000003o0000oooo08D0oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`1H0?ooo`030000o`3oool0o`0000L0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`130?ooo`00703oool00`000000o`000?ooo`250?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool0F@3oool00`000?l0o`000?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0@`3oool001`0oooo00<000000?l0003oool0QP3oool0
0`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo05X0oooo00<0003o0?l0003oool00`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo04@0oooo000L0?ooo`030000003o0000oooo
08H0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`1J0?ooo`030000o`3o0000oooo
0080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`150?ooo`00703oool00`000000
o`000?ooo`270?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0F`3oool00`000?l0
oooo0?l000020?l000T0oooo00<0003o0?ooo`3oool0A@3oool001`0oooo00<000000?l0003oool0
Q`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo05`0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`160?ooo`00703oool00`000000o`000?ooo`280?ooo`030?l0003o
ool0oooo00X0oooo00<0o`000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo04L0oooo000L0?ooo`030000003o0000oooo08P0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`1N0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0B03oool0
00030?ooo`000000000000<00000103oool4000000@0oooo100000060?ooo`030000003o0000oooo
08T0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`1P0?ooo`80003o0`3oool20000
od/0oooo00000`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?l0003oool0R@3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0680oooo0`000?m=0?ooo`000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003o0000oooo08T0oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`2b0?ooo`000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o0000
000008X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`2b0?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003o0000oooo08X0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`2c0?ooo`001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o0000oooo08/0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2c0?ooo`0000<0oooo0000003oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003o0000oooo08/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`2c0?ooo`000P3oool3000000D0oooo100000040?ooo`@000001P3oool00`000000o`000?oo
o`2;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0/`3oool001`0oooo00<00000
0?l0003oool0S03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0;@0oooo000L0?oo
o`030000003o0000oooo08`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`2d0?oo
o`00703oool00`000000o`000?ooo`2=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool0]03oool001`0oooo00<000000?l0003oool0S@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0;@0oooo000L0?ooo`030000003oool0oooo08d0oooo00D0o`000?ooo`3oool0oooo
0?l0002g0?ooo`00703oool00`000000oooo0?ooo`2>0?ooo`040?l0003oool0oooo0?l00;L0oooo
000L0?ooo`030000003oool0oooo08l0oooo0P3o002h0?ooo`00703oool00`000000oooo0?ooo`3o
0?ooodX0oooo000L0?ooo`030000003oool0oooo0?l0ooooBP3oool001`0oooo00<000000?ooo`3o
ool0o`3ooom:0?ooo`00703oool200000?l0ooooB`3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0;L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo0`0000050?ooo`030000003oool0oooo
00h0oooo002g0?ooo`8000006@3oool2000004L0oooo00<000000?ooo`3oool02`3oool200000140
oooo0P00000C0?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`0000<000000?ooo`3oool0
1@0000040?ooo`D000000`3oool500000080oooo1@0000090?ooo`800000103oool5000000@0oooo
0P00000<0?ooo`D000000P3oool3000000040?ooo`0000000000000000<0oooo0P0000050?ooo`D0
00000P3oool5000000<0oooo1@0000040?ooo`D000001P3oool3000000H0oooo100000050?ooo`80
000000@0oooo000000000000oooo1@0000040?ooo`D000000`3oool500000080oooo1@0000020?oo
o`030000003oool0oooo00P0oooo1@0000020?ooo`D00000103oool00`000000oooo0?ooo`070?oo
o`<000000`3oool010000000oooo0?ooo`3oool3000000<0oooo1@0000050?ooo`<00000103oool4
000000@0oooo1@0000030?ooo`@000000`3oool5000000030?ooo`000000oooo00@0oooo10000005
0?ooo`030000003oool0oooo00P0oooo100000040?ooo`030000003oool0oooo00P0oooo10000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool300000040oooo0@000001
00000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P0000040?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000040?ooo`800000103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool000000080oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo0P00000;0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`8000002@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`8000002@3oool010000000oooo0?ooo`3o
ool100000000103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo0?ooo`40000000001@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3o
ool6000000<0oooo100000080?ooo`040000003oool0oooo000000@0oooo1000000D0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00<0oooo1P0000030?ooo`030000003oool0oooo00D0oooo100000030?ooo`H000001`3oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`020?ooo`H000000`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3o
ool4000000<0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`3oool10000000000@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool00`3oool200000080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3o
ool3000000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool200000140oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`06
0?ooo`@000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool5000000000`3oool2000000040?ooo`0000000000000000<0oooo0`0000050?ooo`@00000103o
ool5000000D0oooo0`0000020?ooo`<000000P3oool5000001<0oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`00000000000080oooo0`0000020?ooo`<000000P3oool4000000<0oooo0P00
0000103oool000000000000000030?ooo`D000000`3oool4000000P0oooo00<000000?ooo`000000
1@3oool4000000<0oooo0P0000020?ooo`8000000P3oool2000000040?ooo`0000000000000000<0
oooo0`0000050?ooo`@000000`3oool2000000040?ooo`0000000000000000h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`@000000`3oool2000000030?ooo`00
0000000000800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`400000
00180?ooo`030000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`<00000
103oool01@000000oooo0?ooo`3oool0000000l0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0?ooo`400000000>0?ooo`030000
003oool0oooo03D0oooo1@00000f0?ooo`H000007@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00<0oooo0`00000?0?ooo`D000001@3oool400000080oooo1@0000050?ooo`@00000
303oool200000180oooo0`0000030?ooo`@00000403oool4000000l0oooo100000030?ooo`<00000
403oool300000040oooo0@00000100000000o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-29.2172, -179.033, 1.28285, \
3.33498}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Series classified as chaotic.\"\>",
            FontFamily->"Helvetica",
            FontSize->14,
            FontWeight->"Bold",
            FontColor->GrayLevel[0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> GrayLevel[ 0], 
            FontSize -> 14, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\n    Autocorrelation Analysis:   Period: 99   \
Autocorrelation: 0.486433   Bounds: {-169.021, 231.326}\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\n    Fourier Analysis:   Frequency: {308, 307, 4, \
3, 1}\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Series classified as chaotic.", FontWeight -> "Bold", FontColor -> 
          GrayLevel[ 0], FontSize -> 14, FontFamily -> "Helvetica"], 
        StyleForm[ 
        "\n    Autocorrelation Analysis:   Period: 99   Autocorrelation: \
0.486433   Bounds: {-169.021, 231.326}", FontSize -> 12, FontFamily -> 
          "Helvetica"], 
        StyleForm[ 
        "\n    Fourier Analysis:   Frequency: {308, 307, 4, 3, 1}", FontSize -> 
          12, FontFamily -> "Helvetica"]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({"chaotic", 309}\)], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.0112564 0.00130503 [
[.17532 -0.00124 -6 -9 ]
[.17532 -0.00124 6 0 ]
[.32993 -0.00124 -9 -9 ]
[.32993 -0.00124 9 0 ]
[.48454 -0.00124 -9 -9 ]
[.48454 -0.00124 9 0 ]
[.63915 -0.00124 -9 -9 ]
[.63915 -0.00124 9 0 ]
[.79375 -0.00124 -9 -9 ]
[.79375 -0.00124 9 0 ]
[.94836 -0.00124 -9 -9 ]
[.94836 -0.00124 9 0 ]
[.00822 .14176 -18 -4.5 ]
[.00822 .14176 0 4.5 ]
[.00822 .27226 -18 -4.5 ]
[.00822 .27226 0 4.5 ]
[.00822 .40276 -18 -4.5 ]
[.00822 .40276 0 4.5 ]
[.00822 .53327 -18 -4.5 ]
[.00822 .53327 0 4.5 ]
[.5 .63053 -159.688 0 ]
[.5 .63053 159.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .01126 m
.17532 .01751 L
s
[(50)] .17532 -0.00124 0 1 Mshowa
.32993 .01126 m
.32993 .01751 L
s
[(100)] .32993 -0.00124 0 1 Mshowa
.48454 .01126 m
.48454 .01751 L
s
[(150)] .48454 -0.00124 0 1 Mshowa
.63915 .01126 m
.63915 .01751 L
s
[(200)] .63915 -0.00124 0 1 Mshowa
.79375 .01126 m
.79375 .01751 L
s
[(250)] .79375 -0.00124 0 1 Mshowa
.94836 .01126 m
.94836 .01751 L
s
[(300)] .94836 -0.00124 0 1 Mshowa
.125 Mabswid
.05164 .01126 m
.05164 .01501 L
s
.08256 .01126 m
.08256 .01501 L
s
.11348 .01126 m
.11348 .01501 L
s
.1444 .01126 m
.1444 .01501 L
s
.20625 .01126 m
.20625 .01501 L
s
.23717 .01126 m
.23717 .01501 L
s
.26809 .01126 m
.26809 .01501 L
s
.29901 .01126 m
.29901 .01501 L
s
.36085 .01126 m
.36085 .01501 L
s
.39177 .01126 m
.39177 .01501 L
s
.4227 .01126 m
.4227 .01501 L
s
.45362 .01126 m
.45362 .01501 L
s
.51546 .01126 m
.51546 .01501 L
s
.54638 .01126 m
.54638 .01501 L
s
.5773 .01126 m
.5773 .01501 L
s
.60823 .01126 m
.60823 .01501 L
s
.67007 .01126 m
.67007 .01501 L
s
.70099 .01126 m
.70099 .01501 L
s
.73191 .01126 m
.73191 .01501 L
s
.76283 .01126 m
.76283 .01501 L
s
.82468 .01126 m
.82468 .01501 L
s
.8556 .01126 m
.8556 .01501 L
s
.88652 .01126 m
.88652 .01501 L
s
.91744 .01126 m
.91744 .01501 L
s
.97928 .01126 m
.97928 .01501 L
s
.25 Mabswid
0 .01126 m
1 .01126 L
s
.02072 .14176 m
.02697 .14176 L
s
[(100)] .00822 .14176 1 0 Mshowa
.02072 .27226 m
.02697 .27226 L
s
[(200)] .00822 .27226 1 0 Mshowa
.02072 .40276 m
.02697 .40276 L
s
[(300)] .00822 .40276 1 0 Mshowa
.02072 .53327 m
.02697 .53327 L
s
[(400)] .00822 .53327 1 0 Mshowa
.125 Mabswid
.02072 .03736 m
.02447 .03736 L
s
.02072 .06346 m
.02447 .06346 L
s
.02072 .08956 m
.02447 .08956 L
s
.02072 .11566 m
.02447 .11566 L
s
.02072 .16786 m
.02447 .16786 L
s
.02072 .19396 m
.02447 .19396 L
s
.02072 .22006 m
.02447 .22006 L
s
.02072 .24616 m
.02447 .24616 L
s
.02072 .29836 m
.02447 .29836 L
s
.02072 .32446 m
.02447 .32446 L
s
.02072 .35056 m
.02447 .35056 L
s
.02072 .37666 m
.02447 .37666 L
s
.02072 .42887 m
.02447 .42887 L
s
.02072 .45497 m
.02447 .45497 L
s
.02072 .48107 m
.02447 .48107 L
s
.02072 .50717 m
.02447 .50717 L
s
.02072 .55937 m
.02447 .55937 L
s
.02072 .58547 m
.02447 .58547 L
s
.02072 .61157 m
.02447 .61157 L
s
.25 Mabswid
.02072 0 m
.02072 .61803 L
s
gsave
.5 .63053 -220.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Time) show
111.000 14.000 moveto
(Series) show
147.000 14.000 moveto
0.000 0.000 rmoveto
147.000 14.000 moveto
(,) show
156.563 14.000 moveto
(12) show
168.563 14.000 moveto
(,) show
178.125 14.000 moveto
(RGBColor) show
226.125 14.000 moveto
([) show
232.125 14.000 moveto
(0) show
238.125 14.000 moveto
(,) show
247.688 14.000 moveto
(0) show
253.688 14.000 moveto
(,) show
263.250 14.000 moveto
(0) show
269.250 14.000 moveto
(]) show
275.250 14.000 moveto
(,) show
284.813 14.000 moveto
0.000 0.000 rmoveto
284.813 14.000 moveto
(Helvetica) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(,) show
348.375 14.000 moveto
0.000 0.000 rmoveto
348.375 14.000 moveto
(Bold) show
372.375 14.000 moveto
0.000 0.000 rmoveto
372.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 1 r
.5 Mabswid
.02381 .60332 m
.0269 .01472 L
.02999 .02012 L
.03309 .02515 L
.03618 .03169 L
.03927 .03884 L
.04236 .0463 L
.04545 .05333 L
.04855 .06087 L
.05164 .06765 L
.05473 .07452 L
.05782 .08117 L
.06092 .08691 L
.06401 .09155 L
.0671 .09513 L
.07019 .09737 L
.07328 .10116 L
.07638 .10399 L
.07947 .10627 L
.08256 .10674 L
.08565 .10657 L
.08874 .10392 L
.09184 .10112 L
.09493 .0963 L
.09802 .09061 L
.10111 .08316 L
.10421 .07662 L
.1073 .06976 L
.11039 .06369 L
.11348 .05768 L
.11657 .05204 L
.11967 .04691 L
.12276 .04274 L
.12585 .03926 L
.12894 .03704 L
.13203 .03647 L
.13513 .03762 L
.13822 .0404 L
.14131 .04507 L
.1444 .05068 L
.1475 .05722 L
.15059 .06457 L
.15368 .0728 L
.15677 .08227 L
.15986 .09265 L
.16296 .10384 L
.16605 .11587 L
.16914 .12835 L
.17223 .14137 L
.17532 .15526 L
Mistroke
.17842 .1693 L
.18151 .18352 L
.1846 .19793 L
.18769 .21238 L
.19079 .2263 L
.19388 .24048 L
.19697 .25411 L
.20006 .26831 L
.20315 .28173 L
.20625 .29494 L
.20934 .30709 L
.21243 .31979 L
.21552 .33078 L
.21861 .34146 L
.22171 .34974 L
.2248 .35568 L
.22789 .35872 L
.23098 .36048 L
.23408 .36085 L
.23717 .36094 L
.24026 .36001 L
.24335 .35902 L
.24644 .35753 L
.24954 .3557 L
.25263 .35413 L
.25572 .3532 L
.25881 .35259 L
.2619 .35325 L
.265 .3531 L
.26809 .35301 L
.27118 .35294 L
.27427 .35261 L
.27737 .35232 L
.28046 .35273 L
.28355 .35242 L
.28664 .3531 L
.28973 .3549 L
.29283 .35794 L
.29592 .36131 L
.29901 .36552 L
.3021 .37063 L
.30519 .37682 L
.30829 .38253 L
.31138 .38761 L
.31447 .3912 L
.31756 .39126 L
.32066 .38689 L
.32375 .38063 L
.32684 .37335 L
.32993 .3647 L
Mistroke
.33302 .3542 L
.33612 .34181 L
.33921 .3278 L
.3423 .31284 L
.34539 .29725 L
.34848 .28151 L
.35158 .26575 L
.35467 .25007 L
.35776 .23438 L
.36085 .21871 L
.36395 .20314 L
.36704 .18762 L
.37013 .1718 L
.37322 .15613 L
.37631 .14066 L
.37941 .12546 L
.3825 .11067 L
.38559 .09655 L
.38868 .0834 L
.39177 .07181 L
.39487 .06261 L
.39796 .05719 L
.40105 .05696 L
.40414 .0622 L
.40724 .07174 L
.41033 .08395 L
.41342 .09737 L
.41651 .11113 L
.4196 .1253 L
.4227 .14004 L
.42579 .15562 L
.42888 .17123 L
.43197 .1863 L
.43506 .20087 L
.43816 .21408 L
.44125 .22596 L
.44434 .23713 L
.44743 .24648 L
.45053 .25559 L
.45362 .26436 L
.45671 .27349 L
.4598 .28331 L
.46289 .29354 L
.46599 .30395 L
.46908 .31508 L
.47217 .32668 L
.47526 .33818 L
.47835 .34954 L
.48145 .36041 L
.48454 .37094 L
Mistroke
.48763 .37951 L
.49072 .3837 L
.49382 .3826 L
.49691 .37757 L
.5 .36956 L
.50309 .35888 L
.50618 .3467 L
.50928 .33372 L
.51237 .32027 L
.51546 .30665 L
.51855 .29292 L
.52165 .27917 L
.52474 .26561 L
.52783 .25214 L
.53092 .23909 L
.53401 .22596 L
.53711 .21291 L
.5402 .19995 L
.54329 .18714 L
.54638 .17461 L
.54947 .16266 L
.55257 .15143 L
.55566 .14117 L
.55875 .13208 L
.56184 .12449 L
.56494 .119 L
.56803 .11549 L
.57112 .11351 L
.57421 .11261 L
.5773 .11359 L
.5804 .11652 L
.58349 .12196 L
.58658 .12899 L
.58967 .13765 L
.59276 .14645 L
.59586 .15562 L
.59895 .16442 L
.60204 .17305 L
.60513 .1796 L
.60823 .1825 L
.61132 .18267 L
.61441 .18084 L
.6175 .17764 L
.62059 .17409 L
.62369 .17084 L
.62678 .16807 L
.62987 .16572 L
.63296 .16404 L
.63605 .16358 L
.63915 .16374 L
Mistroke
.64224 .16509 L
.64533 .16689 L
.64842 .16983 L
.65152 .17366 L
.65461 .17849 L
.6577 .18419 L
.66079 .19113 L
.66388 .19902 L
.66698 .20777 L
.67007 .21731 L
.67316 .22704 L
.67625 .23542 L
.67934 .24075 L
.68244 .2434 L
.68553 .24247 L
.68862 .2393 L
.69171 .23448 L
.69481 .22908 L
.6979 .22368 L
.70099 .21863 L
.70408 .21423 L
.70717 .21063 L
.71027 .20728 L
.71336 .20427 L
.71645 .20176 L
.71954 .19979 L
.72263 .19842 L
.72573 .1978 L
.72882 .19815 L
.73191 .19917 L
.735 .20064 L
.7381 .20269 L
.74119 .20504 L
.74428 .2077 L
.74737 .21077 L
.75046 .21479 L
.75356 .21929 L
.75665 .22432 L
.75974 .23071 L
.76283 .23804 L
.76592 .24583 L
.76902 .25386 L
.77211 .26184 L
.7752 .26981 L
.77829 .27731 L
.78139 .28442 L
.78448 .29182 L
.78757 .29926 L
.79066 .30647 L
.79375 .31204 L
Mistroke
.79685 .3165 L
.79994 .32083 L
.80303 .32454 L
.80612 .32705 L
.80921 .32712 L
.81231 .3222 L
.8154 .3159 L
.81849 .30829 L
.82158 .29979 L
.82468 .28967 L
.82777 .27846 L
.83086 .26737 L
.83395 .25582 L
.83704 .24502 L
.84014 .23506 L
.84323 .22676 L
.84632 .22059 L
.84941 .21615 L
.8525 .2131 L
.8556 .20999 L
.85869 .20691 L
.86178 .20397 L
.86487 .20093 L
.86797 .19788 L
.87106 .19495 L
.87415 .19211 L
.87724 .18876 L
.88033 .18459 L
.88343 .17899 L
.88652 .17206 L
.88961 .16342 L
.8927 .15307 L
.89579 .14079 L
.89889 .12711 L
.90198 .11269 L
.90507 .09761 L
.90816 .08215 L
.91126 .06648 L
.91435 .05056 L
.91744 .03456 L
.92053 .01879 L
.92362 .0209 L
.92672 .03656 L
.92981 .05199 L
.9329 .0668 L
.93599 .0806 L
.93908 .09403 L
.94218 .10703 L
.94527 .12004 L
.94836 .13295 L
Mistroke
.95145 .14585 L
.95455 .15856 L
.95764 .1711 L
.96073 .18389 L
.96382 .19645 L
.96691 .20852 L
.97001 .22036 L
.9731 .23176 L
.97619 .24206 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oBP3oool4
000000@0oooo1000000O0?ooo`D000000`3oool4000000@0oooo1000000K0?ooo`D000000`3oool4
000000@0oooo1000000J0?ooo`D00000103oool4000000@0oooo1000000K0?ooo`D00000103oool4
000000@0oooo1000000K0?ooo`<000001@3oool4000000@0oooo1000000R0?ooo`00B@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01l0oooo001>0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool07`3oool004h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0O
0?ooo`00BP3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool4000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0I0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool07`3oool004X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0K0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool01@000000oooo0?ooo`3oool0
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0O0?ooo`00BP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool3
000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01P0oooo0`0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0O0?ooo`00BP3oool5
000000<0oooo1000000Q0?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000007@3oool0
0`000000oooo0?ooo`030?ooo`D000000`3oool4000001/0oooo0`0000050?ooo`@00000103oool4
000001`0oooo0`0000050?ooo`D000000`3oool4000001/0oooo0`0000050?ooo`@00000103oool4
00000280oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooA@3oool00240oooo00<000000?ooo`3oool0o`3ooom50?oo
o`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000K0?ooool00000<P00000L0?ooo`008@3o
ool00`000000oooo0000o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0
003o02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo00H0oooo00<000000?ooo`3oool0:@3oool00240oooo00@000000?ooo`000?l0003oo`3oool?
0?ooo`80003o<`3oool00240oooo00D000000?ooo`000?l0oooo0000o`3o0?ooo`h0oooo0P000?lc
0?ooo`008@3oool01@000000oooo0000o`3oool0003o0?l0oooo3@3oool00`000?l0oooo0000o`0c
0?ooo`008@3oool00`000000oooo0000o`020?ooo`030000o`3oool0oooo0?l0oooo2P3oool01000
0?l0oooo0?ooo`000?lb0?ooo`008@3oool00`000000oooo0000o`020?ooo`030000o`3oool0oooo
0?l0oooo2P3oool010000?l0oooo0?ooo`000?lb0?ooo`008@3oool2000000050000o`3oool0oooo
0?ooo`000?l06P3oool30000ond0oooo00@0003o0?ooo`3oool0003o<P3oool00240oooo00<00000
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0G0?ooo`050000o`3oool0oooo0?ooo`000?l0k03o
ool010000?l0oooo0?ooo`000?lb0?ooo`008@3oool00`000000oooo0000o`030?ooo`030000o`3o
ool0oooo01H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`3X0?ooo`050000o`3o
ool0oooo0?ooo`000?l0<P3oool00240oooo00<000000?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0j03oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo02l0oooo000Q0?ooo`030000003oool0003o00<0oooo00<0003o
0?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0>L0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0_0?ooo`008@3oool00`000000oooo0000o`040?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`3W0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;`3oool00240oooo00<000000?ooo`00
0?l0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0B@3oool20000oi/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0_0?ooo`00
8@3oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`180?ooo`030000o`3oool0003o09X0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0_0?ooo`008@3oool2000000030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo04P0oooo00@0
003o0?ooo`3oool0003oV@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02h0oooo
000Q0?ooo`030000003oool0003o00H0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo04P0oooo00@0003o0?ooo`3oool0003oV@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo02h0oooo000Q0?ooo`030000003oool0003o00H0oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04H0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`2F0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0;P3oool00240oooo00<000000?ooo`000?l01`3oool00`000?l0oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo09H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0^
0?ooo`008@3oool00`000000oooo0000o`070?ooo`030000o`3oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0U@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02d0oooo000Q0?ooo`03
0000003oool0003o00P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`2D0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;@3oool00240oooo00<000000?ooo`000?l0
203oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0
A03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo09@0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0]0?ooo`008@3oool00`000000oooo0000o`090?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`140?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0U03oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo02d0oooo000Q0?ooo`80000000<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo09@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0/
0?ooo`008@3oool00`000000oooo0000o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0T`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02`0oooo000Q0?ooo`03
0000003oool0003o00/0oooo0P000?l60?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3o
ool0@P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo09<0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0/0?ooo`008@3oool00`000000oooo0000o`0<0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`110?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0T`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo02`0oooo000Q0?ooo`030000003oool0003o00d0oooo0P000?l30?ooo`80003o503o
ool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0T`3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo02/0oooo000Q0?ooo`030000003oool0
003o00l0oooo0`000?lF0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`2A0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0:`3oool0
0240oooo00<000000?ooo`000?l0:03oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool0T@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
02/0oooo000Q0?ooo`030000003oool0003o02T0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo02`0oooo0`000?mR0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool0:`3oool00240oooo0P0000000`000?l0oooo0?ooo`0W0?ooo`030000
o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0[0?ooo`050000
o`3oool0oooo0?ooo`000?l0H@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02X0
oooo000Q0?ooo`030000003oool0003o02T0oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1O0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0:P3oool00240oooo00<0
00000?ooo`000?l0:@3oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05h0oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0Z0?ooo`008@3oool00`000000oooo0000o`0Z
0?ooo`030000o`3oool0oooo03d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0Y
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0GP3oool00`000?l0oooo0?ooo`0;
0?ooo`030000o`3oool0oooo02X0oooo000Q0?ooo`030000003oool0003o02X0oooo00<0003o0?oo
o`3oool0?@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02P0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`1M0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?oo
o`3oool0:@3oool000L0oooo1@0000030?ooo`@00000103oool4000000H0oooo00<000000?ooo`00
0?l0:P3oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0Y0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0003o02X0oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1K0?ooo`03
0000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0:@3oool000T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000o`0[0?ooo`030000o`3oool0oooo03/0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0F`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo02T0oooo00090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo0P0000000`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo03/0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo02P0
oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000?l0:`3oool00`000?l0
oooo0?ooo`0k0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool09P3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo05X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0X0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0003o02/0
oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo02@0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1I0?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0:03oool000L0oooo0`0000040?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0003o02`0
oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo02@0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0:03oool000T0oooo00<000000?ooo`3oool00`3oool4000000@0oooo
100000060?ooo`030000003oool0003o02`0oooo00<0003o0?ooo`3oool0>@3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`1H0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool09`3oool00240oooo00<0
00000?ooo`000?l0;03oool00`000?l0oooo0?ooo`0i0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo05L0oooo00<0
003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0W0?ooo`008@3oool00`000000oooo0000o`0/
0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0S
0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo02L0oooo000Q0?ooo`030000003oool0003o02d0oooo00<0003o0?oo
o`3oool0=`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0280oooo00<0003o0?oo
o`3oool0303oool00`000?l0oooo0?ooo`070?ooo`@0003oB`3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo02L0oooo000Q0?ooo`80000000<0003o0?ooo`3oool0:`3oool00`000?l0
oooo0?ooo`0g0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`170?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool09P3oool00240oooo
00<000000?ooo`000?l0;@3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo00l0oooo
00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0oooo01<0oooo
00<0003o0?ooo`3oool09P3oool00240oooo00<000000?ooo`000?l0;@3oool00`000?l0oooo0?oo
o`0g0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`140?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool09P3oool00240oooo00<00000
0?ooo`000?l0;P3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0oooo00l0oooo00<0003o
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?ooo`3oool09P3oool00240oooo00<000000?ooo`000?l0;P3oool00`000?l0oooo0?ooo`0e0?oo
o`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0@0?oo
o`@0003o2`3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo01D0oooo00<0003o0?oo
o`3oool09P3oool00240oooo00<000000?ooo`000?l0;P3oool00`000?l0oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo0440oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0V0?ooo`00
8@3oool00`000000oooo0000o`0^0?ooo`030000o`3oool0oooo03D0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool0
@03oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo02H0oooo000Q0?ooo`030000003o
ool0003o02h0oooo00<0003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo01l0oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3o
ool0oooo01L0oooo00<0003o0?ooo`3oool09P3oool00240oooo0P0000000`000?l0oooo0?ooo`0]
0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0N
0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0I
0?ooo`030000o`3oool0oooo02D0oooo000Q0?ooo`030000003oool0003o02l0oooo00<0003o0?oo
o`3oool0=03oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`0?0?ooo`@0003o:03oool00`000?l0oooo0?ooo`0J0?oo
o`030000o`3oool0oooo02D0oooo000Q0?ooo`030000003oool0003o02l0oooo00<0003o0?ooo`3o
ool0=03oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`0=0?ooo`80003o103oool00`000?l0oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool09@3oool00240oooo00<000000?ooo`000?l0
;`3oool00`000?l0oooo0?ooo`0d0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0
7@3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0
1@3oool20000ob<0oooo00<0003o0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0T0?ooo`008@3o
ool00`000000oooo0000o`0`0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0200oooo00<0003o0?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0T0?ooo`008@3oool00`000000oooo0000o`0`0?ooo`030000o`3oool0
oooo0380oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo01h0oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0T0?ooo`008@3oool00`00
0000oooo0000o`0`0?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool0803oool00`00
0?l0oooo0?ooo`0T0?ooo`008@3oool00`000000oooo0000o`0`0?ooo`030000o`3oool0oooo0380
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0oooo02H0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo01`0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`0S0?ooo`008@3oool2000000030000
o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01X0oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0R0?ooo`030000
o`3oool0oooo02<0oooo000Q0?ooo`030000003oool0003o0340oooo00<0003o0?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo02<0oooo000Q0?ooo`030000003oool0
003o0340oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0
oooo01T0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0
oooo0280oooo000Q0?ooo`030000003oool0003o0340oooo00<0003o0?ooo`3oool0<03oool00`00
0?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo0280oooo000Q0?ooo`030000003oool0003o0340
oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo01L0
oooo00<0003o0?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0003o01@0oooo00<0003o0?oo
o`3oool05P3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo0280oooo000Q0?ooo`03
0000003oool0003o0380oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0003o
01D0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo
0280oooo000Q0?ooo`030000003oool0003o0380oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0G0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0:`3oool010000?l0
oooo0?ooo`000?lE0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`0Q0?ooo`008@3oool00`000000oooo0000o`0b0?ooo`030000o`3oool0oooo02h0
oooo00<0003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo02`0
oooo0P000?lG0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool09`3oool00`000?l0
oooo0?ooo`0Q0?ooo`008@3oool2000000030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool0
;P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool0
AP3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo04/0oooo000Q0?ooo`030000003o
ool0003o03<0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo01D0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo04`0oooo000Q0?ooo`030000003oool0003o03<0oooo00<0003o0?ooo`3oool0;@3oool0
0`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0A`3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo04`0oooo000Q0?ooo`030000003oool0003o
03<0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo
01@0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04`0oooo000Q0?ooo`030000003oool0003o03<0oooo00<0003o0?ooo`3oool0;03oool00`000?l0
oooo0?ooo`0K0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0B03oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0oooo04`0oooo00060?ooo`D00000103oool4000000@0oooo
100000060?ooo`030000003oool0003o03@0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo04d0oooo00060?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000o`0d0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3o
ool0703oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo04P0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`1=0?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0003o03@0oooo00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo04d0oooo00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo0P0000000`000?l0
oooo0?ooo`0b0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool07@3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`1>0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0003o03@0
oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo0140
oooo00<0003o0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo04h0
oooo000:0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000?l0=03oool00`000?l0oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`1;0?oo
o`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0CP3oool000H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0003o03@0oooo00<0003o0?ooo`3oool0:P3oool0
0`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0C03oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04h0oooo00070?ooo`<000001@3oool40000
00@0oooo100000060?ooo`030000003oool0003o03@0oooo00<0003o0?ooo`3oool0:P3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0C@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo04l0oooo000Q0?ooo`030000003oool0003o03@0
oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00h0
oooo00<0003o0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo04l0
oooo000Q0?ooo`030000003oool0003o03D0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0CP3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo04l0oooo000Q0?ooo`030000003oool0003o03D0oooo00<0
003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0500oooo000Q
0?ooo`80000000<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0X0?ooo`030000o`3oool0
oooo0280oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0D03oool00240oooo00<000000?ooo`000?l0=P3oool00`00
0?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0D03oool00240
oooo00<000000?ooo`000?l0=P3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo02<0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool0D@3oool00240oooo00<000000000o`3oool0=P3oool00`000?l0oooo
0?ooo`0V0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`1A0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0D@3oool00240oooo00<0
00000000o`3oool0=P3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo02@0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1C0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0DP3oool00240oooo00<000000000o`3oool0=`3oool00`000?l0oooo0?ooo`0U
0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1D
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0DP3oool00240oooo00<000000000
o`3oool0=`3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo02@0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`1D0?ooo`050000o`3oool0oooo0?ooo`000?l0E@3oool0
0240oooo00<000000000o`3oool0=`3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo
02H0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1D0?ooo`050000o`3oool0oooo
0?ooo`000?l0E@3oool00240oooo00<000000000o`3oool0=`3oool00`000?l0oooo0?ooo`0T0?oo
o`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1E0?oo
o`<0003oEP3oool00240oooo00<000000000o`3oool0>03oool00`000?l0oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`2_0?ooo`00
8@3oool00`000000003o0?ooo`0h0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool0
9P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0:l0oooo000Q0?ooo`0300000000
0?l0oooo03P0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool0[`3oool00240oooo00<000000000o`3oool0>@3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02L0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`2_0?ooo`008@3oool00`000000003o0?ooo`0i0?ooo`030000o`3oool0oooo
0240oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
0;00oooo000Q0?ooo`03000000000?l0oooo03T0oooo00<0003o0?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0X0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0/03oool00240oooo
00<000000000o`3oool0>P3oool00`000?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo02T0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`2`0?ooo`008@3oool00`000000003o0?oo
o`0j0?ooo`030000o`3oool0oooo00P0oooo2P000?l=0?ooo`030000o`3oool0oooo02T0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`2a0?ooo`008@3oool00`000000003o0?ooo`0k
0?ooo`030000o`3oool0oooo00D0oooo0P000?l:0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0;40oooo000Q0?oo
o`03000000000?l0oooo03`0oooo00<0003o0?ooo`3oool00P3oool20000o`d0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0/@3oool00240oooo00<000000000o`3oool0?@3oool40000oa00oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0/@3oool00240oooo00<000000000o`3oool0DP3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo02/0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`2b0?ooo`008@3o
ool00`000000003o0?ooo`1B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0;80oooo000Q0?ooo`03000000000?l0
oooo05<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0]0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0/P3oool00240oooo00<000000000o`3oool0D`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02d0oooo00D0003o0?ooo`3oool0oooo0000o`2e
0?ooo`008@3oool00`000000003o0?ooo`1D0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0;`3oool010000?l0oooo0?ooo`000?ne0?ooo`008@3oool00`000000003o0?ooo`1E0?oo
o`050000o`3oool0oooo0?ooo`000?l0<@3oool00`000?l0oooo0000o`2f0?ooo`008@3oool00`00
0000003o0?ooo`1E0?ooo`040000o`3oool0oooo0000oc<0oooo00<0003o0?ooo`3oool0]@3oool0
0240oooo00<000000000o`3oool0E@3oool010000?l0oooo0?ooo`000?o[0?ooo`008@3oool00`00
0000003o0?ooo`1F0?ooo`80003ok03oool000L0oooo0`0000050?ooo`@00000103oool4000000H0
oooo00<000000000o`3oool0o`3ooom50?ooo`001P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo00<000000000o`3oool0o`3ooom50?ooo`002P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03000000000?l0
oooo0?l0ooooA@3oool000X0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000003o0000003o0?ooodD0oooo0008
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000003o0?ooo`3o0?ooodD0oooo000:0?ooo`050000003oool0
oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo
00<000000000o`3oool0o`3ooom50?ooo`001P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0
oooo00<000000000o`3oool0o`3ooom50?ooo`001`3oool3000000D0oooo100000040?ooo`@00000
1P3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3o
ool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?oo
odD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0
o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0
oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000
003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<0
00000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?oo
o`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`00
8@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3o
ool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?oo
odD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0
o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0
oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000
003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<0
00000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?oo
o`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`00
8@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3o
ool000T0oooo0`0000030?ooo`@00000103oool4000000H0oooo00<000000000o`3oool0o`3ooom5
0?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`03000000000?l0oooo0?l0ooooA@3oool000X0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000003o0?ooo`3o0?ooodD0oooo00060?ooo`H000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000003o
0000003o0?ooodD0oooo00070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000000o`3o
ool0o`3ooom50?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`03000000000?l0oooo
0?l0ooooA@3oool000P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000003o0?ooo`3o0?oo
odD0oooo00090?ooo`800000103oool4000000@0oooo100000060?ooo`03000000000?l0oooo0?l0
ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?oo
o`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000
o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`030000
00000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool0
0`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240
oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo
000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom5
0?ooo`008@3oool00`000000003o0?ooo`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0
ooooA@3oool00240oooo00<000000000o`3oool0o`3ooom50?ooo`008@3oool00`000000003o0?oo
o`3o0?ooodD0oooo000Q0?ooo`03000000000?l0oooo0?l0ooooA@3oool00240oooo00<000000?oo
o`3oool0o`3ooom50?ooo`008@3oool200000?l0ooooAP3oool00240oooo00<000000?ooo`3oool0
o`3ooom50?ooo`008@3oool00`000000oooo0?ooo`3o0?ooodD0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo0003000005H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`160?ooo`<0
00002`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo0`0000050?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0703oool000030000003oool0oooo05H0oooo
0P00000I0?ooo`800000A`3oool00`000000oooo0?ooo`0;0?ooo`8000004@3oool2000001<0oooo
00<000000?ooo`3oool00`3oool2000004h0oooo0P00000M0?ooo`0000<000000?ooo`3oool0103o
ool3000000@0oooo1@0000001@3oool00000000000000000oooo0080000000@0oooo0000003oool0
oooo1@0000080?ooo`030000003oool0000000800000103oool500000080oooo1@0000040?ooo`D0
00000`3oool500000080oooo1@0000020?ooo`030000003oool0oooo00P0oooo1@0000020?ooo`D0
0000103oool00`000000oooo0?ooo`070?ooo`<000000`3oool010000000oooo0?ooo`3oool30000
00<0oooo1@0000050?ooo`<00000103oool4000000@0oooo1@0000030?ooo`@000000`3oool50000
00030?ooo`000000oooo00@0oooo100000050?ooo`030000003oool0oooo00P0oooo100000040?oo
o`030000003oool0oooo00P0oooo100000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool3000000040?ooo`000000000000000080oooo1@0000030?ooo`D00000103oool2
000000D0oooo1@0000040?ooo`<00000103oool5000000<0oooo100000040?ooo`<0000000<0oooo
0000000000002@3oool5000000@0oooo100000040?ooo`<0000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0000000d0oooo0P0000030?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo00000000000;0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`8000002@3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`8000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool4000000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0000000B0?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0100oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool10000000000<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo00000005000000d0oooo00<000000?ooo`3oool01P00
00030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool6000000<0oooo1000
000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool4000000<0oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
00000080oooo1P0000050?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3o
ool6000000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo1@00000;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80000000L0oooo000000000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool01`3oool4000000<0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00H0oooo100000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0`0000030?oo
o`80000000D0oooo0000003oool0oooo000000030?ooo`@000002@3oool00`000000oooo0?ooo`06
0?ooo`@000000`3oool2000000040?ooo`0000000000000000<0oooo0`0000050?ooo`@00000103o
ool5000000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`@0
00000`3oool2000000030?ooo`000000000000800000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool4000000H0oooo00@000000?ooo`3oool0oooo0`000002
0?ooo`<000000P3oool4000000<0oooo1@0000040?ooo`<000001@3oool3000000030?ooo`000000
oooo0080oooo1000000<0?ooo`050000003oool0oooo0?ooo`0000000`3oool4000000H0oooo0@00
000000030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0M0?ooo`040000003oool0oooo0?ooo`800000=03oool3000000@0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
3@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000003@3oool1000000000`0000020?ooo`L0
0000103oool00`000000oooo0?ooo`0I0?ooo`<0000000<0oooo0000003oool0503oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00<0oooo0`00000?0?ooo`D000001@3oool400000080
oooo1@0000050?ooo`@00000303oool200000180oooo0`0000030?ooo`@00000403oool4000000l0
oooo100000030?ooo`<00000403oool3000000040?ooo`0000000000000000/0oooo0P00000O0?oo
o`030000003oool0oooo01X0oooo1@00000=0?ooo`800000003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-35.3948, -37.8517, 1.32587, \
3.14152}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00308214 0.309017 0.309017 [
[.17792 .29652 -6 -9 ]
[.17792 .29652 6 0 ]
[.33202 .29652 -9 -9 ]
[.33202 .29652 9 0 ]
[.48613 .29652 -9 -9 ]
[.48613 .29652 9 0 ]
[.64024 .29652 -9 -9 ]
[.64024 .29652 9 0 ]
[.79434 .29652 -9 -9 ]
[.79434 .29652 9 0 ]
[.94845 .29652 -9 -9 ]
[.94845 .29652 9 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -174.688 0 ]
[.5 .63053 174.688 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17792 .30902 m
.17792 .31527 L
s
[(50)] .17792 .29652 0 1 Mshowa
.33202 .30902 m
.33202 .31527 L
s
[(100)] .33202 .29652 0 1 Mshowa
.48613 .30902 m
.48613 .31527 L
s
[(150)] .48613 .29652 0 1 Mshowa
.64024 .30902 m
.64024 .31527 L
s
[(200)] .64024 .29652 0 1 Mshowa
.79434 .30902 m
.79434 .31527 L
s
[(250)] .79434 .29652 0 1 Mshowa
.94845 .30902 m
.94845 .31527 L
s
[(300)] .94845 .29652 0 1 Mshowa
.125 Mabswid
.05463 .30902 m
.05463 .31277 L
s
.08545 .30902 m
.08545 .31277 L
s
.11627 .30902 m
.11627 .31277 L
s
.1471 .30902 m
.1471 .31277 L
s
.20874 .30902 m
.20874 .31277 L
s
.23956 .30902 m
.23956 .31277 L
s
.27038 .30902 m
.27038 .31277 L
s
.3012 .30902 m
.3012 .31277 L
s
.36284 .30902 m
.36284 .31277 L
s
.39367 .30902 m
.39367 .31277 L
s
.42449 .30902 m
.42449 .31277 L
s
.45531 .30902 m
.45531 .31277 L
s
.51695 .30902 m
.51695 .31277 L
s
.54777 .30902 m
.54777 .31277 L
s
.57859 .30902 m
.57859 .31277 L
s
.60942 .30902 m
.60942 .31277 L
s
.67106 .30902 m
.67106 .31277 L
s
.70188 .30902 m
.70188 .31277 L
s
.7327 .30902 m
.7327 .31277 L
s
.76352 .30902 m
.76352 .31277 L
s
.82517 .30902 m
.82517 .31277 L
s
.85599 .30902 m
.85599 .31277 L
s
.88681 .30902 m
.88681 .31277 L
s
.91763 .30902 m
.91763 .31277 L
s
.97927 .30902 m
.97927 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -235.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Autocorrellagram) show
177.000 14.000 moveto
0.000 0.000 rmoveto
177.000 14.000 moveto
(,) show
186.563 14.000 moveto
(12) show
198.563 14.000 moveto
(,) show
208.125 14.000 moveto
(RGBColor) show
256.125 14.000 moveto
([) show
262.125 14.000 moveto
(0) show
268.125 14.000 moveto
(,) show
277.688 14.000 moveto
(0) show
283.688 14.000 moveto
(,) show
293.250 14.000 moveto
(0) show
299.250 14.000 moveto
(]) show
305.250 14.000 moveto
(,) show
314.813 14.000 moveto
0.000 0.000 rmoveto
314.813 14.000 moveto
(Helvetica) show
368.813 14.000 moveto
0.000 0.000 rmoveto
368.813 14.000 moveto
(,) show
378.375 14.000 moveto
0.000 0.000 rmoveto
378.375 14.000 moveto
(Bold) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02689 .59401 m
.02997 .58924 L
.03306 .58248 L
.03614 .57398 L
.03922 .5639 L
.0423 .55242 L
.04538 .53973 L
.04847 .52607 L
.05155 .51161 L
.05463 .49659 L
.05771 .48118 L
.0608 .46554 L
.06388 .4498 L
.06696 .43411 L
.07004 .41858 L
.07312 .40346 L
.07621 .38877 L
.07929 .37462 L
.08237 .36097 L
.08545 .34785 L
.08853 .33519 L
.09162 .32312 L
.0947 .31157 L
.09778 .30058 L
.10086 .29011 L
.10395 .28029 L
.10703 .2711 L
.11011 .26258 L
.11319 .25474 L
.11627 .24759 L
.11936 .24113 L
.12244 .23537 L
.12552 .23029 L
.1286 .22589 L
.13168 .22217 L
.13477 .21911 L
.13785 .21669 L
.14093 .2149 L
.14401 .21368 L
.1471 .21297 L
.15018 .21275 L
.15326 .21299 L
.15634 .21369 L
.15942 .2148 L
.16251 .21628 L
.16559 .2181 L
.16867 .22021 L
.17175 .22258 L
.17483 .22519 L
.17792 .22797 L
Mistroke
.181 .23089 L
.18408 .2339 L
.18716 .23697 L
.19025 .24003 L
.19333 .24308 L
.19641 .24609 L
.19949 .24911 L
.20257 .25206 L
.20566 .25497 L
.20874 .25779 L
.21182 .26062 L
.2149 .26337 L
.21798 .26612 L
.22107 .26877 L
.22415 .27132 L
.22723 .27374 L
.23031 .2761 L
.23339 .2784 L
.23648 .2807 L
.23956 .28299 L
.24264 .28531 L
.24572 .28766 L
.24881 .29003 L
.25189 .29248 L
.25497 .29503 L
.25805 .29767 L
.26113 .30046 L
.26422 .3033 L
.2673 .30618 L
.27038 .30906 L
.27346 .31189 L
.27654 .31462 L
.27963 .31723 L
.28271 .3196 L
.28579 .32176 L
.28887 .32371 L
.29196 .32543 L
.29504 .32689 L
.29812 .3281 L
.3012 .3291 L
.30428 .32991 L
.30737 .3305 L
.31045 .33086 L
.31353 .33097 L
.31661 .33075 L
.31969 .33013 L
.32278 .32923 L
.32586 .32814 L
.32894 .32688 L
.33202 .32546 L
Mistroke
.33511 .3239 L
.33819 .32222 L
.34127 .32046 L
.34435 .31862 L
.34743 .31671 L
.35052 .31474 L
.3536 .3127 L
.35668 .31056 L
.35976 .3083 L
.36284 .30592 L
.36593 .30338 L
.36901 .30064 L
.37209 .29769 L
.37517 .2945 L
.37826 .29107 L
.38134 .28737 L
.38442 .2834 L
.3875 .27917 L
.39058 .27472 L
.39367 .27012 L
.39675 .26551 L
.39983 .26105 L
.40291 .2569 L
.40599 .25311 L
.40908 .2497 L
.41216 .24668 L
.41524 .24407 L
.41832 .24189 L
.42141 .24022 L
.42449 .23909 L
.42757 .23851 L
.43065 .23849 L
.43373 .23904 L
.43682 .24013 L
.4399 .24176 L
.44298 .24395 L
.44606 .24662 L
.44914 .24982 L
.45223 .25353 L
.45531 .25776 L
.45839 .26248 L
.46147 .26765 L
.46456 .27321 L
.46764 .27914 L
.47072 .28539 L
.4738 .29191 L
.47688 .29864 L
.47997 .30554 L
.48305 .31258 L
.48613 .31966 L
Mistroke
.48921 .32659 L
.49229 .33323 L
.49538 .33955 L
.49846 .34553 L
.50154 .35111 L
.50462 .3563 L
.50771 .36112 L
.51079 .36554 L
.51387 .36958 L
.51695 .37321 L
.52003 .37644 L
.52312 .37924 L
.5262 .38158 L
.52928 .38345 L
.53236 .38481 L
.53544 .38564 L
.53853 .38588 L
.54161 .38554 L
.54469 .38458 L
.54777 .38302 L
.55086 .38088 L
.55394 .37819 L
.55702 .37502 L
.5601 .37141 L
.56318 .36746 L
.56627 .36322 L
.56935 .35875 L
.57243 .35408 L
.57551 .34929 L
.57859 .34447 L
.58168 .33971 L
.58476 .33503 L
.58784 .3305 L
.59092 .32609 L
.59401 .32187 L
.59709 .31781 L
.60017 .31394 L
.60325 .31016 L
.60633 .30637 L
.60942 .30255 L
.6125 .2987 L
.61558 .29484 L
.61866 .29099 L
.62174 .28721 L
.62483 .28351 L
.62791 .27991 L
.63099 .27644 L
.63407 .27313 L
.63716 .26996 L
.64024 .26696 L
Mistroke
.64332 .26411 L
.6464 .26143 L
.64948 .25893 L
.65257 .25663 L
.65565 .25454 L
.65873 .25268 L
.66181 .25109 L
.66489 .24978 L
.66798 .24877 L
.67106 .24806 L
.67414 .24759 L
.67722 .24724 L
.68031 .24701 L
.68339 .24678 L
.68647 .24661 L
.68955 .24649 L
.69263 .24647 L
.69572 .24658 L
.6988 .24685 L
.70188 .24731 L
.70496 .24799 L
.70804 .24887 L
.71113 .24995 L
.71421 .25125 L
.71729 .25277 L
.72037 .25451 L
.72346 .25646 L
.72654 .25864 L
.72962 .26102 L
.7327 .26356 L
.73578 .26626 L
.73887 .26907 L
.74195 .27199 L
.74503 .27499 L
.74811 .27807 L
.75119 .28122 L
.75428 .28441 L
.75736 .28768 L
.76044 .29101 L
.76352 .29438 L
.76661 .29777 L
.76969 .30115 L
.77277 .30452 L
.77585 .30784 L
.77893 .3111 L
.78202 .31434 L
.7851 .31755 L
.78818 .32071 L
.79126 .32374 L
.79434 .32664 L
Mistroke
.79743 .32945 L
.80051 .33213 L
.80359 .33464 L
.80667 .3369 L
.80975 .33873 L
.81284 .34025 L
.81592 .34142 L
.819 .34228 L
.82208 .34279 L
.82517 .34295 L
.82825 .34283 L
.83133 .34244 L
.83441 .34185 L
.83749 .3411 L
.84058 .34028 L
.84366 .33946 L
.84674 .33871 L
.84982 .33805 L
.8529 .33745 L
.85599 .33695 L
.85907 .33655 L
.86215 .33626 L
.86523 .33609 L
.86832 .33604 L
.8714 .33611 L
.87448 .33624 L
.87756 .33642 L
.88064 .33658 L
.88373 .33668 L
.88681 .33667 L
.88989 .33649 L
.89297 .33608 L
.89605 .3354 L
.89914 .33445 L
.90222 .33317 L
.9053 .33157 L
.90838 .32961 L
.91147 .32727 L
.91455 .32456 L
.91763 .32147 L
.92071 .31896 L
.92379 .3171 L
.92688 .31542 L
.92996 .31388 L
.93304 .31247 L
.93612 .3112 L
.9392 .31008 L
.94229 .30913 L
.94537 .30835 L
.94845 .30777 L
Mistroke
.95153 .30737 L
.95462 .30717 L
.9577 .30719 L
.96078 .30741 L
.96386 .30784 L
.96694 .30847 L
.97003 .3093 L
.97311 .31029 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`004`3oool500000?l0ooooD@3oool001D0oooo00<0
00000?ooo`3oool0o`3ooomA0?ooo`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo000:0?oo
o`H000001@3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooom90?ooo`005@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooB@3oool001D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000C0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooodT0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom9
0?ooo`007@3oool200000?l0ooooBP3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0
oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo
000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?oo
o`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00
7@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3o
ool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool000@0
oooo0P0000070?ooo`030000003oool0oooo00<0oooo100000060?ooo`030000003oool0oooo0?l0
ooooB@3oool000@0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB@3oool000d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooB@3o
ool000h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`<00000o`3ooom9
0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool00`000000oooo0?ooo`3o0?oo
odT0oooo000?0?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`3o0?oo
odT0oooo000:0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?oo
o`030000003oool0oooo0?l0ooooB@3oool000X0oooo1P0000030?ooo`D000001@3oool00`000000
oooo0?ooo`3o0?ooodT0oooo000M0?ooo`800000o`3ooom:0?ooo`007@3oool00`000000oooo0?oo
o`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?oo
o`3oool0o`3ooom90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`800000
o`3ooom:0?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0
oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool00`000000
oooo0?ooo`3o0?ooodT0oooo000M0?ooo`800000o`3ooom:0?ooo`007@3oool00`000000oooo0?oo
o`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?oo
o`3oool0o`3ooom90?ooo`007@3oool200000?l0ooooBP3oool001d0oooo00<000000?ooo`3oool0
o`3ooom90?ooo`000`3oool4000000D0oooo0P0000050?ooo`@000001P3oool00`000000oooo0?oo
o`3o0?ooodT0oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?l0ooooB@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom90?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool300000?l0
ooooB@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`@00000
1P3oool00`000000oooo0?ooo`3o0?ooodT0oooo00020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0ooooB@3o
ool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooom90?ooo`000`3oool4000000`0oooo1@0000050?oo
o`030000003oool0oooo0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000
003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool0
0`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0
oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0ooooB@3oool001d0oooo00<0
00000?ooo`3oool0o`3ooom90?ooo`007@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000M0?oo
o`030000003oool0oooo0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000
003oool0oooo0?l0ooooB@3oool001d0oooo00<000000?ooo`3oool0o`3ooom90?ooo`007@3oool0
0`000000oooo0?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo0280oooo1`3o003o0?oo
ob00oooo000M0?ooo`8000008P3oool00`3o0000oooo0?ooo`050?ooo`80o`00o`3ooolN0?ooo`00
7@3oool00`000000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
o`3ooolK0?ooo`00103oool2000000@0oooo1@0000040?ooo`@000001P3oool00`000000oooo0?oo
o`0O0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0o`3ooolJ0?ooo`00103oool2
000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00`0oooo0P3o
003o0?oooaX0oooo000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0o`3ooolG
0?ooo`00303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo0`00000L0?oo
o`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0o`3ooolF0?ooo`003@3oool00`000000
oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0180
oooo00<0o`000?ooo`3oool0o`3ooolE0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo04D0oooo1P3o00380?ooo`002P3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030?l0003oool0oooo01D0oooo
00<0o`000?ooo`3oool0@P3oool20?l000H0oooo0P3o00360?ooo`002`3oool3000000D0oooo1@00
00050?ooo`8000006`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0400oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`160?ooo`P0o`00M@3oool001d0oooo00<00000
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo03h0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`110?ooo`@0o`001`3oool40?l00780oooo000M0?oo
o`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0m0?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0?P3oool20?l000l0oooo0P3o001`0?oo
o`007@3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3o
ool0>`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo03`0oooo0P3o000C0?ooo`80
o`00KP3oool001d0oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0L0?ooo`030?l0
003oool0oooo03X0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0
003oool0oooo01D0oooo00<0o`000?ooo`3oool0J`3oool001d0oooo0P00000I0?ooo`030?l0003o
ool0oooo00d0oooo100000040?ooo`@00000103oool00`3o0000oooo0?ooo`0I0?ooo`D000000`3o
ool4000000@0oooo1000000<0?ooo`030?l0003oool0oooo00h0oooo00<000000?l0000000000P00
00030?ooo`@00000103oool4000001/0oooo1@0000040?ooo`@0000000@0o`000?ooo`3oool0oooo
1000000B0?ooo`030?l0003oool0oooo00L0oooo1@0000040?ooo`@00000103oool4000001`0oooo
0`0000050?ooo`@00000103oool4000001h0oooo000M0?ooo`030000003oool0oooo01P0oooo00<0
o`000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool20?l001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`3o0000
oooo0?ooo`0@0?ooo`030?l000000000oooo00<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`060000003oool0oooo0?ooo`3o000000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo0P3o00070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo01/0oooo000M0?ooo`030000003oool0oooo01L0oooo00<0o`00
0?ooo`3oool04P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<0
o`000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo0180oooo
00<0o`000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0103oool01P000000oooo0?ooo`3o0000oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool06`3oool001d0oooo00<000000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`070?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0o`000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0C0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo000000040?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0>0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo00<0o`000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?oo
o`030?l0003oool0oooo01<0oooo00<000000?l0003oool00`3oool4000000<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00<000000?l0
003oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01@0oooo00<0o`00
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`@000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`007@3oool2000001L0oooo00<0o`00
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool20?l001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`0D0?ooo`030000003o0000oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo0?l000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo0140oooo0`0000040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo0180oooo0`0000000`3oool0o`000?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`3o000000000?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5P3oool0103o0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo
00l0oooo1@0000030?ooo`@000003@3oool20?l001<0oooo00<000000?ooo`3oool00`3oool40000
00@0oooo100000070?ooo`030?l0003oool0oooo01D0oooo00@000000?ooo`3oool0o`000P3oool5
000000<0oooo1000000L0?ooo`<000000P3oool00`3o0000oooo0?ooo`04000000@0oooo1000000J
0?ooo`030?l0003oool0oooo00<000001@3oool5000000<0oooo1000000L0?ooo`<000001@3oool4
000000@0oooo1000000N0?ooo`007@3oool00`000000oooo0?ooo`0F0?ooo`030?l0003oool0oooo
02X0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo
02`0oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`1Q0?ooo`007@3oool00`000000
oooo0?ooo`0F0?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool09P3oool00`3o0000
oooo0?ooo`0K0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000
oooo0?ooo`1P0?ooo`007@3oool2000001L0oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo
0?ooo`0T0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`0/0?ooo`030?l0003oool0oooo05l0oooo000M0?ooo`030000003oool0oooo01D0oooo00<0
o`000?ooo`3oool0;P3oool20?l002<0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`0X0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool0GP3oool001d0oooo00<00000
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0`0?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo02l0oooo00<0o`00
0?ooo`3oool0G@3oool001d0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0a0?oo
o`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0V0?oo
o`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0G03oool001d0oooo00<000000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0380oooo00<0o`000?ooo`3o
ool0=@3oool40?l002<0oooo000F0?oooah0000000<0o`00000000000000=00000000`3o00000000
0000000H00000080o`009@0000000`3o000000000000000S000000030?l000000000000003@00000
00<0o`00000000000000<00000040?l000@000001@3o0007000001L0oooo000M0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3o00050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000o`000?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0?l000000000oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00@0o`000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo0?ooo`<0o`000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01/0oooo000M0?ooo`030000003oool0oooo01@0oooo00<0o`000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0L0?ooo`80o`003`3oool00`000000oooo0?ooo`020?ooo`80o`00:@3oool00`3o
000000000?ooo`0Q0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool01@3o
0000oooo0?ooo`3oool0000002L0oooo0P3o00060?ooo`030000003oool0oooo02D0oooo000M0?oo
o`030000003oool0oooo01<0oooo00<0o`000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0@0?oo
o`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0h0?oo
o`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool0;P3oool001d0oooo00<000000?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0oooo00d0oooo0P3o000]0?ooo`03
0?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0U0?ooo`03
0?l0003oool0oooo02l0oooo000M0?ooo`800000503oool00`3o0000oooo0?ooo`0k0?ooo`80o`00
2`3oool20?l00300oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?ooo`0l0?ooo`80o`00
903oool00`3o0000oooo0?ooo`0`0?ooo`007@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo03h0oooo0`3o00050?ooo`<0o`00<P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo03l0oooo00<0o`000?ooo`3oool07`3oool20?l003<0oooo000M0?ooo`030000003oool0
oooo0180oooo00<0o`000?ooo`3oool0@@3oool50?l003H0oooo00<0o`000?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0<`3oool0
01d0oooo00<000000?ooo`3oool04P3oool00`3o0000oooo0?ooo`1l0?ooo`030?l0003oool0oooo
01X0oooo00<0o`000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0@0?ooo`D0o`001@3oool30?l0
03H0oooo000M0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool0O03oool00`3o0000
oooo0?ooo`0I0?ooo`030?l0003oool0oooo04<0oooo0P3o000:0?ooo`H0o`001@3oool50?l003T0
oooo000M0?ooo`8000004P3oool00`3o0000oooo0?ooo`1n0?ooo`030?l0003oool0oooo01P0oooo
00<0o`000?ooo`3oool0A@3oool30?l000<0oooo103o00190?ooo`007@3oool00`000000oooo0?oo
o`0A0?ooo`030?l0003oool0oooo07l0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?oo
o`190?ooo`<0o`00C@3oool001d0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`1o
0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0VP3oool001d0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`1o0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?oo
o`3oool0VP3oool001d0oooo0P00000A0?ooo`030?l0003oool0oooo0800oooo00<0o`000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`2K0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo0840oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`2L0?ooo`007@3o
ool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0880oooo00<0o`000?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`2L0?ooo`007@3oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0880oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`2M0?ooo`007@3oool00`00
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo08<0oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`2N0?ooo`007@3oool200000100oooo00<0o`000?ooo`3oool0Q@3oool00`3o0000
oooo0?ooo`0<0?ooo`030?l0003oool0oooo09l0oooo000M0?ooo`030000003oool0oooo00l0oooo
00<0o`000?ooo`3oool0QP3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo09l0oooo
00040?ooo`800000103oool5000000@0oooo100000060?ooo`030000003oool0oooo00l0oooo00<0
o`000?ooo`3oool0Q`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0:00oooo0004
0?ooo`800000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0R03o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0:40oooo000;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo08X0oooo0P3o00050?ooo`80o`00Y03oool000`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`<000003P3oool00`3o0000oooo0?ooo`2<0?ooo`D0o`00YP3oool000d0
oooo00<000000?ooo`3oool00`3oool4000000H0oooo00<000000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`3o0?ooocP0oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0?l0oooo>03oool000X0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`3o0?ooocP0oooo000;0?ooo`<000001@3oool5000000D0oooo00<0
00000?ooo`3oool03@3oool00`3o0000oooo0?ooo`3o0?ooocT0oooo000M0?ooo`8000003P3oool0
0`3o0000oooo0?ooo`3o0?ooocT0oooo000M0?ooo`030000003oool0oooo00d0oooo00<0o`000?oo
o`3oool0o`3oooli0?ooo`007@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0
oooo>@3oool001d0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?ooocX0oooo
000M0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0o`3ooolj0?ooo`007@3oool2
000000d0oooo00<0o`000?ooo`3oool0o`3ooolj0?ooo`007@3oool00`000000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0?l0oooo>P3oool001d0oooo00<000000?ooo`3oool0303oool00`3o0000
oooo0?ooo`3o0?ooocX0oooo000M0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0
o`3ooolk0?ooo`007@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0oooo>`3o
ool001d0oooo0P00000<0?ooo`030?l0003oool0oooo0?l0oooo>`3oool001d0oooo00<000000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`3o0?oooc/0oooo000M0?ooo`030000003oool0oooo00/0
oooo00<0o`000?ooo`3oool0o`3ooolk0?ooo`007@3oool00`000000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0?l0oooo?03oool001d0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`3o0?oooc`0oooo000M0?ooo`8000002`3oool00`3o0000oooo0?ooo`3o0?oooc`0oooo00030?oo
o`@000001@3oool2000000D0oooo100000060?ooo`030000003oool0oooo00X0oooo00<0o`000?oo
o`3oool0o`3oooll0?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo0?l0oooo?03oool00080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo00020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`<000002@3oool00`3o0000oooo0?oo
o`3o0?ooocd0oooo00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool4
000000H0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3o0?ooocd0oooo00020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<0o`000?ooo`3oool0o`3ooolm0?ooo`000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`090?ooo`030?l0003oool0oooo0?l0oooo?@3oool000<0oooo1000000<0?ooo`D00000
1@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0oooo?P3oool001d0oooo0P00
00090?ooo`030?l0003oool0oooo0?l0oooo?P3oool001d0oooo00<000000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`3o0?oooch0oooo000M0?ooo`030000003oool0oooo00P0oooo00<0o`000?oo
o`3oool0o`3oooln0?ooo`007@3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0?l0
oooo?P3oool001d0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3o0?ooocl0oooo
000M0?ooo`800000203oool00`3o0000oooo0?ooo`3o0?ooocl0oooo000M0?ooo`030000003oool0
oooo00L0oooo00<0o`000?ooo`3oool0o`3ooolo0?ooo`007@3oool00`000000oooo0?ooo`070?oo
o`030?l0003oool0oooo0?l0oooo?`3oool001d0oooo00<000000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`3o0?ooocl0oooo000M0?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0
o`3ooom00?ooo`007@3oool2000000L0oooo00<0o`000?ooo`3oool0o`3ooom00?ooo`007@3oool0
0`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0?l0oooo@03oool001d0oooo00<000000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`3o0?oood00oooo000M0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool0o`3ooom10?ooo`007@3oool00`000000oooo0?ooo`050?ooo`030?l0
003oool0oooo0?l0oooo@@3oool001d0oooo0P0000060?ooo`030?l0003oool0oooo0?l0oooo@@3o
ool001d0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oood40oooo00040?oo
o`8000001`3oool00`000000oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo0?l0oooo@P3oool000@0oooo0P0000070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<0o`000?ooo`3oool0o`3ooom20?ooo`003@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`3o0?oood80oooo
000>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool3000000@0oooo00<0
o`000?ooo`3oool0o`3ooom20?ooo`003P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo@`3oool000l0oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3ooom3
0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo@`3oool000X0oooo1P0000030?oo
o`D000001@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?l0oooo@`3oool001d0
oooo0P0000030?ooo`030?l0003oool0oooo0?l0ooooA03oool001d0oooo00<000000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`3o0?oood@0oooo000M0?ooo`030000003oool0oooo0080oooo00<0
o`000?ooo`3oool0o`3ooom40?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0
oooo0?l0ooooA03oool001d0oooo0P0000020?ooo`030?l0003oool0oooo0?l0ooooA@3oool001d0
oooo00D000000?ooo`3oool0oooo0?l0003o0?ooodL0oooo000M0?ooo`050000003oool0oooo0?oo
o`3o0000o`3ooom70?ooo`007@3oool010000000oooo0?ooo`3o003o0?ooodP0oooo000M0?ooo`04
0000003oool0oooo0?l00?l0ooooB03oool001d0oooo0P0000000`3o0000oooo0?ooo`3o0?ooodL0
oooo000M0?ooo`030000003oool0o`000?l0ooooB@3oool001d0oooo00<000000?l0003oool0o`3o
oom90?ooo`007@3oool00`000000o`000?ooo`3o0?ooodT0oooo000M0?ooo`030000003oool0oooo
0?l0ooooB@3oool001d0oooo0P00003o0?ooodX0oooo000M0?ooo`030000003oool0oooo0?l0oooo
B@3oool001<0oooo1@0000050?ooo`030000003oool0oooo0?l0ooooB@3oool001D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooodT0oooo000E0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0o`3ooom90?ooo`005@3oool00`000000oooo0?ooo`050?ooo`<0
0000o`3ooom90?ooo`005@3oool00`000000oooo0?ooo`3o0?oooe40oooo000E0?ooo`030000003o
ool0oooo0?l0ooooD@3oool001<0oooo0`00003o0?oooe<0oooo000E0?ooo`030000003oool0oooo
0?l0ooooD@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool005@0oooo1000000D
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool3000000/0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo00X0oooo001H0?ooo`030000003oool0oooo0140oooo0P00000I0?oo
o`800000A`3oool00`000000oooo0?ooo`0;0?ooo`8000004@3oool2000001<0oooo00<000000?oo
o`3oool00`3oool2000004d0oooo0P00000;0?ooo`000P0000030?ooo`<00000103oool4000000@0
oooo100000040?ooo`@000000`3oool5000000<0oooo1@0000040?ooo`D000000`3oool5000000<0
oooo1@0000030?ooo`<0000000<0oooo0000000000000P3oool3000000040?ooo`000000oooo0?oo
o`D00000103oool3000000030?ooo`000000000000H0000000<0oooo0000003oool01@3oool50000
0080oooo1@0000040?ooo`030000003oool0oooo00L0oooo0`0000030?ooo`040000003oool0oooo
0?ooo`<000000`3oool5000000D0oooo0`0000040?ooo`@00000103oool5000000<0oooo10000003
0?ooo`D0000000<0oooo0000003oool0103oool4000000D0oooo00<000000?ooo`3oool0203oool4
000000@0oooo00<000000?ooo`3oool0203oool4000000D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`070?ooo`<0000000@0oooo00000000000000000P3oool5000000<0oooo1@00
00040?ooo`8000001@3oool5000000@0oooo0`0000040?ooo`D000000`3oool4000000@0oooo0`00
00000`3oool00000000000080?ooo`80000000001@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0000000000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000@0oooo0P0000090?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P00
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`<000002@3oool10000000000D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`40000000001@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00@0oooo1P0000050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool500000080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo1@0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00l0oooo100000030?ooo`040000003oool0oooo0?ooo`<000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo000000020?ooo`H000001@3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo000000<0oooo1P0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`D000002P3oool10000000000D000000?oo
o`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000H0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`02000000050?ooo`00000000000?ooo`000000203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00H0oooo100000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0?0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool10000
000000<000000?ooo`3oool01@0000040?ooo`@00000103oool3000000030?ooo`000000oooo0080
oooo100000030?ooo`80000000@0oooo00000000000000000P3oool2000000040?ooo`0000000000
000000<0oooo100000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool4
000000@0oooo0`000000103oool000000000003oool2000000040?ooo`0000000000000000<0oooo
100000020?ooo`80000000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool4
000000H0oooo00<000000?ooo`3oool00`3oool4000000<0oooo0P0000000`3oool0000000000002
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000<0oooo1000
00060?ooo`040000003oool0oooo0?ooo`<000000P3oool300000080oooo100000030?ooo`D00000
103oool3000000D0oooo0`0000000`3oool000000?ooo`020?ooo`@000002`3oool100000000103o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3o
ool3000000@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`400000000m0?ooo`8000001P3o
ool2000003<0oooo00<000000?ooo`3oool00`3oool3000000l0oooo1@0000050?ooo`@000000P3o
ool5000000D0oooo1000000<0?ooo`8000004P3oool3000000<0oooo1000000@0?ooo`@000003`3o
ool4000000<0oooo0`00000@0?ooo`<0000000@0oooo00000000000000002`3oool2000001l0oooo
00<000000?ooo`3oool06@3oool200000000o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-30.729, -1.0579, 1.2899, \
0.0128654}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00649351 0.00649351 0.0106889 0.0001813 [
[.12338 -0.00181 -6 -9 ]
[.12338 -0.00181 6 0 ]
[.25325 -0.00181 -6 -9 ]
[.25325 -0.00181 6 0 ]
[.38312 -0.00181 -6 -9 ]
[.38312 -0.00181 6 0 ]
[.51299 -0.00181 -6 -9 ]
[.51299 -0.00181 6 0 ]
[.64286 -0.00181 -9 -9 ]
[.64286 -0.00181 9 0 ]
[.77273 -0.00181 -9 -9 ]
[.77273 -0.00181 9 0 ]
[.9026 -0.00181 -9 -9 ]
[.9026 -0.00181 9 0 ]
[-0.01899 .10134 -18 -4.5 ]
[-0.01899 .10134 0 4.5 ]
[-0.01899 .19199 -24 -4.5 ]
[-0.01899 .19199 0 4.5 ]
[-0.01899 .28264 -24 -4.5 ]
[-0.01899 .28264 0 4.5 ]
[-0.01899 .37329 -24 -4.5 ]
[-0.01899 .37329 0 4.5 ]
[-0.01899 .46394 -24 -4.5 ]
[-0.01899 .46394 0 4.5 ]
[.5 .5125 -186.688 0 ]
[.5 .5125 186.688 14 ]
[ -0.00649 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12338 .01069 m
.12338 .01694 L
s
[(20)] .12338 -0.00181 0 1 Mshowa
.25325 .01069 m
.25325 .01694 L
s
[(40)] .25325 -0.00181 0 1 Mshowa
.38312 .01069 m
.38312 .01694 L
s
[(60)] .38312 -0.00181 0 1 Mshowa
.51299 .01069 m
.51299 .01694 L
s
[(80)] .51299 -0.00181 0 1 Mshowa
.64286 .01069 m
.64286 .01694 L
s
[(100)] .64286 -0.00181 0 1 Mshowa
.77273 .01069 m
.77273 .01694 L
s
[(120)] .77273 -0.00181 0 1 Mshowa
.9026 .01069 m
.9026 .01694 L
s
[(140)] .9026 -0.00181 0 1 Mshowa
.125 Mabswid
.02597 .01069 m
.02597 .01444 L
s
.05844 .01069 m
.05844 .01444 L
s
.09091 .01069 m
.09091 .01444 L
s
.15584 .01069 m
.15584 .01444 L
s
.18831 .01069 m
.18831 .01444 L
s
.22078 .01069 m
.22078 .01444 L
s
.28571 .01069 m
.28571 .01444 L
s
.31818 .01069 m
.31818 .01444 L
s
.35065 .01069 m
.35065 .01444 L
s
.41558 .01069 m
.41558 .01444 L
s
.44805 .01069 m
.44805 .01444 L
s
.48052 .01069 m
.48052 .01444 L
s
.54545 .01069 m
.54545 .01444 L
s
.57792 .01069 m
.57792 .01444 L
s
.61039 .01069 m
.61039 .01444 L
s
.67532 .01069 m
.67532 .01444 L
s
.70779 .01069 m
.70779 .01444 L
s
.74026 .01069 m
.74026 .01444 L
s
.80519 .01069 m
.80519 .01444 L
s
.83766 .01069 m
.83766 .01444 L
s
.87013 .01069 m
.87013 .01444 L
s
.93506 .01069 m
.93506 .01444 L
s
.96753 .01069 m
.96753 .01444 L
s
.25 Mabswid
0 .01069 m
1 .01069 L
s
-0.00649 .10134 m
-0.00024 .10134 L
s
[(500)] -0.01899 .10134 1 0 Mshowa
-0.00649 .19199 m
-0.00024 .19199 L
s
[(1000)] -0.01899 .19199 1 0 Mshowa
-0.00649 .28264 m
-0.00024 .28264 L
s
[(1500)] -0.01899 .28264 1 0 Mshowa
-0.00649 .37329 m
-0.00024 .37329 L
s
[(2000)] -0.01899 .37329 1 0 Mshowa
-0.00649 .46394 m
-0.00024 .46394 L
s
[(2500)] -0.01899 .46394 1 0 Mshowa
.125 Mabswid
-0.00649 .02882 m
-0.00274 .02882 L
s
-0.00649 .04695 m
-0.00274 .04695 L
s
-0.00649 .06508 m
-0.00274 .06508 L
s
-0.00649 .08321 m
-0.00274 .08321 L
s
-0.00649 .11947 m
-0.00274 .11947 L
s
-0.00649 .1376 m
-0.00274 .1376 L
s
-0.00649 .15573 m
-0.00274 .15573 L
s
-0.00649 .17386 m
-0.00274 .17386 L
s
-0.00649 .21012 m
-0.00274 .21012 L
s
-0.00649 .22825 m
-0.00274 .22825 L
s
-0.00649 .24638 m
-0.00274 .24638 L
s
-0.00649 .26451 m
-0.00274 .26451 L
s
-0.00649 .30077 m
-0.00274 .30077 L
s
-0.00649 .3189 m
-0.00274 .3189 L
s
-0.00649 .33703 m
-0.00274 .33703 L
s
-0.00649 .35516 m
-0.00274 .35516 L
s
-0.00649 .39142 m
-0.00274 .39142 L
s
-0.00649 .40955 m
-0.00274 .40955 L
s
-0.00649 .42768 m
-0.00274 .42768 L
s
-0.00649 .44581 m
-0.00274 .44581 L
s
-0.00649 .48207 m
-0.00274 .48207 L
s
.25 Mabswid
-0.00649 0 m
-0.00649 .5 L
s
gsave
.5 .5125 -247.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Fourier) show
129.000 14.000 moveto
(Coefficients) show
201.000 14.000 moveto
0.000 0.000 rmoveto
201.000 14.000 moveto
(,) show
210.563 14.000 moveto
(12) show
222.563 14.000 moveto
(,) show
232.125 14.000 moveto
(RGBColor) show
280.125 14.000 moveto
([) show
286.125 14.000 moveto
(0) show
292.125 14.000 moveto
(,) show
301.688 14.000 moveto
(0) show
307.688 14.000 moveto
(,) show
317.250 14.000 moveto
(0) show
323.250 14.000 moveto
(]) show
329.250 14.000 moveto
(,) show
338.813 14.000 moveto
0.000 0.000 rmoveto
338.813 14.000 moveto
(Helvetica) show
392.813 14.000 moveto
0.000 0.000 rmoveto
392.813 14.000 moveto
(,) show
402.375 14.000 moveto
0.000 0.000 rmoveto
402.375 14.000 moveto
(Bold) show
426.375 14.000 moveto
0.000 0.000 rmoveto
426.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
0 0 .502 r
.5 Mabswid
0 .4881 m
.00649 .07337 L
.01299 .10301 L
.01948 .07005 L
.02597 .0896 L
.03247 .05791 L
.03896 .06643 L
.04545 .03162 L
.05195 .03556 L
.05844 .02266 L
.06494 .03255 L
.07143 .03366 L
.07792 .02468 L
.08442 .02816 L
.09091 .02347 L
.0974 .01359 L
.1039 .02132 L
.11039 .0119 L
.11688 .01794 L
.12338 .01623 L
.12987 .01546 L
.13636 .01463 L
.14286 .01657 L
.14935 .01752 L
.15584 .01741 L
.16234 .01619 L
.16883 .01783 L
.17532 .01619 L
.18182 .01635 L
.18831 .01691 L
.19481 .01567 L
.2013 .01532 L
.20779 .01554 L
.21429 .01506 L
.22078 .01489 L
.22727 .01455 L
.23377 .01485 L
.24026 .01481 L
.24675 .01486 L
.25325 .0156 L
.25974 .01516 L
.26623 .01531 L
.27273 .01544 L
.27922 .01524 L
.28571 .0152 L
.29221 .01522 L
.2987 .0151 L
.30519 .01504 L
.31169 .01468 L
.31818 .01482 L
Mistroke
.32468 .01452 L
.33117 .01465 L
.33766 .01472 L
.34416 .01458 L
.35065 .01469 L
.35714 .01477 L
.36364 .01486 L
.37013 .01487 L
.37662 .01477 L
.38312 .01486 L
.38961 .01476 L
.3961 .01482 L
.4026 .01477 L
.40909 .01467 L
.41558 .01459 L
.42208 .01452 L
.42857 .01455 L
.43506 .01455 L
.44156 .01456 L
.44805 .01449 L
.45455 .01452 L
.46104 .01457 L
.46753 .01465 L
.47403 .01461 L
.48052 .01468 L
.48701 .01466 L
.49351 .01465 L
.5 .01463 L
.50649 .01463 L
.51299 .01456 L
.51948 .01452 L
.52597 .0145 L
.53247 .01447 L
.53896 .0144 L
.54545 .01447 L
.55195 .01448 L
.55844 .01446 L
.56494 .01447 L
.57143 .01452 L
.57792 .01453 L
.58442 .01455 L
.59091 .01457 L
.5974 .01457 L
.6039 .01453 L
.61039 .01452 L
.61688 .01452 L
.62338 .01449 L
.62987 .01447 L
.63636 .01443 L
.64286 .01441 L
Mistroke
.64935 .01444 L
.65584 .01443 L
.66234 .01444 L
.66883 .01444 L
.67532 .01447 L
.68182 .01449 L
.68831 .01449 L
.69481 .01453 L
.7013 .01451 L
.70779 .01449 L
.71429 .01447 L
.72078 .01449 L
.72727 .01448 L
.73377 .01446 L
.74026 .01444 L
.74675 .01443 L
.75325 .01444 L
.75974 .01443 L
.76623 .01443 L
.77273 .01443 L
.77922 .01445 L
.78571 .01444 L
.79221 .01447 L
.7987 .01448 L
.80519 .01446 L
.81169 .01446 L
.81818 .01445 L
.82468 .01445 L
.83117 .01446 L
.83766 .01444 L
.84416 .01444 L
.85065 .01441 L
.85714 .01442 L
.86364 .01441 L
.87013 .01442 L
.87662 .01444 L
.88312 .01445 L
.88961 .01444 L
.8961 .01444 L
.9026 .01445 L
.90909 .01445 L
.91558 .01447 L
.92208 .01446 L
.92857 .01444 L
.93506 .01441 L
.94156 .01444 L
.94805 .01442 L
.95455 .01443 L
.96104 .01442 L
.96753 .0144 L
Mistroke
.97403 .01442 L
.98052 .01444 L
.98701 .01449 L
.99351 .01448 L
1 .01445 L
Mfstroke
1 .01445 m
1 .01445 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003oo`3ooomY
0?ooo`00?P3oool5000000@0oooo1000000L0?ooo`<000000`3oool4000001/0oooo0`0000040?oo
o`@000006P3oool4000000@0oooo1000000F0?ooo`D000000`3oool4000000@0oooo1000000B0?oo
o`D000000P3oool5000000@0oooo1000000B0?ooo`D000001@3oool3000000<0oooo1000000e0?oo
o`00?P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0G
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0<P3oool003l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01X0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0<P3oool00400oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo1P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool05`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0380oooo00110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0<P3oool00480oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01L0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0380
oooo000n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01<0oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`<00000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`<000001P3o
ool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<P3o
ool003l0oooo0`0000050?ooo`@00000703oool2000000@0oooo1000000L0?ooo`<000000`3oool4
000001X0oooo100000040?ooo`@00000603oool00`000000oooo0?ooo`030?ooo`@00000103oool4
000001@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo1000000D0?ooo`030000003oool0
oooo00D0oooo0P0000040?ooo`@00000=@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0oooo
J@3oool001l0oooo00<000000?ooo`3oool0o`3ooom70?ooo`007`3oool00`000000oooo0?ooo`3o
0?ooodL0oooo000O0?ooo`030000003oool0oooo0?l0ooooA`3oool001l0oooo00<000000?ooo`00
0000o`00000U00000280oooo000O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0002000<0oooo00D000200?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000P03oool0000000T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`050?ooo`X0002000<0oooo0000003oool0203oool00`000000oooo0?ooo`060?ooo`h0
00201@3oool010000000oooo0?ooo`3oool30000P0<0oooo5P0008040?oooa0000201@3oool00`00
0800oooo0?ooo`0P0?ooo`007`3oool00`000000oooo0?ooo`0J0?ooo`070000P03oool000200?oo
o`000800oooo0000P0020?ooogT0002000<0oooo0000P00008006P0008020?ooo`030000003oool0
oooo00D0oooo5000080:0?ooo`040000003oool0oooo0?ooo`T000200`3oool30000P1<0oooo00<0
00000?ooo`3oool01000080@0?ooo`D000208`3oool001l0oooo00<000000?ooo`3oool06P3oool0
1@000800oooo0000P03oool000200080oooo0P00083o0?ooob@0oooo000O0?ooo`030000003oool0
oooo0100oooo00<000200?ooo`3oool00`3oool010000800oooo0?ooo`0008030?ooo`030000P03o
ool0oooo0?l0oooo9`3oool001l0oooo00<000000?ooo`3oool03`3oool00`000800oooo0000P003
0?ooo`040000P03oool000200000P?l0oooo;P3oool001l0oooo0P00000@0?ooo`030000P03oool0
002000<0oooo00@000200?ooo`3oool00020o`3oool^0?ooo`007`3oool00`000000oooo0?ooo`0<
0?ooo`030000P03oool0002000<0oooo0`00083o0?oooc80oooo000O0?ooo`030000003oool0oooo
00`0oooo0`00083o0?ooocP0oooo000O0?ooo`030000003oool0oooo00`0oooo00<000200?ooo`3o
ool0o`3ooolh0?ooo`007`3oool00`000000oooo0?ooo`0;0?ooo`030000P03oool0oooo0?l0oooo
>@3oool001l0oooo0P00000<0?ooo`030000P03oool0oooo0?l0oooo>@3oool001l0oooo00<00000
0?ooo`3oool02`3oool00`000800oooo0?ooo`3o0?ooocT0oooo000O0?ooo`030000003oool0oooo
00/0oooo00<000200?ooo`3oool0o`3oooli0?ooo`007`3oool00`000000oooo0?ooo`080?ooo`04
0000P03oool0oooo0000P?l0oooo>`3oool001l0oooo00<000000?ooo`3oool0203oool30000P?l0
oooo?03oool001l0oooo0P0000090?ooo`<00020o`3oooll0?ooo`007`3oool00`000000oooo0?oo
o`080?ooo`030000P03oool000200?l0oooo?03oool001l0oooo00<000000?ooo`3oool01@3oool0
10000800oooo0?ooo`00083o0?oooch0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3o
ool00`000800oooo0000P03o0?ooocl0oooo000O0?ooo`050000003oool0oooo0?ooo`0008000`3o
ool30000P?l0oooo?`3oool001l0oooo00D000000?ooo`3oool0oooo0000P0020?ooo`040000P03o
ool000200000P?l0oooo?`3oool001l0oooo0P0000020?ooo`80002000D0oooo0000P03oool0oooo
0000P03o0?ooocl0oooo000O0?ooo`040000003oool0oooo0?ooo`80002000D0oooo0000P03oool0
oooo0000P03o0?ooocl0oooo00050?ooo`@00000103oool4000000@0oooo100000060?ooo`040000
003oool0oooo0?ooo`80002000<0oooo0000P03oool0o`3ooom10?ooo`00103oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<00020o`3ooom30?ooo`002@3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0?ooo`3oool000200?ooo`000800o`3ooom30?ooo`002@3oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool30000
00040?ooo`000800oooo0000P?l0oooo@`3oool000D0oooo100000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000800o`3ooom50?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`000800o`3ooom50?ooo`001@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`000800o`3ooom50?ooo`001@3oool5000000<0oooo100000040?ooo`@00000
1P3oool01@000000oooo0?ooo`3oool000200?l0ooooA@3oool001l0oooo0P0000020?ooo`030000
P03oool0oooo0?l0oooo@`3oool001l0oooo00D000000?ooo`3oool0oooo0000P03o0?ooodD0oooo
000O0?ooo`050000003oool0oooo0?ooo`000800o`3ooom50?ooo`007`3oool01@000000oooo0?oo
o`3oool000200?l0ooooA@3oool001l0oooo00D000000?ooo`3oool0oooo0000P03o0?ooodD0oooo
000O0?ooo`8000000P3oool00`000800oooo0?ooo`3o0?oood<0oooo000O0?ooo`050000003oool0
oooo0?ooo`000800o`3ooom50?ooo`007`3oool01@000000oooo0?ooo`3oool000200?l0ooooA@3o
ool001l0oooo00D000000?ooo`3oool0oooo0000P03o0?ooodD0oooo000O0?ooo`050000003oool0
oooo0?ooo`000800o`3ooom50?ooo`007`3oool01@000000oooo0?ooo`3oool000200?l0ooooA@3o
ool001l0oooo0P0000020?ooo`030000P03oool0oooo0?l0oooo@`3oool001l0oooo00D000000?oo
o`3oool0oooo0000P03o0?ooodD0oooo000O0?ooo`050000003oool0oooo0?ooo`000800o`3ooom5
0?ooo`007`3oool01@000000oooo0?ooo`3oool000200?l0ooooA@3oool001l0oooo00D000000?oo
o`3oool0oooo0000P03o0?ooodD0oooo000O0?ooo`8000000P3oool00`000800oooo0?ooo`3o0?oo
od<0oooo000O0?ooo`050000003oool0oooo0?ooo`000800o`3ooom50?ooo`000P0000030?ooo`@0
0000103oool4000000@0oooo100000060?ooo`040000003oool0oooo0000P?l0ooooAP3oool000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00083o0?ooodH0oooo0004
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`00
103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`<0000000<000200?ooo`3oool0o`3ooom40?oo
o`00103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000P?l0ooooAP3o
ool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00083o0?ooodH0
oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00020o`3ooom6
0?ooo`001@3oool4000000@0oooo100000040?ooo`@000001P3oool010000000oooo0?ooo`00083o
0?ooodH0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo0P0000000`3o
ool000200?ooo`3o0?ooodD0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0
oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool010000000oooo0?ooo`00083o0?oo
odH0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo0P0000000`3oool0
00200?ooo`3o0?ooodD0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo
00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool010000000oooo0?ooo`00083o0?ooodH0
oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo0P0000000`3oool00020
0?ooo`3o0?ooodD0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo00@0
00000?ooo`3oool00020o`3ooom60?ooo`007`3oool010000000oooo0?ooo`00083o0?ooodH0oooo
000O0?ooo`040000003oool0oooo0000P?l0ooooAP3oool001l0oooo00@000000?ooo`3oool00020
o`3ooom60?ooo`007`3oool2000000030?ooo`000800oooo0?l0ooooA@3oool001l0oooo00@00000
0?ooo`3oool00020o`3ooom60?ooo`000P0000030?ooo`@00000103oool4000000@0oooo10000006
0?ooo`040000003oool0oooo0000P?l0ooooAP3oool000@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00083o0?ooodH0oooo00090?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
0000P?l0ooooAP3oool000T0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo0`0000000`000800oooo0?ooo`3o0?oood@0oooo0005
0?ooo`@000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00083o0?ooodH0oooo00050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo0000P?l0ooooAP3oool000D0oooo1@0000030?ooo`@0
0000103oool4000000H0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool200000003
0?ooo`000800oooo0?l0ooooA@3oool001l0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`00
7`3oool010000000oooo0?ooo`00083o0?ooodH0oooo000O0?ooo`040000003oool0oooo0000P?l0
ooooAP3oool001l0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool2000000030?oo
o`000800oooo0?l0ooooA@3oool001l0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3o
ool010000000oooo0?ooo`00083o0?ooodH0oooo000O0?ooo`040000003oool0oooo0000P?l0oooo
AP3oool001l0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool010000000oooo0?oo
o`00083o0?ooodH0oooo000O0?ooo`80000000<0oooo0000P03oool0o`3ooom50?ooo`007`3oool0
10000000oooo0?ooo`00083o0?ooodH0oooo000O0?ooo`040000003oool0oooo0000P?l0ooooAP3o
ool001l0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`007`3oool010000000oooo0?ooo`00
083o0?ooodH0oooo000O0?ooo`80000000<0oooo0000P03oool0o`3ooom50?ooo`007`3oool01000
0000oooo0?ooo`00083o0?ooodH0oooo00000`000000oooo0?ooo`020?ooo`@00000103oool40000
00@0oooo100000060?ooo`040000003oool0oooo0000P?l0ooooAP3oool000050000003oool0oooo
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00083o0?ooodH0oooo00040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00020o`3ooom60?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooo`<0000000<000200?ooo`3oool0o`3ooom40?ooo`00103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000P?l0ooooAP3oool000050000
003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00083o0?ooodH0oooo0000
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00020o`3ooom60?oo
o`001@3oool4000000@0oooo100000040?ooo`@000001P3oool00`000000oooo0000P03o0?ooodL0
oooo000O0?ooo`030000003oool000200?l0ooooA`3oool001l0oooo0P0000000`000800oooo0?oo
o`3o0?ooodD0oooo000O0?ooo`030000003oool000200?l0ooooA`3oool001l0oooo00<000000?oo
o`000800o`3ooom70?ooo`007`3oool00`000000oooo0000P03o0?ooodL0oooo000O0?ooo`030000
003oool000200?l0ooooA`3oool001l0oooo0P0000000`000800oooo0?ooo`3o0?ooodD0oooo000O
0?ooo`030000003oool000200?l0ooooA`3oool001l0oooo00<000000?ooo`000800o`3ooom70?oo
o`007`3oool00`000000oooo0000P03o0?ooodL0oooo000O0?ooo`030000003oool000200?l0oooo
A`3oool001l0oooo0P0000000`000800oooo0?ooo`3o0?ooodD0oooo000O0?ooo`030000003oool0
00200?l0ooooA`3oool001l0oooo00<000000?ooo`000800o`3ooom70?ooo`007`3oool00`000000
oooo0000P03o0?ooodL0oooo000O0?ooo`030000003oool000200?l0ooooA`3oool001l0oooo00<0
00000?ooo`000800o`3ooom70?ooo`007`3oool2000000030000P03oool0oooo0?l0ooooA@3oool0
01l0oooo00<000000?ooo`000800o`3ooom70?ooo`0000<000000?ooo`3oool00P3oool4000000@0
oooo100000040?ooo`@000001P3oool00`000000oooo0000P03o0?ooodL0oooo00001@000000oooo
0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000800o`3ooom70?ooo`002@3oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0000P03o0?ooodL0oooo00090?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`80000000<000200?ooo`3oool0
o`3ooom50?ooo`001@3oool4000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000800o`3ooom70?ooo`0000<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool000200?l0oooo
A`3oool000030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0000P03o0?ooodL0oooo00050?ooo`D000000`3oool4000000@0oooo100000060?ooo`030000003o
ool000200?l0ooooA`3oool001l0oooo0P0000000`000800oooo0?ooo`3o0?ooodD0oooo000O0?oo
o`030000003oool000200?l0ooooA`3oool001l0oooo00<000000?ooo`000800o`3ooom70?ooo`00
7`3oool00`000000oooo0?ooo`3o0?ooodL0oooo000O0?ooo`030000003oool0oooo0?l0ooooA`3o
ool001l0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
N`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04H0oooo0`00000;0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0403oool3000000D0oooo00<000000?ooo`3oool0
BP3oool007/0oooo0P00000I0?ooo`800000A`3oool00`000000oooo0?ooo`0;0?ooo`8000004@3o
ool2000001<0oooo00<000000?ooo`3oool00`3oool2000004/0oooo00000`000000oooo0?ooo`02
0?ooo`D000000`3oool500000080oooo1@0000090?ooo`<00000103oool4000000@0oooo1@000002
0?ooo`H000000P3oool6000000<0oooo1@0000030?ooo`@00000103oool5000000<0oooo1@000002
0?ooo`<0000000@0oooo00000000000000000`3oool3000000<0oooo1@00000:0?ooo`D000000P3o
ool5000000@0oooo00<000000?ooo`3oool01`3oool3000000<0oooo00@000000?ooo`3oool0oooo
0`0000030?ooo`D000001@3oool3000000@0oooo100000040?ooo`D000000`3oool4000000<0oooo
1@0000000`3oool000000?ooo`040?ooo`@000001@3oool00`000000oooo0?ooo`080?ooo`@00000
103oool00`000000oooo0?ooo`080?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00L0oooo0`000000103oool000000000000000020?ooo`D000000`3oool5000000@0
oooo0P0000050?ooo`D00000103oool3000000@0oooo1@0000030?ooo`@00000103oool100000000
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3oool2000000/0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo0P0000090?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000P0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0P000004
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000010?ooo`001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000L0
oooo00<000000?ooo`3oool00P3oool6000000<0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P0000040?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool6000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00D0oooo1000000<0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool4000000<0oooo00@000000?ooo`3oool0oooo0`000002
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool000000080oooo1P0000050?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool6000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0@00000000L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`8000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`@000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`000000
2@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool100000040
oooo0002000000<0oooo0`0000050?ooo`@000000`3oool2000000040?ooo`0000000000000000H0
oooo00<000000?ooo`3oool01P3oool4000000@0oooo100000030?ooo`H000000P3oool6000000<0
oooo0`0000050?ooo`<0000000<0oooo0000003oool00P3oool3000000D0oooo100000030?ooo`80
000000<0oooo0000000000000`3oool5000000@0oooo1@00000;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool4
000000H0oooo00<000000?ooo`3oool00`3oool4000000<0oooo0P0000000`3oool0000000000002
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000<0oooo1000
00060?ooo`040000003oool0oooo0?ooo`<000000P3oool300000080oooo100000030?ooo`D00000
103oool3000000D0oooo0`0000000`3oool000000?ooo`020?ooo`400000000Q0?ooo`050000003o
ool0oooo0?ooo`000000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool04`3oool3000000@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool0000000d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`00
1`3oool00`000000oooo0?ooo`0H0?ooo`@000005@3oool3000000D0oooo0`0000050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`<00000
3`3oool5000000D0oooo100000020?ooo`D000001@3oool4000000`0oooo0P00000B0?ooo`<00000
0`3oool400000100oooo1000000?0?ooo`@000000`3oool300000100oooo0`000000103oool00000
00000000000;0?ooo`8000007`3oool00`000000oooo0?ooo`0<0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-16.6237, -281.362, 0.658939, \
23.6008}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0207174 0.00309215 0.00910665 0.00105579 [
[.17532 -0.00339 -6 -9 ]
[.17532 -0.00339 6 0 ]
[.32993 -0.00339 -9 -9 ]
[.32993 -0.00339 9 0 ]
[.48454 -0.00339 -9 -9 ]
[.48454 -0.00339 9 0 ]
[.63915 -0.00339 -9 -9 ]
[.63915 -0.00339 9 0 ]
[.79375 -0.00339 -9 -9 ]
[.79375 -0.00339 9 0 ]
[.94836 -0.00339 -9 -9 ]
[.94836 -0.00339 9 0 ]
[.00822 .11469 -18 -4.5 ]
[.00822 .11469 0 4.5 ]
[.00822 .22026 -18 -4.5 ]
[.00822 .22026 0 4.5 ]
[.00822 .32584 -18 -4.5 ]
[.00822 .32584 0 4.5 ]
[.00822 .43142 -18 -4.5 ]
[.00822 .43142 0 4.5 ]
[.5 .5125 -234.688 0 ]
[.5 .5125 234.688 14 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17532 .00911 m
.17532 .01536 L
s
[(50)] .17532 -0.00339 0 1 Mshowa
.32993 .00911 m
.32993 .01536 L
s
[(100)] .32993 -0.00339 0 1 Mshowa
.48454 .00911 m
.48454 .01536 L
s
[(150)] .48454 -0.00339 0 1 Mshowa
.63915 .00911 m
.63915 .01536 L
s
[(200)] .63915 -0.00339 0 1 Mshowa
.79375 .00911 m
.79375 .01536 L
s
[(250)] .79375 -0.00339 0 1 Mshowa
.94836 .00911 m
.94836 .01536 L
s
[(300)] .94836 -0.00339 0 1 Mshowa
.125 Mabswid
.05164 .00911 m
.05164 .01286 L
s
.08256 .00911 m
.08256 .01286 L
s
.11348 .00911 m
.11348 .01286 L
s
.1444 .00911 m
.1444 .01286 L
s
.20625 .00911 m
.20625 .01286 L
s
.23717 .00911 m
.23717 .01286 L
s
.26809 .00911 m
.26809 .01286 L
s
.29901 .00911 m
.29901 .01286 L
s
.36085 .00911 m
.36085 .01286 L
s
.39177 .00911 m
.39177 .01286 L
s
.4227 .00911 m
.4227 .01286 L
s
.45362 .00911 m
.45362 .01286 L
s
.51546 .00911 m
.51546 .01286 L
s
.54638 .00911 m
.54638 .01286 L
s
.5773 .00911 m
.5773 .01286 L
s
.60823 .00911 m
.60823 .01286 L
s
.67007 .00911 m
.67007 .01286 L
s
.70099 .00911 m
.70099 .01286 L
s
.73191 .00911 m
.73191 .01286 L
s
.76283 .00911 m
.76283 .01286 L
s
.82468 .00911 m
.82468 .01286 L
s
.8556 .00911 m
.8556 .01286 L
s
.88652 .00911 m
.88652 .01286 L
s
.91744 .00911 m
.91744 .01286 L
s
.97928 .00911 m
.97928 .01286 L
s
.25 Mabswid
0 .00911 m
1 .00911 L
s
.02072 .11469 m
.02697 .11469 L
s
[(100)] .00822 .11469 1 0 Mshowa
.02072 .22026 m
.02697 .22026 L
s
[(200)] .00822 .22026 1 0 Mshowa
.02072 .32584 m
.02697 .32584 L
s
[(300)] .00822 .32584 1 0 Mshowa
.02072 .43142 m
.02697 .43142 L
s
[(400)] .00822 .43142 1 0 Mshowa
.125 Mabswid
.02072 .03022 m
.02447 .03022 L
s
.02072 .05134 m
.02447 .05134 L
s
.02072 .07245 m
.02447 .07245 L
s
.02072 .09357 m
.02447 .09357 L
s
.02072 .1358 m
.02447 .1358 L
s
.02072 .15692 m
.02447 .15692 L
s
.02072 .17803 m
.02447 .17803 L
s
.02072 .19915 m
.02447 .19915 L
s
.02072 .24138 m
.02447 .24138 L
s
.02072 .2625 m
.02447 .2625 L
s
.02072 .28361 m
.02447 .28361 L
s
.02072 .30473 m
.02447 .30473 L
s
.02072 .34696 m
.02447 .34696 L
s
.02072 .36807 m
.02447 .36807 L
s
.02072 .38919 m
.02447 .38919 L
s
.02072 .41031 m
.02447 .41031 L
s
.02072 .45254 m
.02447 .45254 L
s
.02072 .47365 m
.02447 .47365 L
s
.02072 .49477 m
.02447 .49477 L
s
.25 Mabswid
.02072 0 m
.02072 .5 L
s
gsave
.5 .5125 -295.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sF) show
75.000 14.000 moveto
([) show
81.000 14.000 moveto
0.000 0.000 rmoveto
81.000 14.000 moveto
(Originial) show
141.000 14.000 moveto
(Series) show
183.000 14.000 moveto
(vs) show
195.000 14.000 moveto
(.) show
207.000 14.000 moveto
(Inverse) show
255.000 14.000 moveto
(Fourier) show
297.000 14.000 moveto
0.000 0.000 rmoveto
297.000 14.000 moveto
(,) show
306.563 14.000 moveto
(12) show
318.563 14.000 moveto
(,) show
328.125 14.000 moveto
(RGBColor) show
376.125 14.000 moveto
([) show
382.125 14.000 moveto
(0) show
388.125 14.000 moveto
(,) show
397.688 14.000 moveto
(0) show
403.688 14.000 moveto
(,) show
413.250 14.000 moveto
(0) show
419.250 14.000 moveto
(]) show
425.250 14.000 moveto
(,) show
434.813 14.000 moveto
0.000 0.000 rmoveto
434.813 14.000 moveto
(Helvetica) show
488.813 14.000 moveto
0.000 0.000 rmoveto
488.813 14.000 moveto
(,) show
498.375 14.000 moveto
0.000 0.000 rmoveto
498.375 14.000 moveto
(Bold) show
522.375 14.000 moveto
0.000 0.000 rmoveto
522.375 14.000 moveto
(]) show
1.000 setlinewidth
grestore
1 0 0 r
.001 w
.02381 .4881 m
.0269 .0119 L
.02999 .01628 L
.03309 .02035 L
.03618 .02564 L
.03927 .03142 L
.04236 .03746 L
.04545 .04314 L
.04855 .04924 L
.05164 .05473 L
.05473 .06029 L
.05782 .06566 L
.06092 .07031 L
.06401 .07407 L
.0671 .07696 L
.07019 .07878 L
.07328 .08184 L
.07638 .08413 L
.07947 .08597 L
.08256 .08635 L
.08565 .08622 L
.08874 .08408 L
.09184 .08181 L
.09493 .07791 L
.09802 .0733 L
.10111 .06728 L
.10421 .06199 L
.1073 .05643 L
.11039 .05153 L
.11348 .04666 L
.11657 .04211 L
.11967 .03795 L
.12276 .03458 L
.12585 .03176 L
.12894 .02996 L
.13203 .0295 L
.13513 .03044 L
.13822 .03268 L
.14131 .03646 L
.1444 .041 L
.1475 .0463 L
.15059 .05224 L
.15368 .05889 L
.15677 .06656 L
.15986 .07495 L
.16296 .08401 L
.16605 .09374 L
.16914 .10384 L
.17223 .11437 L
.17532 .12561 L
Mistroke
.17842 .13697 L
.18151 .14847 L
.1846 .16013 L
.18769 .17182 L
.19079 .18308 L
.19388 .19455 L
.19697 .20558 L
.20006 .21707 L
.20315 .22793 L
.20625 .23861 L
.20934 .24844 L
.21243 .25871 L
.21552 .26761 L
.21861 .27624 L
.22171 .28295 L
.2248 .28775 L
.22789 .29021 L
.23098 .29164 L
.23408 .29194 L
.23717 .29201 L
.24026 .29125 L
.24335 .29046 L
.24644 .28925 L
.24954 .28776 L
.25263 .28649 L
.25572 .28574 L
.25881 .28525 L
.2619 .28578 L
.265 .28566 L
.26809 .28559 L
.27118 .28554 L
.27427 .28527 L
.27737 .28504 L
.28046 .28536 L
.28355 .28511 L
.28664 .28566 L
.28973 .28712 L
.29283 .28958 L
.29592 .29231 L
.29901 .29571 L
.3021 .29984 L
.30519 .30485 L
.30829 .30947 L
.31138 .31358 L
.31447 .31648 L
.31756 .31653 L
.32066 .313 L
.32375 .30794 L
.32684 .30205 L
.32993 .29505 L
Mistroke
.33302 .28655 L
.33612 .27653 L
.33921 .2652 L
.3423 .25309 L
.34539 .24048 L
.34848 .22775 L
.35158 .21499 L
.35467 .20231 L
.35776 .18961 L
.36085 .17694 L
.36395 .16434 L
.36704 .15179 L
.37013 .13899 L
.37322 .12631 L
.37631 .11379 L
.37941 .1015 L
.3825 .08953 L
.38559 .07811 L
.38868 .06747 L
.39177 .05809 L
.39487 .05065 L
.39796 .04627 L
.40105 .04608 L
.40414 .05032 L
.40724 .05804 L
.41033 .06792 L
.41342 .07877 L
.41651 .08991 L
.4196 .10137 L
.4227 .1133 L
.42579 .1259 L
.42888 .13853 L
.43197 .15072 L
.43506 .16251 L
.43816 .17319 L
.44125 .18281 L
.44434 .19184 L
.44743 .19941 L
.45053 .20678 L
.45362 .21387 L
.45671 .22125 L
.4598 .2292 L
.46289 .23748 L
.46599 .2459 L
.46908 .2549 L
.47217 .26429 L
.47526 .2736 L
.47835 .28278 L
.48145 .29158 L
.48454 .3001 L
Mistroke
.48763 .30703 L
.49072 .31042 L
.49382 .30953 L
.49691 .30546 L
.5 .29898 L
.50309 .29034 L
.50618 .28048 L
.50928 .26999 L
.51237 .25911 L
.51546 .24809 L
.51855 .23697 L
.52165 .22585 L
.52474 .21488 L
.52783 .20399 L
.53092 .19343 L
.53401 .1828 L
.53711 .17225 L
.5402 .16176 L
.54329 .1514 L
.54638 .14126 L
.54947 .1316 L
.55257 .12251 L
.55566 .11421 L
.55875 .10685 L
.56184 .10071 L
.56494 .09628 L
.56803 .09343 L
.57112 .09183 L
.57421 .09111 L
.5773 .0919 L
.5804 .09427 L
.58349 .09867 L
.58658 .10436 L
.58967 .11136 L
.59276 .11848 L
.59586 .1259 L
.59895 .13302 L
.60204 .14 L
.60513 .1453 L
.60823 .14764 L
.61132 .14779 L
.61441 .1463 L
.6175 .14371 L
.62059 .14084 L
.62369 .13822 L
.62678 .13597 L
.62987 .13407 L
.63296 .13271 L
.63605 .13234 L
.63915 .13247 L
Mistroke
.64224 .13356 L
.64533 .13502 L
.64842 .1374 L
.65152 .14049 L
.65461 .1444 L
.6577 .14901 L
.66079 .15463 L
.66388 .16101 L
.66698 .16809 L
.67007 .17581 L
.67316 .18368 L
.67625 .19046 L
.67934 .19477 L
.68244 .19691 L
.68553 .19616 L
.68862 .1936 L
.69171 .1897 L
.69481 .18533 L
.6979 .18096 L
.70099 .17687 L
.70408 .17332 L
.70717 .1704 L
.71027 .1677 L
.71336 .16526 L
.71645 .16323 L
.71954 .16163 L
.72263 .16052 L
.72573 .16003 L
.72882 .16031 L
.73191 .16113 L
.735 .16232 L
.7381 .16398 L
.74119 .16588 L
.74428 .16803 L
.74737 .17052 L
.75046 .17377 L
.75356 .17741 L
.75665 .18148 L
.75974 .18665 L
.76283 .19257 L
.76592 .19888 L
.76902 .20538 L
.77211 .21183 L
.7752 .21828 L
.77829 .22435 L
.78139 .2301 L
.78448 .23609 L
.78757 .24211 L
.79066 .24794 L
.79375 .25245 L
Mistroke
.79685 .25606 L
.79994 .25955 L
.80303 .26256 L
.80612 .26459 L
.80921 .26465 L
.81231 .26066 L
.8154 .25557 L
.81849 .24941 L
.82158 .24253 L
.82468 .23435 L
.82777 .22528 L
.83086 .2163 L
.83395 .20696 L
.83704 .19823 L
.84014 .19017 L
.84323 .18346 L
.84632 .17846 L
.84941 .17487 L
.8525 .1724 L
.8556 .16988 L
.85869 .16739 L
.86178 .16502 L
.86487 .16255 L
.86797 .16009 L
.87106 .15772 L
.87415 .15542 L
.87724 .15271 L
.88033 .14934 L
.88343 .1448 L
.88652 .1392 L
.88961 .13221 L
.8927 .12384 L
.89579 .1139 L
.89889 .10283 L
.90198 .09117 L
.90507 .07897 L
.90816 .06646 L
.91126 .05378 L
.91435 .04091 L
.91744 .02796 L
.92053 .0152 L
.92362 .01691 L
.92672 .02958 L
.92981 .04206 L
.9329 .05404 L
.93599 .0652 L
.93908 .07607 L
.94218 .08659 L
.94527 .09711 L
.94836 .10756 L
Mistroke
.95145 .118 L
.95455 .12828 L
.95764 .13843 L
.96073 .14877 L
.96382 .15893 L
.96691 .1687 L
.97001 .17827 L
.9731 .1875 L
.97619 .19583 L
Mfstroke
0 0 1 r
.02381 .16726 m
.0269 .16726 L
.02999 .16726 L
.03309 .16726 L
.03618 .16726 L
.03927 .16726 L
.04236 .16726 L
.04545 .16726 L
.04855 .16726 L
.05164 .16726 L
.05473 .16726 L
.05782 .16726 L
.06092 .16726 L
.06401 .16726 L
.0671 .16726 L
.07019 .16726 L
.07328 .16726 L
.07638 .16726 L
.07947 .16726 L
.08256 .16726 L
.08565 .16726 L
.08874 .16726 L
.09184 .16726 L
.09493 .16726 L
.09802 .16726 L
.10111 .16726 L
.10421 .16726 L
.1073 .16726 L
.11039 .16726 L
.11348 .16726 L
.11657 .16726 L
.11967 .16726 L
.12276 .16726 L
.12585 .16726 L
.12894 .16726 L
.13203 .16726 L
.13513 .16726 L
.13822 .16726 L
.14131 .16726 L
.1444 .16726 L
.1475 .16726 L
.15059 .16726 L
.15368 .16726 L
.15677 .16726 L
.15986 .16726 L
.16296 .16726 L
.16605 .16726 L
.16914 .16726 L
.17223 .16726 L
.17532 .16726 L
Mistroke
.17842 .16726 L
.18151 .16726 L
.1846 .16726 L
.18769 .16726 L
.19079 .16726 L
.19388 .16726 L
.19697 .16726 L
.20006 .16726 L
.20315 .16726 L
.20625 .16726 L
.20934 .16726 L
.21243 .16726 L
.21552 .16726 L
.21861 .16726 L
.22171 .16726 L
.2248 .16726 L
.22789 .16726 L
.23098 .16726 L
.23408 .16726 L
.23717 .16726 L
.24026 .16726 L
.24335 .16726 L
.24644 .16726 L
.24954 .16726 L
.25263 .16726 L
.25572 .16726 L
.25881 .16726 L
.2619 .16726 L
.265 .16726 L
.26809 .16726 L
.27118 .16726 L
.27427 .16726 L
.27737 .16726 L
.28046 .16726 L
.28355 .16726 L
.28664 .16726 L
.28973 .16726 L
.29283 .16726 L
.29592 .16726 L
.29901 .16726 L
.3021 .16726 L
.30519 .16726 L
.30829 .16726 L
.31138 .16726 L
.31447 .16726 L
.31756 .16726 L
.32066 .16726 L
.32375 .16726 L
.32684 .16726 L
.32993 .16726 L
Mistroke
.33302 .16726 L
.33612 .16726 L
.33921 .16726 L
.3423 .16726 L
.34539 .16726 L
.34848 .16726 L
.35158 .16726 L
.35467 .16726 L
.35776 .16726 L
.36085 .16726 L
.36395 .16726 L
.36704 .16726 L
.37013 .16726 L
.37322 .16726 L
.37631 .16726 L
.37941 .16726 L
.3825 .16726 L
.38559 .16726 L
.38868 .16726 L
.39177 .16726 L
.39487 .16726 L
.39796 .16726 L
.40105 .16726 L
.40414 .16726 L
.40724 .16726 L
.41033 .16726 L
.41342 .16726 L
.41651 .16726 L
.4196 .16726 L
.4227 .16726 L
.42579 .16726 L
.42888 .16726 L
.43197 .16726 L
.43506 .16726 L
.43816 .16726 L
.44125 .16726 L
.44434 .16726 L
.44743 .16726 L
.45053 .16726 L
.45362 .16726 L
.45671 .16726 L
.4598 .16726 L
.46289 .16726 L
.46599 .16726 L
.46908 .16726 L
.47217 .16726 L
.47526 .16726 L
.47835 .16726 L
.48145 .16726 L
.48454 .16726 L
Mistroke
.48763 .16726 L
.49072 .16726 L
.49382 .16726 L
.49691 .16726 L
.5 .16726 L
.50309 .16726 L
.50618 .16726 L
.50928 .16726 L
.51237 .16726 L
.51546 .16726 L
.51855 .16726 L
.52165 .16726 L
.52474 .16726 L
.52783 .16726 L
.53092 .16726 L
.53401 .16726 L
.53711 .16726 L
.5402 .16726 L
.54329 .16726 L
.54638 .16726 L
.54947 .16726 L
.55257 .16726 L
.55566 .16726 L
.55875 .16726 L
.56184 .16726 L
.56494 .16726 L
.56803 .16726 L
.57112 .16726 L
.57421 .16726 L
.5773 .16726 L
.5804 .16726 L
.58349 .16726 L
.58658 .16726 L
.58967 .16726 L
.59276 .16726 L
.59586 .16726 L
.59895 .16726 L
.60204 .16726 L
.60513 .16726 L
.60823 .16726 L
.61132 .16726 L
.61441 .16726 L
.6175 .16726 L
.62059 .16726 L
.62369 .16726 L
.62678 .16726 L
.62987 .16726 L
.63296 .16726 L
.63605 .16726 L
.63915 .16726 L
Mistroke
.64224 .16726 L
.64533 .16726 L
.64842 .16726 L
.65152 .16726 L
.65461 .16726 L
.6577 .16726 L
.66079 .16726 L
.66388 .16726 L
.66698 .16726 L
.67007 .16726 L
.67316 .16726 L
.67625 .16726 L
.67934 .16726 L
.68244 .16726 L
.68553 .16726 L
.68862 .16726 L
.69171 .16726 L
.69481 .16726 L
.6979 .16726 L
.70099 .16726 L
.70408 .16726 L
.70717 .16726 L
.71027 .16726 L
.71336 .16726 L
.71645 .16726 L
.71954 .16726 L
.72263 .16726 L
.72573 .16726 L
.72882 .16726 L
.73191 .16726 L
.735 .16726 L
.7381 .16726 L
.74119 .16726 L
.74428 .16726 L
.74737 .16726 L
.75046 .16726 L
.75356 .16726 L
.75665 .16726 L
.75974 .16726 L
.76283 .16726 L
.76592 .16726 L
.76902 .16726 L
.77211 .16726 L
.7752 .16726 L
.77829 .16726 L
.78139 .16726 L
.78448 .16726 L
.78757 .16726 L
.79066 .16726 L
.79375 .16726 L
Mistroke
.79685 .16726 L
.79994 .16726 L
.80303 .16726 L
.80612 .16726 L
.80921 .16726 L
.81231 .16726 L
.8154 .16726 L
.81849 .16726 L
.82158 .16726 L
.82468 .16726 L
.82777 .16726 L
.83086 .16726 L
.83395 .16726 L
.83704 .16726 L
.84014 .16726 L
.84323 .16726 L
.84632 .16726 L
.84941 .16726 L
.8525 .16726 L
.8556 .16726 L
.85869 .16726 L
.86178 .16726 L
.86487 .16726 L
.86797 .16726 L
.87106 .16726 L
.87415 .16726 L
.87724 .16726 L
.88033 .16726 L
.88343 .16726 L
.88652 .16726 L
.88961 .16726 L
.8927 .16726 L
.89579 .16726 L
.89889 .16726 L
.90198 .16726 L
.90507 .16726 L
.90816 .16726 L
.91126 .16726 L
.91435 .16726 L
.91744 .16726 L
.92053 .16726 L
.92362 .16726 L
.92672 .16726 L
.92981 .16726 L
.9329 .16726 L
.93599 .16726 L
.93908 .16726 L
.94218 .16726 L
.94527 .16726 L
.94836 .16726 L
Mistroke
.95145 .16726 L
.95455 .16726 L
.95764 .16726 L
.96073 .16726 L
.96382 .16726 L
.96691 .16726 L
.97001 .16726 L
.9731 .16726 L
.97619 .16726 L
Mfstroke
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 144},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000]2000`400?l00000o`00003oo`3ooomY
0?ooo`00CP3oool4000000@0oooo1000000M0?ooo`D000000`3oool4000000@0oooo1000000I0?oo
o`D000000`3oool4000000@0oooo1000000I0?ooo`D00000103oool4000000@0oooo1000000H0?oo
o`D00000103oool4000000@0oooo1000000I0?ooo`<000001@3oool4000000@0oooo1000000X0?oo
o`00C@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo02D0oooo001B0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01T0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool09@3oool00580oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
6@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0U0?ooo`00CP3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool40000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool00`3oool4000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool09@3oool004h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0J0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0U
0?ooo`00CP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06P3oool3000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo01H0oooo0`0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
5@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0U
0?ooo`00CP3oool5000000<0oooo1000000O0?ooo`030000003oool0oooo00<0oooo100000040?oo
o`@000006`3oool00`000000oooo0?ooo`030?ooo`D000000`3oool4000001X0oooo0`0000050?oo
o`@00000103oool4000001T0oooo0`0000050?ooo`D000000`3oool4000001T0oooo0`0000050?oo
o`@00000103oool4000002P0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o
0?ooofT0oooo000W0?ooo`030000003oool0oooo0?l0oooo?`3oool002L0oooo00<000000?ooo`3o
ool0o`3ooolo0?ooo`008@3ooooo000002H000008P3oool002L0oooo00<000000?ooo`3o00001P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0V0?ooo`009`3oool010000000oooo0?l0003o000Y0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`060?ooo`030000003o
ool0oooo02l0oooo000W0?ooo`040000003oool0o`000?l00?l0oooo0`3oool20?l003T0oooo000W
0?ooo`050000003oool0o`000?ooo`3o0000o`3oool20?ooo`80o`00>@3oool002L0oooo00<00000
0?ooo`3o00000P3oool00`3o0000oooo0?ooo`3n0?ooo`030?l0003oool0o`0003P0oooo000W0?oo
o`030000003oool0o`000080oooo00<0o`000?ooo`3oool0603oool20?l00>@0oooo00<0o`000?oo
o`3o0000>03oool002L0oooo0P0000001@3o0000oooo0?ooo`3oool0o`0001P0oooo00<0o`000?oo
o`3oool00P3o003R0?ooo`030?l0003oool0o`0003P0oooo000W0?ooo`030000003oool0o`0000<0
oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0=h0
oooo00@0o`000?ooo`3oool0o`00>03oool002L0oooo00<000000?ooo`3o0000103oool00`3o0000
oooo0?ooo`0C0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0gP3oool01@3o0000
oooo0?ooo`3oool0o`0003L0oooo000W0?ooo`030000003oool0o`0000D0oooo00<0o`000?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0=h0oooo00D0o`000?ooo`3o
ool0oooo0?l0000g0?ooo`009`3oool00`000000oooo0?l000050?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`160?ooo`80o`00U@3oool01@3o0000
oooo0?ooo`3oool0o`0003L0oooo000W0?ooo`030000003oool0o`0000H0oooo00<0o`000?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo04D0oooo00@0o`000?ooo`3o
ool0o`00T`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo03@0oooo000W0?ooo`80
000000<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0A03oool0103o0000oooo0?ooo`3o002C0?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0=03oool002L0oooo00<000000?ooo`3o00001P3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0900oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0d0?ooo`009`3oool00`000000oooo0?l000070?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`120?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0S`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo03@0oooo
000W0?ooo`030000003oool0o`0000L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0480oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`2?0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0<`3oool002L0oooo00<00000
0?ooo`3o0000203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0o`00
0?ooo`3oool0@@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo08h0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0c0?ooo`009`3oool00`000000oooo0?l000090?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`110?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0SP3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo03<0oooo000W0?ooo`80000000<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0?`3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo08d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0b0?ooo`009`3oool00`000000oooo0?l0000;0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0S03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0380oooo
000W0?ooo`030000003oool0o`0000`0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0A0?ooo`030?l0003oool0oooo03l0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`2<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0<P3oool002L0oooo00<00000
0?ooo`3o00003@3oool20?l00080oooo0P3o000D0?ooo`030?l0003oool0oooo03d0oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`2<0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3o00003`3oool20?l001H0oooo00<0o`000?oo
o`3oool0?@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo08X0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?l0000X0?ooo`03
0?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Z0?ooo`80
o`00GP3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0340oooo000W0?ooo`800000
00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0l0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool0:@3oool0103o0000oooo0?ooo`3o001M0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool0<03oool002L0oooo00<000000?ooo`3o0000:03oool00`3o0000oooo
0?ooo`0k0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo05T0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0`0?ooo`009`3oool00`000000oooo0?l0000Y0?ooo`030?l0003oool0oooo03X0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0300oooo000>
0?ooo`D000000`3oool4000000@0oooo100000050?ooo`030000003oool0o`0002T0oooo00<0o`00
0?ooo`3oool0>P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo02D0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`1H0?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0?ooo`3oool0;`3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?l0000Y
0?ooo`030?l0003oool0oooo03T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0U
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`0<
0?ooo`030?l0003oool0oooo02l0oooo000@0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3o0000:P3oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0903oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo05H0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0_0?ooo`00403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`80000000<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`0h0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo05H0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0_0?ooo`00403oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0o`0002X0oooo00<0o`000?ooo`3oool0>03oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0;`3oool0
0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?l0000Z0?ooo`030?l0003oool0
oooo03L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0
oooo02l0oooo000>0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?l0000Z0?ooo`030?l0003oool0
oooo03L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo02h0oooo000@0?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000001@3oool00`00
0000oooo0?l0000Z0?ooo`030?l0003oool0oooo03L0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0DP3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo02h0oooo000W0?ooo`030000003oool0o`0002X0
oooo00<0o`000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0240
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`<0o`00A`3oool00`3o0000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo02h0oooo000W0?ooo`80000000<0o`000?ooo`3oool0
:@3oool00`3o0000oooo0?ooo`0e0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0
803oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo0P3o00020?ooo`80o`00
AP3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo02d0oooo000W0?ooo`030000003o
ool0o`0002/0oooo00<0o`000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0200oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo02d0oooo000W0?ooo`030000003oool0o`0002/0oooo00<0o`000?ooo`3oool0=@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo02d0oooo000W0?ooo`030000003oool0o`00
02`0oooo00<0o`000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0200oooo00<0o`000?ooo`3oool03P3oool0103o0000oooo0?l0003o000:0?ooo`030?l0003oool0
oooo0400oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0/0?ooo`009`3oool00`00
0000oooo0?l0000/0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool0403oool00`3o
0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0n0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0;03oool002L0
oooo00<000000?ooo`3o0000;03oool00`3o0000oooo0?ooo`0c0?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo03d0
oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`0/0?ooo`009`3oool2000000030?l0
003oool0oooo02/0oooo00<0o`000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo01h0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0k0?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool0:`3oool002L0oooo00<000000?ooo`3o0000;@3o
ool00`3o0000oooo0?ooo`0a0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0703o
ool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo00l0oooo0`3o000W0?ooo`80o`006P3o
ool00`3o0000oooo0?ooo`0[0?ooo`009`3oool00`000000oooo0?l0000]0?ooo`030?l0003oool0
oooo0340oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0
oooo0240oooo00<0o`000?ooo`3oool0303oool20?l000<0oooo0P3o000T0?ooo`030?l0003oool0
oooo01X0oooo00<0o`000?ooo`3oool0:`3oool002L0oooo00<000000000o`000?l0o`000?lF0000
obT0oooo000W0?ooo`030000003oool0o`0002h0oooo00<0o`000?ooo`3oool0<03oool00`3o0000
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool08`3oool00`3o0000
oooo0?ooo`080?ooo`80o`002@3oool20?l001l0oooo00<0o`000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0Z0?ooo`009`3oool00`000000oooo0?l0000^0?ooo`030?l0003oool0oooo02l0oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo02<0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01/0oooo
00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0Z0?ooo`009`3oool00`000000oooo0?l0
000^0?ooo`030?l0003oool0oooo02l0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?oo
o`0Y0?ooo`009`3oool2000000030?l0003oool0oooo02d0oooo00<0o`000?ooo`3oool0;P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo02T0oooo000W0?ooo`030000003oool0o`00
02l0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo
01P0oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00l0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
02T0oooo000W0?ooo`030000003oool0o`0002l0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool09@3oool00`3o0000
oooo0?ooo`040?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0503oool00`3o0000
oooo0?ooo`0T0?ooo`030?l0003oool0oooo02P0oooo000W0?ooo`030000003oool0o`000300oooo
00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo01H0oooo
00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0140oooo
00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo02P0oooo
000W0?ooo`030000003oool0o`000300oooo00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?oo
o`0F0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0:03oool0103o0000oooo0?oo
o`3o000E0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo
0?ooo`0W0?ooo`009`3oool00`000000oooo0?l0000`0?ooo`030?l0003oool0oooo02`0oooo00<0
o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02T0oooo0P3o
000F0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?oo
o`0W0?ooo`009`3oool2000000030?l0003oool0oooo02h0oooo00<0o`000?ooo`3oool0;03oool0
0`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0@P3oool0
0`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo0500oooo000W0?ooo`030000003oool0o`00
0340oooo00<0o`000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0540oooo000W0?ooo`030000003oool0o`000340oooo00<0o`000?ooo`3oool0:`3oool00`3o0000
oooo0?ooo`0I0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0540oooo000=0?ooo`D00000103oool4000000@0oooo
100000050?ooo`030000003oool0o`000340oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0540oooo000=0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?l0000b0?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo04D0oooo00<0o`000?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`1B0?ooo`003P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0o`000380oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0580oooo000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000000`3o0000
oooo0?ooo`0`0?ooo`030?l0003oool0oooo02P0oooo00<0o`000?ooo`3oool0703oool00`3o0000
oooo0?ooo`0@0?ooo`030?l0003oool0oooo04L0oooo00<0o`000?ooo`3oool0303oool00`3o0000
oooo0?ooo`1C0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0o`0003<0
oooo00<0o`000?ooo`3oool09`3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0100
oooo00<0o`000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo05<0
oooo000A0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3o0000<`3oool00`3o0000oooo0?ooo`0W0?oo
o`030?l0003oool0oooo01d0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`180?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0D`3oool000d0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0o`0003<0oooo00<0o`000?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo05<0oooo000>0?ooo`<000001@3oool40000
00@0oooo100000050?ooo`030000003oool0o`0003<0oooo00<0o`000?ooo`3oool09P3oool00`3o
0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0B`3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo05<0oooo000W0?ooo`030000003oool0o`0003<0
oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00d0
oooo00<0o`000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo05@0
oooo000W0?ooo`80000000<0o`000?ooo`3oool0<@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo01l0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`1<0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0E03oool002L0oooo00<000000?ooo`3o0000=03o
ool00`3o0000oooo0?ooo`0U0?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`1<0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0E@3o
ool002L0oooo00<000000?ooo`3o0000=03oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo0240oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`1=0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0E@3oool002L0oooo00<000000?l0003oool0=03oool00`3o
0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo0280oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`1>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0EP3oool002L0
oooo00<000000?l0003oool0=@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0280
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`1?0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool0EP3oool002L0oooo00<000000?l0003oool0=@3oool00`3o0000oooo
0?ooo`0R0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`1@0?ooo`050?l0003oool0oooo0?ooo`3o0000F@3oool002L0oooo00<000000?l000000000
=@3oool00`3o0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`1A0?ooo`040?l0003oool0oooo0?l005T0oooo000W0?ooo`030000
003o0000oooo03H0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0D`3oool20?l005X0oooo000W0?ooo`030000003o
0000oooo03H0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool0[`3oool002L0oooo00<000000?l0003oool0=P3oool0
0`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`2_0?ooo`009`3oool00`000000o`000?ooo`0g0?ooo`030?l0003oool0oooo
01l0oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
0;00oooo000W0?ooo`030000003o0000oooo03L0oooo00<0o`000?ooo`3oool07`3oool00`3o0000
oooo0?ooo`0W0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0/03oool002L0oooo
00<000000?l000000000>03oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo02P0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`2`0?ooo`009`3oool00`000000o`000?oo
o`0h0?ooo`030?l0003oool0oooo00H0oooo303o000;0?ooo`030?l0003oool0oooo02P0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`2a0?ooo`009`3oool00`000000o`000?ooo`0i
0?ooo`80o`000`3oool30?l000`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0Y
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0/@3oool002L0oooo00<000000?l0
003oool0>`3oool30?l00100oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0Z0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0/@3oool002L0oooo00<000000?l0003o
ool0CP3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`2b0?ooo`009`3oool00`000000o`000?ooo`1?0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0;80oooo000W0?ooo`030000003o0000000004l0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0Z0?ooo`050?l0003oool0oooo0?ooo`3o0000]@3oool002L0oooo00<0
00000?l0003oool0D03oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo02`0oooo00@0
o`000?ooo`3oool0o`00]@3oool002L0oooo00<000000?l0003oool0D@3oool01@3o0000oooo0?oo
o`3oool0o`000300oooo0P3o002f0?ooo`009`3oool00`000000o`000?ooo`1B0?ooo`040?l0003o
ool0oooo0?l00>P0oooo000>0?ooo`<000001@3oool4000000@0oooo100000050?ooo`030000003o
0000oooo05<0oooo0P3o003Y0?ooo`003@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?l0003oool0o`3ooolo0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o0000oooo0?l0
oooo?`3oool00140oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool00`000000o`000000003o0?ooocl0oooo000?0?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000o`000?ooo`3o0?ooocl0oooo000A0?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?l0003oool0o`3ooolo0?ooo`003@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?l0003oool0o`3ooolo0?ooo`003P3oool3000000D0oooo100000040?ooo`@000001@3oool0
0`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0
oooo00<000000?l000000000o`3ooolo0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo
000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l0003oool0o`3ooolo
0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o0000oooo0?l0
oooo?`3oool002L0oooo00<000000?l000000000o`3ooolo0?ooo`009`3oool00`000000o`000?oo
o`3o0?ooocl0oooo000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l0
003oool0o`3ooolo0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000
003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l000000000o`3ooolo0?ooo`009`3oool0
0`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0
oooo00<000000?l0003oool0o`3ooolo0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo
000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l000000000o`3ooolo
0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o0000oooo0?l0
oooo?`3oool00100oooo0`0000030?ooo`@00000103oool4000000D0oooo00<000000?l0003oool0
o`3ooolo0?ooo`004@3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`020?ooo`030000003o0000oooo0?l0oooo?`3oool00140oooo
00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000o`000?ooo`3o0?ooocl0oooo000=0?ooo`H000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000o`000000003o0?ooocl0oooo000>0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?l0003oool0o`3ooolo0?ooo`003P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
0000oooo0?l0oooo?`3oool000l0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000o`000?oo
o`3o0?ooocl0oooo000@0?ooo`800000103oool4000000@0oooo100000050?ooo`030000003o0000
oooo0?l0oooo?`3oool002L0oooo00<000000?l0003oool0o`3ooolo0?ooo`009`3oool00`000000
o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o000000000?l0oooo?`3oool002L0oooo00<0
00000?l0003oool0o`3ooolo0?ooo`009`3oool00`000000o`000?ooo`3o0?ooocl0oooo000W0?oo
o`030000003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l0003oool0o`3ooolo0?ooo`00
9`3oool00`000000o`000?ooo`3o0?ooocl0oooo000W0?ooo`030000003o000000000?l0oooo?`3o
ool002L0oooo00<000000?l0003oool0o`3ooolo0?ooo`009`3oool00`000000o`000?ooo`3o0?oo
ocl0oooo000W0?ooo`030000003o0000oooo0?l0oooo?`3oool002L0oooo00<000000?l0003oool0
o`3ooolo0?ooo`009`3oool00`000000oooo0?ooo`3o0?ooocl0oooo000W0?ooo`<00000o`3ooolo
0?ooo`009`3oool00`000000oooo0?ooo`3o0?ooocl0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
002g0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool3000000/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000001@3oool00`000000oooo0?oo
o`0>0?ooo`00]`3oool2000001T0oooo0P0000170?ooo`030000003oool0oooo00/0oooo0P00000A
0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`8000003`3oool000030000003oool0oooo
00D00000103oool5000000<0oooo1@0000020?ooo`D000002@3oool2000000@0oooo1@0000040?oo
o`800000303oool500000080oooo0`000000103oool000000000000000030?ooo`8000001@3oool5
00000080oooo1@0000030?ooo`D00000103oool5000000H0oooo0`0000060?ooo`@000001@3oool2
000000040?ooo`00000000000?ooo`D00000103oool5000000<0oooo1@0000020?ooo`D000000P3o
ool00`000000oooo0?ooo`080?ooo`D000000P3oool5000000@0oooo00<000000?ooo`3oool01`3o
ool3000000<0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`D000001@3oool3000000@0oooo
100000040?ooo`D000000`3oool4000000<0oooo1@0000000`3oool000000?ooo`040?ooo`@00000
1@3oool00`000000oooo0?ooo`080?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`@00000
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0`0000010?ooo`400000
0@00000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000003P3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool2000000@0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`8000002`3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool2000000T0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000T0oooo00@000000?ooo`3oool0
oooo0@00000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool00000303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`3oool10000000000D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo0080
oooo1P0000030?ooo`@00000203oool010000000oooo0?ooo`0000040?ooo`@00000503oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`H000000`3oool00`000000oooo0?ooo`050?ooo`@000000`3oool6000000L0oooo00<0
00000?ooo`000000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool6000000<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0
oooo100000030?ooo`040000003oool0oooo0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool0oooo0@00000000040000003oool0oooo0?ooo`800000203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool2000000D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo0`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool0oooo0P00000A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1P3oool4000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo1@00000000<0oooo0P000000103oool000000000000000030?ooo`<000001@3oool4000000@0
oooo1@0000050?ooo`<000000P3oool300000080oooo1@00000C0?ooo`030000003oool0oooo0080
oooo0P0000000`3oool00000000000020?ooo`<000000P3oool300000080oooo100000030?ooo`80
000000@0oooo00000000000000000`3oool5000000<0oooo100000080?ooo`030000003oool00000
00D0oooo100000030?ooo`8000000P3oool200000080oooo0P000000103oool00000000000000003
0?ooo`<000001@3oool4000000<0oooo0P000000103oool0000000000000000>0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01P3oool4000000H0oooo00<000000?ooo`3oool00`3oool4000000<0oooo0P0000000`3oool0
000000000002000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool10000
0000B03oool00`000000oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`000000?03oool30000
00@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool1000000003P3oool00`00
0000oooo0?ooo`0e0?ooo`D00000=P3oool6000001d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`030?ooo`<000003`3oool5000000D0oooo100000020?ooo`D000001@3oool40000
00`0oooo0P00000B0?ooo`<000000`3oool400000100oooo1000000?0?ooo`@000000`3oool30000
0100oooo0`0000010?ooo`4000000@0000000?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {179, 0}} -> {-44.3202, -48.4253, 1.38802, \
4.06518}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Series classified as chaotic.\"\>",
            FontFamily->"Helvetica",
            FontSize->14,
            FontWeight->"Bold",
            FontColor->GrayLevel[0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> GrayLevel[ 0], 
            FontSize -> 14, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          
          StyleBox["\<\"\\n    Autocorrelation Analysis:   Period: 167   \
Autocorrelation: 0.248748   Bounds:           Sqrt[128640037]\\n{2.65026, \
---------------}\\n                25\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"\\n    Fourier Analysis:   Frequency: {1, 0}\"\>",
            FontFamily->"Helvetica",
            FontSize->12],
          (StyleForm[ #, FontSize -> 12, FontFamily -> "Helvetica"]&)]}],
      SequenceForm[ 
        StyleForm[ 
        "Series classified as chaotic.", FontWeight -> "Bold", FontColor -> 
          GrayLevel[ 0], FontSize -> 14, FontFamily -> "Helvetica"], 
        StyleForm[ 
        "\n    Autocorrelation Analysis:   Period: 167   Autocorrelation: \
0.248748   Bounds:           Sqrt[128640037]\n{2.65026, ---------------}\n    \
            25", FontSize -> 12, FontFamily -> "Helvetica"], 
        StyleForm[ 
        "\n    Fourier Analysis:   Frequency: {1, 0}", FontSize -> 12, 
          FontFamily -> "Helvetica"]],
      Editable->False]], "Print"],

Cell[BoxData[
    \({"chaotic", 309}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preliminaries", "Section"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input - Initialization Cell"],

Cell[CellGroupData[{

Cell["Import packages", "Subsubsection"],

Cell[BoxData[{
    \(<< "\<JLink`\>"\), "\[IndentingNewLine]", 
    \(<< Graphics`Arrow`\), "\[IndentingNewLine]", 
    \(<< Geometry`Rotations`\), "\[IndentingNewLine]", 
    \(<< Statistics`ContinuousDistributions`\), "\[IndentingNewLine]", 
    \(<< Graphics`MultipleListPlot`\), "\n", 
    \(<< Graphics`Colors`\), "\[IndentingNewLine]", 
    \(\(<< Graphics`Graphics` (*\ pres\ graphics\ for\ histo, \ 
        DisplayTogether\ *) ;\)\)}], "Input - Initialization Cell"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set directories, install Java and bring up console.", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dirmyMathematica = 
        Which[\[IndentingNewLine]dirmyMathematicaLaptop = 
            StringDrop[\ 
              ToFileName[{"\<C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\>"}], \(-1\)]; 
          SetDirectory[dirmyMathematicaLaptop] === 
            dirmyMathematicaLaptop, \
\[IndentingNewLine]\[IndentingNewLine]dirmyMathematicaLaptop, 
          dirmyMathematicaDesktop = 
            StringDrop[\ 
              ToFileName[{"\<C:\\Documents and Settings\\macal\\My \
Documents\\_myMathematica\>"}], \(-1\)]; 
          SetDirectory[dirmyMathematicaDesktop] === dirmyMathematicaDesktop, 
          dirmyMathematicaDesktop\[IndentingNewLine]];\)\), "\
\[IndentingNewLine]", 
    \(\(\(Print["\<dirmyMathematica set to = \>", 
        dirmyMathematica];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(dirJar = 
        ToFileName[{dirmyMathematica, "\<MathematicaRepast\>"}];\)\), "\
\[IndentingNewLine]", 
    \(\(\(Print["\<Jar directory set to = \>", 
        dirJar];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(AddToClassPath[dirJar];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<JavaClassPath = \>", 
        ColumnForm[JavaClassPath[]]];\)\)}], "Input - Initialization Cell"],

Cell[BoxData[
    InterpretationBox[\("dirmyMathematica set to = \
"\[InvisibleSpace]"C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica"\),
      SequenceForm[ 
      "dirmyMathematica set to = ", 
        "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Jar directory set to = \
"\[InvisibleSpace]"C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\"\),
      SequenceForm[ 
      "Jar directory set to = ", 
        "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"JavaClassPath = \"\>", "\[InvisibleSpace]", 
        InterpretationBox[GridBox[{
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\SystemFiles\\\\Java\\\\\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\SystemFiles\\\\Java\\\\WolframSSH.jar\"\>"},\

              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\SystemFiles\\\\Java\\\\WolframSSHKeyGen.jar\
\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\DatabaseLink\\\\\
Java\\\\\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\DatabaseLink\\\\\
Java\\\\glazedlists.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\DatabaseLink\\\\\
Java\\\\hsqldb.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\DatabaseLink\\\\\
Java\\\\jtds-0.9-rc2.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\DatabaseLink\\\\\
Java\\\\mysql-connector-java-2.0.14-bin.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
bsf-Wolfram.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
bsf.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
concurrent.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
diva-canvas-core.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
GUIKit.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
OculusLayout.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
xercesImpl.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\GUIKit\\\\Java\\\\\
xmlParserAPIs.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\axis-ant.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\axis.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\commons-discovery.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\commons-logging.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\jaxrpc.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\log4j-1.2.8.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\saaj.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\servlet.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\wsdl4j.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\xercesImpl.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\Applications\\\\WebServices\\\\\
Java\\\\xmlParserAPIs.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\ExtraPackages\\\\Convert\\\\Java\\\
\\\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\ExtraPackages\\\\Convert\\\\Java\\\
\\Convert.jar\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\AddOns\\\\ExtraPackages\\\\Convert\\\\Java\\\
\\jxl.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\ActivateLive3D\\\\LIVE.JAR\"\>"},
              {"\<\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\5.2\\\\SystemFiles\\\\Java\\\\Windows\\\\lib\\\\\
tools.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\colt.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\JLink-Repast.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\plot.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\repastj.jar\"\>"},
              {"\<\"C:\\\\Documents and Settings\\\\macal.DIS\\\\My Documents\
\\\\_myMathematica\\\\MathematicaRepast\\\\trove.jar\"\>"}
              },
            GridBaseline->{Baseline, {1, 1}},
            ColumnAlignments->{Left}],
          
          ColumnForm[ {
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\SystemFiles\\Java\\", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\SystemFiles\\Java\\WolframSSH.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\SystemFiles\\Java\\WolframSSHKeyGen.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\\
glazedlists.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\hsqldb.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\jtds-0.\
9-rc2.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\mysql-\
connector-java-2.0.14-bin.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\bsf-Wolfram.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\bsf.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\concurrent.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\diva-canvas-\
core.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\GUIKit.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\OculusLayout.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\xercesImpl.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\xmlParserAPIs.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\axis-ant.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\axis.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\commons-\
discovery.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\commons-\
logging.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\jaxrpc.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\log4j-1.\
2.8.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\saaj.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\servlet.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\wsdl4j.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\\
xercesImpl.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\\
xmlParserAPIs.jar", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\", 
            
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\Convert.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\jxl.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\ActivateLive3D\\LIVE.JAR", 
            "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\SystemFiles\\Java\\Windows\\lib\\tools.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\colt.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\JLink-Repast.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\plot.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\repastj.jar", 
            "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\trove.jar"}],
          Editable->False]}],
      SequenceForm[ "JavaClassPath = ", 
        ColumnForm[ {
          "C:\\Program Files\\Wolfram Research\\Mathematica\\5.2\\SystemFiles\
\\Java\\", 
          "C:\\Program Files\\Wolfram Research\\Mathematica\\5.2\\SystemFiles\
\\Java\\WolframSSH.jar", 
          "C:\\Program Files\\Wolfram Research\\Mathematica\\5.2\\SystemFiles\
\\Java\\WolframSSHKeyGen.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\\
glazedlists.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\hsqldb.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\jtds-0.\
9-rc2.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\DatabaseLink\\Java\\mysql-\
connector-java-2.0.14-bin.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\bsf-Wolfram.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\bsf.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\concurrent.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\diva-canvas-\
core.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\GUIKit.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\OculusLayout.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\xercesImpl.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\GUIKit\\Java\\xmlParserAPIs.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\axis-ant.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\axis.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\commons-\
discovery.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\commons-\
logging.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\jaxrpc.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\log4j-1.\
2.8.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\saaj.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\servlet.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\wsdl4j.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\\
xercesImpl.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\Applications\\WebServices\\Java\\\
xmlParserAPIs.jar", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\", 
          "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\Convert.\
jar", "C:\\Program Files\\Wolfram \
Research\\Mathematica\\5.2\\AddOns\\ExtraPackages\\Convert\\Java\\jxl.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\ActivateLive3D\\LIVE.JAR", 
          "C:\\Program Files\\Wolfram Research\\Mathematica\\5.2\\SystemFiles\
\\Java\\Windows\\lib\\tools.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\colt.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\JLink-Repast.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\plot.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\repastj.jar", 
          "C:\\Documents and Settings\\macal.DIS\\My \
Documents\\_myMathematica\\MathematicaRepast\\trove.jar"}]],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bring up Java console.", "Subsubsection"],

Cell[BoxData[
    \(\(ShowJavaConsole[];\)\)], "Input - Initialization Cell"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Optional", "Subsubsection"],

Cell[BoxData[
    \(UninstallJava[]\)], "Input"],

Cell[BoxData[
    \(InstallJava[]\)], "Input"],

Cell[BoxData[
    \(Names["\<Global`*\>"]\)], "Input"],

Cell[BoxData[
    RowBox[{"Complement", "[", 
      RowBox[{\(Names["\<Global`*\>"]\), ",", 
        RowBox[{"Flatten", "@", 
          RowBox[{"StringCases", "[", 
            RowBox[{\(Names["\<Global`*\>"]\), ",", 
              RowBox[{
                StyleBox[
                  RowBox[{"x", 
                    StyleBox["___",
                      "MR"]}]], 
                StyleBox["~~",
                  "MR"], 
                StyleBox["\"\<$\>\"",
                  "MR"]}]}], "]"}]}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Documentation", "Subsection"],

Cell[CellGroupData[{

Cell["Data Type Defintions:", "Subsubsection"],

Cell[TextData[{
  "agent[id_, x_, y_, vx_, vy_, col_, sz_, \
fil_,v0_,sel_,nColl_,ty_,target_,orient_,leat_]\n\n",
  StyleBox["Pos",
    FontVariations->{"Underline"->True}],
  "\t",
  StyleBox["Variable\tDefiniition",
    FontVariations->{"Underline"->True}],
  "\n1\tid\t\tagent ID\n2\tx\t\tx-coord of agent\n3\ty\t\ty-coord of agent\n4\
\tvx\t\tspeed of agent in x-direction\n5\tvy\t\tspeed of agent in y-direction\
\n6\tcol\t\tagent color (Java)\n7\tsz\t\tagent diameter\n8\tfil\t\tfill \
status (True = filled, False = not filled)\n9\tv0\t\tspeed of agent at \
speedFac=1\n10\tsel\t\tselection status (True = selected, False = not \
selcted)\n11\tnColl\t\tnumber of collisions\n12\tty\t\tagent type (0 = prey, \
1 = predator, 2 = obstacle, 3 = exit)\n13\ttarget\t\tagent id of target agent \
if any\n14\torient\t\torientation of agent (angle relative to x-axis in \
radians)\n15\tleat\t\t{time of eating, last eaten agent}"
}], "Text",
  CellFrame->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Global Variables:", "Subsubsection"],

Cell[TextData[{
  StyleBox["User Specified Parameters:",
    FontVariations->{"Underline"->True}],
  "\nnumAgentsUser\tnumber of agents specified by user\noffSet\t\t\t{x, y} \
offSet of graphics frame\npanelFrameSizeX\tx-size of panel square\n\
panelFrameSizeY\ty-size of panel square\nspeedBndInit\t\tupper bound for \
speed of agents created at initialization\nspeedBndClick\tupper bound for \
speed of agents added on mouse click\n\n",
  StyleBox["Program Variables",
    FontVariations->{"Underline"->True}],
  "\nagents\t\t\tlist of agents\nbSelected0\t\tagent currently selected\n\
numAgents\t\tcurrent number of agents in simulation\ntNow\t\t\tcurrent \
simulation time\n\n",
  StyleBox["Mathe. Variables:",
    FontVariations->{"Underline"->True}],
  "\ndirJar\t\t\tdirectory for jar files\ng\t\t\tJava graphics object\n\
mathFrame\t\tgraphics frame\nmathPanel\t\tgraphics panel\nmml\t\t\tmouse \
listener 1 for panel\noffscreen\t\tgraphics object"
}], "Text",
  CellFrame->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GUI Layout:", "Subsubsection"],

Cell["\<\
mathFrame@{2,75,702,575}
sliderFrame@{703,75,1003,135}
probeFrame@{703,136,783,296}\
\>", "Text",
  CellFrame->True]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Repast functions", "Section"],

Cell[CellGroupData[{

Cell["Simulate", "Subsubsection"],

Cell[BoxData[{\(Clear[
        Simulate];\), "\[IndentingNewLine]", \(Options[
          Simulate] = {motion \[Rule] straightLine\ \  (*\ 
            straightLine\ brownian\ *) , 
          drawCollisionQ \[Rule] True};\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Simulate",
            FontColor->RGBColor[0, 0, 1]], "[", \(numAgents0_, 
          opts___?OptionQ\), "]"}], ":=", 
        RowBox[{"JavaBlock", "[", 
          RowBox[{"Module", "[", 
            
            RowBox[{\({programName}\), ",", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              RowBox[{\({drawCollisionQ0, 
                    motion0} = \({drawCollisionQ, motion} /. {opts}\) /. 
                    Options[Simulate]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ Set\ init\ parameters\ *) \), 
                "\[IndentingNewLine]", \(numAgents = \(numAgentsUser = 
                    numAgents0\)\), ";", 
                "\[IndentingNewLine]", \(programName = "\<Boids \
Mathematica-Repast Test Program\>"\), ";", 
                "\[IndentingNewLine]", \(panelFrameSizeX = 700\), 
                ";", \(panelFrameSizeY = 500\), ";", 
                "\[IndentingNewLine]", \(offSet = {2, 75}\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ Load\ Java\ classes\ *) \), 
                "\[IndentingNewLine]", \
\(LoadJavaClass["\<java.lang.System\>"]\), ";", 
                "\[IndentingNewLine]", \
\(LoadJavaClass["\<java.awt.Color\>"]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ 
                  Create\ and\ attach\ the\ panel\ mouse\ event\ handler\ \
*) \), "\[IndentingNewLine]", \(mathFrame = 
                  JavaNew["\<com.wolfram.jlink.MathJFrame\>", "\<Agents in \
Motion\>"]\), ";", 
                "\[IndentingNewLine]", \(mathPanel = 
                  JavaNew["\<com.wolfram.jlink.MathGraphicsJPanel\>"]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(mathPanel@
                  setBounds[offSet\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    offSet\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    offSet\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                      panelFrameSizeX, 
                    offSet\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                      panelFrameSizeY]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(mathFrame@
                  setBounds[offSet\[LeftDoubleBracket]1\[RightDoubleBracket], 
                    offSet\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    offSet\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                      panelFrameSizeX, 
                    offSet\[LeftDoubleBracket]2\[RightDoubleBracket] + 
                      panelFrameSizeY]\), ";", 
                "\[IndentingNewLine]", \(contentPane = 
                  mathFrame[getContentPane[]]\), ";", 
                "\[IndentingNewLine]", \(contentPane[add[mathPanel]]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ 
                  create\ and\ attach\ the\ panel\ mouse\ event\ handler\ \
*) \), "\[IndentingNewLine]", \(mml = 
                  JavaNew["\<com.wolfram.jlink.MathMouseListener\>"]\), ";", 
                "\[IndentingNewLine]", \(mml@
                  setHandler["\<mousePressed\>", "\<mousePressedFunc\>"]\), 
                ";", "\[IndentingNewLine]", \(mathPanel@
                  addMouseListener[mml]\), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ 
                  Create\ Repast\ controller\ *) \), "\[IndentingNewLine]", 
                RowBox[{"(*", 
                  RowBox[{
                    RowBox[{"controller", "@", 
                      RowBox[{
                        StyleBox["scheduleMethodAtInterval",
                          FontColor->GrayLevel[0.500008]], "[", \("\<step\>", 
                        5\), "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
                RowBox[{"(*", 
                  RowBox[{
                    RowBox[{"controller", "@", 
                      RowBox[{
                        StyleBox["scheduleMethodAt",
                          FontColor->GrayLevel[0.500008]], "[", \("\<step\>", 
                        20\), "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(controller = 
                  JavaNew["\<anl.jlink.MathematicaModel\>", 
                    programName, "\<init\>", "\<stop\>", "\<exit\>"]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{"controller", "@", 
                  RowBox[{
                    StyleBox["scheduleMethodBeginning",
                      FontColor->GrayLevel[0.500008]], "[", \("\<step\>", 1\),
                     "]"}]}], ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \( (*\ 
                  create\ Repast\ chart\ before\ start . \ 
                      Repast\ will\ add\ a\ data\ point\ to\ chart\ each\ \
\(\(step\)\(.\)\)\ *) \), "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(controller@
                  addChartDataSource["\<Prey Center of Mass (X)\>", \
"\<plotCMX\>"]\), \( (*\ Repast\ chart\ *) \), ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(controller@start[]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(JavaShow[mathFrame]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(offscreen = 
                  mathPanel[createImage[panelFrameSizeX, panelFrameSizeY]]\), 
                ";", "\[IndentingNewLine]", \(g = offscreen[getGraphics[]]\), 
                ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(mathFrame[setModal[]]\), ";", 
                "\[IndentingNewLine]", \(DoModal[]\), ";"}]}], 
            "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.701961]]
}, Closed]],

Cell[CellGroupData[{

Cell["init", "Subsubsection"],

Cell[BoxData[{\(Clear[init];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["init",
          FontColor->RGBColor[0, 0, 1]], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({speedBnd, vx, vy}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              set\ global\ Mathe\ model\ parameters\ *) \), 
            "\[IndentingNewLine]", 
            
            RowBox[{\(tNow = 0\), ";", 
              "\[IndentingNewLine]", \(zero = 1\/10\^10\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"agentPattern", "=", 
                RowBox[{
                  StyleBox["agent",
                    FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, 
                  vy_, col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, 
                  orient_, leat_\), "]"}]}], ";", 
              "\[IndentingNewLine]", \(aSelected = Null\), ";", 
              "\[IndentingNewLine]", \(speedFac0 = 1\), 
              ";", \(speedFacMin = 0\), ";", \(speedFacMax = 4\), 
              ";", \(speedFac = speedFac0\), ";", 
              "\[IndentingNewLine]", \(zoomFac0 = 0.8\), 
              ";", \(zoomFacMin = 0\), ";", \(zoomFacMax = 1\), 
              ";", \(zoomFac = zoomFac0\), ";", 
              "\[IndentingNewLine]", \(speedBndInit = 10\), ";", 
              "\[IndentingNewLine]", \(speedBndClick = 12\), ";", 
              "\[IndentingNewLine]", \(sizeInitMin = \(sizeInitMax = 
                  24\)\), \( (*16*) \), ";", 
              "\[IndentingNewLine]", \(sizeClickMin = \(sizeClickMax = 
                  42\)\), \( (*28*) \), ";", 
              "\[IndentingNewLine]", \(Clear[cmPreyL]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                out - of - bounds\ parameters\ *) \), 
              "\[IndentingNewLine]", \(obLim = \((panelFrameSizeX + 
                      panelFrameSizeY)\)/5. \), ";", 
              "\[IndentingNewLine]", \(obLim = 10\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                set\ default\ target\ for\ prey\ *) \), 
              "\[IndentingNewLine]", \(goal = {panelFrameSizeX/2, 
                  panelFrameSizeY/2}\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                set\ default\ target\ for\ predator\ *) \), 
              "\[IndentingNewLine]", \(defaultPredTarget = {0, 0}\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                init\ agent\ rule\ parameters\ *) \), 
              "\[IndentingNewLine]", \(rule1Param0 = \(rule1Param = 0.2\)\), 
              ";", \(rule1ParamMin = 0\), 
              ";", \(rule1ParamMax = 1\), \( (*\ COHESION\ *) \), ";", 
              "\[IndentingNewLine]", \(rule2Param0 = \(rule2Param = 0.17\)\), 
              ";", \(rule2ParamMin = 0\), 
              ";", \(rule2ParamMax = 1\), \( (*\ SEPARATION\ *) \), ";", 
              "\[IndentingNewLine]", \(rule3Param0 = \(rule3Param = 10\)\), 
              ";", \(rule3ParamMin = 0\), 
              ";", \(rule3ParamMax = 20\), \( (*\ ALIGNMENT\ *) \), ";", 
              "\[IndentingNewLine]", \(rule4Param0 = \(rule4Param = 1\)\), 
              ";", \(rule4ParamMin = 0\), 
              ";", \(rule4ParamMax = 1\), \( (*\ FUZZY\ MOVE\ *) \), ";", 
              "\[IndentingNewLine]", \(rule5Param0 = \(rule5Param = 1\)\), 
              ";", \(rule5ParamMin = 0\), 
              ";", \(rule5ParamMax = 5\), \( (*\ AVOIDANCE\ *) \), ";", 
              "\[IndentingNewLine]", \(rule6Param0 = \(rule6Param = 0.5\)\), 
              ";", \(rule6ParamMin = 0\), 
              ";", \(rule6ParamMax = 1\), \( (*\ CONTAINMENT\ *) \), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ create\ filled\ agents\ *) \), 
              "\[IndentingNewLine]", \(agents = {}\), ";", 
              "\[IndentingNewLine]", \( (*\ 
                ASSUMPTION : \ 
                  Prey\ agent\ speeds\ are\ distributed\ N[speedBndInit, 
                      0.25*speedBndInit]\ *) \), "\[IndentingNewLine]", 
              " ", \(ndist = 
                NormalDistribution[speedBndInit, 0.25*speedBndInit]\), ";", 
              "\[IndentingNewLine]", \( (*\ 
                AGENT\ \(PATTERN : \ 
                    agent[id_, x_, y_, vx_, vy_, col_, sz_, fil_, v0_, sel_, 
                      nColl_, ty_, target_, orient_, leat_]\)\ *) \), 
              "\[IndentingNewLine]", \( (*\ Add\ agent\ prey\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"Do", "[", "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{
                    StyleBox["newAgent",
                      FontColor->RGBColor[0, 0, 1]], 
                    "[", \("\<#\>" <> ToString[i], 
                    Random[Integer, {0, panelFrameSizeX}], 
                    Random[Integer, {0, panelFrameSizeY}], 
                    vx = Sign[Random[Real, {\(-1\), 1}]]*Random[ndist]; 
                    vx*speedFac, 
                    vy = Sign[Random[Real, {\(-1\), 1}]]*Random[ndist]; 
                    vy*speedFac, 
                    JavaNew["\<java.awt.Color\>", Random[], Random[], 
                      Random[]], Random[Integer, {sizeInitMin, sizeInitMax}], 
                    True, \@\(vx\^2 + vy\^2\), False, 0, 0, 
                    TargetNone, \[IndentingNewLine]Which[Abs[vx] > 0, 
                      ArcTan[vy\/vx], vy > 0, \[Pi]\/2, 
                      vy < 0, \(3\ \[Pi]\)\/2, True, 
                      Random[Real, {0, 2\ \[Pi]}]], {}\), "]"}], ",", 
                  "\[IndentingNewLine]", \({i, numAgentsUser}\)}], "]"}], ";",
               "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                REPORT\ on\ agents\ created\ *) \), 
              "\[IndentingNewLine]", \(agentsCreated = numAgentsUser\), ";", 
              "\[IndentingNewLine]", \(Print["\<There are \>", 
                ToString@Length[agents], "\< agents.\>"]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                INITIALIZE\ center\ of\ mass\ of\ agent\ positions\ *) \), 
              "\[IndentingNewLine]", \(cmPreyL = {{0, 0}}\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{\({xCM0, yCM0}\), "=", 
                RowBox[{"Mean", "@", 
                  RowBox[{"Cases", "[", 
                    RowBox[{"agents", ",", 
                      RowBox[{
                        RowBox[{
                          StyleBox["agent",
                            FontColor->RGBColor[0, 0, 1]], "[", \(_, x1_, 
                          y1_, ___, 0, _, _, _\), "]"}], 
                        "\[RuleDelayed]", \({x1, y1}\)}]}], "]"}]}]}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ DRAW\ PANEL\ WITH\ AGENTS\ *) \), 
              "\[IndentingNewLine]", \( (*\ draw\ white\ panel\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`WHITE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                fillRect[0, 0, panelFrameSizeX, panelFrameSizeY]]\), ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ blue\ rectangle\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`BLUE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                drawRect[
                  Round[panelFrameSizeX/2 + 
                      zoomFac*\((10 - panelFrameSizeX/2)\)], 
                  Round[
                    panelFrameSizeY/2 + 
                      zoomFac*\((\(-panelFrameSizeY\)/2)\)], 
                  Round[zoomFac*\((panelFrameSizeX - 20)\)], 
                  Round[zoomFac*\((panelFrameSizeY - 10)\)]]]\), ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ all\ agents\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["drawAgent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(g, #1\), "]"}], 
                    "&"}], ")"}], "/@", "agents"}], ";", 
              "\[IndentingNewLine]", \(mathPanel[setImage[offscreen]]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"(*", " ", 
                RowBox[{"FORMAT", " ", 
                  RowBox[{"TEMPLATE", ":", " ", 
                    RowBox[{
                      StyleBox["createSliderWindow",
                        FontColor->RGBColor[0, 0, 1]], 
                      "[", \(sliderTitle = "\<Agent Rule Parameters\>", 
                      sliderFrameX = 703, sliderFrameY = 75, 
                      sliderFrameXDim = 300, sliderFrameYDim = 120, 
                      scrollValue0 = 25, scrollValueMin = 0, 
                      scrollValueMax = 100\), "]"}]}]}], " ", "*)"}], 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                create\ window\ for\ agent\ rule\ sliders\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(! JavaObjectQ[windowParams]\), ",", 
                  RowBox[{"windowParams", "=", 
                    RowBox[{
                      StyleBox["createSliderWindow",
                        FontColor->RGBColor[0, 0, 1]], 
                      "[", \("\<Agent Rule Parameters\>", 703, 75, 300, 120, 
                      25, 0, 100\), "]"}]}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                create\ window\ for\ gobal\ parameters\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(! JavaObjectQ[windowGlobal]\), ",", 
                  RowBox[{"windowGlobal", "=", 
                    RowBox[{
                      StyleBox["createSliderWindowGlobal",
                        FontColor->RGBColor[0, 0, 1]], 
                      "[", \("\<Global Parameters\>", 703, 196, 300, 80, 25, 
                      0, 100\), "]"}]}]}], "]"}], ";"}]}], 
          "\[IndentingNewLine]", 
          "\[IndentingNewLine]", \( (*\ 
            create\ window\ for\ sliders\ using\ JSlider\ *) \), 
          "\[IndentingNewLine]", 
          RowBox[{"(*", "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{
                StyleBox["createSliderWindowTest",
                  FontColor->RGBColor[0, 0, 1]], "[", \("\<Agent Speed\>", 
                703, 75, 300, 120, 25, 0, 100\), "]"}], ";"}], 
            "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.701961]]
}, Closed]],

Cell[CellGroupData[{

Cell["step", "Subsubsection"],

Cell[BoxData[{\(Clear[step];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["step",
          FontColor->RGBColor[0, 0, 1]], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({dataUpdata}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ UPDATE\ global\ time\ *) \), 
            "\[IndentingNewLine]", 
            
            RowBox[{\(++tNow\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                print\ number\ of\ agents\ if\ number\ has\ changed\ in\ \
previous\ step\ *) \), 
              "\[IndentingNewLine]", \( (*\[IndentingNewLine]\(If[\((Length[
                          agents])\) \[NotEqual] numAgents, 
                    numAgents = Length[agents]; 
                    Print["\<There are \>", 
                      ToString@numAgents, "\< agents at time \>", 
                      tNow, "\<.\>"];];\)\[IndentingNewLine]*) \), 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                UPDATE\ agent\ positions\ and\ states\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"agents", "=", 
                RowBox[{
                  StyleBox["agentRulesBoid",
                    FontColor->RGBColor[0, 0, 1]], "/@", "agents"}]}], 
              " ", \( (*\ 
                agentRules\ agentRulesBoid\ agentRulesCMM\ *) \), \( (*\ 
                apply\ agent\ rules\ to\ all\ agents\ *) \), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                UPDATE\ running\ coordinates\ in\ data\ panel\ *) \), 
              "\[IndentingNewLine]", \( (*\ 
                check\ for\ existence\ of\ a\ selected\ agent\ *) \), 
              "\[IndentingNewLine]", \(If[agents === {}, 
                Print["\<Error:step: agents list is empty.\>"]]\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(aSelected =!= Null\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"agentData", "=", 
                      RowBox[{"First", "@", 
                        RowBox[{"Cases", "[", 
                          RowBox[{"agents", ",", 
                            RowBox[{
                              StyleBox["agent",
                                FontColor->RGBColor[0, 0, 1]], 
                              "[", \(aSelected\[LeftDoubleBracket]1\
\[RightDoubleBracket], ___\), "]"}]}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", \(textField1@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]1\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField2@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]2\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField3@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]3\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField4@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]4\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField5@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]5\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField6@setText[ToString[speedFac]]\), 
                    ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                UPDATE\ agent\ rule\ parameters\ in\ slider\ window\ *) \), 
              "\[IndentingNewLine]", \(textFields1@
                setText[ToString[rule1Param]]\), ";", 
              "\[IndentingNewLine]", \(textFields2@
                setText[ToString[rule2Param]]\), ";", 
              "\[IndentingNewLine]", \(textFields3@
                setText[ToString[rule3Param]]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                UPDATE\ global\ parameters\ in\ slider\ window\ *) \), 
              "\[IndentingNewLine]", \(textFieldsG1@
                setText[ToString[speedFac]]\), ";", 
              "\[IndentingNewLine]", \(textFieldsG2@
                setText[ToString[zoomFac]]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                EVENT : \ Predators\ eats\ prey\ if\ within\ range\ *) \), 
              "\[IndentingNewLine]", \(eatenAgents = {}\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"predL", "=", 
                RowBox[{"Cases", "[", 
                  RowBox[{"agents", ",", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(___, 
                      1, _, _, _\), "]"}]}], "]"}]}], \( (*\ 
                predator\ list\ *) \), ";", "\[IndentingNewLine]", 
              RowBox[{"preyL", "=", 
                RowBox[{"Cases", "[", 
                  RowBox[{"agents", ",", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(___, 
                      0, _, _, _\), "]"}]}], "]"}]}], \( (*\ 
                prey\ list\ *) \), ";", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                
                RowBox[{\(predL =!= {} && preyL =!= {}\), ",", 
                  "\[IndentingNewLine]", 
                  
                  RowBox[{\(predEatL = \((Cases[preyL, 
                              a : agent[idP_, xP_, yP_, ___, 
                                      0, _, _, _] /; \@\(\((xP - #1\
\[LeftDoubleBracket]2\[RightDoubleBracket])\)\^2 + \((yP - #1\
\[LeftDoubleBracket]3\[RightDoubleBracket])\)\^2\) < #1\[LeftDoubleBracket]7\
\[RightDoubleBracket] \[RuleDelayed] ReplacePart[#1, {tNow, a}, 15]] &)\) /@ 
                        predL\), \( (*\ 
                      predator\ eats\ prey\ if\ within\ one\ body\ \(\(length\
\)\(.\)\)\ *) \), ";", "\[IndentingNewLine]", 
                    RowBox[{"eatenAgents", "=", 
                      RowBox[{"Cases", "[", 
                        RowBox[{"predEatL", ",", 
                          RowBox[{
                            StyleBox["agent",
                              FontColor->RGBColor[0, 0, 1]], 
                            "[", \(id_, ___\), "]"}], ",", \({4}\)}], 
                        "]"}]}], \( (*\ eaten\ prey\ *) \), ";"}]}], 
                "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                CALCULATE\ agent\ CM\ for\ plot\ and\ Mathe\ time\ series\ \
analysis\ *) \), 
              "\[IndentingNewLine]", \( (*\ global : \ agents\ cmPreyL\ *) \),
               "\[IndentingNewLine]", 
              RowBox[{\({cmPreyX, cmPreyY}\), "=", 
                RowBox[{"If", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"preyLocL", "=", 
                          RowBox[{"Cases", "[", 
                            RowBox[{"agents", ",", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["agent",
                                    FontColor->RGBColor[0, 0, 1]], "[", \(_, 
                                  x1_, y1_, ___, 0, _, _, _\), "]"}], 
                                "\[RuleDelayed]", \({x1, y1}\)}]}], "]"}]}], 
                        ")"}], "===", \({}\)}], ",", \(Last[cmPreyL]\), 
                    ",", \(Mean[preyLocL] - {xCM0, yCM0}\)}], "]"}]}], \( (*\ 
                calc\ center\ of\ mass\ for\ prey\ *) \), ";", 
              "\[IndentingNewLine]", \(cmPreyL = 
                Join[cmPreyL, {{cmPreyX, cmPreyY}}]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ DRAW\ PANEL\ WITH\ AGENTS\ *) \), 
              "\[IndentingNewLine]", \( (*\ DRAW\ white\ panel\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`WHITE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                fillRect[0, 0, panelFrameSizeX, panelFrameSizeY]]\), ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ blue\ rectangle\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`BLUE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                drawRect[
                  Round[panelFrameSizeX/2 + 
                      zoomFac*\((10 - panelFrameSizeX/2)\)], 
                  Round[panelFrameSizeY/2 + 
                      zoomFac*\((\(-panelFrameSizeY\)/2)\)], 
                  Round[zoomFac*\((panelFrameSizeX - 20)\)], 
                  Round[zoomFac*\((panelFrameSizeY - 10)\)]]]\), ";", 
              "\[IndentingNewLine]", \( (*\ 
                HIGHLIGHT\ predators\ eating\ prey\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(predL =!= {}\), ",", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["drawAgent",
                            FontColor->RGBColor[0, 0, 1]], "[", \(g, #1, 
                          oval\), "]"}], "&"}], ")"}], 
                    "/@", \(First[predEatL]\)}]}], "]"}], ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ all\ agents\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["drawAgent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(g, #1\), "]"}], 
                    "&"}], ")"}], "/@", "agents"}], ";", 
              "\[IndentingNewLine]", \(mathPanel[setImage[offscreen]]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                UPDATE\ agents\ IF\ PREY\ EATEN\ *) \), 
              "\[IndentingNewLine]", \( (*\ 
                eliminate\ eaten\ prey\ from\ agents\ list\ and\ update\ \
predators\ with\ eaten\ prey\ in\ agents\ list\ *) \), "\[IndentingNewLine]", 
              
              RowBox[{"If", "[", 
                RowBox[{\(eatenAgents =!= {}\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"agents", "=", 
                      RowBox[{"Fold", "[", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"DeleteCases", "[", 
                              RowBox[{"#1", ",", 
                                RowBox[{
                                  StyleBox["agent",
                                    FontColor->RGBColor[0, 0, 1]], 
                                  "[", \(#2\[LeftDoubleBracket]1\
\[RightDoubleBracket], ___\), "]"}]}], "]"}], "&"}], ",", "agents", ",", 
                          "eatenAgents"}], "]"}]}], \( (*\ 
                      eliminate\ eaten\ prey\ from\ agents\ list\ *) \), ";", 
                    "\[IndentingNewLine]", \(agents = 
                      First[\((agents /. \[InvisibleSpace]agent[#1\
\[LeftDoubleBracket]1\[RightDoubleBracket], x_, y_, vx_, vy_, col_, sz_, 
                                    fil_, v0_, sel_, nColl_, ty_, target_, 
                                    orient_, leat_] \[RuleDelayed] 
                                  agent[#1\[LeftDoubleBracket]1\
\[RightDoubleBracket], x, y, vx, vy, col, sz, fil, v0, sel, nColl, ty, 
                                    TargetNone, orient, leat] &)\) /@ 
                          Flatten[predEatL, 1]]\), \( (*\ 
                      UPDATE\ predators\ with\ eaten\ prey\ in\ agents\ list\ \
and\ remove\ prey\ as\ target*) \), ";"}]}], "\[IndentingNewLine]", "]"}], 
              ";"}]}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.701961]]
}, Closed]],

Cell[CellGroupData[{

Cell["plotCMX", "Subsubsection"],

Cell["\<\
Program for creating data to feed to Repast for plotting. Returns single \
value for each step. Also, records time series for analysis. \
\>", "Text"],

Cell[BoxData[{\(Clear[plotCMX];\), "\n", 
    RowBox[{
      RowBox[{
        StyleBox["plotCMX",
          FontColor->RGBColor[0, 0, 1]], 
        ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            called\ by\ Repast\ at\ each\ step\ *) \[IndentingNewLine] (*\ 
            cmPreyX\ return\ value\ for\ Repast\ plot\ \
*) \[IndentingNewLine]cmPreyX\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.700008]],

Cell["Test", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox["plotCMX",
      FontColor->RGBColor[0, 0, 1]]], "Input"],

Cell[BoxData[
    \(165.43286267948395`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["stop", "Subsubsection"],

Cell[BoxData[{\(Clear[stop];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["stop",
          FontColor->RGBColor[0, 0, 1]], 
        ":=", \(Module[{}, \[IndentingNewLine]\[IndentingNewLine] (*\(agents \
= {} (*\ reset\ agents\ *) ;\)*) \[IndentingNewLine]numAgents = 
            numAgentsUser; \[IndentingNewLine]Print["\<Simulation completed \
at time \>", tNow, "\<.\>"]; \[IndentingNewLine]tNow = 
            0; \[IndentingNewLine]aSelected = 
            Null; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            reset\ panel\ *) \[IndentingNewLine]g[
            setColor[Color`WHITE]]; \[IndentingNewLine]g[
            fillRect[0, 0, panelFrameSizeX, 
              panelFrameSizeY]]; \[IndentingNewLine]mathPanel[
            setImage[offscreen]];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.700999]]
}, Closed]],

Cell[CellGroupData[{

Cell["exit", "Subsubsection"],

Cell[BoxData[{\(Clear[exit];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["exit",
          FontColor->RGBColor[0, 0, 1]], ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Print["\<exit button pressed.\>"]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(windowGlobal@dispose[]\), ";", 
              "\[IndentingNewLine]", \(windowParams@dispose[]\), ";", 
              "\[IndentingNewLine]", \(mathFrame@dispose[]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(ReleaseJavaObject[windowGlobal]\), ";",
               "\[IndentingNewLine]", \(ReleaseJavaObject[windowParams]\), 
              ";", "\[IndentingNewLine]", \(ReleaseJavaObject[mathFrame]\), 
              ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RETURN\ control\ to\ Mathematica\ *) \), 
              "\[IndentingNewLine]", 
              StyleBox[\(EndModal[]\),
                "MR"], 
              StyleBox[";",
                "MR"], 
              StyleBox["\[IndentingNewLine]",
                "MR"], 
              StyleBox["\[IndentingNewLine]",
                "MR"], \( (*\ PLOT\ center\ of\ mass\ of\ agents\ *) \), 
              "\[IndentingNewLine]", \(tsCMPrey = 
                Transpose[
                  cmPreyL0 = \(Split[
                        cmPreyL, #1 =!= #2 &]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]\), ";", 
              "\[IndentingNewLine]", \(Print["\<cmPreyL created: time series \
of agent CM locations during simulation of length \>", 
                Length@cmPreyL "\<.\>"]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                DISPLAY\ time\ series\ from\ simulation\ *) \), 
              "\[IndentingNewLine]", \(distCM = 
                MapThread[Sqrt[#1\^2 + #2\^2] &, tsCMPrey]\), \( (*\ 
                dist\ from\ initial\ CM\ *) \), ";", 
              "\[IndentingNewLine]", \(g1 = 
                DisplayTogether@
                  MapThread[
                    ListPlot[#1, AspectRatio \[Rule] 0.6, 
                        AxesOrigin \[Rule] Automatic, 
                        Background \[Rule] RGBColor[1, 1, 1], 
                        DisplayFunction \[Rule] $DisplayFunction, 
                        Epilog \[Rule] {}, 
                        Frame \[Rule] 
                          True, \[IndentingNewLine]FrameLabel \[Rule] {\
\[IndentingNewLine]StyleForm["\<Time\>", FontSize \[Rule] 12], 
                            StyleForm["\<CM(X = Red, Y = Blue, d = Gold)\>", 
                              FontSize \[Rule] 12]\[IndentingNewLine]}, 
                        FrameTicks \[Rule] Automatic, 
                        ImageSize \[Rule] 500\ {1, 0.66}, 
                        PlotJoined \[Rule] True, 
                        PlotLabel \[Rule] 
                          StyleForm["\<Agent Center of Mass and Distance\>", 
                            FontSize \[Rule] 14], PlotRange \[Rule] All, 
                        PlotRegion \[Rule] Automatic, 
                        PlotStyle \[Rule] {#2, Thickness[0.005]}, 
                        TextStyle \[Rule] {FontFamily \[Rule] \
"\<Helvetica\>", FontWeight \[Rule] "\<Bold\>", 
                            FontColor \[Rule] RGBColor[0, 0, 0], 
                            FontSize \[Rule] 
                              10}] &, \
\[IndentingNewLine]{\[IndentingNewLine]Join[{distCM}, tsCMPrey] (*\ 
                        list\ of\ times\ series\ from\ simulation\ *) , \
\[IndentingNewLine]{RGBColor[1, 0.85, 0], RGBColor[1, 0, 0], 
                        RGBColor[0, 0, 1]} (*\ 
                        list\ of\ colors\ for\ times\ series\ \
*) \[IndentingNewLine]}]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(Print["\<Mean Center of Mass: \>", 
                Mean /@ tsCMPrey]\), ";", 
              "\[IndentingNewLine]", \(Print["\<S.D. Center of Mass: \>", 
                StandardDeviation /@ tsCMPrey]\), ";"}]}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell",
  Background->RGBColor[1, 1, 0.700999]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UI functions", "Section"],

Cell[CellGroupData[{

Cell["mousePressedFunc[e_,x_,y_,_]", "Subsubsection"],

Cell["\<\
Speicfy mouse functions.  Left button: Add new agent.  Right button: Select \
agent, Deselect agent (double).\
\>", "Text"],

Cell[BoxData[{\(Clear[mousePressedFunc];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["mousePressedFunc",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, xM_, yM_, _\), "]"}], ":=",
         
        RowBox[{"Module", "[", 
          
          RowBox[{\({mouseOffset = 0, ndist, numCollisions = 0, x, y, vx, 
              vy}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ 
              refine\ mouse\ click\ location\ *) \), "\[IndentingNewLine]", 
            
            RowBox[{\({x, y} = {xM + mouseOffset, yM + mouseOffset}\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                rt\ \(click : \ select/deselect\ agent\), \ 
                lft\ \(click : \ add\ new\ agent\)\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                
                RowBox[{\(e@isMetaDown[]\), ",", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    RowBox[{
                      StyleBox[\(e@getClickCount[] == 1\),
                        FormatType->StandardForm], 
                      StyleBox[",",
                        FormatType->StandardForm], 
                      StyleBox["\[IndentingNewLine]",
                        FormatType->StandardForm], 
                      StyleBox["\[IndentingNewLine]",
                        FormatType->StandardForm], \( (*\ 
                        rt\ single\ \(click : \ select\ agent\)\ *) \), 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        RowBox[{"aSelected", "=", 
                          RowBox[{
                            StyleBox["computeClosest",
                              FontColor->RGBColor[0, 0, 1]], "[", \(x, y\), 
                            "]"}]}], \( (*\ return\ agent\ *) \), ";", 
                        "\[IndentingNewLine]", \( (*\(Print["\<Point \
selected: \>", {x, y}, "\<  \>", aSelected];\)*) \), 
                        "\[IndentingNewLine]", \( (*\ 
                          deselect\ all\ agents\ *) \), "\[IndentingNewLine]",
                         
                        RowBox[{"agents", "=", 
                          RowBox[{"agents", "/.", "\[InvisibleSpace]", 
                            RowBox[{
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], "[", \(id_, 
                                x_, y_, vx_, vy_, col_, sz_, fil_, v0_, sel_, 
                                nColl_, ty_, target_, orient_, leat_\), "]"}],
                               "\[RuleDelayed]", 
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], "[", \(id, 
                                x, y, vx, vy, col, sz, fil, v0, False, nColl, 
                                ty, target, orient, leat\), "]"}]}]}]}], ";", 
                        "\[IndentingNewLine]", \( (*\ 
                          select\ selected\ agent\ *) \), 
                        "\[IndentingNewLine]", 
                        RowBox[{"agents", "=", 
                          RowBox[{"agents", "/.", 
                            RowBox[{
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], 
                                "[", \(aSelected\[LeftDoubleBracket]1\
\[RightDoubleBracket], x_, y_, vx_, vy_, col_, sz_, fil_, v0_, sel_, nColl_, 
                                ty_, target_, orient_, leat_\), "]"}], 
                              "\[RuleDelayed]", 
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], 
                                "[", \(aSelected\[LeftDoubleBracket]1\
\[RightDoubleBracket], x, y, vx, vy, col, sz, fil, v0, True, nColl, ty, 
                                target, orient, leat\), "]"}]}]}]}], ";", 
                        "\[IndentingNewLine]", \( (*\ 
                          display\ probe\ for\ selected\ agent\ *) \), 
                        "\[IndentingNewLine]", 
                        RowBox[{
                          StyleBox["displayProbeFrame",
                            FontColor->RGBColor[0, 0, 1]], "[", "aSelected", 
                          "]"}]}], ",", "\[IndentingNewLine]", 
                      "\[IndentingNewLine]", \( (*\ 
                        rt\ dbl\ \(click : \ deselect\ agent\)\ *) \), 
                      "\[IndentingNewLine]", \( (*\ 
                        deselect\ all\ agents\ *) \), "\[IndentingNewLine]", 
                      
                      RowBox[{\(aSelected = Null\), ";", 
                        "\[IndentingNewLine]", 
                        RowBox[{"agents", "=", 
                          RowBox[{"agents", "/.", "\[InvisibleSpace]", 
                            RowBox[{
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], "[", \(id_, 
                                x_, y_, vx_, vy_, col_, sz_, fil_, v0_, sel_, 
                                nColl_, target_, orient_, leat_\), "]"}], 
                              "\[RuleDelayed]", 
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], "[", \(id, 
                                x, y, vx, vy, col, sz, fil, v0, False, nColl, 
                                target, orient, leat\), "]"}]}]}]}], ";", 
                        "\[IndentingNewLine]", \( (*\ 
                          destroy\ data\ frame\ if\ exists\ *) \), 
                        "\[IndentingNewLine]", \(If[JavaObjectQ[probeFrame], 
                          probeFrame@dispose[]; 
                          ReleaseJavaObject[probeFrame]]\), ";"}]}], 
                    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", \( (*\ 
                    lft\ \(click : \ create\ unfilled\ agent\)\ *) \), 
                  "\[IndentingNewLine]", \( (*\ 
                    ASSUMPTION : \ 
                      Predator\ agent\ speeds\ are\ distributed\ N[0, 
                          speedBndClick]\ *) \), "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  
                  RowBox[{\(ndist = NormalDistribution[0, speedBndClick]\), 
                    ";", "\[IndentingNewLine]", 
                    "\[IndentingNewLine]", \( (*\ 
                      AGENT\ \(PATTERN : \ 
                          agent[id_, x_, y_, vx_, vy_, col_, sz_, fil_, v0_, 
                            sel_, nColl_, ty_, target_, orient_, 
                            leat_]\)\ *) \), 
                    "\[IndentingNewLine]", \( (*\ Add\ agent\ predator\ *) \),
                     "\[IndentingNewLine]", \(agentsCreated++\), ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                      StyleBox["newAgent",
                        FontColor->RGBColor[0, 0, 1]], 
                      "[", \("\<#\>" <> ToString[agentsCreated], x, y, 
                      vx = Random[ndist]; vx*speedFac, vy = Random[ndist]; 
                      vy*speedFac, 
                      JavaNew["\<java.awt.Color\>", Random[], Random[], 
                        Random[]], 
                      Random[Integer, {sizeClickMin, sizeClickMax}], 
                      False, \@\(vx\^2 + vy\^2\), False, 0, 1, 
                      TargetNone, \[IndentingNewLine]Which[Abs[vx] > 0, 
                        ArcTan[vy\/vx], vy > 0, \[Pi]\/2, 
                        vy < 0, \(3\ \[Pi]\)\/2, True, 
                        Random[Real, {0, 2\ \[Pi]}]], {}\), "]"}], ";"}]}], 
                "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                REDRAW\ is\ needed\ if\ simulation\ is\ paused\ *) \), 
              "\[IndentingNewLine]", \( (*\ DRAW\ PANEL\ WITH\ AGENTS\ *) \), 
              "\[IndentingNewLine]", \( (*\ DRAW\ white\ panel\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`WHITE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                fillRect[0, 0, panelFrameSizeX, panelFrameSizeY]]\), ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ blue\ rectangle\ *) \), 
              "\[IndentingNewLine]", \(g[setColor[Color`BLUE]]\), ";", 
              "\[IndentingNewLine]", \(g[
                drawRect[
                  Round[panelFrameSizeX/2 + 
                      zoomFac*\((10 - panelFrameSizeX/2)\)], 
                  Round[panelFrameSizeY/2 + 
                      zoomFac*\((\(-panelFrameSizeY\)/2)\)], 
                  Round[zoomFac*\((panelFrameSizeX - 20)\)], 
                  Round[zoomFac*\((panelFrameSizeY - 10)\)]]]\), ";", 
              "\[IndentingNewLine]", \( (*\ DRAW\ all\ agents\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["drawAgent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(g, #1\), "]"}], 
                    "&"}], ")"}], "/@", "agents"}], ";", 
              "\[IndentingNewLine]", \(mathPanel[setImage[offscreen]]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(ReleaseJavaObject[e]\)}]}], 
          "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["createSliderWindow", "Subsubsection"],

Cell["Create slider window for agent rule parameters.", "Text"],

Cell[BoxData[{\(Clear[createSliderWindow];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["createSliderWindow",
            FontColor->RGBColor[0, 0, 1]], "[", \(sliderTitleS_String, 
          sliderFrameX_Integer, sliderFrameY_Integer, 
          sliderFrameXDim_Integer, sliderFrameYDim_Integer, 
          scrollValue0_Integer, scrollValueMin_Integer, 
          scrollValueMax_Integer\), "]"}], 
        ":=", \(Module[{}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            create\ slider\ frame\ *) \[IndentingNewLine]sliderFrame = 
            JavaNew["\<javax.swing.JFrame\>", 
              sliderTitleS]; \[IndentingNewLine] (*\ 
            set\ layout\ *) \[IndentingNewLine]contentSliderFrame = 
            sliderFrame@getContentPane[]; \[IndentingNewLine]sliderLayout = 
            JavaNew["\<java.awt.GridLayout\>", 0, 3] (*\ any\ rows, \ 
            3\ col\ *) ; \[IndentingNewLine]contentSliderFrame@
            setLayout[
              sliderLayout]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            row\ 1\ *) \[IndentingNewLine] (*\ 
            label1\ *) \[IndentingNewLine]labels1 = 
            JavaNew["\<java.awt.Label\>", "\<COHESION:\>"]; \
\[IndentingNewLine]labels1@
            setAlignment[0]; \[IndentingNewLine]contentSliderFrame@
            add[labels1]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            textFields1\ *) \[IndentingNewLine]textFields1 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[rule1Param0], 
              10]; \[IndentingNewLine]contentSliderFrame@
            add[textFields1]; \[IndentingNewLine]textFields1@
            setEditable[False]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider1\ *) \[IndentingNewLine]slider1 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              Round[100*\((rule1Param0 - rule1ParamMin)\)/\((rule1ParamMax - 
                        rule1ParamMin)\)], 1, 0, 
              100]; \[IndentingNewLine] (*\ 
            create\ and\ attach\ the\ slider1\ event\ handler\ \
*) \[IndentingNewLine]slider1Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine] (*\ 
            FIX\ THIS\ FOR\ JAVA\ not\ \
MathJava\[IndentingNewLine]\(slider1Listener = 
                  
                  JavaNew["\<java.awt.AdjustmentListener\>"];\)\
*) \[IndentingNewLine]slider1Listener@
            setHandler["\<adjustmentValueChanged\>", 
              ToString[slider1Func]]; \[IndentingNewLine]slider1@
            addAdjustmentListener[
              slider1Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slider1]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            row\ 2\ *) \[IndentingNewLine] (*\ 
            label2\ *) \[IndentingNewLine]labels2 = 
            JavaNew["\<java.awt.Label\>", "\<SEPARATION:\>"]; \
\[IndentingNewLine]labels2@
            setAlignment[0]; \[IndentingNewLine]contentSliderFrame@
            add[labels2]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            textFields2\ *) \[IndentingNewLine]textFields2 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[rule2Param0], 
              10]; \[IndentingNewLine]contentSliderFrame@
            add[textFields2]; \[IndentingNewLine]textFields2@
            setEditable[False]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider2\ *) \[IndentingNewLine]slider2 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              Round[100*\((rule2Param0 - rule2ParamMin)\)/\((rule2ParamMax - 
                        rule2ParamMin)\)], 1, 0, 
              100]; \[IndentingNewLine] (*\ 
            create\ and\ attach\ the\ slider2\ event\ handler\ \
*) \[IndentingNewLine]slider2Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine]slider2Listener@
            setHandler["\<adjustmentValueChanged\>", 
              ToString[slider2Func]]; \[IndentingNewLine]slider2@
            addAdjustmentListener[
              slider2Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slider2]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            row\ 3\ *) \[IndentingNewLine] (*\ 
            label3\ *) \[IndentingNewLine]labels3 = 
            JavaNew["\<java.awt.Label\>", "\<ALIGNMENT:\>"]; \
\[IndentingNewLine]labels3@
            setAlignment[0]; \[IndentingNewLine]contentSliderFrame@
            add[labels3]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            textFields3\ *) \[IndentingNewLine]textFields3 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[rule3Param0], 
              10]; \[IndentingNewLine]contentSliderFrame@
            add[textFields3]; \[IndentingNewLine]textFields3@
            setEditable[False]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider3\ *) \[IndentingNewLine]slider3 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              Round[100*\((rule3Param0 - rule3ParamMin)\)/\((rule3ParamMax - 
                        rule3ParamMin)\)], 1, 0, 
              100]; \[IndentingNewLine] (*\ 
            create\ and\ attach\ the\ slider3\ event\ handler\ \
*) \[IndentingNewLine]slider3Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine]slider3Listener@
            setHandler["\<adjustmentValueChanged\>", 
              ToString[slider3Func]]; \[IndentingNewLine]slider3@
            addAdjustmentListener[
              slider3Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slider3]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider\ frame\ *) \[IndentingNewLine]sliderFrame@
            setBounds[sliderFrameX, sliderFrameY, sliderFrameXDim, 
              sliderFrameYDim]; \[IndentingNewLine]sliderFrame@
            setResizable[False]; \[IndentingNewLine]JavaShow[
            sliderFrame]; \
\[IndentingNewLine]sliderFrame\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["slider1Func", "Subsubsection"],

Cell["agent rule 1 parameter  ", "Text"],

Cell[BoxData[{\(Clear[slider1Func];\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["slider1Func",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, type_, scrollPos_\), 
          "]"}], ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            scrollPos\ is\ int\ between\ 0\ and\ 100\ \
*) \[IndentingNewLine]rule1Param = 
            N[rule1ParamMin + \((rule1ParamMax - rule1ParamMin)\)*
                  scrollPos/
                    100]; \[IndentingNewLine] (*\(Print["\<rule1Param = \>", 
                rule1Param];\)*) \[IndentingNewLine]\[IndentingNewLine]\
ReleaseObject[e];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["slider2Func", "Subsubsection"],

Cell["agent rule 2 parameter ", "Text"],

Cell[BoxData[{\(Clear[slider2Func];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["slider2Func",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, type_, scrollPos_\), 
          "]"}], ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            scrollPos\ is\ int\ between\ 0\ and\ 100\ \
*) \[IndentingNewLine]rule2Param = 
            N[rule2ParamMin + \((rule2ParamMax - rule2ParamMin)\)*
                  scrollPos/
                    100]; \[IndentingNewLine] (*\(Print["\<rule2Param = \>", 
                rule2Param];\)*) \[IndentingNewLine]\[IndentingNewLine]\
ReleaseObject[e];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["slider3Func", "Subsubsection"],

Cell["agent rule 3 parameter.", "Text"],

Cell[BoxData[{\(Clear[slider3Func];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["slider3Func",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, type_, scrollPos_\), 
          "]"}], ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            scrollPos\ is\ int\ between\ 0\ and\ 100\ \
*) \[IndentingNewLine]rule3Param = 
            N[rule3ParamMin + \((rule3ParamMax - rule3ParamMin)\)*
                  scrollPos/
                    100]; \[IndentingNewLine] (*\(Print["\<rule3Param = \>", 
                rule3Param];\)*) \[IndentingNewLine]\[IndentingNewLine]\
ReleaseObject[e];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["createSliderWindowGlobal", "Subsubsection"],

Cell[BoxData[{\(Clear[createSliderWindowGlobal];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["createSliderWindowGlobal",
            FontColor->RGBColor[0, 0, 1]], "[", \(sliderTitleS_String, 
          sliderFrameX_Integer, sliderFrameY_Integer, 
          sliderFrameXDim_Integer, sliderFrameYDim_Integer, 
          scrollValue0_Integer, scrollValueMin_Integer, 
          scrollValueMax_Integer\), "]"}], 
        ":=", \(Module[{}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            create\ slider\ frame\ *) \[IndentingNewLine]sliderFrame = 
            JavaNew["\<javax.swing.JFrame\>", 
              sliderTitleS]; \[IndentingNewLine] (*\ 
            set\ layout\ *) \[IndentingNewLine]contentSliderFrame = 
            sliderFrame@
              getContentPane[]; \[IndentingNewLine] (*\(sliderLayout = 
                JavaNew["\<java.awt.BorderLayout\>"];\)*) \[IndentingNewLine]\
sliderLayout = JavaNew["\<java.awt.GridLayout\>", 0, 3] (*\ any\ rows, \ 
            1\ col\ *) ; \[IndentingNewLine]contentSliderFrame@
            setLayout[
              sliderLayout]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            labelsG1\ *) \[IndentingNewLine]labelsG1 = 
            JavaNew["\<java.awt.Label\>", "\<Speed Factor:\>"]; \
\[IndentingNewLine]labelsG1@
            setAlignment[0]; \[IndentingNewLine]contentSliderFrame@
            add[labelsG1]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            textFieldsG1\ *) \[IndentingNewLine]textFieldsG1 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[speedFac0], 
              10]; \[IndentingNewLine]contentSliderFrame@
            add[textFieldsG1]; \[IndentingNewLine]textFieldsG1@
            setEditable[False]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slidersG1\ *) \[IndentingNewLine]slidersG1 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              Round[100*\((speedFac0 - speedFacMin)\)/\((speedFacMax - 
                        speedFacMin)\)], 1, 0, 100]; \[IndentingNewLine] (*\ 
            create\ and\ attach\ the\ slider1\ event\ handler\ \
*) \[IndentingNewLine]slidersG1Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine] (*\ 
            FIX\ THIS\ FOR\ JAVA\ not\ \
MathJava\[IndentingNewLine]\(slidersG1Listener = 
                  JavaNew["\<java.awt.AdjustmentListener\>"];\)\
*) \[IndentingNewLine]slidersG1Listener@
            setHandler["\<adjustmentValueChanged\>", 
              ToString[slidersG1Func]]; \[IndentingNewLine]slidersG1@
            addAdjustmentListener[
              slidersG1Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slidersG1]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            labelsG2\ *) \[IndentingNewLine]labelsG2 = 
            JavaNew["\<java.awt.Label\>", "\<Zoom Factor:\>"]; \
\[IndentingNewLine]labelsG2@
            setAlignment[0]; \[IndentingNewLine]contentSliderFrame@
            add[labelsG2]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            textFieldsG2\ *) \[IndentingNewLine]textFieldsG2 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[zoomFac0], 
              10]; \[IndentingNewLine]contentSliderFrame@
            add[textFieldsG2]; \[IndentingNewLine]textFieldsG2@
            setEditable[False]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slidersG2\ *) \[IndentingNewLine]slidersG2 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              Round[100*\((zoomFac0 - zoomFacMin)\)/\((zoomFacMax - 
                        zoomFacMin)\)], 1, 0, 100]; \[IndentingNewLine] (*\ 
            create\ and\ attach\ the\ slider1\ event\ handler\ \
*) \[IndentingNewLine]slidersG2Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine]slidersG2Listener@
            setHandler["\<adjustmentValueChanged\>", 
              ToString[slidersG2Func]]; \[IndentingNewLine]slidersG2@
            addAdjustmentListener[
              slidersG2Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slidersG2]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider\ frame\ *) \[IndentingNewLine]sliderFrame@
            setBounds[sliderFrameX, sliderFrameY, sliderFrameXDim, 
              sliderFrameYDim]; \[IndentingNewLine]sliderFrame@
            setResizable[False]; \[IndentingNewLine]JavaShow[
            sliderFrame]; \
\[IndentingNewLine]sliderFrame\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["slidersG1Func", "Subsubsection"],

Cell["\<\
Scale agents speeds by speedFac.  If agent has zero velocity, but speedFac > \
0, set velocity to be in random driections at magnitude speedFac * v0.  \
\>", "Text"],

Cell[BoxData[{\(Clear[slidersG1Func];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["slidersG1Func",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, type_, scrollPos_\), 
          "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({agentData}\), ",", 
            "\[IndentingNewLine]", \( (*\ 
              scrollPos\ is\ int\ between\ 0\ and\ 90\ *) \), 
            "\[IndentingNewLine]", 
            
            RowBox[{\(speedFac = 
                N[speedFacMin + \((speedFacMax - speedFacMin)\)*
                      scrollPos/100]\), ";", 
              "\[IndentingNewLine]", \( (*\(Print["\<speedFac = \>", 
                    speedFac];\)*) \), "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                update\ running\ coordinates\ in\ data\ panel . \ 
                    check\ for\ existence\ of\ selected\ agent\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
                RowBox[{\(aSelected =!= Null\), ",", "\[IndentingNewLine]", 
                  RowBox[{
                    RowBox[{"agentData", "=", 
                      RowBox[{"First", "@", 
                        RowBox[{"Cases", "[", 
                          RowBox[{"agents", ",", 
                            RowBox[{
                              StyleBox["agent",
                                FontColor->RGBColor[0, 0, 1]], 
                              "[", \(aSelected\[LeftDoubleBracket]1\
\[RightDoubleBracket], ___\), "]"}]}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", \(textField1@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]1\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField2@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]2\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField3@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]3\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField4@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]4\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField5@
                      setText[
                        ToString[
                          agentData\[LeftDoubleBracket]5\[RightDoubleBracket]]\
]\), ";", "\[IndentingNewLine]", \(textField6@setText[ToString[speedFac]]\), 
                    ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(ReleaseObject[e]\), ";"}]}], 
          "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["slidersG2Func", "Subsubsection"],

Cell["zoom factor", "Text"],

Cell[BoxData[{\(Clear[slidersG2Func];\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["slidersG2Func",
            FontColor->RGBColor[0, 0, 1]], "[", \(e_, type_, scrollPos_\), 
          "]"}], ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            scrollPos\ is\ int\ between\ 0\ and\ 100\ \
*) \[IndentingNewLine]zoomFac = 
            N[zoomFacMin + \((zoomFacMax - zoomFacMin)\)*
                  scrollPos/
                    100]; \[IndentingNewLine] (*\(Print["\<zoomFac = \>", 
                zoomFac];\)*) \[IndentingNewLine]\[IndentingNewLine]\
ReleaseObject[e];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cannot do JSlider event handling to Mathe.", "Subsection",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["createSliderWindowTest", "Subsubsection"],

Cell[BoxData[{\(Clear[createSliderWindowTest];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["createSliderWindowTest",
            FontColor->RGBColor[0, 0, 1]], "[", \(sliderTitleS_String, 
          sliderFrameX_Integer, sliderFrameY_Integer, 
          sliderFrameXDim_Integer, sliderFrameYDim_Integer, 
          scrollValue0_Integer, scrollValueMin_Integer, 
          scrollValueMax_Integer\), "]"}], 
        ":=", \(Module[{}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            create\ slider\ frame\ *) \[IndentingNewLine]sliderFrame = 
            JavaNew["\<javax.swing.JFrame\>", 
              sliderTitleS]; \[IndentingNewLine] (*\ 
            set\ layout\ *) \[IndentingNewLine]contentSliderFrame = 
            sliderFrame@getContentPane[]; \[IndentingNewLine]sliderLayout = 
            JavaNew["\<java.awt.BorderLayout\>"]; \
\[IndentingNewLine]contentSliderFrame@
            setLayout[
              sliderLayout]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider2\ *) \[IndentingNewLine]slider2 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              scrollValue0, 1, scrollValueMin, 
              scrollValueMax]; \[IndentingNewLine] (*\(slider2 = 
                JavaNew["\<javax.swing.JSlider\>"];\)*) \[IndentingNewLine] \
(*\ create\ and\ attach\ the\ slider2\ event\ handler\ \
*) \[IndentingNewLine]slider2Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine]slider2Listener@
            setHandler["\<adjustmentValueChanged\>", "\<slider2Func\>"]; \
\[IndentingNewLine]slider2@
            addAdjustmentListener[
              slider2Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slider2]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            slider1\ *) \[IndentingNewLine]slider1 = 
            JavaNew["\<java.awt.Scrollbar\>", Scrollbar`HORIZONTAL, 
              scrollValue0, 1, scrollValueMin, 
              scrollValueMax]; \[IndentingNewLine] (*\(slider1 = 
                JavaNew["\<javax.swing.JSlider\>"];\)*) \[IndentingNewLine] \
(*\ create\ and\ attach\ the\ slider1\ event\ handler\ \
*) \[IndentingNewLine]slider1Listener = 
            JavaNew["\<com.wolfram.jlink.MathAdjustmentListener\>"]; \
\[IndentingNewLine]slider1Listener@
            setHandler["\<adjustmentValueChanged\>", "\<slider1Func\>"]; \
\[IndentingNewLine]slider1@
            addAdjustmentListener[
              slider1Listener]; \[IndentingNewLine]contentSliderFrame@
            add[slider1]; \[IndentingNewLine]\[IndentingNewLine] \
(*\[IndentingNewLine] (*\ slider1\ *) \[IndentingNewLine]fpsMIN\  = \ 
              0; \[IndentingNewLine]fpsMAX\  = \ 
              100; \[IndentingNewLine]fpsINIT\  = \ 
              50; \[IndentingNewLine]slider1 = 
              JavaNew["\<javax.swing.JSlider\>", fpsMIN, \ fpsMAX, \ 
                fpsINIT]; \[IndentingNewLine] (*\ 
              create\ and\ attach\ the\ slider1\ event\ handler\ \
*) \[IndentingNewLine]slider1Listener = 
              JavaNew["\<BasicSliderUI.ChangeHandler\>"]; \
\[IndentingNewLine]slider1@
              addChangeListener[
                slider1Listener]; \[IndentingNewLine]slider1Listener@
              setHandler["\<stateChanged\>", "\<slider1Func\>"]; \
\[IndentingNewLine] (*\ 
              Turn\ on\ labels\ at\ major\ tick\ \(\(marks\)\(.\)\)\ \
*) \[IndentingNewLine]slider1@
              setMajorTickSpacing[10]; \[IndentingNewLine]slider1@
              setMinorTickSpacing[1]; \[IndentingNewLine]slider1@
              setPaintTicks[True] (*\ 
              Java\ boolean\ is\ True\ or\ False\ *) ; \
\[IndentingNewLine]slider1@
              setPaintLabels[True]; \[IndentingNewLine]contentSliderFrame@
              add[slider1];\[IndentingNewLine]*) \[IndentingNewLine]\
\[IndentingNewLine] (*\ slider\ frame\ *) \[IndentingNewLine]sliderFrame@
            setBounds[sliderFrameX, sliderFrameY, sliderFrameXDim, 
              sliderFrameYDim]; \[IndentingNewLine]sliderFrame@
            setResizable[False]; \[IndentingNewLine]JavaShow[
            sliderFrame];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["displayProbeFrame", "Subsubsection"],

Cell[BoxData[{\(Clear[displayProbeFrame];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["displayProbeFrame",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{"a", ":", 
            RowBox[{
              StyleBox["agent",
                FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, vy_, 
              col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
              leat_\), "]"}]}], "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({probeFrameX, probeFrameY, probeFrameXDim, 
              probeFrameYDim}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ if\ probe\ frame\ exists, \ 
              update\ contents; \ else\ create\ frame\ *) \), 
            "\[IndentingNewLine]", 
            RowBox[{
              RowBox[{"If", "[", 
                
                RowBox[{\(JavaObjectQ[probeFrame]\), ",", 
                  "\[IndentingNewLine]", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                    
                    RowBox[{\(aSelected =!= Null\), ",", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        RowBox[{"agentData", "=", 
                          RowBox[{"First", "@", 
                            RowBox[{"Cases", "[", 
                              RowBox[{"agents", ",", 
                                RowBox[{
                                  StyleBox["agent",
                                    FontColor->RGBColor[0, 0, 1]], 
                                  "[", \(id, ___\), "]"}]}], "]"}]}]}], ";", 
                        "\[IndentingNewLine]", \(textField1@
                          setText[ToString[id]]\), ";", 
                        "\[IndentingNewLine]", \(textField2@
                          setText[ToString[x]]\), ";", 
                        "\[IndentingNewLine]", \(textField3@
                          setText[ToString[y]]\), ";", 
                        "\[IndentingNewLine]", \(textField4@
                          setText[ToString[vx]]\), ";", 
                        "\[IndentingNewLine]", \(textField5@
                          setText[ToString[vy]]\), ";", 
                        "\[IndentingNewLine]", \(textField6@
                          setText[ToString[speedFac]]\), ";"}]}], 
                    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                    StyleBox["createProbeFrame",
                      FontColor->RGBColor[0, 0, 1]], "[", "a", "]"}]}], 
                "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
          "]"}]}], ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["createProbeFrame", "Subsubsection"],

Cell[BoxData[{\(Clear[createProbeFrame];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["createProbeFrame",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{
            StyleBox["agent",
              FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, vy_, 
            col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
            leat_\), "]"}], "]"}], 
        ":=", \(Module[{probeFrameX, probeFrameY, probeFrameXDim, 
            probeFrameYDim}, \[IndentingNewLine]\[IndentingNewLine]probeFrame \
= JavaNew["\<javax.swing.JFrame\>", "\<Agent Probe\>"]; \
\[IndentingNewLine]{probeFrameX, probeFrameY, probeFrameXDim, 
              probeFrameYDim} = {703, 135, 80, 
              160}; \[IndentingNewLine]probeFrame@
            setBounds[probeFrameX, probeFrameY, probeFrameXDim, 
              probeFrameYDim]; \[IndentingNewLine]probeFrame@
            setResizable[
              False]; \[IndentingNewLine]\[IndentingNewLine]contentFrame = 
            probeFrame@getContentPane[]; \[IndentingNewLine]probeLayout = 
            JavaNew["\<java.awt.GridLayout\>", 0, 2] (*\ unlimited\ rows, \ 
            2\ \(\(cols\)\(.\)\)\ *) ; \[IndentingNewLine]contentFrame@
            setLayout[
              probeLayout]; \[IndentingNewLine]\[IndentingNewLine]label1 = 
            JavaNew["\<java.awt.Label\>", "\<Agent:\>"]; \
\[IndentingNewLine]label1@setAlignment[2]; \[IndentingNewLine]contentFrame@
            add[label1]; \[IndentingNewLine]textField1 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[id], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField1]; \[IndentingNewLine]textField1@
            setEditable[
              False]; \[IndentingNewLine]\[IndentingNewLine]label2 = 
            JavaNew["\<java.awt.Label\>", "\<x:\>"]; \
\[IndentingNewLine]label2@setAlignment[2] (*\ 2 = RIGHT, \ 0 = LEFT, \ 
            1 = CENTER\ *) ; \[IndentingNewLine]contentFrame@
            add[label2]; \[IndentingNewLine]textField2 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[x], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField2]; \[IndentingNewLine]\[IndentingNewLine]label3 = 
            
            JavaNew["\<java.awt.Label\>", "\<y:\>"]; \
\[IndentingNewLine]label3@setAlignment[2]; \[IndentingNewLine]contentFrame@
            add[label3]; \[IndentingNewLine]textField3 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[y], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField3]; \[IndentingNewLine]\[IndentingNewLine]label4 = 
            JavaNew["\<java.awt.Label\>", "\<vx:\>"]; \
\[IndentingNewLine]label4@setAlignment[2]; \[IndentingNewLine]contentFrame@
            add[label4]; \[IndentingNewLine]textField4 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[vx], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField4]; \[IndentingNewLine]\[IndentingNewLine]label5 = 
            JavaNew["\<java.awt.Label\>", "\<vy:\>"]; \
\[IndentingNewLine]label5@setAlignment[2]; \[IndentingNewLine]contentFrame@
            add[label5]; \[IndentingNewLine]textField5 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[vy], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField5]; \[IndentingNewLine]\[IndentingNewLine]label6 = 
            JavaNew["\<java.awt.Label\>", "\<speed:\>"]; \
\[IndentingNewLine]label6@setAlignment[2]; \[IndentingNewLine]contentFrame@
            add[label6]; \[IndentingNewLine]textField6 = 
            JavaNew["\<javax.swing.JTextField\>", ToString[speedFac], 
              10]; \[IndentingNewLine]contentFrame@
            add[textField6]; \[IndentingNewLine]\[IndentingNewLine]JavaShow[
            probeFrame];\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Agent Rules", "Section"],

Cell[CellGroupData[{

Cell["agentRules", "Subsubsection"],

Cell["Compute new position and velocity of agent based on physics.", "Text"],

Cell[BoxData[{\(Clear[agentRules];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["agentRules",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{
            StyleBox["agent",
              FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, vy_, 
            col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
            leat_\), "]"}], "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({speedBnd, xx, yy, wx, wy}\), ",", "\[IndentingNewLine]", 
            
            
            RowBox[{\(speedBnd = If[fil, speedBndClick, speedBndInit]\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                compute\ new\ velocity\ and\ position\ *) \), 
              "\[IndentingNewLine]", \({wx, wy} = 
                If[motion0 === 
                    straightLine, \[IndentingNewLine]If[\((speed = \@\(vx\^2 \
+ vy\^2\))\) < zero, {speedFac\ v0\ \((cosT = Random[Real, {0, 1}])\), 
                      speedFac\ v0\ \((1 - 
                            cosT)\)}, {\(speedFac\ v0\ vx\)\/speed, \
\(speedFac\ v0\ vy\)\/speed}], \[IndentingNewLine]speedFac*{Random[
                        Integer, {\(-speedBnd\), speedBnd}], 
                      Random[Integer, {\(-speedBnd\), 
                          speedBnd}]}\[IndentingNewLine]]\), ";", 
              "\[IndentingNewLine]", \({xx, yy} = {x, y} + {wx, wy}\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ address\ out - of - bounds\ *) \),
               "\[IndentingNewLine]", \(If[xx < 0, xx = \(-xx\); 
                wx = \(-wx\)]\), ";", 
              "\[IndentingNewLine]", \(If[yy < 0, yy = \(-yy\); 
                wy = \(-wy\)]\), ";", 
              "\[IndentingNewLine]", \(If[xx > panelFrameSizeX, 
                xx = panelFrameSizeX - \((xx - panelFrameSizeX)\); 
                wx = \(-wx\)]\), ";", 
              "\[IndentingNewLine]", \(If[yy > panelFrameSizeY, 
                yy = panelFrameSizeY - \((yy - panelFrameSizeY)\); 
                wy = \(-wy\)]\), ";", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["agent",
                  FontColor->RGBColor[0, 0, 1]], "[", \(id, xx, yy, wx, wy, 
                col, sz, fil, v0, sel, nColl, target, orient, leat\), 
                "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["agentRulesBoid", "Subsubsection"],

Cell[BoxData[
    \(\(Clear[agentRulesBoid];\)\)], "Input - Initialization Cell"],

Cell[TextData[{
  StyleBox["Prey Behavioral Rules",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Rule 1 (Cohesion): ",
  "Move toward exclusive center of mass of prey neighbors.\nRule 2 \
(Separation): Maintain separation from other prey neighbors.\nRule 3 \
(Alignment): Move toward average velocity of prey neighbors.\nRule 5 \
(Territory): Prey stays within territory.\nRule 6 (Avoidance) Prey move away \
from predators in neighborhood."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["agentRulesBoid",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{"a", ":", 
            RowBox[{
              StyleBox["agent",
                FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, vy_, 
              col_, sz_, fil_, v0_, sel_, nColl_, 0, target_, orient_, 
              leat_\), "]"}]}], "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({neighborhoodSzPrey, neighborsXPrey, neighborsXPreyLocs, 
              cmXPrey, neighborhoodSzPred, neighborsPred, v1, c, v2, v3, 
              velocityNeighborsX, rule4Param, v4, v5, v6x, v6y, v6, newVel, 
              wx, wy, xx, yy}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \( (*\ prey\ parameters\ *) \), 
            "\[IndentingNewLine]", 
            
            RowBox[{\(neighborhoodSzPrey = 100\), ";", "\[IndentingNewLine]", 
              
              RowBox[{"neighborsXPrey", "=", 
                RowBox[{"DeleteCases", "[", 
                  RowBox[{
                    RowBox[{
                      StyleBox["computeNearAgents",
                        FontColor->RGBColor[0, 0, 1]], "[", 
                      RowBox[{"a", ",", 
                        RowBox[{"Cases", "[", 
                          RowBox[{"agents", ",", 
                            RowBox[{
                              StyleBox["agent",
                                FontColor->RGBColor[0, 0, 1]], "[", \(___, 
                              0, _, _, _\), "]"}]}], "]"}], ",", 
                        "neighborhoodSzPrey"}], "]"}], ",", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(id, ___\), 
                      "]"}]}], "]"}]}], \( (*\ prey\ in\ nghbrhd\ *) \), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"neighborsXPreyLocs", "=", 
                RowBox[{"Cases", "[", 
                  RowBox[{"neighborsXPrey", ",", 
                    RowBox[{
                      RowBox[{
                        StyleBox["agent",
                          FontColor->RGBColor[0, 0, 1]], "[", \(_, x1_, 
                        y1_, ___, 0, _, _, _\), "]"}], 
                      "\[RuleDelayed]", \({x1, y1}\)}]}], "]"}]}], \( (*\ 
                exclusive\ prey\ loc\ list\ *) \), ";", 
              "\[IndentingNewLine]", \(cmXPrey = 
                If[neighborsXPreyLocs === {}, {0, 0}, 
                  Mean[neighborsXPreyLocs] - {x, y}]\), \( (*\ 
                prey\ XCM\ *) \), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ predator\ parameters\ *) \), 
              "\[IndentingNewLine]", \(neighborhoodSzPred = 150\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"neighborsPred", "=", 
                RowBox[{
                  StyleBox["computeNearAgents",
                    FontColor->RGBColor[0, 0, 1]], "[", 
                  RowBox[{"a", ",", 
                    RowBox[{"Cases", "[", 
                      RowBox[{"agents", ",", 
                        RowBox[{
                          StyleBox["agent",
                            FontColor->RGBColor[0, 0, 1]], "[", \(___, 
                          1, _, _, _\), "]"}]}], "]"}], ",", 
                    "neighborhoodSzPred"}], "]"}]}], \( (*\ 
                pred\ in\ nghbrhd\ *) \), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 1 : \ 
                  COHESION\ Move\ rule1Param\ %\ way\ toward\ \
\(\(XCM\)\(.\)\)\ *) \), "\[IndentingNewLine]", \(v1 = cmXPrey*rule1Param\), 
              ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 2 : \ SEPARATION\ If\ within\ neighborhood, \ 
                move\ rule2Param\ as\ far\ away\ again\ as\ already\ \(\(is\)\
\(.\)\)\ *) \), "\[IndentingNewLine]", \(c = {0, 0}\), ";", 
              "\[IndentingNewLine]", \(v2 = 
                If[neighborsXPrey === {}, {0, 0}, \[IndentingNewLine]Do[
                    c = c - \(({\(neighborsXPrey\[LeftDoubleBracket]j\
\[RightDoubleBracket]\)\[LeftDoubleBracket]2\[RightDoubleBracket], \
\(neighborsXPrey\[LeftDoubleBracket]j\[RightDoubleBracket]\)\
\[LeftDoubleBracket]3\[RightDoubleBracket]} - {x, y})\), {j, 
                      Length[neighborsXPrey]}]; \[IndentingNewLine]rule2Param*
                    c]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 3 : \ 
                  ALIGNMENT\ Add\ perceived\ average\ velocity\ \(\(component\
\)\(.\)\)\ *) \), 
              "\[IndentingNewLine]", \( (*\ 
                perceived\ velocity\ of\ prey\ neighborsXPrey\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"v3", "=", 
                RowBox[{"If", "[", 
                  RowBox[{\(neighborsXPrey === {}\), ",", \({0, 0}\), ",", 
                    RowBox[{
                      RowBox[{"velocityNeighborsX", "=", 
                        RowBox[{"Mean", "[", 
                          RowBox[{"neighborsXPrey", "/.", 
                            RowBox[{
                              RowBox[{
                                StyleBox["agent",
                                  FontColor->RGBColor[0, 0, 1]], 
                                "[", \(_, _, _, vx1_, vy1_, ___\), "]"}], 
                              "\[RuleDelayed]", \({vx1, vy1}\)}]}], "]"}]}], 
                      ";", "\[IndentingNewLine]", \(velocityNeighborsX*
                        rule3Param\)}]}], "]"}]}], ";", "\[IndentingNewLine]",
               "\[IndentingNewLine]", \( (*\ 
                RULE\ 5 : \ 
                  AVOIDANCE\ Move\ away\ from\ \(\(predators\)\(.\)\)\ *) \), 
              "\[IndentingNewLine]", \( (*\(v5 = 
                    If[neighborsPred === {}, {0, 
                        0}, \(rule5Param\ Plus @@ \(\(({x, y} - {#1\
\[LeftDoubleBracket]2\[RightDoubleBracket], #1\[LeftDoubleBracket]3\
\[RightDoubleBracket]} &)\) /@ neighborsPred\)\)\/Length[neighborsPred]];\)\
*) \), "\[IndentingNewLine]", \(v5 = {0, 0}\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 6 : \ CONTAINMENT\ Move\ toward\ in - bounds\ *) \), 
              "\[IndentingNewLine]", \({v6x, v6y} = {0, 0}\), ";", 
              "\[IndentingNewLine]", \(If[x < obLim, 
                v6x = rule6Param*0.50*\((panelFrameSizeX/2 - x)\) + \((1 - 
                          rule6Param)\)*vx]\), ";", 
              "\[IndentingNewLine]", \(If[y < obLim, 
                v6y = rule6Param*0.50*\((panelFrameSizeY/2 - y)\) + \((1 - 
                          rule6Param)\)*vy]\), ";", 
              "\[IndentingNewLine]", \(If[x > panelFrameSizeX - obLim, 
                v6x = rule6Param*0.50*\((panelFrameSizeX/2 - x)\) + \((1 - 
                          rule6Param)\)*vx]\), ";", 
              "\[IndentingNewLine]", \(If[y > panelFrameSizeY - obLim, 
                v6y = rule6Param*0.50*\((panelFrameSizeY/2 - y)\) + \((1 - 
                          rule6Param)\)*vy]\), ";", 
              "\[IndentingNewLine]", \(v6 = {v6x, v6y}\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                compute\ new\ velocity\ and\ position\ *) \), 
              "\[IndentingNewLine]", \(newVel = v1 + v2 + v3 + v5 + v6\), ";",
               "\[IndentingNewLine]", \( (*\(If[id === "\<#10\>", 
                    Print["\<{tNow,id,x,y,v1,v2,v3,v5,v6} = \>", {tNow, id, 
                        x, y, v1, v2, v3, v5, v6}]];\)*) \), 
              "\[IndentingNewLine]", \({wx, wy} = 
                If[Norm[newVel] > v0*speedFac, 
                  v0*speedFac*newVel/Norm[newVel], newVel]\), \( (*\ 
                new\ velocity\ *) \), ";", 
              "\[IndentingNewLine]", \({xx, yy} = {x, y} + {wx, wy}\), \( (*\ 
                new\ position\ *) \), ";", 
              "\[IndentingNewLine]", \(newOrient = 
                Which[wx > 0 && wy > 0, ArcCot[wy\/wx], wx > 0 && wy < 0, 
                  ArcCot[wy\/wx] + \[Pi], wx < 0 && wy > 0, ArcCot[wy\/wx], 
                  wx < 0 && wy < 0, ArcCot[wy\/wx] + \[Pi], 
                  True, \[Omega] = v0; 
                  orient - \(2\ \[Pi]\ tNow\)\/\[Omega]]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["agent",
                  FontColor->RGBColor[0, 0, 1]], "[", \(id, xx, yy, wx, wy, 
                col, sz, fil, v0, sel, nColl, 0, target, newOrient, leat\), 
                "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]], "Input - Initialization Cell"],

Cell[TextData[{
  StyleBox["Predator Behavioral Rules",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "OFF Rule 1 (Cohesion): ",
  "Move toward exclusive center of mass of predator neighbors.\n",
  "Rule 2 (Pursuit): ",
  "Move toward center of mass of all prey.\nRule 3 (Separation): Maintain \
separation from other predator neighbors.\nRule 6 (Territory): Prey stays \
within territory."
}], "Text"],

Cell["\<\
Valid values for target:
\tTargetNone\t\tno target. Predator goes to default location
\tagent[...]\t\tPredator is locked on a particular prey agent\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["agentRulesBoid",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{"a", ":", 
            RowBox[{
              StyleBox["agent",
                FontColor->RGBColor[0, 0, 1]], "[", \(idX_, x_, y_, vx_, vy_, 
              col_, sz_, fil_, v0_, sel_, nColl_, 1, target_, orient_, 
              leat_\), "]"}]}], "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({\[Alpha], ty, neighborhoodSzPred, neighborsXPred, 
              ptsPredator, allPreyL, focusPreyL, tmp1, focusD, tmp2, 
              lockPreyL, newTarget, newTargetLoc, v1, rule2Param, v2, c, v3, 
              v6x, v6y, v6, wx, wy, xx, yy}\), ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(ty = 1\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ predator\ parameters\ *) \), 
              "\[IndentingNewLine]", 
              RowBox[{"neighborsXPred", "=", 
                RowBox[{"DeleteCases", "[", 
                  RowBox[{
                    RowBox[{
                      StyleBox["computeNearAgents",
                        FontColor->RGBColor[0, 0, 1]], "[", 
                      RowBox[{"a", ",", 
                        RowBox[{"Cases", "[", 
                          RowBox[{"agents", ",", 
                            RowBox[{
                              StyleBox["agent",
                                FontColor->RGBColor[0, 0, 1]], "[", \(___, 
                              1, _, _, _\), "]"}]}], "]"}], 
                        ",", \(neighborhoodSzPred = 50\)}], "]"}], ",", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(idX, ___\), 
                      "]"}]}], "]"}]}], \( (*\ pred\ in\ X - nghbrhd\ *) \), 
              ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ determine\ prey\ in\ focus\ *) \),
               "\[IndentingNewLine]", 
              RowBox[{"allPreyL", "=", 
                RowBox[{"Cases", "[", 
                  RowBox[{"agents", ",", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(_, x1_, 
                      y1_, ___, 0, _, _, _\), "]"}]}], "]"}]}], \( (*\ 
                all\ prey\ list\ *) \), \( (*\ 
                predator\ prey\ target\ selection\ *) \), ";", 
              "\[IndentingNewLine]", \(ptsPredator = \[IndentingNewLine]\({x, 
                        y} + Rotate2D[#1, 
                        orient] &\) /@ {{0, \(-0.67\)\ sz}, {0.25\ sz, 
                      0.33\ sz}, {\(-0.25\)\ sz, 0.33\ sz}}\), \( (*\ 
                get\ points\ defining\ predator\ shape\ *) \), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\(Show[
                    Graphics[{{Red, Polygon[ptsPredator]}, {PointSize[0.05], 
                          RGBColor[0, 0, 1], 
                          Point[{xP, yP}]}, {PointSize[0.05], 
                          RGBColor[1, 1, 0], Point[{xc, yc}]}}, 
                      ImageSize \[Rule] 100, 
                      AspectRatio \[Rule] Automatic]];\)*) \), 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{"focusPreyL", "=", 
                RowBox[{"Select", "[", 
                  RowBox[{"allPreyL", ",", 
                    RowBox[{
                      RowBox[{
                        StyleBox["predatorFocus",
                          FontColor->RGBColor[0, 0, 1]], 
                        "[", \({#1\[LeftDoubleBracket]2\[RightDoubleBracket], \
#1\[LeftDoubleBracket]3\[RightDoubleBracket]}, ptsPredator, 
                        predatorChase \[Rule] halfplane\), \( (*\ 
                          all\ flashlight\ halfplane\ *) \), "]"}], "&"}]}], 
                  "]"}]}], \( (*\ locations\ of\ all\ prey\ in\ focus\ *) \), 
              ";", "\n", "\[IndentingNewLine]", 
              RowBox[{"newTargetLoc", "=", 
                RowBox[{"If", "[", 
                  
                  RowBox[{\(focusPreyL === {}\), ",", 
                    "\[IndentingNewLine]", \(newTarget = TargetNone; {0, 0}\),
                     ",", "\[IndentingNewLine]", 
                    
                    RowBox[{\(tt1 = \(({\@\(\((#1\[LeftDoubleBracket]2\
\[RightDoubleBracket] - x)\)\^2 + \((#1\[LeftDoubleBracket]3\
\[RightDoubleBracket] - y)\)\^2\), #1} &)\) /@ focusPreyL\), ";", 
                      "\[IndentingNewLine]", \(closestPrey = 
                        First[Cases[
                            tt1, {Min[
                                  tt1\[LeftDoubleBracket]All, 
                                    1\[RightDoubleBracket]], 
                                agentPrey_} \[RuleDelayed] agentPrey]]\), 
                      ";", \( (*\(Print["\<closestPrey = \>", 
                            closestPrey];\)*) \), "\[IndentingNewLine]", 
                      "\[IndentingNewLine]", 
                      RowBox[{"atts", "=", 
                        RowBox[{
                          StyleBox["getAgentAtts",
                            FontColor->RGBColor[0, 0, 1]], 
                          "[", \(closestPrey\[LeftDoubleBracket]1\
\[RightDoubleBracket]\), "]"}]}], 
                      ";", \(newTarget = 
                        atts\[LeftDoubleBracket]1\[RightDoubleBracket]\), 
                      ";", \(atts\[LeftDoubleBracket]{2, 
                          3}\[RightDoubleBracket]\)}]}], 
                  "\[IndentingNewLine]", "]"}]}], \( (*\ 
                new\ target\ is\ closest\ prey\ in\ focus\ *) \), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\(Print["\<tNow, idX, \
Length[focusPreyL], newTargetLoc, closestPrey = \>", {tNow, \ idX, \ 
                      Length[focusPreyL], \ newTargetLoc, \ 
                      closestPrey\[LeftDoubleBracket]1\[RightDoubleBracket]}];\
\)*) \), "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ PREDATOR\ BEHAVIOR\ RULES\ *) \), 
              "\[IndentingNewLine]", \(v1 = {0, 0}\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 2 : \ 
                  PURSUIT\ Move\ rule2Param\ %\ way\ toward\ prey\ CM, \ 
                fuzzy\ \(\(movement\)\(.\)\)\ *) \), 
              "\[IndentingNewLine]", \(rule2Param = 
                Random[Real, {0.1, 0.3}]\), ";", 
              "\[IndentingNewLine]", \(rule2Param = 0.23\), ";", 
              "\[IndentingNewLine]", \(v2 = 
                rule2Param*\((newTargetLoc - {x, y})\)\), ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                RULE\ 3 : \ SEPARATION\ If\ within\ neighborhood, \ 
                move\ rule3Param\ as\ far\ away\ again\ as\ already\ \(\(is\)\
\(.\)\)\ *) \), "\[IndentingNewLine]", \(rule3Param = 0.5\), ";", 
              "\[IndentingNewLine]", \(v3 = \(c = {0, 0}\)\), ";", 
              "\[IndentingNewLine]", \(v3 = 
                If[neighborsXPred === {}, {0, 0}, \[IndentingNewLine]Do[
                    c = 
                      c - \(({\(neighborsXPred\[LeftDoubleBracket]
                                  j\[RightDoubleBracket]\)\[LeftDoubleBracket]\
2\[RightDoubleBracket], \(neighborsXPred\[LeftDoubleBracket]
                                  j\[RightDoubleBracket]\)\[LeftDoubleBracket]\
3\[RightDoubleBracket]} - {x, y})\), {j, 
                      Length[neighborsXPred]}]; \[IndentingNewLine]c*
                    rule3Param]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \( (*\ 
                compute\ new\ velocity\ and\ position\ *) \), 
              "\[IndentingNewLine]", \({wx, wy} = 
                speedFac*\((v1 + v2 + v3)\)\), \( (*\ new\ velocity\ *) \), 
              ";", "\[IndentingNewLine]", \({xx, 
                  yy} = {x, y} + {wx, wy}\), \( (*\ new\ position\ *) \), ";",
               "\[IndentingNewLine]", \(newOrient = 
                Which[wx > 0 && wy > 0, ArcCot[wy\/wx] + \[Pi], 
                  wx > 0 && wy < 0, ArcCot[wy\/wx], wx < 0 && wy > 0, 
                  ArcCot[wy\/wx] + \[Pi], wx < 0 && wy < 0, ArcCot[wy\/wx], 
                  True, \[Omega] = 20; 
                  orient - \(2\ \[Pi]\ tNow\)\/\[Omega]]\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["agent",
                  FontColor->RGBColor[0, 0, 1]], "[", \(idX, xx, yy, wx, wy, 
                col, sz, fil, v0, sel, nColl, 1, newTarget, newOrient, leat\),
                 "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
      ";"}]], "Input - Initialization Cell",
  CellTags->"predator rules"],

Cell["Default: ", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["agentRulesBoid",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{
            StyleBox["agent",
              FontColor->RGBColor[0, 0, 1]], "[", \(idX_, x_, y_, vx_, vy_, 
            col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
            leat_\), "]"}], "]"}], ":=", 
        RowBox[{
          StyleBox["agent",
            FontColor->RGBColor[0, 0, 1]], "[", \(idX, x, y, vx, vy, col, sz, 
          fil, v0, sel, nColl, ty, target, orient, leat\), "]"}]}], 
      ";"}]], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["predatorFocus", "Subsubsection"],

Cell[BoxData[{\(Clear[
        predatorFocus];\), "\[IndentingNewLine]", \(Options[
          predatorFocus] = {predatorChase \[Rule] all};\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["predatorFocus",
            FontColor->RGBColor[0, 0, 1]], "[", \({xP_, yP_}, refPtsL_List, 
          opts___?OptionQ\), "]"}], 
        ":=", \(Module[{fitcheckssL, inequalConstraints, 
            predatorChase0}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            assumes\ predator\ is\ defined\ by\ 3\ points\ \((triangle)\)\ \
and\ the\ front\ in\ the\ flat\ part\ defined\ by\ the\ second\ and\ third\ \
points . \ 
                the\ first\ point\ is\ the\ \(\(tail\)\(.\)\)\ \
*) \[IndentingNewLine]\[IndentingNewLine]{predatorChase0} = \({predatorChase} \
/. {opts}\) /. 
              Options[predatorFocus]; \[IndentingNewLine]\[IndentingNewLine] \
(*\ \(constraints\ test\ if\ point\ in\ front\ half - 
                  plane\ define\ by\ pts\ 2\  &\)\ 3\ \
*) \[IndentingNewLine]inequalConstraints = 
            Switch[predatorChase0, \
\[IndentingNewLine]\[IndentingNewLine]halfplane, \[IndentingNewLine] (*\ \
\(constraints\ test\ if\ point\ in\ front\ half - 
                      plane\ define\ by\ pts\ 2\  &\)\ 3\ \
*) \[IndentingNewLine]{y999 \[GreaterEqual] \(-\(\(\((\(-y1\) + 
                                  y2)\)\ x999\)\/\(x1 - 
                              x2\)\)\) - \(x2\ y1 - x1\ y2\)\/\(x1 - x2\) \
/. \[InvisibleSpace]{x1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 1\[RightDoubleBracket], 
                    y1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 2\[RightDoubleBracket], 
                    x2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 1\[RightDoubleBracket], 
                    y2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 
                        2\[RightDoubleBracket]}}, \[IndentingNewLine]\
\[IndentingNewLine]flashlight, \[IndentingNewLine] (*\ 
                constraints\ test\ if\ point\ in\ frontal\ cone\ define\ by\ \
3\ constraints\ *) \[IndentingNewLine]{ (*\ side\ 1\ and\ 2\ *) 
                  y999 \[GreaterEqual] \(-\(\(\((\(-y1\) + 
                                  y2)\)\ x999\)\/\(x1 - 
                              x2\)\)\) - \(x2\ y1 - x1\ y2\)\/\(x1 - x2\) \
/. \[InvisibleSpace]{x1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
                    y1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]1, 2\[RightDoubleBracket], 
                    x2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 1\[RightDoubleBracket], 
                    y2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 
                        2\[RightDoubleBracket]}, \[IndentingNewLine] (*\ 
                  side\ 1\ and\ 3\ *) 
                  y999 \[LessEqual] \(-\(\(\((\(-y1\) + y2)\)\ x999\)\/\(x1 - 
                              x2\)\)\) - \(x2\ y1 - x1\ y2\)\/\(x1 - x2\) \
/. \[InvisibleSpace]{x1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
                    y1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]1, 2\[RightDoubleBracket], 
                    x2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 1\[RightDoubleBracket], 
                    y2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 
                        2\[RightDoubleBracket]}, \[IndentingNewLine] (*\ 
                  side\ 2\ and\ 3\ is\ front\ *) 
                  y999 \[GreaterEqual] \(-\(\(\((\(-y1\) + 
                                  y2)\)\ x999\)\/\(x1 - 
                              x2\)\)\) - \(x2\ y1 - x1\ y2\)\/\(x1 - x2\) \
/. \[InvisibleSpace]{x1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 1\[RightDoubleBracket], 
                    y1 \[Rule] 
                      refPtsL\[LeftDoubleBracket]2, 2\[RightDoubleBracket], 
                    x2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 1\[RightDoubleBracket], 
                    y2 \[Rule] 
                      refPtsL\[LeftDoubleBracket]3, 
                        2\[RightDoubleBracket]}}, \[IndentingNewLine]_, \
{True}\[IndentingNewLine]]; \[IndentingNewLine]checks = 
            inequalConstraints /. \[InvisibleSpace]{x999 \[Rule] xP, 
                y999 \[Rule] yP}; \[IndentingNewLine]If[\(Union[
                checks]\)\[LeftDoubleBracket]1\[RightDoubleBracket], True, 
            False]\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["lookForTarget", "Subsubsection"],

Cell[BoxData[{\(Clear[lookForTarget];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["lookForTarget",
            FontColor->RGBColor[0, 0, 1]], "[", \(x_, y_, focusPreyL_, 
          focusD_\), "]"}], 
        ":=", \(Module[{tmp1, 
            tmp2}, \[IndentingNewLine]tmp1 = \
\(({\@\(\((#1\[LeftDoubleBracket]2\[RightDoubleBracket] - x)\)\^2 + \((#1\
\[LeftDoubleBracket]3\[RightDoubleBracket] - y)\)\^2\), #1} &)\) /@ 
              focusPreyL; \[IndentingNewLine]tmp2 = 
            Cases[tmp1, {d_, aa_agent} /; d < focusD \[RuleDelayed] {d, 
                  aa}]; \[IndentingNewLine]lockPreyL = 
            Cases[tmp2, {Min[
                    tmp1\[LeftDoubleBracket]All, 1\[RightDoubleBracket]], 
                  agent[id_, r___]} \[RuleDelayed] agent[id, r]] (*\ 
            list\ of\ all\ closest\ prey\ locked\ on\ *) ; \
\[IndentingNewLine]If[lockPreyL === {}, TargetNone, 
            First@lockPreyL]\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " model functions"
}], "Section"],

Cell[CellGroupData[{

Cell["getAgent", "Subsubsection"],

Cell["Get agent id# from agents list.  ", "Text"],

Cell[BoxData[{\(Clear[getAgent];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["getAgent",
            FontColor->RGBColor[0, 0, 1]], "[", "id_String", "]"}], 
        ":=", \(Module[{agL}, \[IndentingNewLine]agL = 
            Cases[agents, agent[id, ___]]; \[IndentingNewLine]If[agL === {}, 
            Print["\<Error: Cannot find agent \>", 
              id, "\< in agent list.\>"]; {}, 
            First@agL]\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"],

Cell["Test", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["getAgent",
        FontColor->RGBColor[0, 0, 1]], "[", "\"\<#1\>\"", "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["getAgentAtts", "Subsubsection"],

Cell["Get attributes for agent id# from agents list.  ", "Text"],

Cell[BoxData[{\(Clear[getAgentAtts];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["getAgentAtts",
            FontColor->RGBColor[0, 0, 1]], "[", "id_String", "]"}], 
        ":=", \(Module[{attsL}, \[IndentingNewLine]attsL = 
            Cases[agents, 
              agent[id, atts___] \[RuleDelayed] {id, 
                  atts}]; \[IndentingNewLine]If[attsL === {}, 
            Print["\<Error: Cannot find agent \>", 
              id, "\< in agent list.\>"]; {}, 
            First@attsL]\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"],

Cell["Test", "Text"],

Cell[BoxData[{
    RowBox[{
      StyleBox["getAgentAtts",
        FontColor->RGBColor[0, 0, 1]], "[", "\"\<#1\>\"", 
      "]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["getAgentAtts",
          FontColor->RGBColor[0, 0, 1]], "[", "\"\<#1\>\"", "]"}], 
      "\[LeftDoubleBracket]", \({2, 3}\), "\[RightDoubleBracket]"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["newAgent", "Subsubsection"],

Cell["Constructor for agent.", "Text"],

Cell[BoxData[{\(Clear[newAgent];\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["newAgent",
            FontColor->RGBColor[0, 0, 1]], "[", \(id_, x_, y_, vx_, vy_, 
          col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, leat_\), 
          "]"}], ":=", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"agents", "=", 
              RowBox[{"Join", "[", 
                RowBox[{"agents", ",", 
                  RowBox[{"{", 
                    RowBox[{
                      StyleBox["agent",
                        FontColor->RGBColor[0, 0, 1]], "[", \(id, x, y, vx, 
                      vy, col, sz, fil, v0, sel, nColl, ty, target, orient, 
                      leat\), "]"}], "}"}]}], "]"}]}], ";"}], ")"}]}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["drawAgent", "Subsubsection"],

Cell[BoxData[
    \(\(Clear[drawAgent];\)\)], "Input - Initialization Cell"],

Cell["Draw agent as circle.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["drawAgent",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{"g_", ",", 
            RowBox[{
              StyleBox["agent",
                FontColor->RGBColor[0, 0, 1]], "[", \(id_, xc_, yc_, vx_, 
              vy_, col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
              leat_\), "]"}], ",", "oval"}], "]"}], 
        ":=", \(Module[{}, \[IndentingNewLine] (*\ 
            draw\ yellow\ circle\ behind\ agent\ *) \[IndentingNewLine]g[
            setColor[Color`YELLOW]]; \[IndentingNewLine]g[
            fillOval[
              Round[panelFrameSizeX\/2 + 
                  zoomFac\ \((xc - panelFrameSizeX\/2)\)], 
              Round[panelFrameSizeY\/2 + 
                  zoomFac\ \((yc - panelFrameSizeY\/2)\)], sz, 
              sz]]\[IndentingNewLine]]\)}], 
      ";"}]], "Input - Initialization Cell"],

Cell["Draw agent as chevron.", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["drawAgent",
            FontColor->RGBColor[0, 0, 1]], "[", 
          RowBox[{"g_", ",", 
            RowBox[{
              StyleBox["agent",
                FontColor->RGBColor[0, 0, 1]], "[", \(id_, xc_, yc_, vx_, 
              vy_, col_, sz_, fil_, v0_, sel_, nColl_, ty_, target_, orient_, 
              leat_\), "]"}]}], "]"}], 
        ":=", \(Module[{gPts}, \[IndentingNewLine] (*\ set\ color, \ 
            BLACK\ if\ agent\ selected\ *) \[IndentingNewLine]If[
            sel, \[IndentingNewLine]g[
              setColor[Color`BLACK]], \[IndentingNewLine]g[
              setColor[
                col]]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine] (*\ 
            get\ points\ defining\ shape\ *) \[IndentingNewLine]gPts = 
            Transpose[\({xc, yc} + Rotate2D[#1, orient] &\) /@ {{0, 
                    0.67\ sz}, {0.25\ sz, \(-0.33\)\ sz}, {\(-0.25\)\ sz, \
\(-0.33\)\ sz}}] (*If[
              ty == 0,  (*\ 
                prey\ *) {{0, 
                  0.67\ sz}, {0.25\ sz, \(-0.33\)\ sz}, {\(-0.25\)\ sz, \
\(-0.33\)\ sz}},  (*\ 
                predator\ *) {{0, \(-0.67\)\ sz}, {0.25\ sz, 
                  0.33\ sz}, {\(-0.25\)\ sz, 
                  0.33\ sz}}]*) ; \[IndentingNewLine]\[IndentingNewLine] \
(*\(Show[Graphics[{{Green, Polygon[pts]}, {Red, 
                      Polygon[\((center + #1 &)\) /@ pts]}, {Blue, 
                      Polygon[\({xc, yc} + Rotate2D[#1, orient] &\) /@ 
                          pts]}}, ImageSize \[Rule] 100, 
                  AspectRatio \[Rule] 
                    Automatic]];\)*) \[IndentingNewLine]\[IndentingNewLine] \
(*\ draw\ chevrons\ *) \[IndentingNewLine]If[
            fil || sel, \[IndentingNewLine]g@
              fillPolygon[
                Round[panelFrameSizeX\/2 + 
                    zoomFac\ \
\((gPts\[LeftDoubleBracket]1\[RightDoubleBracket] - panelFrameSizeX\/2)\)], 
                Round[panelFrameSizeY\/2 + 
                    zoomFac\ \
\((gPts\[LeftDoubleBracket]2\[RightDoubleBracket] - panelFrameSizeY\/2)\)], 
                Length@\(First@gPts\)] (*\ 
              fill\ *) , \[IndentingNewLine]\[IndentingNewLine]g@
              drawPolygon[
                Round[panelFrameSizeX\/2 + 
                    zoomFac\ \
\((gPts\[LeftDoubleBracket]1\[RightDoubleBracket] - panelFrameSizeX\/2)\)], 
                Round[panelFrameSizeY\/2 + 
                    
                    zoomFac\ \
\((gPts\[LeftDoubleBracket]2\[RightDoubleBracket] - panelFrameSizeY\/2)\)], 
                Length@\(First@gPts\)] (*\ 
              boundary\ only\ \
*) \[IndentingNewLine]];\[IndentingNewLine]]\)}], 
      ";"}]], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["ptOppSide", "Subsubsection"],

Cell[BoxData[{\(Clear[ptOppSide]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["ptOppSide",
            FontColor->RGBColor[0, 0, 1]], "[", \({xc_, yc_}, {xt_, yt_}, 
          rel_\), "]"}], 
        ":=", \(Not[\((yc \[GreaterEqual] \((rel /. \[InvisibleSpace]x999 \
\[Rule] xc)\))\) === \((yt \[GreaterEqual] \((rel /. \[InvisibleSpace]x999 \
\[Rule] xt)\))\)]\)}], ";"}]}], "Input - Initialization Cell"],

Cell["Test", "Text"],

Cell[BoxData[{\(p = {{384, 193}, {388, 150}, {367, 153}}\), "\n", 
    RowBox[{\(pp = Partition[p, 2, 1, 1]\), 
      "\[IndentingNewLine]"}], "\n", \({xc, yc} = {379.7792229569352`, 
        164.9026798779218`}\), "\n", \({xt, yt} = {xc, yc}\), "\n", 
    RowBox[{\({xt, yt} = {0, 0}\), 
      "\[IndentingNewLine]"}], "\n", \(ff = \((Fit[#1, {1, x999}, x999] &)\) /@ 
        pp\), "\n", 
    RowBox[{
      RowBox[{
        StyleBox["ptOppSide",
          FontColor->RGBColor[0, 0, 1]], "[", \({xc, yc}, {xt, yt}, 
        ff\[LeftDoubleBracket]2\[RightDoubleBracket]\), "]"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Show[
        Graphics[{{Yellow, Polygon[p]}, {Black, PointSize[0.05], 
              Point[{xc, yc}]}, {Red, PointSize[0.05], 
              Point[p\[LeftDoubleBracket]1\[RightDoubleBracket]]}, {Green, 
              PointSize[0.05], 
              Point[p\[LeftDoubleBracket]2\[RightDoubleBracket]]}, {Blue, 
              PointSize[0.05], 
              Point[p\[LeftDoubleBracket]3\[RightDoubleBracket]]}, {Navy, 
              Thickness[0.025], 
              Line[{p\[LeftDoubleBracket]2\[RightDoubleBracket], 
                  p\[LeftDoubleBracket]3\[RightDoubleBracket]}]}, \
{ForestGreen, PointSize[0.05], Point[{xt, yt}]}}, 
          AspectRatio \[Rule] Automatic, PlotRange \[Rule] All, 
          ImageSize \[Rule] {300, 300}, 
          AspectRatio \[Rule] Automatic]];\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["ptFeasbile", "Subsubsection"],

Cell["\<\
Test whether a point meets a set of inequality constrints, i.e., point is \
feasible.\
\>", "Text"],

Cell[BoxData[{\(Clear[ptFeasbile]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["ptFeasbile",
            FontColor->RGBColor[0, 0, 1]], "[", \({xt_, yt_}, {}\), "]"}], ":=",
         "True"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["ptFeasbile",
            FontColor->RGBColor[0, 0, 1]], "[", \({xt_, yt_}, 
          ineqConstraints_List\), "]"}], 
        ":=", \(Union[
            ineqConstraints /. \[InvisibleSpace]x999 \[Rule] 
                xt] === {True}\)}], ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["predatorFocus", "Subsubsection"],

Cell["\<\
The predator may only focus on a limited number of prey when in pursuit.  \
predatorFocus[{xP_,yP_},refPtsL_List,opts___?OptionQ] returns True if the \
point in question {xP_, yP_} is in \"front\" of the predator and False \
otherwise.   The predator is defined by the list of points refPtsL_List.  The \
options for what constitutes in front of the predator are as follows: \
halfplane (all points in the half-plane in front of the predator, flashlight \
(all points in the cone in front of the predator), and all (default, all \
points in the space).  \
\>", "Text"],

Cell[BoxData[{\(Clear[
        predatorFocus];\), "\[IndentingNewLine]", \(Options[
          predatorFocus] = {predatorChase \[Rule] all};\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["predatorFocus",
            FontColor->RGBColor[0, 0, 1]], "[", \({xP_, yP_}, refPtsL_List, 
          opts___?OptionQ\), "]"}], ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({fitsL, inequalConstraints, predatorChase0}\), ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            RowBox[{\({predatorChase0} = \({predatorChase} /. {opts}\) /. 
                  Options[predatorFocus]\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(pp = Partition[refPtsL, 2, 1, 1]\), 
              ";", "\[IndentingNewLine]", \(fitsL = \((Fit[#1, {1, x999}, 
                        x999] &)\) /@ pp\), \( (*\ 
                fit\ lines\ between\ adjacent\ pairs\ of\ points\ *) \), ";", 
              "\[IndentingNewLine]", \(inequalConstraints = 
                Switch[predatorChase0, \[IndentingNewLine]halfPlane, {yP - 
                        fitsL\[LeftDoubleBracket]2\[RightDoubleBracket] \
\[LessEqual] 0} (*\ point\ in\ half - 
                      plane\ in\ front\ of\ predator\ *) , \
\[IndentingNewLine]flashlight, {yP - 
                        fitsL\[LeftDoubleBracket]1\[RightDoubleBracket] \
\[LessEqual] 0, yP - 
                        fitsL\[LeftDoubleBracket]3\[RightDoubleBracket] \
\[GreaterEqual] 0} (*\ 
                    point\ in\ cone\ in\ front\ of\ predator\ *) , \
\[IndentingNewLine]_, {}\[IndentingNewLine]]\), ";", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["ptFeasbile",
                  FontColor->RGBColor[0, 0, 1]], "[", \({xP, yP}, 
                inequalConstraints\), "]"}]}]}], "\[IndentingNewLine]", 
          "]"}]}], ";"}]}], "Input - Initialization Cell"],

Cell["Test", "Text"],

Cell[BoxData[{
    RowBox[{\(pL = {{384, 193}, {388, 150}, {367, 153}}\), \( (*\ 
        list\ of\ points\ that\ define\ the\ predator\ *) \)}], "\n", 
    RowBox[{\({xc, yc} = {379.7792229569352`, 164.9026798779218`}\), 
      "\[IndentingNewLine]"}], "\n", \({xt, yt} = {0, 
        0}\), "\[IndentingNewLine]", 
    RowBox[{\({xt, yt} = {xc, yc}\), \( (*\ point\ in\ question\ *) \), 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      StyleBox["predatorFocus",
        FontColor->RGBColor[0, 0, 1]], "[", \({xt, yt}, pL, 
      predatorChase \[Rule] halfPlane\), "]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["predatorFocus",
        FontColor->RGBColor[0, 0, 1]], "[", \({xt, yt}, pL, 
      predatorChase \[Rule] flashlight\), "]"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["predatorFocus",
        FontColor->RGBColor[0, 0, 1]], "[", \({xt, yt}, pL, 
      predatorChase \[Rule] all\), "]"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["computeNearAgents", "Subsubsection"],

Cell["\<\
Determine which agents in the list agentsL are within distance r to agent a.  \
agentsL is a list of items, possibly empty, with head agent.\
\>", "Text"],

Cell[BoxData[{\(Clear[computeNearAgents];\), "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["computeNearAgents",
            FontColor->RGBColor[0, 0, 1]], "[", \(a_agent, 
          agentsL : {_agent ... }, r_\), "]"}], 
        ":=", \(Module[{agentsL1, 
            nearAgents = {}}, \[IndentingNewLine]agentsL1 = 
            DeleteCases[agentsL, a] (*\ 
            delete\ agent\ a\ if\ in\ list\ *) ; \
\[IndentingNewLine]\(If[\((\@\(\((a\[LeftDoubleBracket]2\[RightDoubleBracket] \
- #1\[LeftDoubleBracket]2\[RightDoubleBracket])\)\^2 + \((a\
\[LeftDoubleBracket]3\[RightDoubleBracket] - #1\[LeftDoubleBracket]3\
\[RightDoubleBracket])\)\^2\))\) \[LessEqual] r, 
                nearAgents = nearAgents~Join~{#}] &\) /@ 
            agentsL1; \[IndentingNewLine]nearAgents\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"],

Cell["Test", "Text"],

Cell[BoxData[{\(agents\[LeftDoubleBracket]1\[RightDoubleBracket]\), "\
\[IndentingNewLine]", \(agents;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["computeNearAgents",
          FontColor->RGBColor[0, 0, 1]], 
        "[", \(agents\[LeftDoubleBracket]1\[RightDoubleBracket], agents, 
        100\), "]"}], "//", "ColumnForm"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["computeClosest", "Subsubsection"],

Cell["Get agent id closest to mouse click at {x, y}.", "Text"],

Cell[BoxData[{\(Clear[computeClosest];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["computeClosest",
            FontColor->RGBColor[0, 0, 1]], "[", \(x_, y_\), "]"}], 
        ":=", \(Module[{dist, minDist = Infinity, 
            minAgent = 
              Null}, \[IndentingNewLine]\((If[\((dist = 
                        N@\(\@\(\((x - #1\[LeftDoubleBracket]2\
\[RightDoubleBracket])\)\^2 + \((y - #1\[LeftDoubleBracket]3\
\[RightDoubleBracket])\)\^2\)\))\) \[LessEqual] 
                    minDist, \[IndentingNewLine]minDist = dist; 
                  minAgent = #] &)\) /@ 
            agents; \[IndentingNewLine]minAgent\[IndentingNewLine]]\)}], 
      ";"}]}], "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["OpenInitial", "Subsubsection"],

Cell[BoxData[
    \(OpenInitial[nb_] := \((NotebookOpen[nb]; 
        FrontEndExecute[{FrontEndToken["\<EvaluateInitialization\>"]}])\)\)], \
"Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{

Cell["Create generic grid neighborhood graphic", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics[{\[IndentingNewLine]{Yellow, 
              Rectangle[{1, 1}, {2, 2}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{1, 0}, {2, 1}]}, \[IndentingNewLine]{GrayLevel[
                0.95], Rectangle[{0, 1}, {1, 2}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{2, 1}, {3, 2}]}, \[IndentingNewLine]{GrayLevel[
                0.95], Rectangle[{1, 2}, {2, 3}]}, \[IndentingNewLine]{Red, 
              Rectangle[{0, 0}, {1, 1}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{2, 0}, {3, 1}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{0, 2}, {1, 3}]}, \[IndentingNewLine]{Red, 
              Rectangle[{2, 2}, {3, 
                  3}]}, \[IndentingNewLine]\[IndentingNewLine] (*\({Text[
                  StyleForm["\< Moore  Neighborhood\>", 
                    FontFamily \[Rule] "\<Helvetica\>", FontSize \[Rule] 16, 
                    FontWeight \[Rule] "\<Bold\>"], {1.5, 
                    3.2}]}\)\(,\)*) \[IndentingNewLine]\[IndentingNewLine]{\
Text[StyleForm["\<agent\>", FontFamily \[Rule] "\<Helvetica\>", 
                  FontSize \[Rule] 16, FontWeight \[Rule] "\<Bold\>"], {1.5, 
                  1.5}]}\[IndentingNewLine]\[IndentingNewLine] \
(*\[IndentingNewLine]{Text[
                  StyleForm["\<south\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {1.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<west\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    1.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<north\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {1.5, 
                    2.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<east\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {2.5, 
                    1.5}]}, \[IndentingNewLine]\[IndentingNewLine]{Text[
                  StyleForm["\<sw\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<se\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {2.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<nw\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    2.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<ne\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] 
                      RGBColor[1, 1, 1]], \[IndentingNewLine]{2.5, 
                    2.5}]}\[IndentingNewLine]*) \[IndentingNewLine]}, 
          PlotRange \[Rule] {{\(-1\), 4}, {\(-1\), 4}}, 
          GridLines \[Rule] Automatic, Frame \[Rule] False, 
          ImageSize \[Rule] 300, 
          AspectRatio \[Rule] Automatic]];\)\)], "Input",
  CellFrame->True,
  FontSize->14,
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 300 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.2 0.2 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 1 L
s
.2 0 m
.2 1 L
s
.4 0 m
.4 1 L
s
.6 0 m
.6 1 L
s
.8 0 m
.8 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 .2 m
1 .2 L
s
0 .4 m
1 .4 L
s
0 .6 m
1 .6 L
s
0 .8 m
1 .8 L
s
0 1 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 0 r
.4 .4 m
.4 .6 L
.6 .6 L
.6 .4 L
F
0 0 1 r
.4 .2 m
.4 .4 L
.6 .4 L
.6 .2 L
F
.95 g
.2 .4 m
.2 .6 L
.4 .6 L
.4 .4 L
F
0 0 1 r
.6 .4 m
.6 .6 L
.8 .6 L
.8 .4 L
F
.95 g
.4 .6 m
.4 .8 L
.6 .8 L
.6 .6 L
F
1 0 0 r
.2 .2 m
.2 .4 L
.4 .4 L
.4 .2 L
F
0 0 1 r
.6 .2 m
.6 .4 L
.8 .4 L
.8 .2 L
F
.2 .6 m
.2 .8 L
.4 .8 L
.4 .6 L
F
1 0 0 r
.6 .6 m
.6 .8 L
.8 .8 L
.8 .6 L
F
0 g
gsave
.5 .5 -84.5 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(agent) show
106.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 300},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001;2000`400?l00000o`00003oo`0007l]
0000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?oo
o`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0
001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000
O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0
>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo0@0007l00?l0001o;@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h
0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h
0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l003/0001o?03o001h0000ocd0001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0
003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0
?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03o
o`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l
0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??c
lc`0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
lo?c?03oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03clo<D0?oo00060:NW001XJ00000000000001XJ000/[808P3oo`0l0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<C0?oo000308b<00000000000000@0
000000<0_Kd00?oo003oo`007`3oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03clo<C0?oo0080000000H0hN400?oo003oo`00alL00000001XJ00Q0?oo
03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??cl`/0
ool000L0VYX00000001=C@00YjL00>WY00000000YjL00080ool000D0fMT006QX00000000VYX00?oo
0002000000<0ool000D0fMT006QX00000000CDd00<O700030?oo00800000103oo`0200000080ool0
00@0d=0004e=00000000S8`0203oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03clo<:0?oo000308b<0000000000000080000000D0CDd00000003`l000
ool00>7Q00040000000307al0000000000000080ool000<0hN400000000000000`0000000`3If@00
ool00?oo0002000000@0ool00P0000020?oo000404e=00000000000009ZJ00P0ool0?0000?l00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c2P3oo`0200000003
0>WY003oo`00alL0008000000P3oo`000`2JVP0000000:NW00020?oo000308b<0000000000000080
ool000L0VYX00000002WY`00ool00=WI00000000J6P00080ool00P0000040?oo008000000P3oo`02
000000X0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
oc`0lo?c2P3oo`001@1XJ00000000;:b003Qh@00l?00008000000P3oo`02000000040?3`003oo`00
ool00?3`008000000P3oo`02000000L0ool00P0000040?oo008000000P3oo`02000000X0ool0?000
0?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c2P3oo`00
0`3If@00CDd00000000400000080ool00P0000040?oo008000000P3oo`0700000080ool00P000004
0?oo008000000P3oo`02000000X0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?c303oo`000`3If@00/[8007al000200000080ool00P000000103`
l000ool00?oo003`l00200000080ool000<0CDd00000000000000`0000000`1=C@00ool00?oo0002
000000040?3`003oo`00ool00?oo008000000P3oo`02000000X0ool0?0000?l00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c2P3oo`001@1=C@0000000=WI003o
o`00jNT0008000000P3oo`000`2JVP0000000:NW00020?oo000309ZJ0000000000000080ool000L0
VYX00000003Qh@00ool00>7Q00000000VYX00080ool00P000000102JVP00l?000?oo002m_@020000
0080ool00P00000:0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oooll0??cl`X0ool000<0_Kd00000000000000`000000102<S000ool00?oo003Qh@040000
000306QX0000000000000080ool000<0hN400000000000000`0000000`3Qh@00ool00?oo00070000
000309ZJ003oo`00000000@00000203oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03clo<;0?oo00060;fm001=C@0000000000002JVP00jNT00`3oo`00
1@3If@00J6P00000002<S000jNT0008000000`3oo`001@3If@00J6P00000001XJ000fMT000<0ool0
0P0000001@3Qh@00VYX0000000000000YjL00080ool01@0000080?oo03`0003o00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc00ool00P00000:0?oo03`0003o
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc00ool00P00
000:0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll
0??clc00ool000<0hN4008b<003oo`002@3oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000
O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3o
ool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?0000?l00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo03`0003o
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0ool0?000
0?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c?03oo`0l
0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<l0?oo
03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??clc`0
ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c
?03oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03c
lo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll
0??clc`0ool0?0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
oc`0lo?c?03oo`0l0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03clo<l0?oo03`0003o00<0001o0?ooo`3oool0>@3oool10000O`00>`0007ll0??clc`0ool0
?0000?lm0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o0000
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l0
00030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0
o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c
?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03c
lo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll
0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000
oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o0000
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l0
00030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0
o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c
?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03c
lo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll
0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000
oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0
oooo0@0007l003/0001o?0000?ll0??clc`0o`00?@0007l000030000O`3oool0oooo03P0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0
>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?oo
o`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0
001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000
O`00o`0007l]0000O`00\
\>"],
  ImageRangeCache->{{{0, 299}, {299, 0}} -> {-1.00003, -1.00003, 0.0167226, \
0.0167226}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics[{\[IndentingNewLine]{Blue, 
              Rectangle[{1, 1}, {2, 2}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{1, 0}, {2, 1}]}, \[IndentingNewLine]{GrayLevel[
                0.95], Rectangle[{0, 1}, {1, 2}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{2, 1}, {3, 2}]}, \[IndentingNewLine]{GrayLevel[
                0.95], Rectangle[{1, 2}, {2, 3}]}, \[IndentingNewLine]{Red, 
              Rectangle[{0, 0}, {1, 1}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{2, 0}, {3, 1}]}, \[IndentingNewLine]{Blue, 
              Rectangle[{0, 2}, {1, 3}]}, \[IndentingNewLine]{Red, 
              Rectangle[{2, 2}, {3, 
                  3}]}, \[IndentingNewLine]\[IndentingNewLine] (*\({Text[
                  StyleForm["\< Moore  Neighborhood\>", 
                    FontFamily \[Rule] "\<Helvetica\>", FontSize \[Rule] 16, 
                    FontWeight \[Rule] "\<Bold\>"], {1.5, 
                    3.2}]}\)\(,\)*) \[IndentingNewLine]\[IndentingNewLine]{\
Text[StyleForm["\<agent\>", FontFamily \[Rule] "\<Helvetica\>", 
                  FontSize \[Rule] 16, FontWeight \[Rule] "\<Bold\>"], {1.5, 
                  1.5}]}\[IndentingNewLine]\[IndentingNewLine] \
(*\[IndentingNewLine]{Text[
                  StyleForm["\<south\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {1.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<west\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    1.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<north\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {1.5, 
                    2.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<east\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {2.5, 
                    1.5}]}, \[IndentingNewLine]\[IndentingNewLine]{Text[
                  StyleForm["\<sw\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<se\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {2.5, 
                    0.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<nw\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] RGBColor[1, 1, 1]], {0.5, 
                    2.5}]}, \[IndentingNewLine]{Text[
                  StyleForm["\<ne\>", FontFamily \[Rule] "\<Helvetica\>", 
                    FontSize \[Rule] 14, FontWeight \[Rule] "\<Bold\>", 
                    FontColor \[Rule] 
                      RGBColor[1, 1, 1]], \[IndentingNewLine]{2.5, 
                    2.5}]}\[IndentingNewLine]*) \[IndentingNewLine]}, 
          PlotRange \[Rule] {{\(-1\), 4}, {\(-1\), 4}}, 
          GridLines \[Rule] Automatic, Frame \[Rule] False, 
          ImageSize \[Rule] 300, 
          AspectRatio \[Rule] Automatic]];\)\)], "Input",
  CellFrame->True,
  FontSize->14,
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 300 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.2 0.2 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 1 L
s
.2 0 m
.2 1 L
s
.4 0 m
.4 1 L
s
.6 0 m
.6 1 L
s
.8 0 m
.8 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
s
0 .2 m
1 .2 L
s
0 .4 m
1 .4 L
s
0 .6 m
1 .6 L
s
0 .8 m
1 .8 L
s
0 1 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.4 .4 m
.4 .6 L
.6 .6 L
.6 .4 L
F
.4 .2 m
.4 .4 L
.6 .4 L
.6 .2 L
F
.95 g
.2 .4 m
.2 .6 L
.4 .6 L
.4 .4 L
F
0 0 1 r
.6 .4 m
.6 .6 L
.8 .6 L
.8 .4 L
F
.95 g
.4 .6 m
.4 .8 L
.6 .8 L
.6 .6 L
F
1 0 0 r
.2 .2 m
.2 .4 L
.4 .4 L
.4 .2 L
F
0 0 1 r
.6 .2 m
.6 .4 L
.8 .4 L
.8 .2 L
F
.2 .6 m
.2 .8 L
.4 .8 L
.4 .6 L
F
1 0 0 r
.6 .6 m
.6 .8 L
.8 .8 L
.8 .6 L
F
0 g
gsave
.5 .5 -84.5 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(agent) show
106.000 17.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{300, 300},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0001;2000`400?l00000o`00003oo`0007l]
0000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?oo
o`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0
001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000
O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0
>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo0@0007l00?l0001o;@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h
0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h
0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?03o001h0000o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03o
001h0000o`030000O`3oool0oooo03T0oooo0@0007l003/0001o?03o001h0000ocd0001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
oc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c
N0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN000
0?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0lo?c50000?l01P000:L0001X000000000000001X0000/Uh0003o00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??cla<0003o00<0002<00000000
0000100000000`000;d0003o0000o`1K0000o`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo?03clo<C0000o`80000000H0003Q0000o`000?l000370000000006QM0000
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<;0000o`07
0000VP000000001=0000Y`000>T000000000Y`020000o`050000f@0006P000000000VP000?l00P00
00030000o`050000f@0006P000000000C@000<L00`000?l2000000@0003o0P0000020000o`040000
d00004d000000000S4@0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0
>03oooll0??cl`X0003o00<0002<0000000000000P0000001@0004d000000000l0000?l0003Q00@0
000000<0001l0000000000000P000?l00`000>40000000000003000000030000f@000?l0003o0080
000010000?l200000080003o00@0001=000000000000002JA0000?l00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c2P000?l2000000030000j@000?l000370080
00000P000?l00`0009X000000000Y`020000o`030000S000000000000080003o00L0002J00000000
0:L0003o0000f@000000001X0080003o0P0000040000o`8000000P000?l2000004H0003o00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0??cl`X0003o00D0001X0000
00000;80003Q0000l00200000080003o0P00000010000?00003o0000o`000?0200000080003o0P00
00070000o`80000010000?l200000080003o0P0000160000o`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?03clo<:0000o`030000f@0004d0000000@000000P000?l2
000000@0003o0P0000020000o`L000000P000?l2000000@0003o0P0000020000o`800000AP000?l0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c30000?l00`00
0=T0002b0000O00200000080003o0P00000010000?00003o0000o`000?0200000080003o00<0001=
0000000000000`0000000`0004d0003o0000o`02000000040000l0000?l0003o0000o`8000000P00
0?l2000004H0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll
0??cl`X0003o00D0001=000000000=T0003o0000j@0200000080003o00<0002J000000000:L00P00
0?l00`0009X00000000000020000o`070000VP000000003Q0000o`000>4000000000VP020000o`80
000000@0002J0000l0000?l0002m0P0000020000o`800000AP000?l00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c2P000?l00`000;d000000000000300000004
0000S0000?l0003o0000h@@0000000<0001X0000000000000P000?l00`000>400000000000030000
00030000h@000?l0003o00L0000000<0002J0000o`000000100000140000o`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<;0000o`060000_@0004d000000000
000009X0003Y0`000?l01@000=T0001X0000000008`0003Y008000000`000?l01@000=T0001X0000
000006P0003I00<0003o0P0000001@000>40002J000000000000002W0080003o1@0000140000o`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?03clo<`0000o`800000
AP000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c<000
0?l2000004H0003o00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll
0??clc00003o00<0003Q0000S0000?l0A@000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
oc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?c
N0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN000
0?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?oooc`0lo?cN0000?l00`0007l0oooo0?ooo`0i0?ooo`40001o000k0000Oc`0lo?c
N0000?lm0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o0000
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l0
00030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0
o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c
?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03c
lo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll
0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000
oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o0000
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l0
00030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0
o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c
?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03c
lo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo?0000?ll
0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oooll0000
oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oooc`0
003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo
0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo?0000?ll0??clc`0o`0000<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oooll0000oc`0lo?c?03o00000`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?oooc`0003o?03clo<l0?l000030000O`3oool0oooo03T0
oooo0@0007l003/0001o?0000?ll0??clc`0o`00?@0007l000030000O`3oool0oooo03P0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l00003
0000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0
>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool1
0000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0
oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l0
00030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3o
ool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`00
07l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@00
07l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?oo
o`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o0000
0`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo
03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o
0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o
00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0
oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0
oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0
oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo
0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0
001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0
001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h
0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i
0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?oo
o`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?oo
o`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`03
0000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40
001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0
>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3o
ool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3o
ool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool0
0`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool0
0`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo
03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo
03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0
oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`00
00<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo
00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?oo
o`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o
0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o
0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0i0?oo
o`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?oo
o`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3o
ool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo0@0007l000030000
O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000
O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000O`0000<0001o0?ooo`3oool0>03o
ool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3o
ool00`0007l0oooo0?ooo`0i0?ooo`40001o00000`0007l0oooo0?ooo`0h0?ooo`030000O`3oool0
oooo03T0oooo00<0001o0?ooo`3oool0>@3oool00`0007l0oooo0?ooo`0i0?ooo`030000O`3oool0
oooo03T0oooo0@0007l000030000O`3oool0oooo03P0oooo00<0001o0?ooo`3oool0>@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000O`3oool0oooo03T0oooo00<0001o0?ooo`3oool0>@3oool10000
O`00o`0007l]0000O`00\
\>"],
  ImageRangeCache->{{{0, 299}, {299, 0}} -> {-1.00003, -1.00003, 0.0167226, \
0.0167226}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Java reference", "Section"],

Cell["\<\
for Java help: http://java.sun.com/j2se/1.4.2/docs/api/index.html\
\>", "Text",
  FontSize->16,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[ColumnForm[Sort@Names["\<*`*\>"]]];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"a\"\>"},
          {"\<\"Abort\"\>"},
          {"\<\"AbortProtect\"\>"},
          {"\<\"Above\"\>"},
          {"\<\"Abs\"\>"},
          {"\<\"Absolute\"\>"},
          {"\<\"AbsoluteDashing\"\>"},
          {"\<\"AbsoluteOptions\"\>"},
          {"\<\"AbsolutePointSize\"\>"},
          {"\<\"AbsoluteThickness\"\>"},
          {"\<\"AbsoluteTime\"\>"},
          {"\<\"AbsoluteTiming\"\>"},
          {"\<\"AcceleratedOffScreenImage`getAccelerationThreshold\"\>"},
          {"\<\"AcceleratedOffScreenImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"AcceleratedOffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"AcceleratedOffScreenImage`SCALEUFAST\"\>"},
          {"\<\"AcceleratedOffScreenImage`SCALEUREPLICATE\"\>"},
          {"\<\"AcceleratedOffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"AcceleratedOffScreenImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"AcceleratedOffScreenImage`UndefinedProperty\"\>"},
          {"\<\"AccountingForm\"\>"},
          {"\<\"Accuracy\"\>"},
          {"\<\"AccuracyGoal\"\>"},
          {"\<\"Active\"\>"},
          {"\<\"ActiveItem\"\>"},
          {"\<\"add\"\>"},
          {"\<\"addAdjustmentListener\"\>"},
          {"\<\"addMouseListener\"\>"},
          {"\<\"AddOnHelpPath\"\>"},
          {"\<\"AddPeriodical\"\>"},
          {"\<\"AddTo\"\>"},
          {"\<\"AddToClassPath\"\>"},
          {"\<\"AdjustmentBox\"\>"},
          {"\<\"AdjustmentBoxOptions\"\>"},
          {"\<\"After\"\>"},
          {"\<\"agent\"\>"},
          {"\<\"agentRules\"\>"},
          {"\<\"agents\"\>"},
          {"\<\"agentsL\"\>"},
          {"\<\"agentsL1\"\>"},
          {"\<\"agentsL1$\"\>"},
          {"\<\"AiryAi\"\>"},
          {"\<\"AiryAiPrime\"\>"},
          {"\<\"AiryBi\"\>"},
          {"\<\"AiryBiPrime\"\>"},
          {"\<\"Algebra`FactorSquareFreeModList\"\>"},
          {"\<\"Algebra`Horner\"\>"},
          {"\<\"AlgebraicRules\"\>"},
          {"\<\"AlgebraicRulesData\"\>"},
          {"\<\"Algebraics\"\>"},
          {"\<\"Algebraics`Private`AlgebraicsCode\"\>"},
          {"\<\"Algebraics`Private`ANProperties\"\>"},
          {"\<\"Algebraics`Private`NFDiscriminant\"\>"},
          {"\<\"Algebraics`Private`NFFundamentalUnits\"\>"},
          {"\<\"Algebraics`Private`NFIntegralBasis\"\>"},
          {"\<\"Algebraics`Private`NFNormReps\"\>"},
          {"\<\"Algebraics`Private`NFRegulator\"\>"},
          {"\<\"Algebraics`Private`NFRootsOfUnity\"\>"},
          {"\<\"Algebraics`Private`NFToCommonField\"\>"},
          {"\<\"Algebraics`Private`ToNFElement\"\>"},
          {"\<\"Algebra`MatrixPowerMod\"\>"},
          {"\<\"Algebra`PartialSquareFreeDecompositionModList\"\>"},
          {"\<\"Algebra`PolynomialDerivativeModList\"\>"},
          {"\<\"Algebra`PolynomialDivisionModList\"\>"},
          {"\<\"Algebra`PolynomialExtendedGCDModList\"\>"},
          {"\<\"Algebra`PolynomialFactorModList\"\>"},
          {"\<\"Algebra`PolynomialGCDModList\"\>"},
          {"\<\"Algebra`PolynomialMakeMonicModList\"\>"},
          {"\<\"Algebra`PolynomialMinusModList\"\>"},
          {"\<\"Algebra`PolynomialPlusModList\"\>"},
          {"\<\"Algebra`PolynomialPowerMod\"\>"},
          {"\<\"Algebra`PolynomialPowerModList\"\>"},
          {"\<\"Algebra`PolynomialPthRootModList\"\>"},
          {"\<\"Algebra`PolynomialQuotientModList\"\>"},
          {"\<\"Algebra`PolynomialRemainderModList\"\>"},
          {"\<\"Algebra`PolynomialSubtractModList\"\>"},
          {"\<\"Algebra`PolynomialTimesModList\"\>"},
          {"\<\"Algebra`ReduciblePolynomialModListQ\"\>"},
          {"\<\"Algebra`SquareFreeDecompositionModList\"\>"},
          {"\<\"Algebra`SquareFreeModQ\"\>"},
          {"\<\"Algebra`SquareFreePartModList\"\>"},
          {"\<\"Algebra`SymmetricPolynomials`SymmetricPolynomial\"\>"},
          {"\<\"Algebra`SymmetricPolynomials`SymmetricReduction\"\>"},
          {"\<\"Alias\"\>"},
          {"\<\"AlignmentMarker\"\>"},
          {"\<\"All\"\>"},
          {"\<\"AllowInlineCells\"\>"},
          {"\<\"AllowRaggedArrays\"\>"},
          {"\<\"AllowScriptLevelChange\"\>"},
          {"\<\"AllowShortContext\"\>"},
          {"\<\"Alternatives\"\>"},
          {"\<\"AmbientLight\"\>"},
          {"\<\"Analytic\"\>"},
          {"\<\"AnchoredSearch\"\>"},
          {"\<\"And\"\>"},
          {"\<\"AnimationCycleOffset\"\>"},
          {"\<\"AnimationCycleRepetitions\"\>"},
          {"\<\"AnimationDirection\"\>"},
          {"\<\"AnimationDisplayTime\"\>"},
          {"\<\"anl`jlink`MathematicaModel`create\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`addDisplay\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`begin\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`create\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`getInitParam\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`getName\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`getSchedule\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`scheduleMethodAt\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`scheduleMethodAtInterval\"\
\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`scheduleMethodBeginning\"\
\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`setup\"\>"},
          {"\<\"anl`jlink`MathematicaModel`JPrivate`start\"\>"},
          {"\<\"Apart\"\>"},
          {"\<\"ApartSquareFree\"\>"},
          {"\<\"AppellF1\"\>"},
          {"\<\"Append\"\>"},
          {"\<\"AppendTo\"\>"},
          {"\<\"AppletViewer\"\>"},
          {"\<\"Apply\"\>"},
          {"\<\"ArcCos\"\>"},
          {"\<\"ArcCosh\"\>"},
          {"\<\"ArcCot\"\>"},
          {"\<\"ArcCoth\"\>"},
          {"\<\"ArcCsc\"\>"},
          {"\<\"ArcCsch\"\>"},
          {"\<\"ArcSec\"\>"},
          {"\<\"ArcSech\"\>"},
          {"\<\"ArcSin\"\>"},
          {"\<\"ArcSinh\"\>"},
          {"\<\"ArcTan\"\>"},
          {"\<\"ArcTanh\"\>"},
          {"\<\"Arg\"\>"},
          {"\<\"ArgumentCountQ\"\>"},
          {"\<\"ArithmeticGeometricMean\"\>"},
          {"\<\"Array\"\>"},
          {"\<\"arraycopy\"\>"},
          {"\<\"ArrayDepth\"\>"},
          {"\<\"ArrayPlot\"\>"},
          {"\<\"ArrayQ\"\>"},
          {"\<\"ArrayRules\"\>"},
          {"\<\"Arrow\"\>"},
          {"\<\"aSelected\"\>"},
          {"\<\"aSelected0\"\>"},
          {"\<\"aSelected$\"\>"},
          {"\<\"AspectRatio\"\>"},
          {"\<\"AspectRatioFixed\"\>"},
          {"\<\"Assuming\"\>"},
          {"\<\"Assumptions\"\>"},
          {"\<\"Assumptions`AAlgebraicQ\"\>"},
          {"\<\"Assumptions`AAssumedIneqQ\"\>"},
          {"\<\"Assumptions`AAssumedQ\"\>"},
          {"\<\"Assumptions`ABooleanQ\"\>"},
          {"\<\"Assumptions`AComplexQ\"\>"},
          {"\<\"Assumptions`AEvenQ\"\>"},
          {"\<\"Assumptions`AImpossibleIneqQ\"\>"},
          {"\<\"Assumptions`AInfSup\"\>"},
          {"\<\"Assumptions`AIntegerQ\"\>"},
          {"\<\"Assumptions`AllAssumptions\"\>"},
          {"\<\"Assumptions`AMathIneqs\"\>"},
          {"\<\"Assumptions`AMod\"\>"},
          {"\<\"Assumptions`ANegative\"\>"},
          {"\<\"Assumptions`ANonNegative\"\>"},
          {"\<\"Assumptions`ANonPositive\"\>"},
          {"\<\"Assumptions`AOddQ\"\>"},
          {"\<\"Assumptions`APositive\"\>"},
          {"\<\"Assumptions`APrimeQ\"\>"},
          {"\<\"Assumptions`ARationalQ\"\>"},
          {"\<\"Assumptions`ARealQ\"\>"},
          {"\<\"Assumptions`ASign\"\>"},
          {"\<\"Assumptions`AssumedFalse\"\>"},
          {"\<\"Assumptions`AUnequalQ\"\>"},
          {"\<\"Assumptions`AWeakSign\"\>"},
          {"\<\"AssumptionsDump`e\"\>"},
          {"\<\"AssumptionsDump`f\"\>"},
          {"\<\"AssumptionsDump`ineqs\"\>"},
          {"\<\"AssumptionsDump`m\"\>"},
          {"\<\"AssumptionsDump`vals\"\>"},
          {"\<\"AssumptionsDump`var\"\>"},
          {"\<\"AssumptionsDump`vars\"\>"},
          {"\<\"AtomQ\"\>"},
          {"\<\"Attributes\"\>"},
          {"\<\"AutoDelete\"\>"},
          {"\<\"AutoEvaluateEvents\"\>"},
          {"\<\"AutoGeneratedPackage\"\>"},
          {"\<\"AutoIndent\"\>"},
          {"\<\"AutoIndentSpacings\"\>"},
          {"\<\"AutoItalicWords\"\>"},
          {"\<\"AutoloadPath\"\>"},
          {"\<\"Automatic\"\>"},
          {"\<\"AutoOpenNotebooks\"\>"},
          {"\<\"AutoOpenPalettes\"\>"},
          {"\<\"AutoScroll\"\>"},
          {"\<\"AutoSpacing\"\>"},
          {"\<\"AutoStyleOptions\"\>"},
          {"\<\"AWTEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"AWTEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"AWTEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"Axes\"\>"},
          {"\<\"AxesEdge\"\>"},
          {"\<\"AxesLabel\"\>"},
          {"\<\"AxesOrigin\"\>"},
          {"\<\"AxesStyle\"\>"},
          {"\<\"Axis\"\>"},
          {"\<\"a$\"\>"},
          {"\<\"Background\"\>"},
          {"\<\"BackgroundTasksSettings\"\>"},
          {"\<\"Backsubstitution\"\>"},
          {"\<\"Backward\"\>"},
          {"\<\"BaseForm\"\>"},
          {"\<\"Baseline\"\>"},
          {"\<\"Before\"\>"},
          {"\<\"Begin\"\>"},
          {"\<\"BeginDialogPacket\"\>"},
          {"\<\"BeginFrontEndInteractionPacket\"\>"},
          {"\<\"BeginJavaBlock\"\>"},
          {"\<\"BeginPackage\"\>"},
          {"\<\"Below\"\>"},
          {"\<\"BernoulliB\"\>"},
          {"\<\"BesselI\"\>"},
          {"\<\"BesselJ\"\>"},
          {"\<\"BesselK\"\>"},
          {"\<\"BesselY\"\>"},
          {"\<\"Beta\"\>"},
          {"\<\"BetaRegularized\"\>"},
          {"\<\"BezoutMatrix\"\>"},
          {"\<\"BinaryFormat\"\>"},
          {"\<\"BinaryGet\"\>"},
          {"\<\"BinaryRead\"\>"},
          {"\<\"BinaryReadList\"\>"},
          {"\<\"BinaryWrite\"\>"},
          {"\<\"Binomial\"\>"},
          {"\<\"BitAnd\"\>"},
          {"\<\"BitNot\"\>"},
          {"\<\"BitOr\"\>"},
          {"\<\"BitXor\"\>"},
          {"\<\"Black\"\>"},
          {"\<\"Blank\"\>"},
          {"\<\"BlankForm\"\>"},
          {"\<\"BlankNullSequence\"\>"},
          {"\<\"BlankSequence\"\>"},
          {"\<\"Block\"\>"},
          {"\<\"Blue\"\>"},
          {"\<\"Boole\"\>"},
          {"\<\"Booleans\"\>"},
          {"\<\"BorderLayout`AFTERULASTULINE\"\>"},
          {"\<\"BorderLayout`AFTERULINEUENDS\"\>"},
          {"\<\"BorderLayout`BEFOREUFIRSTULINE\"\>"},
          {"\<\"BorderLayout`BEFOREULINEUBEGINS\"\>"},
          {"\<\"BorderLayout`CENTER\"\>"},
          {"\<\"BorderLayout`EAST\"\>"},
          {"\<\"BorderLayout`LINEUEND\"\>"},
          {"\<\"BorderLayout`LINEUSTART\"\>"},
          {"\<\"BorderLayout`NORTH\"\>"},
          {"\<\"BorderLayout`PAGEUEND\"\>"},
          {"\<\"BorderLayout`PAGEUSTART\"\>"},
          {"\<\"BorderLayout`SOUTH\"\>"},
          {"\<\"BorderLayout`WEST\"\>"},
          {"\<\"Bottom\"\>"},
          {"\<\"Bounds\"\>"},
          {"\<\"Box\"\>"},
          {"\<\"BoxBaselineShift\"\>"},
          {"\<\"BoxData\"\>"},
          {"\<\"BoxDimensions\"\>"},
          {"\<\"Boxed\"\>"},
          {"\<\"BoxForm`a\"\>"},
          {"\<\"BoxForm`AddCommas\"\>"},
          {"\<\"BoxForm`AddOptions\"\>"},
          {"\<\"BoxForm`AddTraditionalFunction\"\>"},
          {"\<\"BoxForm`apat\"\>"},
          {"\<\"BoxForm`apat$\"\>"},
          {"\<\"BoxForm`arg\"\>"},
          {"\<\"BoxForm`args\"\>"},
          {"\<\"BoxForm`args$\"\>"},
          {"\<\"BoxForm`arguments\"\>"},
          {"\<\"BoxForm`arguments$\"\>"},
          {"\<\"BoxForm`arg$\"\>"},
          {"\<\"BoxForm`AssembleFunctionCall\"\>"},
          {"\<\"BoxForm`a$\"\>"},
          {"\<\"BoxForm`b\"\>"},
          {"\<\"BoxForm`base\"\>"},
          {"\<\"BoxForm`base$\"\>"},
          {"\<\"BoxForm`binary\"\>"},
          {"\<\"BoxForm`binary$\"\>"},
          {"\<\"BoxForm`BoxArgument\"\>"},
          {"\<\"BoxForm`boxexpr\"\>"},
          {"\<\"BoxForm`boxexpr$\"\>"},
          {"\<\"BoxForm`BoxFormAutoLoad\"\>"},
          {"\<\"BoxForm`BoxFormAutoLoadOld\"\>"},
          {"\<\"BoxForm`b$\"\>"},
          {"\<\"BoxForm`Comma\"\>"},
          {"\<\"BoxForm`CommaPat\"\>"},
          {"\<\"BoxForm`CommaSeparated\"\>"},
          {"\<\"BoxForm`CommaSepArgsQ\"\>"},
          {"\<\"BoxForm`cont\"\>"},
          {"\<\"BoxForm`ConvertForm\"\>"},
          {"\<\"BoxForm`CountCommaArgs\"\>"},
          {"\<\"BoxForm`default\"\>"},
          {"\<\"BoxForm`defaultVal\"\>"},
          {"\<\"BoxForm`denom\"\>"},
          {"\<\"BoxForm`derivOperator\"\>"},
          {"\<\"BoxForm`derivOperator$\"\>"},
          {"\<\"BoxForm`e\"\>"},
          {"\<\"BoxForm`elems\"\>"},
          {"\<\"BoxForm`elems$\"\>"},
          {"\<\"BoxForm`else\"\>"},
          {"\<\"BoxForm`else$\"\>"},
          {"\<\"BoxForm`entry\"\>"},
          {"\<\"BoxForm`entry$\"\>"},
          {"\<\"BoxForm`expr\"\>"},
          {"\<\"BoxForm`exprs\"\>"},
          {"\<\"BoxForm`ext\"\>"},
          {"\<\"BoxForm`ExtractArgsSansCommas\"\>"},
          {"\<\"BoxForm`e$\"\>"},
          {"\<\"BoxForm`f\"\>"},
          {"\<\"BoxForm`feLink\"\>"},
          {"\<\"BoxForm`file\"\>"},
          {"\<\"BoxForm`filename\"\>"},
          {"\<\"BoxForm`filename$\"\>"},
          {"\<\"BoxForm`fmt\"\>"},
          {"\<\"BoxForm`fn\"\>"},
          {"\<\"BoxFormFormatTypes\"\>"},
          {"\<\"BoxForm`fpat\"\>"},
          {"\<\"BoxForm`fpat$\"\>"},
          {"\<\"BoxForm`FromTrad\"\>"},
          {"\<\"BoxForm`FrontEndObject\"\>"},
          {"\<\"BoxForm`fTypeset\"\>"},
          {"\<\"BoxForm`fTypeset$\"\>"},
          {"\<\"BoxForm`FuncIntBox\"\>"},
          {"\<\"BoxForm`f$\"\>"},
          {"\<\"BoxForm`GetCommaSepArgs\"\>"},
          {"\<\"BoxForm`GetOtherSepArgs\"\>"},
          {"\<\"BoxForm`grid\"\>"},
          {"\<\"BoxForm`grid$\"\>"},
          {"\<\"BoxForm`h\"\>"},
          {"\<\"BoxForm`head\"\>"},
          {"\<\"BoxForm`head$\"\>"},
          {"\<\"BoxForm`heldDir\"\>"},
          {"\<\"BoxForm`heldDir$\"\>"},
          {"\<\"BoxForm`HeldIntegerQ\"\>"},
          {"\<\"BoxForm`HeldNonOptionQ\"\>"},
          {"\<\"BoxForm`HeldNumberQ\"\>"},
          {"\<\"BoxForm`HeldOptionQ\"\>"},
          {"\<\"BoxForm`HeldRealNumberQ\"\>"},
          {"\<\"BoxForm`HeldSymbolQ\"\>"},
          {"\<\"BoxForm`h$\"\>"},
          {"\<\"BoxForm`id\"\>"},
          {"\<\"BoxForm`insertCommas\"\>"},
          {"\<\"BoxForm`insertCommas$\"\>"},
          {"\<\"BoxForm`Intercalate\"\>"},
          {"\<\"BoxForm`interp\"\>"},
          {"\<\"BoxForm`iter\"\>"},
          {"\<\"BoxForm`leftAbove\"\>"},
          {"\<\"BoxForm`leftBelow\"\>"},
          {"\<\"BoxForm`list\"\>"},
          {"\<\"BoxForm`list$\"\>"},
          {"\<\"BoxForm`loading\"\>"},
          {"\<\"BoxForm`ls\"\>"},
          {"\<\"BoxForm`ls$\"\>"},
          {"\<\"BoxForm`MakeCommaSepArgs\"\>"},
          {"\<\"BoxForm`makeinfixform\"\>"},
          {"\<\"BoxForm`MakeInfixForm\"\>"},
          {"\<\"BoxForm`MakeInterpretationBox\"\>"},
          {"\<\"BoxForm`MakeTraditionalBoxes\"\>"},
          {"\<\"BoxForm`MakeTraditionalExpression\"\>"},
          {"\<\"BoxForm`many\"\>"},
          {"\<\"BoxForm`matrix\"\>"},
          {"\<\"BoxForm`multiple\"\>"},
          {"\<\"BoxForm`multiple$\"\>"},
          {"\<\"BoxForm`Multiscript\"\>"},
          {"\<\"BoxForm`n\"\>"},
          {"\<\"BoxForm`name\"\>"},
          {"\<\"BoxForm`nbName\"\>"},
          {"\<\"BoxForm`nbObj\"\>"},
          {"\<\"BoxForm`newsyms\"\>"},
          {"\<\"BoxForm`newsyms$\"\>"},
          {"\<\"BoxForm`numer\"\>"},
          {"\<\"BoxForm`n$\"\>"},
          {"\<\"BoxForm`object\"\>"},
          {"\<\"BoxForm`old\"\>"},
          {"\<\"BoxForm`OperatorList\"\>"},
          {"\<\"BoxForm`OperatorName\"\>"},
          {"\<\"BoxForm`opts\"\>"},
          {"\<\"BoxForm`orders\"\>"},
          {"\<\"BoxForm`ordersTypeset\"\>"},
          {"\<\"BoxForm`ordersTypeset$\"\>"},
          {"\<\"BoxForm`other\"\>"},
          {"\<\"BoxForm`other$\"\>"},
          {"\<\"BoxForm`patts\"\>"},
          {"\<\"BoxForm`pFile\"\>"},
          {"\<\"BoxForm`pFile$\"\>"},
          {"\<\"BoxForm`PiecewiseDefault\"\>"},
          {"\<\"BoxForm`PiecewiseMakeExpression\"\>"},
          {"\<\"BoxForm`protected\"\>"},
          {"\<\"BoxForm`prots\"\>"},
          {"\<\"BoxForm`Quote\"\>"},
          {"\<\"BoxForm`r\"\>"},
          {"\<\"BoxForm`ReplaceOperatorList\"\>"},
          {"\<\"BoxForm`RestoreValues\"\>"},
          {"\<\"BoxForm`rightAbove\"\>"},
          {"\<\"BoxForm`rightBelow\"\>"},
          {"\<\"BoxForm`r$\"\>"},
          {"\<\"BoxForm`s\"\>"},
          {"\<\"BoxForm`SaveValues\"\>"},
          {"\<\"BoxForm`sep\"\>"},
          {"\<\"BoxForm`separator\"\>"},
          {"\<\"BoxForm`SimulateMultiscriptBox\"\>"},
          {"\<\"BoxForm`singleton\"\>"},
          {"\<\"BoxForm`singleton$\"\>"},
          {"\<\"BoxForm`SmartScriptBox\"\>"},
          {"\<\"BoxForm`sub\"\>"},
          {"\<\"BoxForm`subopts\"\>"},
          {"\<\"BoxForm`subopts$\"\>"},
          {"\<\"BoxForm`subscript\"\>"},
          {"\<\"BoxForm`subscript$\"\>"},
          {"\<\"BoxForm`sub$\"\>"},
          {"\<\"BoxForm`sup\"\>"},
          {"\<\"BoxForm`super\"\>"},
          {"\<\"BoxForm`sup$\"\>"},
          {"\<\"BoxForm`syms\"\>"},
          {"\<\"BoxForm`s$\"\>"},
          {"\<\"BoxForm`t\"\>"},
          {"\<\"BoxForm`TagBoxConstant\"\>"},
          {"\<\"BoxForm`test\"\>"},
          {"\<\"BoxForm`TestSyms\"\>"},
          {"\<\"BoxForm`test$\"\>"},
          {"\<\"BoxForm`TopLevelMakeExpression\"\>"},
          {"\<\"BoxForm`ToTrad\"\>"},
          {"\<\"BoxForm`type\"\>"},
          {"\<\"BoxForm`typeset\"\>"},
          {"\<\"BoxForm`typesetDefault\"\>"},
          {"\<\"BoxForm`typesetDefault$\"\>"},
          {"\<\"BoxForm`typesetEntries\"\>"},
          {"\<\"BoxForm`typesetEntries$\"\>"},
          {"\<\"BoxForm`typesetForm\"\>"},
          {"\<\"BoxForm`typesetForm$\"\>"},
          {"\<\"BoxForm`t$\"\>"},
          {"\<\"BoxForm`UltimateHead\"\>"},
          {"\<\"BoxForm`val\"\>"},
          {"\<\"BoxForm`vals\"\>"},
          {"\<\"BoxForm`valsToConds\"\>"},
          {"\<\"BoxForm`values\"\>"},
          {"\<\"BoxForm`values$\"\>"},
          {"\<\"BoxForm`val$\"\>"},
          {"\<\"BoxForm`wasProt\"\>"},
          {"\<\"BoxForm`wasProtected\"\>"},
          {"\<\"BoxForm`wasProtected$\"\>"},
          {"\<\"BoxForm`x\"\>"},
          {"\<\"BoxForm`x$\"\>"},
          {"\<\"BoxForm`z\"\>"},
          {"\<\"BoxForm`z$\"\>"},
          {"\<\"BoxFrame\"\>"},
          {"\<\"BoxMargins\"\>"},
          {"\<\"BoxRatios\"\>"},
          {"\<\"BoxRegion\"\>"},
          {"\<\"BoxStyle\"\>"},
          {"\<\"Break\"\>"},
          {"\<\"Brown\"\>"},
          {"\<\"BrowserCategoryLoad`BrowserCategory\"\>"},
          {"\<\"BrowserCategoryLoad`Delimiter\"\>"},
          {"\<\"BrowserCategoryLoad`Item\"\>"},
          {"\<\"BrowserCategoryLoad`None\"\>"},
          {"\<\"Buchberger\"\>"},
          {"\<\"BufferedImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"BufferedImage`SCALEUDEFAULT\"\>"},
          {"\<\"BufferedImage`SCALEUFAST\"\>"},
          {"\<\"BufferedImage`SCALEUREPLICATE\"\>"},
          {"\<\"BufferedImage`SCALEUSMOOTH\"\>"},
          {"\<\"BufferedImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"BufferedImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"BufferedImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"BufferedImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"BufferedImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"BufferedImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"BufferedImage`TYPEUCUSTOM\"\>"},
          {"\<\"BufferedImage`TYPEUINTUARGB\"\>"},
          {"\<\"BufferedImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"BufferedImage`TYPEUINTUBGR\"\>"},
          {"\<\"BufferedImage`TYPEUINTURGB\"\>"},
          {"\<\"BufferedImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"BufferedImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"BufferedImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"BufferedImage`UndefinedProperty\"\>"},
          {"\<\"Button\"\>"},
          {"\<\"ButtonBox\"\>"},
          {"\<\"ButtonBoxOptions\"\>"},
          {"\<\"ButtonCell\"\>"},
          {"\<\"ButtonContents\"\>"},
          {"\<\"ButtonData\"\>"},
          {"\<\"ButtonEvaluator\"\>"},
          {"\<\"ButtonExpandable\"\>"},
          {"\<\"ButtonFrame\"\>"},
          {"\<\"ButtonFunction\"\>"},
          {"\<\"ButtonMargins\"\>"},
          {"\<\"ButtonMinHeight\"\>"},
          {"\<\"ButtonNote\"\>"},
          {"\<\"ButtonNotebook\"\>"},
          {"\<\"ButtonSource\"\>"},
          {"\<\"ButtonStyle\"\>"},
          {"\<\"ButtonStyleMenuListing\"\>"},
          {"\<\"ByRef\"\>"},
          {"\<\"Byte\"\>"},
          {"\<\"ByteCount\"\>"},
          {"\<\"ByteOrdering\"\>"},
          {"\<\"C\"\>"},
          {"\<\"CallPacket\"\>"},
          {"\<\"Cancel\"\>"},
          {"\<\"CarmichaelLambda\"\>"},
          {"\<\"Cases\"\>"},
          {"\<\"Catalan\"\>"},
          {"\<\"Catch\"\>"},
          {"\<\"Ceiling\"\>"},
          {"\<\"Cell\"\>"},
          {"\<\"CellAutoOverwrite\"\>"},
          {"\<\"CellBaseline\"\>"},
          {"\<\"CellBoundingBox\"\>"},
          {"\<\"CellBracketOptions\"\>"},
          {"\<\"CellContents\"\>"},
          {"\<\"CellDingbat\"\>"},
          {"\<\"CellEditDuplicate\"\>"},
          {"\<\"CellElementsBoundingBox\"\>"},
          {"\<\"CellElementSpacings\"\>"},
          {"\<\"CellEvaluationDuplicate\"\>"},
          {"\<\"CellFrame\"\>"},
          {"\<\"CellFrameColor\"\>"},
          {"\<\"CellFrameLabelMargins\"\>"},
          {"\<\"CellFrameLabels\"\>"},
          {"\<\"CellFrameMargins\"\>"},
          {"\<\"CellGroup\"\>"},
          {"\<\"CellGroupData\"\>"},
          {"\<\"CellGrouping\"\>"},
          {"\<\"CellGroupingRules\"\>"},
          {"\<\"CellHorizontalScrolling\"\>"},
          {"\<\"CellLabel\"\>"},
          {"\<\"CellLabelAutoDelete\"\>"},
          {"\<\"CellLabelMargins\"\>"},
          {"\<\"CellLabelPositioning\"\>"},
          {"\<\"CellMargins\"\>"},
          {"\<\"CellObject\"\>"},
          {"\<\"CellOpen\"\>"},
          {"\<\"CellPasswords\"\>"},
          {"\<\"CellPrint\"\>"},
          {"\<\"CellSize\"\>"},
          {"\<\"CellStyle\"\>"},
          {"\<\"CellTags\"\>"},
          {"\<\"CellularAutomaton\"\>"},
          {"\<\"Center\"\>"},
          {"\<\"CForm\"\>"},
          {"\<\"Character\"\>"},
          {"\<\"CharacterEncoding\"\>"},
          {"\<\"CharacterEncodingsPath\"\>"},
          {"\<\"CharacteristicPolynomial\"\>"},
          {"\<\"CharacterRange\"\>"},
          {"\<\"Characters\"\>"},
          {"\<\"ChebyshevT\"\>"},
          {"\<\"ChebyshevU\"\>"},
          {"\<\"Check\"\>"},
          {"\<\"CheckAbort\"\>"},
          {"\<\"CheckAll\"\>"},
          {"\<\"CholeskyDecomposition\"\>"},
          {"\<\"Chop\"\>"},
          {"\<\"Circle\"\>"},
          {"\<\"ClassName\"\>"},
          {"\<\"ClassPath\"\>"},
          {"\<\"Clear\"\>"},
          {"\<\"ClearAll\"\>"},
          {"\<\"ClearAttributes\"\>"},
          {"\<\"ClebschGordan\"\>"},
          {"\<\"Clip\"\>"},
          {"\<\"ClipboardNotebook\"\>"},
          {"\<\"ClipFill\"\>"},
          {"\<\"Close\"\>"},
          {"\<\"Closed\"\>"},
          {"\<\"CloseFrontEnd\"\>"},
          {"\<\"ClosingAutoSave\"\>"},
          {"\<\"CMYKColor\"\>"},
          {"\<\"Coefficient\"\>"},
          {"\<\"CoefficientArrays\"\>"},
          {"\<\"CoefficientDomain\"\>"},
          {"\<\"CoefficientList\"\>"},
          {"\<\"CofactorExpansion\"\>"},
          {"\<\"Collect\"\>"},
          {"\<\"collision\"\>"},
          {"\<\"collision0\"\>"},
          {"\<\"ColonForm\"\>"},
          {"\<\"color\"\>"},
          {"\<\"Color`BITMASK\"\>"},
          {"\<\"Color`black\"\>"},
          {"\<\"Color`BLACK\"\>"},
          {"\<\"Color`blue\"\>"},
          {"\<\"Color`BLUE\"\>"},
          {"\<\"Color`cyan\"\>"},
          {"\<\"Color`CYAN\"\>"},
          {"\<\"Color`darkGray\"\>"},
          {"\<\"Color`DARKUGRAY\"\>"},
          {"\<\"Color`decode\"\>"},
          {"\<\"ColorFunction\"\>"},
          {"\<\"ColorFunctionScaling\"\>"},
          {"\<\"Color`getColor\"\>"},
          {"\<\"Color`getHSBColor\"\>"},
          {"\<\"Color`gray\"\>"},
          {"\<\"Color`GRAY\"\>"},
          {"\<\"Color`green\"\>"},
          {"\<\"Color`GREEN\"\>"},
          {"\<\"Color`HSBtoRGB\"\>"},
          {"\<\"Color`lightGray\"\>"},
          {"\<\"Color`LIGHTUGRAY\"\>"},
          {"\<\"Color`magenta\"\>"},
          {"\<\"Color`MAGENTA\"\>"},
          {"\<\"Color`OPAQUE\"\>"},
          {"\<\"Color`orange\"\>"},
          {"\<\"Color`ORANGE\"\>"},
          {"\<\"ColorOutput\"\>"},
          {"\<\"Color`pink\"\>"},
          {"\<\"Color`PINK\"\>"},
          {"\<\"Color`red\"\>"},
          {"\<\"Color`RED\"\>"},
          {"\<\"Color`RGBtoHSB\"\>"},
          {"\<\"ColorRules\"\>"},
          {"\<\"ColorSelectorSettings\"\>"},
          {"\<\"Color`TRANSLUCENT\"\>"},
          {"\<\"Color`white\"\>"},
          {"\<\"Color`WHITE\"\>"},
          {"\<\"Color`yellow\"\>"},
          {"\<\"Color`YELLOW\"\>"},
          {"\<\"color$\"\>"},
          {"\<\"Column\"\>"},
          {"\<\"ColumnAlignments\"\>"},
          {"\<\"ColumnForm\"\>"},
          {"\<\"ColumnLines\"\>"},
          {"\<\"ColumnsEqual\"\>"},
          {"\<\"ColumnSpacings\"\>"},
          {"\<\"ColumnWidths\"\>"},
          {"\<\"CommandLine\"\>"},
          {"\<\"CommonDefaultFormatTypes\"\>"},
          {"\<\"Compile\"\>"},
          {"\<\"Compile`AutoVar11\"\>"},
          {"\<\"Compile`AutoVar21\"\>"},
          {"\<\"Compiled\"\>"},
          {"\<\"CompiledFunction\"\>"},
          {"\<\"Compile`FunctionVariable\"\>"},
          {"\<\"CompileOptimizations\"\>"},
          {"\<\"Compile`SetIterate\"\>"},
          {"\<\"Compile`Variable\"\>"},
          {"\<\"Complement\"\>"},
          {"\<\"CompletionsListPacket\"\>"},
          {"\<\"Complex\"\>"},
          {"\<\"Complexes\"\>"},
          {"\<\"ComplexExpand\"\>"},
          {"\<\"ComplexInfinity\"\>"},
          {"\<\"ComplexityFunction\"\>"},
          {"\<\"Component`ABORT\"\>"},
          {"\<\"Component`ALLBITS\"\>"},
          {"\<\"Component`BOTTOMUALIGNMENT\"\>"},
          {"\<\"Component`CENTERUALIGNMENT\"\>"},
          {"\<\"Component`ERROR\"\>"},
          {"\<\"ComponentEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`COMPONENTUFIRST\"\>"},
          {"\<\"ComponentEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"ComponentEvent`COMPONENTULAST\"\>"},
          {"\<\"ComponentEvent`COMPONENTUMOVED\"\>"},
          {"\<\"ComponentEvent`COMPONENTURESIZED\"\>"},
          {"\<\"ComponentEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"ComponentEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"ComponentEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"ComponentEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"Component`FRAMEBITS\"\>"},
          {"\<\"Component`HEIGHT\"\>"},
          {"\<\"Component`LEFTUALIGNMENT\"\>"},
          {"\<\"Component`PROPERTIES\"\>"},
          {"\<\"Component`RIGHTUALIGNMENT\"\>"},
          {"\<\"Component`SOMEBITS\"\>"},
          {"\<\"Component`TOPUALIGNMENT\"\>"},
          {"\<\"Component`WIDTH\"\>"},
          {"\<\"Compose\"\>"},
          {"\<\"ComposeList\"\>"},
          {"\<\"ComposeSeries\"\>"},
          {"\<\"Composition\"\>"},
          {"\<\"CompoundExpression\"\>"},
          {"\<\"computeClosest\"\>"},
          {"\<\"computeCollision\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`HANDUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`CROSSHAIRUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`DEFAULTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`EURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`HANDUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUBOTH\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUVERT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`MOVEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`NEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`NURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`NWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`onClose\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`setLocation\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`setModal\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`setSize\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`SEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`SURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`SWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`TEXTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`WAITUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`JPrivate`WURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`MOVEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`TEXTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`WAITUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`getDefaultLocale\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`GRAPHICS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`isLightweightComponent\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
addMouseListener\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`createImage\"\>\
"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`FRAMEBITS\"\>"},\

          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
getDefaultLocale\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getImage\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getImageType\"\>\
"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getMathCommand\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getUsesFE\"\>"},
          
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
getUsesTraditionalForm\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`GRAPHICS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
isLightweightComponent\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`LEFTUALIGNMENT\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`paintComponent\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`PROPERTIES\"\>"}\
,
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`recompute\"\>"},\

          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`repaintNow\"\>"}\
,
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`RIGHTUALIGNMENT\
\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setBounds\"\>"},\

          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
setDefaultLocale\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setImage\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setImageType\"\>\
"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setLink\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setMathCommand\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setUsesFE\"\>"},\

          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
setUsesTraditionalForm\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`TOPUALIGNMENT\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`TYPESET\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
UNDEFINEDUCONDITION\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`WHENUFOCUSED\"\>\
"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`JPrivate`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`setDefaultLocale\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`TYPESET\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`UNDEFINEDUCONDITION\"\>"}\
,
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`WHENUFOCUSED\"\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`WHENUINUFOCUSEDUWINDOW\"\
\>"},
          {"\<\"com`wolfram`jlink`MathGraphicsJPanel`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`DISPOSEUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`DOUNOTHINGUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`EXITUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`HANDUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`HIDEUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`isDefaultLookAndFeelDecorated\"\>\
"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`CROSSHAIRUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`DEFAULTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`DISPOSEUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`DOUNOTHINGUONUCLOSE\"\>\
"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`EURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`EXITUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`getContentPane\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`HANDUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`HIDEUONUCLOSE\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`\
isDefaultLookAndFeelDecorated\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUBOTH\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUVERT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`MOVEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`NEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`NURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`NWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`onClose\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`setBounds\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`\
setDefaultLookAndFeelDecorated\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`setModal\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`SEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`SURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`SWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`TEXTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`WAITUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`JPrivate`WURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`MOVEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`setDefaultLookAndFeelDecorated\"\
\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`TEXTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`WAITUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`MathJFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`MathListener`JPrivate`setHandler\"\>"},
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`mouseClicked\"\>\
"},
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`mouseEntered\"\>\
"},
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`mouseExited\"\>"}\
,
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`mousePressed\"\>\
"},
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`mouseReleased\"\>\
"},
          {"\<\"com`wolfram`jlink`MathMouseListener`JPrivate`setHandler\"\>"},\

          {"\<\"com`wolfram`jlink`ObjectMaker`makeBooleanArray\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeBooleanArray2\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeBooleanArray3\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeDoubleArray\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeDoubleArray2\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeDoubleArray3\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeExpr\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeIntArray\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeIntArray2\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeIntArray3\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeObjectArray\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeObjectArray2\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeObjectArray3\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeStringArray\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeStringArray2\"\>"},
          {"\<\"com`wolfram`jlink`ObjectMaker`makeStringArray3\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`BOTTOMUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`CENTERUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`CROSSHAIRUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`DEFAULTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`EURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`getInstance\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`HANDUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`isFirstTime\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ABORT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ALLBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`BOTTOMUALIGNMENT\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`CENTERUALIGNMENT\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`CROSSHAIRUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`DEFAULTUCURSOR\"\>\
"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ERROR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`EURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`FRAMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`getFrames\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`getInstance\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`HANDUCURSOR\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`HEIGHT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ICONIFIED\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`isFirstTime\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`LEFTUALIGNMENT\"\>\
"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUBOTH\"\>\
"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUHORIZ\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUVERT\"\>\
"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MOVEUCURSOR\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NEURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NONE\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NWURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`RIGHTUALIGNMENT\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setCapture\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setFirstTime\"\>"}\
,
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setLocation\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setMaxLines\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setSize\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SEURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`STDERR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`STDOUT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SWURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`TEXTUCURSOR\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`TOPUALIGNMENT\"\>\
"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WAITUCURSOR\"\>"},\

          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WURESIZEUCURSOR\"\
\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`LEFTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUBOTH\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUVERT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`MOVEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`NEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`NONE\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`NORMAL\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`NURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`NWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`PROPERTIES\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`RIGHTUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`setCapture\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`setFirstTime\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`setMaxLines\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`SEURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`SOMEBITS\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`STDERR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`STDOUT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`SURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`SWURESIZEUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`TEXTUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`TOPUALIGNMENT\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`WAITUCURSOR\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`WIDTH\"\>"},
          {"\<\"com`wolfram`jlink`ui`ConsoleWindow`WURESIZEUCURSOR\"\>"},
          {"\<\"Condition\"\>"},
          {"\<\"ConfigurationPath\"\>"},
          {"\<\"Conjugate\"\>"},
          {"\<\"ConjugateTranspose\"\>"},
          {"\<\"Connect\"\>"},
          {"\<\"ConnectToFrontEnd\"\>"},
          {"\<\"ConsoleMessage\"\>"},
          {"\<\"ConsoleMessagePacket\"\>"},
          {"\<\"ConsolePrint\"\>"},
          {"\<\"ConsoleWindow`ABORT\"\>"},
          {"\<\"ConsoleWindow`ALLBITS\"\>"},
          {"\<\"ConsoleWindow`BOTTOMUALIGNMENT\"\>"},
          {"\<\"ConsoleWindow`CENTERUALIGNMENT\"\>"},
          {"\<\"ConsoleWindow`CROSSHAIRUCURSOR\"\>"},
          {"\<\"ConsoleWindow`DEFAULTUCURSOR\"\>"},
          {"\<\"ConsoleWindow`ERROR\"\>"},
          {"\<\"ConsoleWindow`EURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`FRAMEBITS\"\>"},
          {"\<\"ConsoleWindow`getFrames\"\>"},
          {"\<\"ConsoleWindow`getInstance\"\>"},
          {"\<\"ConsoleWindow`HANDUCURSOR\"\>"},
          {"\<\"ConsoleWindow`HEIGHT\"\>"},
          {"\<\"ConsoleWindow`ICONIFIED\"\>"},
          {"\<\"ConsoleWindow`isFirstTime\"\>"},
          {"\<\"ConsoleWindow`LEFTUALIGNMENT\"\>"},
          {"\<\"ConsoleWindow`MAXIMIZEDUBOTH\"\>"},
          {"\<\"ConsoleWindow`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"ConsoleWindow`MAXIMIZEDUVERT\"\>"},
          {"\<\"ConsoleWindow`MOVEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`NEURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`NONE\"\>"},
          {"\<\"ConsoleWindow`NORMAL\"\>"},
          {"\<\"ConsoleWindow`NURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`NWURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`PROPERTIES\"\>"},
          {"\<\"ConsoleWindow`RIGHTUALIGNMENT\"\>"},
          {"\<\"ConsoleWindow`setCapture\"\>"},
          {"\<\"ConsoleWindow`setFirstTime\"\>"},
          {"\<\"ConsoleWindow`setMaxLines\"\>"},
          {"\<\"ConsoleWindow`SEURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`SOMEBITS\"\>"},
          {"\<\"ConsoleWindow`STDERR\"\>"},
          {"\<\"ConsoleWindow`STDOUT\"\>"},
          {"\<\"ConsoleWindow`SURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`SWURESIZEUCURSOR\"\>"},
          {"\<\"ConsoleWindow`TEXTUCURSOR\"\>"},
          {"\<\"ConsoleWindow`TOPUALIGNMENT\"\>"},
          {"\<\"ConsoleWindow`WAITUCURSOR\"\>"},
          {"\<\"ConsoleWindow`WIDTH\"\>"},
          {"\<\"ConsoleWindow`WURESIZEUCURSOR\"\>"},
          {"\<\"Constant\"\>"},
          {"\<\"Constants\"\>"},
          {"\<\"ConstrainedMax\"\>"},
          {"\<\"ConstrainedMin\"\>"},
          {"\<\"Constructors\"\>"},
          {"\<\"Container`ABORT\"\>"},
          {"\<\"Container`ALLBITS\"\>"},
          {"\<\"Container`BOTTOMUALIGNMENT\"\>"},
          {"\<\"Container`CENTERUALIGNMENT\"\>"},
          {"\<\"Container`ERROR\"\>"},
          {"\<\"Container`FRAMEBITS\"\>"},
          {"\<\"Container`HEIGHT\"\>"},
          {"\<\"Container`LEFTUALIGNMENT\"\>"},
          {"\<\"Container`PROPERTIES\"\>"},
          {"\<\"Container`RIGHTUALIGNMENT\"\>"},
          {"\<\"Container`SOMEBITS\"\>"},
          {"\<\"Container`TOPUALIGNMENT\"\>"},
          {"\<\"Container`WIDTH\"\>"},
          {"\<\"contentFrame\"\>"},
          {"\<\"contentPane\"\>"},
          {"\<\"ContentsBoundingBox\"\>"},
          {"\<\"contentSliderFrame\"\>"},
          {"\<\"Context\"\>"},
          {"\<\"Contexts\"\>"},
          {"\<\"ContextToFilename\"\>"},
          {"\<\"ContextToFileName\"\>"},
          {"\<\"Continuation\"\>"},
          {"\<\"Continue\"\>"},
          {"\<\"ContinuedFraction\"\>"},
          {"\<\"ContourGraphics\"\>"},
          {"\<\"ContourLines\"\>"},
          {"\<\"ContourPlot\"\>"},
          {"\<\"Contours\"\>"},
          {"\<\"ContourShading\"\>"},
          {"\<\"ContourSmoothing\"\>"},
          {"\<\"ContourStyle\"\>"},
          {"\<\"controller\"\>"},
          {"\<\"Conversion`LineBoundingBox\"\>"},
          {"\<\"Conversion`LineSpacing\"\>"},
          {"\<\"Conversion`LineWrapBox\"\>"},
          {"\<\"ConversionOptions\"\>"},
          {"\<\"ConversionRules\"\>"},
          {"\<\"Conversion`TeXStringsToTextMode\"\>"},
          {"\<\"Convert`TeX`BoxesToTeX\"\>"},
          {"\<\"Convert`TeX`ExpressionToTeX\"\>"},
          {"\<\"Convert`TeX`TeXToBoxes\"\>"},
          {"\<\"Convert`TeX`TeXToExpression\"\>"},
          {"\<\"ConvertToBitmapPacket\"\>"},
          {"\<\"ConvertToCellExpression\"\>"},
          {"\<\"ConvertToPostScript\"\>"},
          {"\<\"ConvertToPostScriptPacket\"\>"},
          {"\<\"Copyable\"\>"},
          {"\<\"CopyDirectory\"\>"},
          {"\<\"CopyFile\"\>"},
          {"\<\"Cos\"\>"},
          {"\<\"Cosh\"\>"},
          {"\<\"CoshIntegral\"\>"},
          {"\<\"CosIntegral\"\>"},
          {"\<\"Cot\"\>"},
          {"\<\"Coth\"\>"},
          {"\<\"Count\"\>"},
          {"\<\"CounterAssignments\"\>"},
          {"\<\"CounterBox\"\>"},
          {"\<\"CounterBoxOptions\"\>"},
          {"\<\"CounterEvaluator\"\>"},
          {"\<\"CounterFunction\"\>"},
          {"\<\"CounterIncrements\"\>"},
          {"\<\"CounterStyle\"\>"},
          {"\<\"CounterStyleMenuListing\"\>"},
          {"\<\"CreateDirectory\"\>"},
          {"\<\"createImage\"\>"},
          {"\<\"CreatePalettePacket\"\>"},
          {"\<\"createSliderWindow\"\>"},
          {"\<\"Cross\"\>"},
          {"\<\"Csc\"\>"},
          {"\<\"Csch\"\>"},
          {"\<\"Cubics\"\>"},
          {"\<\"Cuboid\"\>"},
          {"\<\"CurrentlySpeakingPacket\"\>"},
          {"\<\"currentTimeMillis\"\>"},
          {"\<\"Cyan\"\>"},
          {"\<\"Cyclotomic\"\>"},
          {"\<\"CylindricalDecomposition\"\>"},
          {"\<\"D\"\>"},
          {"\<\"DampingFactor\"\>"},
          {"\<\"Dashing\"\>"},
          {"\<\"DataRange\"\>"},
          {"\<\"dataUpdata\"\>"},
          {"\<\"Date\"\>"},
          {"\<\"Debug\"\>"},
          {"\<\"Debugger`BreakEnable\"\>"},
          {"\<\"Debugger`DebugAbort\"\>"},
          {"\<\"Debugger`DebugFinish\"\>"},
          {"\<\"Debugger`DebugHandle\"\>"},
          {"\<\"Debugger`DebugNext\"\>"},
          {"\<\"Debugger`DebugOff\"\>"},
          {"\<\"Debugger`DebugOn\"\>"},
          {"\<\"Debugger`DebugStep\"\>"},
          {"\<\"Debugger`EvaluationStack\"\>"},
          {"\<\"Debugger`GetBreakpoints\"\>"},
          {"\<\"Debugger`GetTags\"\>"},
          {"\<\"Debugger`SetBreakpoints\"\>"},
          {"\<\"Debugger`SetExpressionWatchpoints\"\>"},
          {"\<\"Debugger`Tracing\"\>"},
          {"\<\"DebugTag\"\>"},
          {"\<\"Debug`$ExamineCode\"\>"},
          {"\<\"Decimal\"\>"},
          {"\<\"DeclarePackage\"\>"},
          {"\<\"Decompose\"\>"},
          {"\<\"Decrement\"\>"},
          {"\<\"DedekindEta\"\>"},
          {"\<\"Default\"\>"},
          {"\<\"DefaultColor\"\>"},
          {"\<\"DefaultDuplicateCellStyle\"\>"},
          {"\<\"DefaultFont\"\>"},
          {"\<\"DefaultFontProperties\"\>"},
          {"\<\"DefaultFormatType\"\>"},
          {"\<\"DefaultFormatTypeForStyle\"\>"},
          {"\<\"DefaultInlineFormatType\"\>"},
          {"\<\"DefaultInputFormatType\"\>"},
          {"\<\"DefaultNaturalLanguage\"\>"},
          {"\<\"DefaultNewCellStyle\"\>"},
          {"\<\"DefaultNewInlineCellStyle\"\>"},
          {"\<\"DefaultNotebook\"\>"},
          {"\<\"DefaultOutputFormatType\"\>"},
          {"\<\"DefaultStyleDefinitions\"\>"},
          {"\<\"DefaultTextFormatType\"\>"},
          {"\<\"DefaultTextInlineFormatType\"\>"},
          {"\<\"DefaultValues\"\>"},
          {"\<\"DefineExternal\"\>"},
          {"\<\"Definition\"\>"},
          {"\<\"Degree\"\>"},
          {"\<\"DegreeLexicographic\"\>"},
          {"\<\"DegreeReverseLexicographic\"\>"},
          {"\<\"Deletable\"\>"},
          {"\<\"Delete\"\>"},
          {"\<\"DeleteCases\"\>"},
          {"\<\"DeleteContents\"\>"},
          {"\<\"DeleteDirectory\"\>"},
          {"\<\"DeleteFile\"\>"},
          {"\<\"DeletionWarning\"\>"},
          {"\<\"DelimiterFlashTime\"\>"},
          {"\<\"DelimiterMatching\"\>"},
          {"\<\"Delimiters\"\>"},
          {"\<\"Denominator\"\>"},
          {"\<\"DensityGraphics\"\>"},
          {"\<\"DensityPlot\"\>"},
          {"\<\"DependentVariables\"\>"},
          {"\<\"Depth\"\>"},
          {"\<\"Derivative\"\>"},
          {"\<\"Det\"\>"},
          {"\<\"Developer`BesselSimplify\"\>"},
          {"\<\"Developer`BitLength\"\>"},
          {"\<\"Developer`BitShiftLeft\"\>"},
          {"\<\"Developer`BitShiftRight\"\>"},
          {"\<\"Developer`BoxesToMathML\"\>"},
          {"\<\"Developer`ClearCache\"\>"},
          {"\<\"Developer`CompensatedAdd\"\>"},
          {"\<\"Developer`ContextFreeForm\"\>"},
          {"\<\"Developer`FibonacciSimplify\"\>"},
          {"\<\"Developer`FileInformation\"\>"},
          {"\<\"Developer`ForceLocalFrontEnd\"\>"},
          {"\<\"Developer`FourierListConvolve\"\>"},
          {"\<\"Developer`FromPackedArray\"\>"},
          {"\<\"Developer`GammaSimplify\"\>"},
          {"\<\"Developer`HermiteNormalForm\"\>"},
          {"\<\"Developer`InequalityInstance\"\>"},
          {"\<\"Developer`InitializationFunction\"\>"},
          {"\<\"Developer`InstallFrontEnd\"\>"},
          {"\<\"Developer`LaunchCommand\"\>"},
          {"\<\"Developer`LaunchFlags\"\>"},
          {"\<\"Developer`LinearExpressionToMatrix\"\>"},
          {"\<\"Developer`LinearExpressionToSparseMatrix\"\>"},
          {"\<\"Developer`MachineComplexQ\"\>"},
          {"\<\"Developer`MachineIntegerQ\"\>"},
          {"\<\"Developer`MachineRealQ\"\>"},
          {"\<\"Developer`MathMLToBoxes\"\>"},
          {"\<\"Developer`NotebookInformation\"\>"},
          {"\<\"Developer`PackedArrayForm\"\>"},
          {"\<\"Developer`PackedArrayQ\"\>"},
          {"\<\"Developer`PartitionMap\"\>"},
          {"\<\"Developer`PolyGammaSimplify\"\>"},
          {"\<\"Developer`PolyLogSimplify\"\>"},
          {"\<\"Developer`PolynomialDivision\"\>"},
          {"\<\"Developer`PseudoFunctionsSimplify\"\>"},
          {"\<\"Developer`ReplaceAllUnheld\"\>"},
          {"\<\"Developer`SetSystemOptions\"\>"},
          {"\<\"Developer`SparseLinearSolve\"\>"},
          {"\<\"Developer`SystemOptions\"\>"},
          {"\<\"Developer`ToPackedArray\"\>"},
          {"\<\"Developer`TrigToRadicals\"\>"},
          {"\<\"Developer`UninstallFrontEnd\"\>"},
          {"\<\"Developer`UseFrontEnd\"\>"},
          {"\<\"Developer`ZeroQ\"\>"},
          {"\<\"Developer`ZetaSimplify\"\>"},
          {"\<\"Developer`$MaxMachineInteger\"\>"},
          {"\<\"Developer`$SymbolShadowingFunction\"\>"},
          {"\<\"Developer`$SymbolSystemShadowing\"\>"},
          {"\<\"DiacriticalPositioning\"\>"},
          {"\<\"DiagonalMatrix\"\>"},
          {"\<\"Dialog\"\>"},
          {"\<\"DialogIndent\"\>"},
          {"\<\"DialogLevel\"\>"},
          {"\<\"DialogProlog\"\>"},
          {"\<\"DialogSymbols\"\>"},
          {"\<\"diams\"\>"},
          {"\<\"diams$\"\>"},
          {"\<\"DifferenceOrder\"\>"},
          {"\<\"DigitBlock\"\>"},
          {"\<\"DigitCharacter\"\>"},
          {"\<\"DigitCount\"\>"},
          {"\<\"DigitQ\"\>"},
          {"\<\"Dimensions\"\>"},
          {"\<\"DiracDelta\"\>"},
          {"\<\"DirectedInfinity\"\>"},
          {"\<\"Direction\"\>"},
          {"\<\"Directory\"\>"},
          {"\<\"DirectoryName\"\>"},
          {"\<\"DirectoryStack\"\>"},
          {"\<\"dirJar\"\>"},
          {"\<\"dirmyMathematicaDesktop\"\>"},
          {"\<\"dirmyMathematicaLaptop\"\>"},
          {"\<\"DisableConsolePrintPacket\"\>"},
          {"\<\"DiscreteDelta\"\>"},
          {"\<\"Discrete`Difference\"\>"},
          {"\<\"Discrete`FactorialPower\"\>"},
          {"\<\"Disk\"\>"},
          {"\<\"Dispatch\"\>"},
          {"\<\"Display\"\>"},
          {"\<\"displayAgentDataFrame\"\>"},
          {"\<\"DisplayAnimation\"\>"},
          {"\<\"DisplayEndPacket\"\>"},
          {"\<\"DisplayFlushImagePacket\"\>"},
          {"\<\"DisplayForm\"\>"},
          {"\<\"DisplayFunction\"\>"},
          {"\<\"DisplayPacket\"\>"},
          {"\<\"DisplayRules\"\>"},
          {"\<\"DisplaySetSizePacket\"\>"},
          {"\<\"DisplayString\"\>"},
          {"\<\"dispose\"\>"},
          {"\<\"dist\"\>"},
          {"\<\"Distribute\"\>"},
          {"\<\"dist$\"\>"},
          {"\<\"Divide\"\>"},
          {"\<\"DivideBy\"\>"},
          {"\<\"DivisionFreeRowReduction\"\>"},
          {"\<\"Divisors\"\>"},
          {"\<\"DivisorSigma\"\>"},
          {"\<\"Do\"\>"},
          {"\<\"DoModal\"\>"},
          {"\<\"DOSTextFormat\"\>"},
          {"\<\"Dot\"\>"},
          {"\<\"DoubleExponential\"\>"},
          {"\<\"DoublyInfinite\"\>"},
          {"\<\"Down\"\>"},
          {"\<\"DownValues\"\>"},
          {"\<\"DragAndDrop\"\>"},
          {"\<\"drawAgent\"\>"},
          {"\<\"drawCollision\"\>"},
          {"\<\"DrawHighlighted\"\>"},
          {"\<\"drawOval\"\>"},
          {"\<\"drawRect\"\>"},
          {"\<\"Drop\"\>"},
          {"\<\"DSolve\"\>"},
          {"\<\"DSolve`DSolve2Order1NonlinearODEs\"\>"},
          {"\<\"DSolve`DSolve3Order1NonlinearODEs\"\>"},
          {"\<\"DSolve`DSolveBoundaryValueProblem\"\>"},
          {"\<\"DSolve`DSolveClassifyAbelODE\"\>"},
          {"\<\"DSolve`DSolveCompleteIntegral\"\>"},
          {"\<\"DSolve`DSolveCoreNilpotentDecomposition\"\>"},
          {"\<\"DSolve`\
DSolveDegreeBoundForPolynomialSolutionsOfLinearFirstOrderODEs\"\>"},
          {"\<\"DSolve`DSolveDispatchFirstOrderODEs\"\>"},
          {"\<\"DSolve`DSolveDispatchODE\"\>"},
          {"\<\"DSolve`DSolveDispatchPDE\"\>"},
          {"\<\"DSolve`DSolveDispatchPiecewiseODE\"\>"},
          {"\<\"DSolve`DSolveFirstOrderODE\"\>"},
          {"\<\"DSolve`DSolveFirstOrderODEs\"\>"},
          {"\<\"DSolve`DSolveFlatten\"\>"},
          {"\<\"DSolve`DSolveFromPureFunctionToLimit\"\>"},
          {"\<\"DSolve`DSolveHigherOrderODE\"\>"},
          {"\<\"DSolve`DSolveIntegrate\"\>"},
          {"\<\"DSolve`DSolveKovacic\"\>"},
          {"\<\"DSolve`DSolveLinearExactODE\"\>"},
          {"\<\"DSolve`DSolveLinearFirstOrderDAEs\"\>"},
          {"\<\"DSolve`DSolveLinearHomogeneousWithConstantCoefficients\"\>"},
          {"\<\"DSolve`DSolveLinearLegendreEquation\"\>"},
          {"\<\"DSolve`DSolveLinearPDE\"\>"},
          {"\<\"DSolve`DSolveLinearSecondOrderODE\"\>"},
          {"\<\"DSolve`DSolveMakeEquations\"\>"},
          {"\<\"DSolve`DSolveMethodOfUndeterminedCoefficients\"\>"},
          {"\<\"DSolve`DSolveNonlinear2ndOrderODE\"\>"},
          {"\<\"DSolve`DSolveNonZeroQ\"\>"},
          {"\<\"DSolve`DSolveOrder2PFQSols\"\>"},
          {"\<\"DSolve`DSolveOuter\"\>"},
          {"\<\"DSolve`DSolveParser\"\>"},
          {"\<\"DSolve`DSolvePDE\"\>"},
          {"\<\"DSolve`DSolvePFQTypeSolutions\"\>"},
          {"\<\"DSolve`DSolveQuasiLinearPDE\"\>"},
          {"\<\"DSolve`DSolveRationalAndExponentialSolutions\"\>"},
          {"\<\"DSolve`DSolveRationalQ\"\>"},
          {"\<\"DSolve`DSolveSecondOrderODE\"\>"},
          {"\<\"DSolve`DSolveSolve\"\>"},
          {"\<\"DSolve`DSolveSpecialLinearSecondOrderODE\"\>"},
          {"\<\"DSolve`DSolveSpecialLinearThirdOrderODE\"\>"},
          {"\<\"DSolve`DSolveSuccessiveReductionOfOrder\"\>"},
          {"\<\"DSolve`DSolveToPureFunction\"\>"},
          {"\<\"DSolve`DSolveTransformations\"\>"},
          {"\<\"DSolve`DSolveValuation\"\>"},
          {"\<\"DSolve`DSolveVariationOfParameters\"\>"},
          {"\<\"DSolve`DSolveZeroQ\"\>"},
          {"\<\"DSolve`$DSolveLeafCountConstraint\"\>"},
          {"\<\"DSolve`$DSolveSymmetryDegreeConstraint\"\>"},
          {"\<\"DSolve`$DSolveZeroQTimeConstraint\"\>"},
          {"\<\"Dt\"\>"},
          {"\<\"DualLinearProgramming\"\>"},
          {"\<\"DumpGet\"\>"},
          {"\<\"DumpSave\"\>"},
          {"\<\"e\"\>"},
          {"\<\"E\"\>"},
          {"\<\"EdgeForm\"\>"},
          {"\<\"Edit\"\>"},
          {"\<\"Editable\"\>"},
          {"\<\"EditButtonSettings\"\>"},
          {"\<\"EditCellTagsSettings\"\>"},
          {"\<\"EditDefinition\"\>"},
          {"\<\"EditIn\"\>"},
          {"\<\"Eigensystem\"\>"},
          {"\<\"Eigenvalues\"\>"},
          {"\<\"Eigenvectors\"\>"},
          {"\<\"Element\"\>"},
          {"\<\"Eliminate\"\>"},
          {"\<\"EliminationOrder\"\>"},
          {"\<\"EllipticE\"\>"},
          {"\<\"EllipticExp\"\>"},
          {"\<\"EllipticExpPrime\"\>"},
          {"\<\"EllipticF\"\>"},
          {"\<\"EllipticK\"\>"},
          {"\<\"EllipticLog\"\>"},
          {"\<\"EllipticNomeQ\"\>"},
          {"\<\"EllipticPi\"\>"},
          {"\<\"EllipticReducedHalfPeriods\"\>"},
          {"\<\"EllipticTheta\"\>"},
          {"\<\"EllipticThetaPrime\"\>"},
          {"\<\"Empty\"\>"},
          {"\<\"EnableConsolePrintPacket\"\>"},
          {"\<\"Encode\"\>"},
          {"\<\"Encoding\"\>"},
          {"\<\"End\"\>"},
          {"\<\"EndAdd\"\>"},
          {"\<\"EndDialogPacket\"\>"},
          {"\<\"EndFrontEndInteractionPacket\"\>"},
          {"\<\"EndJavaBlock\"\>"},
          {"\<\"EndModal\"\>"},
          {"\<\"EndOfFile\"\>"},
          {"\<\"EndOfLine\"\>"},
          {"\<\"EndOfString\"\>"},
          {"\<\"EndPackage\"\>"},
          {"\<\"EngineeringForm\"\>"},
          {"\<\"Enter\"\>"},
          {"\<\"EnterExpressionPacket\"\>"},
          {"\<\"EnterTextPacket\"\>"},
          {"\<\"Environment\"\>"},
          {"\<\"Epilog\"\>"},
          {"\<\"Equal\"\>"},
          {"\<\"EqualColumns\"\>"},
          {"\<\"EqualRows\"\>"},
          {"\<\"EquatedTo\"\>"},
          {"\<\"Erf\"\>"},
          {"\<\"Erfc\"\>"},
          {"\<\"Erfi\"\>"},
          {"\<\"err\"\>"},
          {"\<\"ErrorBox\"\>"},
          {"\<\"ErrorBoxOptions\"\>"},
          {"\<\"ErrorNorm\"\>"},
          {"\<\"ErrorPacket\"\>"},
          {"\<\"ErrorsDialogSettings\"\>"},
          {"\<\"EulerE\"\>"},
          {"\<\"EulerGamma\"\>"},
          {"\<\"EulerPhi\"\>"},
          {"\<\"Evaluatable\"\>"},
          {"\<\"Evaluate\"\>"},
          {"\<\"EvaluatePacket\"\>"},
          {"\<\"EvaluateToImage\"\>"},
          {"\<\"EvaluateToTypeset\"\>"},
          {"\<\"EvaluationCell\"\>"},
          {"\<\"EvaluationCompletionAction\"\>"},
          {"\<\"EvaluationMonitor\"\>"},
          {"\<\"EvaluationNotebook\"\>"},
          {"\<\"Evaluator\"\>"},
          {"\<\"EvaluatorNames\"\>"},
          {"\<\"EvenQ\"\>"},
          {"\<\"EventEvaluator\"\>"},
          {"\<\"evt\"\>"},
          {"\<\"ExactNumberQ\"\>"},
          {"\<\"ExactRootIsolation\"\>"},
          {"\<\"Except\"\>"},
          {"\<\"ExcludedForms\"\>"},
          {"\<\"Exists\"\>"},
          {"\<\"exit\"\>"},
          {"\<\"Exit\"\>"},
          {"\<\"ExitDialog\"\>"},
          {"\<\"Exp\"\>"},
          {"\<\"Expand\"\>"},
          {"\<\"ExpandAll\"\>"},
          {"\<\"ExpandDenominator\"\>"},
          {"\<\"ExpandNumerator\"\>"},
          {"\<\"Experimental`BinaryExport\"\>"},
          {"\<\"Experimental`BinaryExportString\"\>"},
          {"\<\"Experimental`BinaryImport\"\>"},
          {"\<\"Experimental`BinaryImportString\"\>"},
          {"\<\"Experimental`CompileEvaluate\"\>"},
          {"\<\"Experimental`CreateNumericalFunction\"\>"},
          {"\<\"Experimental`CylindricalAlgebraicDecomposition\"\>"},
          {"\<\"Experimental`DefaultValue\"\>"},
          {"\<\"Experimental`DiophantineInstance\"\>"},
          {"\<\"Experimental`ExistsRealQ\"\>"},
          {"\<\"Experimental`ExtendedLinearSolve\"\>"},
          {"\<\"Experimental`ExtendedLUBackSubstitution\"\>"},
          {"\<\"Experimental`ExtendedMessageOptions\"\>"},
          {"\<\"Experimental`FileBrowse\"\>"},
          {"\<\"Experimental`ForAllRealQ\"\>"},
          {"\<\"Experimental`GenericCylindricalAlgebraicDecomposition\"\>"},
          {"\<\"Experimental`ImpliesQ\"\>"},
          {"\<\"Experimental`ImpliesRealQ\"\>"},
          {"\<\"Experimental`Infimum\"\>"},
          {"\<\"Experimental`IntegerPartitions\"\>"},
          {"\<\"Experimental`IntegerValued\"\>"},
          {"\<\"Experimental`Maximize\"\>"},
          {"\<\"Experimental`Minimize\"\>"},
          {"\<\"Experimental`NumberScale\"\>"},
          {"\<\"Experimental`NumericalFunction\"\>"},
          {"\<\"Experimental`OptimizationSymbol\"\>"},
          {"\<\"Experimental`OptimizedExpression\"\>"},
          {"\<\"Experimental`OptimizeExpression\"\>"},
          {"\<\"Experimental`Orientation\"\>"},
          {"\<\"Experimental`PopDirection\"\>"},
          {"\<\"Experimental`PopupBox\"\>"},
          {"\<\"Experimental`PopupBoxOptions\"\>"},
          {"\<\"Experimental`Range\"\>"},
          {"\<\"Experimental`RegisterConverter\"\>"},
          {"\<\"Experimental`RegisterEncoding\"\>"},
          {"\<\"Experimental`Resolve\"\>"},
          {"\<\"Experimental`SetExtendedMessageOptions\"\>"},
          {"\<\"Experimental`SliderBox\"\>"},
          {"\<\"Experimental`SliderBoxOptions\"\>"},
          {"\<\"Experimental`StructuralForms\"\>"},
          {"\<\"Experimental`Supremum\"\>"},
          {"\<\"Experimental`TrackingFunction\"\>"},
          {"\<\"Experimental`ValueFunction\"\>"},
          {"\<\"Experimental`$BinaryExportFormats\"\>"},
          {"\<\"Experimental`$BinaryImportFormats\"\>"},
          {"\<\"Experimental`$EqualTolerance\"\>"},
          {"\<\"Experimental`$SameQTolerance\"\>"},
          {"\<\"ExpIntegralE\"\>"},
          {"\<\"ExpIntegralEi\"\>"},
          {"\<\"Exponent\"\>"},
          {"\<\"ExponentFunction\"\>"},
          {"\<\"ExponentPosition\"\>"},
          {"\<\"ExponentStep\"\>"},
          {"\<\"Export\"\>"},
          {"\<\"ExportAutoReplacements\"\>"},
          {"\<\"ExportPacket\"\>"},
          {"\<\"ExportString\"\>"},
          {"\<\"Expression\"\>"},
          {"\<\"ExpressionPacket\"\>"},
          {"\<\"ExpToTrig\"\>"},
          {"\<\"ExtendedGCD\"\>"},
          {"\<\"Extension\"\>"},
          {"\<\"ExternalCall\"\>"},
          {"\<\"ExternalDataCharacterEncoding\"\>"},
          {"\<\"Extract\"\>"},
          {"\<\"FaceForm\"\>"},
          {"\<\"FaceGrids\"\>"},
          {"\<\"Factor\"\>"},
          {"\<\"FactorComplete\"\>"},
          {"\<\"Factorial\"\>"},
          {"\<\"Factorial2\"\>"},
          {"\<\"FactorInteger\"\>"},
          {"\<\"FactorList\"\>"},
          {"\<\"FactorSquareFree\"\>"},
          {"\<\"FactorSquareFreeList\"\>"},
          {"\<\"FactorTerms\"\>"},
          {"\<\"FactorTermsList\"\>"},
          {"\<\"Factor`VarForAlgebraic\"\>"},
          {"\<\"Factor`VarForNumeric\"\>"},
          {"\<\"Factor`VarForTrig\"\>"},
          {"\<\"Fail\"\>"},
          {"\<\"False\"\>"},
          {"\<\"FE`a\"\>"},
          {"\<\"FE`allrules\"\>"},
          {"\<\"FE`alphabetrules\"\>"},
          {"\<\"FE`any\"\>"},
          {"\<\"FE`b\"\>"},
          {"\<\"FE`box\"\>"},
          {"\<\"FE`BoxFormData\"\>"},
          {"\<\"FE`c\"\>"},
          {"\<\"FE`cdirWasOff\"\>"},
          {"\<\"FE`DefineFrontEndGlobals\"\>"},
          {"\<\"FE`DefineFrontEndSymbols\"\>"},
          {"\<\"FE`dirCharPos\"\>"},
          {"\<\"FEDisableConsolePrintPacket\"\>"},
          {"\<\"FE`doubleSeparator\"\>"},
          {"\<\"FE`dropLength\"\>"},
          {"\<\"FE`dropPath\"\>"},
          {"\<\"FE`e\"\>"},
          {"\<\"FEEnableConsolePrintPacket\"\>"},
          {"\<\"FE`expr\"\>"},
          {"\<\"FE`FC\"\>"},
          {"\<\"FE`FlC\"\>"},
          {"\<\"FE`FlCGD\"\>"},
          {"\<\"FE`form\"\>"},
          {"\<\"FE`FromBoxForm\"\>"},
          {"\<\"FE`FT\"\>"},
          {"\<\"FE`fullPath\"\>"},
          {"\<\"FE`FunctionInspector\"\>"},
          {"\<\"FE`FunctionInspectorTemplate\"\>"},
          {"\<\"FE`GetSpecialTemplate\"\>"},
          {"\<\"FE`getTemplateFromUsage\"\>"},
          {"\<\"FE`includePath\"\>"},
          {"\<\"FE`InterpretInlineCells\"\>"},
          {"\<\"FE`language\"\>"},
          {"\<\"FE`lastElement\"\>"},
          {"\<\"FE`list\"\>"},
          {"\<\"FE`makeRPC\"\>"},
          {"\<\"FE`makeRPCutil\"\>"},
          {"\<\"FE`makeSymbol\"\>"},
          {"\<\"FE`msg\"\>"},
          {"\<\"FE`name\"\>"},
          {"\<\"FE`nameString\"\>"},
          {"\<\"FE`pat\"\>"},
          {"\<\"FE`patWild\"\>"},
          {"\<\"FE`ResetMedium\"\>"},
          {"\<\"FE`s\"\>"},
          {"\<\"FESafe`saved$Line\"\>"},
          {"\<\"FE`saveAttributes\"\>"},
          {"\<\"FE`SC\"\>"},
          {"\<\"FE`sepPos\"\>"},
          {"\<\"FE`SetBoxForms\"\>"},
          {"\<\"FE`SetLanguage\"\>"},
          {"\<\"FE`SetResultForm\"\>"},
          {"\<\"FE`spell111Off\"\>"},
          {"\<\"FE`spellOff\"\>"},
          {"\<\"FE`sym\"\>"},
          {"\<\"FE`testFile\"\>"},
          {"\<\"FE`testPos\"\>"},
          {"\<\"FE`theNames\"\>"},
          {"\<\"FE`tr\"\>"},
          {"\<\"FE`typesetToInputForm\"\>"},
          {"\<\"FE`usage\"\>"},
          {"\<\"FE`utilfun\"\>"},
          {"\<\"FE`w\"\>"},
          {"\<\"FE`WW\"\>"},
          {"\<\"FE`$FrontEndPackageVersion\"\>"},
          {"\<\"FE`$NoInputFormRules\"\>"},
          {"\<\"FE`$PrePrintAllInputForms\"\>"},
          {"\<\"FE`$PrePrintNoInputForGraphics\"\>"},
          {"\<\"Fibonacci\"\>"},
          {"\<\"FieldFunction\"\>"},
          {"\<\"Fields\"\>"},
          {"\<\"File\"\>"},
          {"\<\"FileByteCount\"\>"},
          {"\<\"FileDate\"\>"},
          {"\<\"FileFormat\"\>"},
          {"\<\"FileInformation\"\>"},
          {"\<\"FileName\"\>"},
          {"\<\"FileNameDialogSettings\"\>"},
          {"\<\"FileNames\"\>"},
          {"\<\"FileType\"\>"},
          {"\<\"fillBoo\"\>"},
          {"\<\"fillBoo$\"\>"},
          {"\<\"fillOval\"\>"},
          {"\<\"fillRect\"\>"},
          {"\<\"Find\"\>"},
          {"\<\"FindFit\"\>"},
          {"\<\"FindInstance\"\>"},
          {"\<\"FindList\"\>"},
          {"\<\"FindMaximum\"\>"},
          {"\<\"FindMinimum\"\>"},
          {"\<\"FindMinimum`ConjugateGradient\"\>"},
          {"\<\"FindMinimum`FMsymbol\"\>"},
          {"\<\"FindMinimum`InitializeMethod\"\>"},
          {"\<\"FindMinimum`LevenbergMarquardt\"\>"},
          {"\<\"FindRoot\"\>"},
          {"\<\"FindRoot`InitializeMethod\"\>"},
          {"\<\"FindRoot`Newton\"\>"},
          {"\<\"FindRoot`Secant\"\>"},
          {"\<\"FindSettings\"\>"},
          {"\<\"First\"\>"},
          {"\<\"Fit\"\>"},
          {"\<\"FitAll\"\>"},
          {"\<\"FixedPoint\"\>"},
          {"\<\"FixedPointList\"\>"},
          {"\<\"Flat\"\>"},
          {"\<\"Flatten\"\>"},
          {"\<\"FlattenAt\"\>"},
          {"\<\"Floor\"\>"},
          {"\<\"FlushPrintOutputPacket\"\>"},
          {"\<\"Fold\"\>"},
          {"\<\"FoldList\"\>"},
          {"\<\"Font\"\>"},
          {"\<\"FontColor\"\>"},
          {"\<\"FontFamily\"\>"},
          {"\<\"FontForm\"\>"},
          {"\<\"FontName\"\>"},
          {"\<\"FontPostScriptName\"\>"},
          {"\<\"FontProperties\"\>"},
          {"\<\"FontReencoding\"\>"},
          {"\<\"FontSize\"\>"},
          {"\<\"FontSlant\"\>"},
          {"\<\"FontSubstitutions\"\>"},
          {"\<\"FontTracking\"\>"},
          {"\<\"FontVariations\"\>"},
          {"\<\"FontWeight\"\>"},
          {"\<\"For\"\>"},
          {"\<\"ForAll\"\>"},
          {"\<\"ForceLaunch\"\>"},
          {"\<\"Format\"\>"},
          {"\<\"FormatRules\"\>"},
          {"\<\"FormatType\"\>"},
          {"\<\"FormatTypeAutoConvert\"\>"},
          {"\<\"FormatValues\"\>"},
          {"\<\"Format`$GenericForm\"\>"},
          {"\<\"FormBox\"\>"},
          {"\<\"FormBoxOptions\"\>"},
          {"\<\"FortranForm\"\>"},
          {"\<\"Forward\"\>"},
          {"\<\"ForwardBackward\"\>"},
          {"\<\"Fourier\"\>"},
          {"\<\"FourierCosTransform\"\>"},
          {"\<\"FourierParameters\"\>"},
          {"\<\"FourierSinTransform\"\>"},
          {"\<\"FourierTransform\"\>"},
          {"\<\"FractionalPart\"\>"},
          {"\<\"FractionBox\"\>"},
          {"\<\"FractionBoxOptions\"\>"},
          {"\<\"FractionLine\"\>"},
          {"\<\"Frame\"\>"},
          {"\<\"Frame`ABORT\"\>"},
          {"\<\"Frame`ALLBITS\"\>"},
          {"\<\"Frame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"FrameBox\"\>"},
          {"\<\"FrameBoxOptions\"\>"},
          {"\<\"Frame`CENTERUALIGNMENT\"\>"},
          {"\<\"Frame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"Frame`DEFAULTUCURSOR\"\>"},
          {"\<\"Frame`ERROR\"\>"},
          {"\<\"Frame`EURESIZEUCURSOR\"\>"},
          {"\<\"Frame`FRAMEBITS\"\>"},
          {"\<\"Frame`getFrames\"\>"},
          {"\<\"Frame`HANDUCURSOR\"\>"},
          {"\<\"Frame`HEIGHT\"\>"},
          {"\<\"Frame`ICONIFIED\"\>"},
          {"\<\"FrameLabel\"\>"},
          {"\<\"Frame`LEFTUALIGNMENT\"\>"},
          {"\<\"Frame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"Frame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"Frame`MAXIMIZEDUVERT\"\>"},
          {"\<\"Frame`MOVEUCURSOR\"\>"},
          {"\<\"Frame`NEURESIZEUCURSOR\"\>"},
          {"\<\"Frame`NORMAL\"\>"},
          {"\<\"Frame`NURESIZEUCURSOR\"\>"},
          {"\<\"Frame`NWURESIZEUCURSOR\"\>"},
          {"\<\"Frame`PROPERTIES\"\>"},
          {"\<\"Frame`RIGHTUALIGNMENT\"\>"},
          {"\<\"Frame`SEURESIZEUCURSOR\"\>"},
          {"\<\"Frame`SOMEBITS\"\>"},
          {"\<\"FrameStyle\"\>"},
          {"\<\"Frame`SURESIZEUCURSOR\"\>"},
          {"\<\"Frame`SWURESIZEUCURSOR\"\>"},
          {"\<\"Frame`TEXTUCURSOR\"\>"},
          {"\<\"FrameTicks\"\>"},
          {"\<\"Frame`TOPUALIGNMENT\"\>"},
          {"\<\"Frame`WAITUCURSOR\"\>"},
          {"\<\"Frame`WIDTH\"\>"},
          {"\<\"Frame`WURESIZEUCURSOR\"\>"},
          {"\<\"FreeQ\"\>"},
          {"\<\"FresnelC\"\>"},
          {"\<\"FresnelS\"\>"},
          {"\<\"FromCharacterCode\"\>"},
          {"\<\"FromContinuedFraction\"\>"},
          {"\<\"FromDate\"\>"},
          {"\<\"FromDigits\"\>"},
          {"\<\"FrontEnd`AbsoluteOptions\"\>"},
          {"\<\"FrontEnd`ButtonNotebook\"\>"},
          {"\<\"FrontEnd`CellPrint\"\>"},
          {"\<\"FrontEnd`ClipboardNotebook\"\>"},
          {"\<\"FrontEnd`CompletionsListPacket\"\>"},
          {"\<\"FrontEnd`ConsoleMessagePacket\"\>"},
          {"\<\"FrontEnd`CopyAsMathML\"\>"},
          {"\<\"FrontEnd`DefaultFormatTypeForStyle\"\>"},
          {"\<\"FrontEnd`DoHTMLMathMLSave\"\>"},
          {"\<\"FrontEnd`DoHTMLSave\"\>"},
          {"\<\"FrontEnd`DoNotebookMLMathMLSave\"\>"},
          {"\<\"FrontEnd`DoNotebookMLSave\"\>"},
          {"\<\"FrontEnd`DotechexplorerSave\"\>"},
          {"\<\"FrontEnd`DoTeXSave\"\>"},
          {"\<\"FrontEnd`EvaluationNotebook\"\>"},
          {"\<\"FrontEndExecute\"\>"},
          {"\<\"FrontEnd`FEDisableConsolePrintPacket\"\>"},
          {"\<\"FrontEnd`FEEnableConsolePrintPacket\"\>"},
          {"\<\"FrontEnd`FileBrowse\"\>"},
          {"\<\"FrontEnd`FileName\"\>"},
          {"\<\"FrontEnd`FrontEndExecute\"\>"},
          {"\<\"FrontEnd`FrontEndToken\"\>"},
          {"\<\"FrontEnd`FullOptions\"\>"},
          {"\<\"FrontEnd`GenerateBitmapCaches\"\>"},
          {"\<\"FrontEnd`HelpBrowserLookup\"\>"},
          {"\<\"FrontEnd`HelpBrowserNotebook\"\>"},
          {"\<\"FrontEnd`InputNotebook\"\>"},
          {"\<\"FrontEnd`InputToInputForm\"\>"},
          {"\<\"FrontEnd`InputToStandardForm\"\>"},
          {"\<\"FrontEnd`Interactive\"\>"},
          {"\<\"FrontEndLink\"\>"},
          {"\<\"FrontEnd`MessagesNotebook\"\>"},
          {"\<\"FrontEnd`MessagesToConsole\"\>"},
          {"\<\"FrontEnd`NeedCurrentFrontEndPackagePacket\"\>"},
          {"\<\"FrontEnd`NotebookApply\"\>"},
          {"\<\"FrontEnd`NotebookClose\"\>"},
          {"\<\"FrontEnd`NotebookConvert\"\>"},
          {"\<\"FrontEnd`NotebookCreateReturnObject\"\>"},
          {"\<\"FrontEnd`NotebookDelete\"\>"},
          {"\<\"FrontEnd`NotebookFindReturnObject\"\>"},
          {"\<\"FrontEnd`NotebookGet\"\>"},
          {"\<\"FrontEnd`NotebookInformation\"\>"},
          {"\<\"FrontEnd`NotebookLocate\"\>"},
          {"\<\"FrontEnd`NotebookObject\"\>"},
          {"\<\"FrontEnd`NotebookOpenReturnObject\"\>"},
          {"\<\"FrontEnd`NotebookPrint\"\>"},
          {"\<\"FrontEnd`NotebookPut\"\>"},
          {"\<\"FrontEnd`NotebookPutReturnObject\"\>"},
          {"\<\"FrontEnd`NotebookRead\"\>"},
          {"\<\"FrontEnd`Notebooks\"\>"},
          {"\<\"FrontEnd`NotebookSave\"\>"},
          {"\<\"FrontEnd`NotebookWrite\"\>"},
          {"\<\"FrontEndObject\"\>"},
          {"\<\"FrontEnd`Options\"\>"},
          {"\<\"FrontEnd`OutputToOutputForm\"\>"},
          {"\<\"FrontEnd`OutputToStandardForm\"\>"},
          {"\<\"FrontEnd`PreserveStyleSheet\"\>"},
          {"\<\"FrontEnd`ReturnInputFormPacket\"\>"},
          {"\<\"FrontEnd`SelectedNotebook\"\>"},
          {"\<\"FrontEnd`SelectionAnimate\"\>"},
          {"\<\"FrontEnd`SelectionCreateCell\"\>"},
          {"\<\"FrontEnd`SelectionEvaluate\"\>"},
          {"\<\"FrontEnd`SelectionEvaluateCreateCell\"\>"},
          {"\<\"FrontEnd`SelectionMove\"\>"},
          {"\<\"FrontEnd`SetBoxFormNamesPacket\"\>"},
          {"\<\"FrontEnd`SetOptions\"\>"},
          {"\<\"FrontEnd`SetSelectedNotebook\"\>"},
          {"\<\"FrontEndSharedQ\"\>"},
          {"\<\"FrontEndStackSize\"\>"},
          {"\<\"FrontEnd`ToFileName\"\>"},
          {"\<\"FrontEndToken\"\>"},
          {"\<\"FrontEndTokenExecute\"\>"},
          {"\<\"FrontEnd`UpdateDynamicObjects\"\>"},
          {"\<\"FrontEnd`Value\"\>"},
          {"\<\"FrontEndVersion\"\>"},
          {"\<\"Full\"\>"},
          {"\<\"FullAxes\"\>"},
          {"\<\"FullDefinition\"\>"},
          {"\<\"FullForm\"\>"},
          {"\<\"FullGraphics\"\>"},
          {"\<\"FullOptions\"\>"},
          {"\<\"FullSimplify\"\>"},
          {"\<\"Function\"\>"},
          {"\<\"FunctionExpand\"\>"},
          {"\<\"FunctionInterpolation\"\>"},
          {"\<\"g\"\>"},
          {"\<\"Gamma\"\>"},
          {"\<\"GammaRegularized\"\>"},
          {"\<\"GaussianIntegers\"\>"},
          {"\<\"GaussKronrod\"\>"},
          {"\<\"GaussPoints\"\>"},
          {"\<\"gc\"\>"},
          {"\<\"GCD\"\>"},
          {"\<\"GegenbauerC\"\>"},
          {"\<\"General\"\>"},
          {"\<\"GenerateBitmapCaches\"\>"},
          {"\<\"GenerateConditions\"\>"},
          {"\<\"GeneratedCell\"\>"},
          {"\<\"GeneratedParameters\"\>"},
          {"\<\"Generic\"\>"},
          {"\<\"Get\"\>"},
          {"\<\"GetBoundingBoxSizePacket\"\>"},
          {"\<\"GetClass\"\>"},
          {"\<\"GetClassPath\"\>"},
          {"\<\"getClickCount\"\>"},
          {"\<\"GetComplexClass\"\>"},
          {"\<\"getContentPane\"\>"},
          {"\<\"GetContext\"\>"},
          {"\<\"getenv\"\>"},
          {"\<\"GetFileName\"\>"},
          {"\<\"GetFrontEndOptionsDataPacket\"\>"},
          {"\<\"getGraphics\"\>"},
          {"\<\"GetJavaException\"\>"},
          {"\<\"GetLinebreakInformationPacket\"\>"},
          {"\<\"GetMenusPacket\"\>"},
          {"\<\"GetPageBreakInformationPacket\"\>"},
          {"\<\"getProperties\"\>"},
          {"\<\"getProperty\"\>"},
          {"\<\"getSecurityManager\"\>"},
          {"\<\"Glaisher\"\>"},
          {"\<\"GlobalPreferences\"\>"},
          {"\<\"GlobalSession\"\>"},
          {"\<\"GoldenRatio\"\>"},
          {"\<\"Goto\"\>"},
          {"\<\"Gradient\"\>"},
          {"\<\"Graphics\"\>"},
          {"\<\"Graphics3D\"\>"},
          {"\<\"GraphicsArray\"\>"},
          {"\<\"Graphics`Arrow`Private`a\"\>"},
          {"\<\"Graphics`Arrow`Private`args\"\>"},
          {"\<\"Graphics`Arrow`Private`arrow\"\>"},
          {"\<\"Graphics`Arrow`Private`arrowscale\"\>"},
          {"\<\"Graphics`Arrow`Private`b\"\>"},
          {"\<\"Graphics`Arrow`Private`beg\"\>"},
          {"\<\"Graphics`Arrow`Private`beg$\"\>"},
          {"\<\"Graphics`Arrow`Private`buildhead\"\>"},
          {"\<\"Graphics`Arrow`Private`buildzero\"\>"},
          {"\<\"Graphics`Arrow`Private`bx\"\>"},
          {"\<\"Graphics`Arrow`Private`by\"\>"},
          {"\<\"Graphics`Arrow`Private`c\"\>"},
          {"\<\"Graphics`Arrow`Private`cent\"\>"},
          {"\<\"Graphics`Arrow`Private`cent$\"\>"},
          {"\<\"Graphics`Arrow`Private`end\"\>"},
          {"\<\"Graphics`Arrow`Private`end$\"\>"},
          {"\<\"Graphics`Arrow`Private`evalarrow\"\>"},
          {"\<\"Graphics`Arrow`Private`ex\"\>"},
          {"\<\"Graphics`Arrow`Private`ey\"\>"},
          {"\<\"Graphics`Arrow`Private`fromdescription\"\>"},
          {"\<\"Graphics`Arrow`Private`fromline\"\>"},
          {"\<\"Graphics`Arrow`Private`fromparams\"\>"},
          {"\<\"Graphics`Arrow`Private`frompoint\"\>"},
          {"\<\"Graphics`Arrow`Private`frompoly\"\>"},
          {"\<\"Graphics`Arrow`Private`fromsparams\"\>"},
          {"\<\"Graphics`Arrow`Private`g\"\>"},
          {"\<\"Graphics`Arrow`Private`garg\"\>"},
          {"\<\"Graphics`Arrow`Private`generatehead\"\>"},
          {"\<\"Graphics`Arrow`Private`generatezero\"\>"},
          {"\<\"Graphics`Arrow`Private`ghead\"\>"},
          {"\<\"Graphics`Arrow`Private`gopts\"\>"},
          {"\<\"Graphics`Arrow`Private`gr\"\>"},
          {"\<\"Graphics`Arrow`Private`grout\"\>"},
          {"\<\"Graphics`Arrow`Private`grout$\"\>"},
          {"\<\"Graphics`Arrow`Private`head\"\>"},
          {"\<\"Graphics`Arrow`Private`heads\"\>"},
          {"\<\"Graphics`Arrow`Private`head$\"\>"},
          {"\<\"Graphics`Arrow`Private`igarg\"\>"},
          {"\<\"Graphics`Arrow`Private`igopts\"\>"},
          {"\<\"Graphics`Arrow`Private`initial\"\>"},
          {"\<\"Graphics`Arrow`Private`initial$\"\>"},
          {"\<\"Graphics`Arrow`Private`l\"\>"},
          {"\<\"Graphics`Arrow`Private`len\"\>"},
          {"\<\"Graphics`Arrow`Private`len$\"\>"},
          {"\<\"Graphics`Arrow`Private`listtostring\"\>"},
          {"\<\"Graphics`Arrow`Private`mathtops\"\>"},
          {"\<\"Graphics`Arrow`Private`nbx\"\>"},
          {"\<\"Graphics`Arrow`Private`nbx$\"\>"},
          {"\<\"Graphics`Arrow`Private`nby\"\>"},
          {"\<\"Graphics`Arrow`Private`nby$\"\>"},
          {"\<\"Graphics`Arrow`Private`ncs\"\>"},
          {"\<\"Graphics`Arrow`Private`ncs$\"\>"},
          {"\<\"Graphics`Arrow`Private`nex\"\>"},
          {"\<\"Graphics`Arrow`Private`nex$\"\>"},
          {"\<\"Graphics`Arrow`Private`ney\"\>"},
          {"\<\"Graphics`Arrow`Private`ney$\"\>"},
          {"\<\"Graphics`Arrow`Private`nls\"\>"},
          {"\<\"Graphics`Arrow`Private`nls$\"\>"},
          {"\<\"Graphics`Arrow`Private`num\"\>"},
          {"\<\"Graphics`Arrow`Private`numberQ\"\>"},
          {"\<\"Graphics`Arrow`Private`numtostring\"\>"},
          {"\<\"Graphics`Arrow`Private`nws\"\>"},
          {"\<\"Graphics`Arrow`Private`nws$\"\>"},
          {"\<\"Graphics`Arrow`Private`oldgaopt\"\>"},
          {"\<\"Graphics`Arrow`Private`oldgaopts\"\>"},
          {"\<\"Graphics`Arrow`Private`oldgaopt$\"\>"},
          {"\<\"Graphics`Arrow`Private`oldgropts\"\>"},
          {"\<\"Graphics`Arrow`Private`oldgropts$\"\>"},
          {"\<\"Graphics`Arrow`Private`opts\"\>"},
          {"\<\"Graphics`Arrow`Private`p\"\>"},
          {"\<\"Graphics`Arrow`Private`pos\"\>"},
          {"\<\"Graphics`Arrow`Private`pos$\"\>"},
          {"\<\"Graphics`Arrow`Private`preparearrows\"\>"},
          {"\<\"Graphics`Arrow`Private`prolog\"\>"},
          {"\<\"Graphics`Arrow`Private`prolog$\"\>"},
          {"\<\"Graphics`Arrow`Private`pshead\"\>"},
          {"\<\"Graphics`Arrow`Private`pshead$\"\>"},
          {"\<\"Graphics`Arrow`Private`p$\"\>"},
          {"\<\"Graphics`Arrow`Private`rest\"\>"},
          {"\<\"Graphics`Arrow`Private`rotatesystem\"\>"},
          {"\<\"Graphics`Arrow`Private`routine\"\>"},
          {"\<\"Graphics`Arrow`Private`routine$\"\>"},
          {"\<\"Graphics`Arrow`Private`scale\"\>"},
          {"\<\"Graphics`Arrow`Private`scale$\"\>"},
          {"\<\"Graphics`Arrow`Private`str\"\>"},
          {"\<\"Graphics`Arrow`Private`stream\"\>"},
          {"\<\"Graphics`Arrow`Private`str$\"\>"},
          {"\<\"Graphics`Arrow`Private`t\"\>"},
          {"\<\"Graphics`Arrow`Private`tocoords\"\>"},
          {"\<\"Graphics`Arrow`Private`w\"\>"},
          {"\<\"Graphics`Arrow`Private`width\"\>"},
          {"\<\"Graphics`Arrow`Private`width$\"\>"},
          {"\<\"Graphics`Arrow`Private`ws\"\>"},
          {"\<\"Graphics`Arrow`Private`ws$\"\>"},
          {"\<\"Graphics`Arrow`Private`x\"\>"},
          {"\<\"Graphics`Arrow`Private`y\"\>"},
          {"\<\"Graphics`Arrow`Private`z\"\>"},
          {"\<\"Graphics`Arrow`Private`zero\"\>"},
          {"\<\"Graphics`Arrow`Private`zeros\"\>"},
          {"\<\"Graphics`Arrow`Private`zero$\"\>"},
          {"\<\"Graphics`Arrow`Private`zhead\"\>"},
          {"\<\"Graphics`Arrow`Private`zhead$\"\>"},
          {"\<\"Graphics`Arrow`Private`zscale\"\>"},
          {"\<\"Graphics`Arrow`Private`zscale$\"\>"},
          {"\<\"Graphics`Arrow`Private`$$HeadDescriptions\"\>"},
          {"\<\"Graphics`Arrow`Private`$$HeadRoutines\"\>"},
          {"\<\"Graphics`Arrow`Private`$$ZeroDescriptions\"\>"},
          {"\<\"Graphics`Arrow`Private`$$ZeroRoutines\"\>"},
          {"\<\"GraphicsData\"\>"},
          {"\<\"GraphicsGrouping\"\>"},
          {"\<\"Graphics`PlotMarkers\"\>"},
          {"\<\"GraphicsSpacing\"\>"},
          {"\<\"Gray\"\>"},
          {"\<\"GrayLevel\"\>"},
          {"\<\"Greater\"\>"},
          {"\<\"GreaterEqual\"\>"},
          {"\<\"Green\"\>"},
          {"\<\"Grid\"\>"},
          {"\<\"GridBaseline\"\>"},
          {"\<\"GridBox\"\>"},
          {"\<\"GridBoxOptions\"\>"},
          {"\<\"GridCreationSettings\"\>"},
          {"\<\"GridDefaultElement\"\>"},
          {"\<\"GridFrame\"\>"},
          {"\<\"GridFrameMargins\"\>"},
          {"\<\"GridLines\"\>"},
          {"\<\"GroebnerBasis\"\>"},
          {"\<\"GroebnerGCD`modPolynomialGCD\"\>"},
          {"\<\"GroebnerWalk`ConvertOnly\"\>"},
          {"\<\"GroebnerWalk`FirstConeSelectionStrategy\"\>"},
          {"\<\"GroebnerWalk`InitialMonomialOrder\"\>"},
          {"\<\"GroebnerWalk`MinimalGroebnerBasis\"\>"},
          {"\<\"GroebnerWalk`Perturbation\"\>"},
          {"\<\"GroebnerWalk`RestConesMethod\"\>"},
          {"\<\"GroebnerWalk`RestConesSelectionStrategy\"\>"},
          {"\<\"GroebnerWalk`TransformationMatrix\"\>"},
          {"\<\"GroupPageBreakWithin\"\>"},
          {"\<\"HarmonicNumber\"\>"},
          {"\<\"Hash\"\>"},
          {"\<\"HashTable\"\>"},
          {"\<\"Head\"\>"},
          {"\<\"HeadCenter\"\>"},
          {"\<\"HeadCompose\"\>"},
          {"\<\"HeadLength\"\>"},
          {"\<\"Heads\"\>"},
          {"\<\"HeadScaling\"\>"},
          {"\<\"HeadShape\"\>"},
          {"\<\"HeadWidth\"\>"},
          {"\<\"HeldPart\"\>"},
          {"\<\"HelpBrowserLookup\"\>"},
          {"\<\"HelpBrowserNotebook\"\>"},
          {"\<\"HelpBrowserSettings\"\>"},
          {"\<\"HermiteH\"\>"},
          {"\<\"HessenbergDecomposition\"\>"},
          {"\<\"Hessian\"\>"},
          {"\<\"HiddenSurface\"\>"},
          {"\<\"Hold\"\>"},
          {"\<\"HoldAll\"\>"},
          {"\<\"HoldAllComplete\"\>"},
          {"\<\"HoldComplete\"\>"},
          {"\<\"HoldFirst\"\>"},
          {"\<\"HoldForm\"\>"},
          {"\<\"HoldPattern\"\>"},
          {"\<\"HoldRest\"\>"},
          {"\<\"HomeDirectory\"\>"},
          {"\<\"Horizontal\"\>"},
          {"\<\"HorizontalForm\"\>"},
          {"\<\"HorizontalScrollPosition\"\>"},
          {"\<\"HTMLSave\"\>"},
          {"\<\"Hue\"\>"},
          {"\<\"Hypergeometric0F1\"\>"},
          {"\<\"Hypergeometric0F1Regularized\"\>"},
          {"\<\"Hypergeometric1F1\"\>"},
          {"\<\"Hypergeometric1F1Regularized\"\>"},
          {"\<\"Hypergeometric2F1\"\>"},
          {"\<\"Hypergeometric2F1Regularized\"\>"},
          {"\<\"HypergeometricLogDump`HypergeometricPFQMa\"\>"},
          {"\<\"HypergeometricLogDump`MeijerGAMain\"\>"},
          {"\<\"HypergeometricPFQ\"\>"},
          {"\<\"HypergeometricPFQRegularized\"\>"},
          {"\<\"HypergeometricU\"\>"},
          {"\<\"HyperlinkCreationSettings\"\>"},
          {"\<\"Hyphenation\"\>"},
          {"\<\"HyphenationOptions\"\>"},
          {"\<\"i\"\>"},
          {"\<\"I\"\>"},
          {"\<\"id\"\>"},
          {"\<\"Identity\"\>"},
          {"\<\"identityHashCode\"\>"},
          {"\<\"IdentityMatrix\"\>"},
          {"\<\"id$\"\>"},
          {"\<\"If\"\>"},
          {"\<\"IgnoreCase\"\>"},
          {"\<\"Im\"\>"},
          {"\<\"ImageCache\"\>"},
          {"\<\"ImageCacheValid\"\>"},
          {"\<\"ImageMargins\"\>"},
          {"\<\"ImageOffset\"\>"},
          {"\<\"ImageRangeCache\"\>"},
          {"\<\"ImageRegion\"\>"},
          {"\<\"ImageResolution\"\>"},
          {"\<\"ImageRotated\"\>"},
          {"\<\"Image`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"Image`SCALEUDEFAULT\"\>"},
          {"\<\"Image`SCALEUFAST\"\>"},
          {"\<\"Image`SCALEUREPLICATE\"\>"},
          {"\<\"Image`SCALEUSMOOTH\"\>"},
          {"\<\"ImageSize\"\>"},
          {"\<\"Image`UndefinedProperty\"\>"},
          {"\<\"ImplementJavaInterface\"\>"},
          {"\<\"Implies\"\>"},
          {"\<\"Import\"\>"},
          {"\<\"ImportAutoReplacements\"\>"},
          {"\<\"ImportString\"\>"},
          {"\<\"in\"\>"},
          {"\<\"In\"\>"},
          {"\<\"IncludeFileExtension\"\>"},
          {"\<\"IncludeSingularTerm\"\>"},
          {"\<\"Increment\"\>"},
          {"\<\"Indent\"\>"},
          {"\<\"IndentingNewlineSpacings\"\>"},
          {"\<\"IndentMaxFraction\"\>"},
          {"\<\"Indeterminate\"\>"},
          {"\<\"IndexCreationOptions\"\>"},
          {"\<\"Inequality\"\>"},
          {"\<\"InexactNumberQ\"\>"},
          {"\<\"InexactNumbers\"\>"},
          {"\<\"Infinity\"\>"},
          {"\<\"Infix\"\>"},
          {"\<\"Information\"\>"},
          {"\<\"Inherited\"\>"},
          {"\<\"init\"\>"},
          {"\<\"InitializationCell\"\>"},
          {"\<\"InitializationCellEvaluation\"\>"},
          {"\<\"InitializationCellWarning\"\>"},
          {"\<\"InlineCounterAssignments\"\>"},
          {"\<\"InlineCounterIncrements\"\>"},
          {"\<\"InlineRules\"\>"},
          {"\<\"Inner\"\>"},
          {"\<\"Input\"\>"},
          {"\<\"InputAliases\"\>"},
          {"\<\"InputAutoFormat\"\>"},
          {"\<\"InputAutoReplacements\"\>"},
          {"\<\"InputEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"InputEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"InputEvent`ALTUDOWNUMASK\"\>"},
          {"\<\"InputEvent`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"InputEvent`ALTUGRAPHUMASK\"\>"},
          {"\<\"InputEvent`ALTUMASK\"\>"},
          {"\<\"InputEvent`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"InputEvent`BUTTON1UMASK\"\>"},
          {"\<\"InputEvent`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"InputEvent`BUTTON2UMASK\"\>"},
          {"\<\"InputEvent`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"InputEvent`BUTTON3UMASK\"\>"},
          {"\<\"InputEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"InputEvent`COMPONENTUFIRST\"\>"},
          {"\<\"InputEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"InputEvent`COMPONENTULAST\"\>"},
          {"\<\"InputEvent`COMPONENTUMOVED\"\>"},
          {"\<\"InputEvent`COMPONENTURESIZED\"\>"},
          {"\<\"InputEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"InputEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"InputEvent`CTRLUDOWNUMASK\"\>"},
          {"\<\"InputEvent`CTRLUMASK\"\>"},
          {"\<\"InputEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"InputEvent`getModifiersExText\"\>"},
          {"\<\"InputEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"InputEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"InputEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"InputEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"InputEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"InputEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"InputEvent`METAUDOWNUMASK\"\>"},
          {"\<\"InputEvent`METAUMASK\"\>"},
          {"\<\"InputEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"InputEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"InputEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"InputEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"InputEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"InputEvent`SHIFTUDOWNUMASK\"\>"},
          {"\<\"InputEvent`SHIFTUMASK\"\>"},
          {"\<\"InputEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"InputEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"InputEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"InputEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"InputForm\"\>"},
          {"\<\"InputGrouping\"\>"},
          {"\<\"InputNamePacket\"\>"},
          {"\<\"InputNotebook\"\>"},
          {"\<\"InputPacket\"\>"},
          {"\<\"InputSettings\"\>"},
          {"\<\"InputStream\"\>"},
          {"\<\"InputString\"\>"},
          {"\<\"InputStringPacket\"\>"},
          {"\<\"InputToBoxFormPacket\"\>"},
          {"\<\"InputToInputForm\"\>"},
          {"\<\"InputToStandardForm\"\>"},
          {"\<\"Insert\"\>"},
          {"\<\"InsertionPointObject\"\>"},
          {"\<\"Install\"\>"},
          {"\<\"InstallJava\"\>"},
          {"\<\"InstanceOf\"\>"},
          {"\<\"InString\"\>"},
          {"\<\"Integer\"\>"},
          {"\<\"IntegerDigits\"\>"},
          {"\<\"IntegerExponent\"\>"},
          {"\<\"IntegerPart\"\>"},
          {"\<\"IntegerQ\"\>"},
          {"\<\"Integers\"\>"},
          {"\<\"Integrate\"\>"},
          {"\<\"Integrate`A\"\>"},
          {"\<\"Integrate`aaaaa\"\>"},
          {"\<\"Integrate`APART\"\>"},
          {"\<\"Integrate`ApartList\"\>"},
          {"\<\"Integrate`APARTLIST\"\>"},
          {"\<\"Integrate`C\"\>"},
          {"\<\"Integrate`ccccc\"\>"},
          {"\<\"Integrate`ConstRules\"\>"},
          {"\<\"Integrate`Consts\"\>"},
          {"\<\"Integrate`DebugAlgebraics\"\>"},
          {"\<\"Integrate`Definite\"\>"},
          {"\<\"Integrate`Degenerate\"\>"},
          {"\<\"Integrate`DENOMINATOR\"\>"},
          {"\<\"Integrate`Deps\"\>"},
          {"\<\"Integrate`Elliptic`Elliptic\"\>"},
          {"\<\"Integrate`EXPAND\"\>"},
          {"\<\"Integrate`ExpandHold\"\>"},
          {"\<\"Integrate`FACTOR\"\>"},
          {"\<\"Integrate`FACTORLIST\"\>"},
          {"\<\"Integrate`FACTORSQUAREFREE\"\>"},
          {"\<\"Integrate`FACTORSQUAREFREELIST\"\>"},
          {"\<\"Integrate`FACTORTERMS\"\>"},
          {"\<\"Integrate`FACTORTERMSLIST\"\>"},
          {"\<\"Integrate`Fail\"\>"},
          {"\<\"Integrate`H\"\>"},
          {"\<\"Integrate`hideConstants\"\>"},
          {"\<\"Integrate`INPUTEXPR\"\>"},
          {"\<\"Integrate`IntegrateAlgebraic\"\>"},
          {"\<\"Integrate`IntegrateG\"\>"},
          {"\<\"Integrate`IntegrateM\"\>"},
          {"\<\"Integrate`INTERNAL\"\>"},
          {"\<\"Integrate`K\"\>"},
          {"\<\"Integrate`LINEARSOLVE\"\>"},
          {"\<\"Integrate`LogRules\"\>"},
          {"\<\"Integrate`Logs\"\>"},
          {"\<\"Integrate`NLtheorem\"\>"},
          {"\<\"Integrate`nnnnn\"\>"},
          {"\<\"Integrate`NUMERATOR\"\>"},
          {"\<\"Integrate`OAlist\"\>"},
          {"\<\"Integrate`Overdetermined\"\>"},
          {"\<\"Integrate`P\"\>"},
          {"\<\"Integrate`PolylogIntegrals\"\>"},
          {"\<\"Integrate`POLYNOMIALGCD\"\>"},
          {"\<\"Integrate`POLYNOMIALLCM\"\>"},
          {"\<\"Integrate`PolyQ\"\>"},
          {"\<\"Integrate`Powers\"\>"},
          {"\<\"Integrate`PPlus\"\>"},
          {"\<\"Integrate`PPlusVector\"\>"},
          {"\<\"Integrate`PPower\"\>"},
          {"\<\"Integrate`PQuotient\"\>"},
          {"\<\"Integrate`Primitives\"\>"},
          {"\<\"Integrate`PTimes\"\>"},
          {"\<\"Integrate`PTimesConstant\"\>"},
          {"\<\"Integrate`PurePlus\"\>"},
          {"\<\"Integrate`PurePower\"\>"},
          {"\<\"Integrate`PureTimes\"\>"},
          {"\<\"Integrate`PVector\"\>"},
          {"\<\"Integrate`QuickLookUp\"\>"},
          {"\<\"Integrate`Radicals\"\>"},
          {"\<\"Integrate`ResetElemNoCC\"\>"},
          {"\<\"Integrate`RESULTANT\"\>"},
          {"\<\"Integrate`ResultantAlpha\"\>"},
          {"\<\"Integrate`S\"\>"},
          {"\<\"Integrate`Singular\"\>"},
          {"\<\"Integrate`SPIN\"\>"},
          {"\<\"Integrate`SPINQ\"\>"},
          {"\<\"Integrate`StructureAlist\"\>"},
          {"\<\"Integrate`StructureStack\"\>"},
          {"\<\"Integrate`TableLookUp\"\>"},
          {"\<\"Integrate`TAR\"\>"},
          {"\<\"Integrate`Thetas\"\>"},
          {"\<\"Integrate`TOGETHER\"\>"},
          {"\<\"Integrate`Tokens\"\>"},
          {"\<\"Integrate`TrigRules\"\>"},
          {"\<\"Integrate`TrivialLogs\"\>"},
          {"\<\"Integrate`TrivialPowers\"\>"},
          {"\<\"Integrate`U\"\>"},
          {"\<\"Integrate`Undefineds\"\>"},
          {"\<\"Integrate`Underdetermined\"\>"},
          {"\<\"Integrate`V\"\>"},
          {"\<\"Integrate`VARIABLES\"\>"},
          {"\<\"Integrate`Y\"\>"},
          {"\<\"Integrate`yyyyy\"\>"},
          {"\<\"Integrate`Z\"\>"},
          {"\<\"Integrate`ZDefs\"\>"},
          {"\<\"Integrate`ZE\"\>"},
          {"\<\"Integrate`ZNest\"\>"},
          {"\<\"Integrate`ZOne\"\>"},
          {"\<\"Integrate`ZPi\"\>"},
          {"\<\"Integrate`ZRanks\"\>"},
          {"\<\"Integrate`ZX\"\>"},
          {"\<\"Integrate`$Algebraic\"\>"},
          {"\<\"Integrate`$Algebraics\"\>"},
          {"\<\"Integrate`$ArcTan2\"\>"},
          {"\<\"Integrate`$Circ\"\>"},
          {"\<\"Integrate`$CRoot\"\>"},
          {"\<\"Integrate`$D\"\>"},
          {"\<\"Integrate`$E\"\>"},
          {"\<\"Integrate`$Hyper\"\>"},
          {"\<\"Integrate`$I\"\>"},
          {"\<\"Integrate`$Im\"\>"},
          {"\<\"Integrate`$Log\"\>"},
          {"\<\"Integrate`$Power\"\>"},
          {"\<\"Integrate`$Primitive\"\>"},
          {"\<\"Integrate`$PRoot\"\>"},
          {"\<\"Integrate`$Pure\"\>"},
          {"\<\"Integrate`$Radical\"\>"},
          {"\<\"Integrate`$Re\"\>"},
          {"\<\"Integrate`$Special\"\>"},
          {"\<\"Integrate`$Token\"\>"},
          {"\<\"Integrate`$Transcendental\"\>"},
          {"\<\"Integrate`$$a\"\>"},
          {"\<\"Integrate`$$b\"\>"},
          {"\<\"Integrate`$$c\"\>"},
          {"\<\"Integrate`$$u\"\>"},
          {"\<\"Interactive\"\>"},
          {"\<\"Interlaced\"\>"},
          {"\<\"Internal`AddHandler\"\>"},
          {"\<\"Internal`AddPeriodical\"\>"},
          {"\<\"Internal`AlgebraDimension\"\>"},
          {"\<\"Internal`AllSymbols\"\>"},
          {"\<\"Internal`AllUnheldSymbols\"\>"},
          {"\<\"Internal`Bag\"\>"},
          {"\<\"Internal`BagPart\"\>"},
          {"\<\"Internal`BlockFlatten\"\>"},
          {"\<\"Internal`CacheConstants\"\>"},
          {"\<\"Internal`CheckCache\"\>"},
          {"\<\"Internal`CheckSolutions\"\>"},
          {"\<\"Internal`ColorRules\"\>"},
          {"\<\"Internal`CompareNumeric\"\>"},
          {"\<\"Internal`CompareToPAT\"\>"},
          {"\<\"Internal`CompileError\"\>"},
          {"\<\"Internal`CompileInline\"\>"},
          {"\<\"Internal`CompileOnDemand\"\>"},
          {"\<\"Internal`CompileValues\"\>"},
          {"\<\"Internal`ConvertFormTest\"\>"},
          {"\<\"Internal`CubeRootModList\"\>"},
          {"\<\"Internal`CubeRootOfUnity\"\>"},
          {"\<\"Internal`CubicResidueQ\"\>"},
          {"\<\"Internal`CubicSwitch\"\>"},
          {"\<\"Internal`DeactivateMessages\"\>"},
          {"\<\"Internal`DeleteCache\"\>"},
          {"\<\"Internal`DeleteTrailingZeros\"\>"},
          {"\<\"Internal`DenseToSparse\"\>"},
          {"\<\"Internal`DependsOnQ\"\>"},
          {"\<\"Internal`DirectPartitionsP\"\>"},
          {"\<\"Internal`DirectPartitionsQ\"\>"},
          {"\<\"Internal`DisplayFormTest\"\>"},
          {"\<\"Internal`DistributedTermsList\"\>"},
          {"\<\"Internal`DynamicEvaluate\"\>"},
          {"\<\"Internal`EffectivePrecision\"\>"},
          {"\<\"Internal`EmbeddedSymbols\"\>"},
          {"\<\"Internal`EncodeCharacters\"\>"},
          {"\<\"Internal`Escape\"\>"},
          {"\<\"Internal`ExactQuotient\"\>"},
          {"\<\"Internal`ExtendedGCDLG\"\>"},
          {"\<\"Internal`ExtendedGCDLI\"\>"},
          {"\<\"Internal`ExtendedGCDSG\"\>"},
          {"\<\"Internal`ExtendedGCDSI\"\>"},
          {"\<\"Internal`ExtraExtendedGCD\"\>"},
          {"\<\"Internal`FIECM\"\>"},
          {"\<\"Internal`FindDivisions\"\>"},
          {"\<\"Internal`FindOneRoot\"\>"},
          {"\<\"Internal`FromCoefficientList\"\>"},
          {"\<\"Internal`FromContinuedFraction\"\>"},
          {"\<\"Internal`FromDistributedTermsList\"\>"},
          {"\<\"Internal`FromNestedTermsList\"\>"},
          {"\<\"Internal`FromPiecewise\"\>"},
          {"\<\"Internal`FundamentalDiscriminantQ\"\>"},
          {"\<\"Internal`GCDLG\"\>"},
          {"\<\"Internal`GCDLI\"\>"},
          {"\<\"Internal`GCDSG\"\>"},
          {"\<\"Internal`GCDSI\"\>"},
          {"\<\"Internal`GetPendingTrackChanges\"\>"},
          {"\<\"Internal`GetRefreshers\"\>"},
          {"\<\"Internal`GetTrackChanges\"\>"},
          {"\<\"Internal`GetTrackedIDs\"\>"},
          {"\<\"Internal`GetTrackedSymbols\"\>"},
          {"\<\"Internal`GroebnerWalk\"\>"},
          {"\<\"Internal`HandlerBlock\"\>"},
          {"\<\"Internal`Handlers\"\>"},
          {"\<\"Internal`HarmonicNumber\"\>"},
          {"\<\"Internal`HashSameQ\"\>"},
          {"\<\"Internal`HelpBrowserHyperlinkText\"\>"},
          {"\<\"Internal`HGCD\"\>"},
          {"\<\"Internal`HoldUntil\"\>"},
          {"\<\"Internal`HornerEvaluate\"\>"},
          {"\<\"Internal`InequalitySolverOptions\"\>"},
          {"\<\"Internal`InheritedBlock\"\>"},
          {"\<\"Internal`InnermostToOutermost\"\>"},
          {"\<\"Internal`IntegerPartitionQ\"\>"},
          {"\<\"Internal`IntegerPartitions\"\>"},
          {"\<\"Internal`IteratorFloor\"\>"},
          {"\<\"Internal`LeastQuadraticNonresidue\"\>"},
          {"\<\"Internal`LejaOrder\"\>"},
          {"\<\"Internal`LinearQ\"\>"},
          {"\<\"Internal`LiteralPresentQ\"\>"},
          {"\<\"Internal`LoadEncodingFile\"\>"},
          {"\<\"Internal`MakePolynomial\"\>"},
          {"\<\"Internal`MakeRat\"\>"},
          {"\<\"Internal`MaxAbs\"\>"},
          {"\<\"Internal`MessageButtonHandler\"\>"},
          {"\<\"Internal`MultivariateResultant\"\>"},
          {"\<\"Internal`NestedTermsList\"\>"},
          {"\<\"Internal`NextIntegerPartition\"\>"},
          {"\<\"Internal`NumericContinuedFraction\"\>"},
          {"\<\"Internal`OutermostToInnermost\"\>"},
          {"\<\"Internal`P2\"\>"},
          {"\<\"Internal`PerfectPower\"\>"},
          {"\<\"Internal`Periodicals\"\>"},
          {"\<\"Internal`PiecewiseOptions\"\>"},
          {"\<\"Internal`PiecewiseOrderless\"\>"},
          {"\<\"Internal`PolyGCDCacheHead\"\>"},
          {"\<\"Internal`PolynomialEvaluate\"\>"},
          {"\<\"Internal`PowerMatrix\"\>"},
          {"\<\"Internal`PowerMatrix1\"\>"},
          {"\<\"Internal`PowerMatrix2\"\>"},
          {"\<\"Internal`PreprocessEquations\"\>"},
          {"\<\"Internal`PreviousIntegerPartition\"\>"},
          {"\<\"Internal`PrintSwitchSettings\"\>"},
          {"\<\"Internal`ProcessEquations`CanonicalizeRecurrence\"\>"},
          {"\<\"Internal`ProcessEquations`CheckDependentVariables\"\>"},
          {"\<\"Internal`ProcessEquations`CheckListability\"\>"},
          {"\<\"Internal`ProcessEquations`Decouple\"\>"},
          {"\<\"Internal`ProcessEquations`DependentSubstitute\"\>"},
          {"\<\"Internal`ProcessEquations`DifferentialOrder\"\>"},
          {"\<\"Internal`ProcessEquations`FindDependentVariables\"\>"},
          {"\<\"Internal`ProcessEquations`FindJacobianDependency\"\>"},
          {"\<\"Internal`ProcessEquations`FirstOrderize\"\>"},
          {"\<\"Internal`ProcessEquations`FirstOrderizeRecurrence\"\>"},
          {"\<\"Internal`ProcessEquations`FirstOrderReplace\"\>"},
          {"\<\"Internal`ProcessEquations`GetArguments\"\>"},
          {"\<\"Internal`ProcessEquations`RecurrenceOrder\"\>"},
          {"\<\"Internal`ProcessEquations`SeparateEquations\"\>"},
          {"\<\"Internal`ProcessEquations`SimplifyDependent\"\>"},
          {"\<\"Internal`ProcessEquations`SubstituteDependentRules\"\>"},
          {"\<\"Internal`ProcessEquations`ToEquationList\"\>"},
          {"\<\"Internal`ProcessEquations`$SubstituteEvaluate\"\>"},
          {"\<\"Internal`ProcessEquations`$SubstituteIndex\"\>"},
          {"\<\"Internal`ProcessEquations`$SubstitutePattern\"\>"},
          {"\<\"Internal`PutInformation\"\>"},
          {"\<\"Internal`QuadraticFundamentalUnit\"\>"},
          {"\<\"Internal`QuadraticIrrationalQ\"\>"},
          {"\<\"Internal`QuadraticSieve\"\>"},
          {"\<\"Internal`QuarticSwitch\"\>"},
          {"\<\"Internal`QuotientMod\"\>"},
          {"\<\"Internal`RadicalMemberQ\"\>"},
          {"\<\"Internal`RasterGraphics\"\>"},
          {"\<\"Internal`RationalNoReduce\"\>"},
          {"\<\"Internal`RealContinuedFraction\"\>"},
          {"\<\"Internal`ReduceOptions\"\>"},
          {"\<\"Internal`RemoveHandler\"\>"},
          {"\<\"Internal`RemovePeriodical\"\>"},
          {"\<\"Internal`RepetitionFromMultiplicity\"\>"},
          {"\<\"Internal`RiemannR\"\>"},
          {"\<\"Internal`S1\"\>"},
          {"\<\"Internal`S2\"\>"},
          {"\<\"Internal`SetCache\"\>"},
          {"\<\"Internal`SetDivisorBound\"\>"},
          {"\<\"Internal`SetHGCDBound\"\>"},
          {"\<\"Internal`SetInequalitySolverOptions\"\>"},
          {"\<\"Internal`SetPiecewiseOptions\"\>"},
          {"\<\"Internal`SetPM1PrimeBound\"\>"},
          {"\<\"Internal`SetPowerMatrixBound\"\>"},
          {"\<\"Internal`SetProductBound\"\>"},
          {"\<\"Internal`SetProductBound2\"\>"},
          {"\<\"Internal`SetQuotientBound\"\>"},
          {"\<\"Internal`SetReduceOptions\"\>"},
          {"\<\"Internal`SetSimplificationOptions\"\>"},
          {"\<\"Internal`SetValueTrack\"\>"},
          {"\<\"Internal`SimplificationOptions\"\>"},
          {"\<\"Internal`SparseFactorModList\"\>"},
          {"\<\"Internal`SparseFactorModList2\"\>"},
          {"\<\"Internal`SparseToDense\"\>"},
          {"\<\"Internal`SpellingChecker\"\>"},
          {"\<\"Internal`SqrtMod\"\>"},
          {"\<\"Internal`SqrtModList\"\>"},
          {"\<\"Internal`SqrtModPrime\"\>"},
          {"\<\"Internal`StuffBag\"\>"},
          {"\<\"Internal`SwitchForm\"\>"},
          {"\<\"Internal`SymbolList\"\>"},
          {"\<\"Internal`TakePart\"\>"},
          {"\<\"Internal`TensorTypeQ\"\>"},
          {"\<\"Internal`ToPiecewise\"\>"},
          {"\<\"Internal`ToricGroebnerBasis\"\>"},
          {"\<\"Internal`TrackChangesPacket\"\>"},
          {"\<\"Internal`TrackExpression\"\>"},
          {"\<\"Internal`TrackExpressionNonStrict\"\>"},
          {"\<\"Internal`TransposeIntegerPartition\"\>"},
          {"\<\"Internal`TryLinearSolve\"\>"},
          {"\<\"Internal`TypeOf\"\>"},
          {"\<\"Internal`UnsignedBitNot\"\>"},
          {"\<\"Internal`ValueTrack\"\>"},
          {"\<\"Internal`WithLocalSettings\"\>"},
          {"\<\"Internal`$ContextMarks\"\>"},
          {"\<\"Internal`$ConvertForms\"\>"},
          {"\<\"Internal`$CreationID\"\>"},
          {"\<\"Internal`$FileCharacterEncoding\"\>"},
          {"\<\"Internal`$GlobalTime\"\>"},
          {"\<\"Internal`$PackageDependencies\"\>"},
          {"\<\"Internal`$ThisPeriodical\"\>"},
          {"\<\"InterpolatingFunction\"\>"},
          {"\<\"InterpolatingPolynomial\"\>"},
          {"\<\"Interpolation\"\>"},
          {"\<\"InterpolationOrder\"\>"},
          {"\<\"InterpolationPoints\"\>"},
          {"\<\"InterpolationPrecision\"\>"},
          {"\<\"InterpretationBox\"\>"},
          {"\<\"InterpretationBoxOptions\"\>"},
          {"\<\"InterpretTemplate\"\>"},
          {"\<\"Interrupt\"\>"},
          {"\<\"InterruptSettings\"\>"},
          {"\<\"Intersection\"\>"},
          {"\<\"Interval\"\>"},
          {"\<\"IntervalIntersection\"\>"},
          {"\<\"IntervalMemberQ\"\>"},
          {"\<\"IntervalUnion\"\>"},
          {"\<\"Inverse\"\>"},
          {"\<\"InverseBetaRegularized\"\>"},
          {"\<\"InverseEllipticNomeQ\"\>"},
          {"\<\"InverseErf\"\>"},
          {"\<\"InverseErfc\"\>"},
          {"\<\"InverseFourier\"\>"},
          {"\<\"InverseFourierCosTransform\"\>"},
          {"\<\"InverseFourierSinTransform\"\>"},
          {"\<\"InverseFourierTransform\"\>"},
          {"\<\"InverseFunction\"\>"},
          {"\<\"InverseFunctions\"\>"},
          {"\<\"InverseGammaRegularized\"\>"},
          {"\<\"InverseJacobiCD\"\>"},
          {"\<\"InverseJacobiCN\"\>"},
          {"\<\"InverseJacobiCS\"\>"},
          {"\<\"InverseJacobiDC\"\>"},
          {"\<\"InverseJacobiDN\"\>"},
          {"\<\"InverseJacobiDS\"\>"},
          {"\<\"InverseJacobiNC\"\>"},
          {"\<\"InverseJacobiND\"\>"},
          {"\<\"InverseJacobiNS\"\>"},
          {"\<\"InverseJacobiSC\"\>"},
          {"\<\"InverseJacobiSD\"\>"},
          {"\<\"InverseJacobiSN\"\>"},
          {"\<\"InverseLaplaceTransform\"\>"},
          {"\<\"InverseSeries\"\>"},
          {"\<\"InverseWeierstrassP\"\>"},
          {"\<\"InverseZTransform\"\>"},
          {"\<\"isMetaDown\"\>"},
          {"\<\"JacobiAmplitude\"\>"},
          {"\<\"Jacobian\"\>"},
          {"\<\"JacobiCD\"\>"},
          {"\<\"JacobiCN\"\>"},
          {"\<\"JacobiCS\"\>"},
          {"\<\"JacobiDC\"\>"},
          {"\<\"JacobiDN\"\>"},
          {"\<\"JacobiDS\"\>"},
          {"\<\"JacobiNC\"\>"},
          {"\<\"JacobiND\"\>"},
          {"\<\"JacobiNS\"\>"},
          {"\<\"JacobiP\"\>"},
          {"\<\"JacobiSC\"\>"},
          {"\<\"JacobiSD\"\>"},
          {"\<\"JacobiSN\"\>"},
          {"\<\"JacobiSymbol\"\>"},
          {"\<\"JacobiZeta\"\>"},
          {"\<\"Java\"\>"},
          {"\<\"java`awt`AWTEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`getID\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`paramString\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`setSource\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`toString\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`JPrivate`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`AWTEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`AWTEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`BorderLayout`AFTERULASTULINE\"\>"},
          {"\<\"java`awt`BorderLayout`AFTERULINEUENDS\"\>"},
          {"\<\"java`awt`BorderLayout`BEFOREUFIRSTULINE\"\>"},
          {"\<\"java`awt`BorderLayout`BEFOREULINEUBEGINS\"\>"},
          {"\<\"java`awt`BorderLayout`CENTER\"\>"},
          {"\<\"java`awt`BorderLayout`EAST\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`addLayoutComponent\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`AFTERULASTULINE\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`AFTERULINEUENDS\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`BEFOREUFIRSTULINE\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`BEFOREULINEUBEGINS\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`CENTER\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`EAST\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`getHgap\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`getLayoutAlignmentX\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`getLayoutAlignmentY\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`getVgap\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`invalidateLayout\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`layoutContainer\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`LINEUEND\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`LINEUSTART\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`maximumLayoutSize\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`minimumLayoutSize\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`NORTH\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`PAGEUEND\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`PAGEUSTART\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`preferredLayoutSize\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`removeLayoutComponent\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`setHgap\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`setVgap\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`SOUTH\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`toString\"\>"},
          {"\<\"java`awt`BorderLayout`JPrivate`WEST\"\>"},
          {"\<\"java`awt`BorderLayout`LINEUEND\"\>"},
          {"\<\"java`awt`BorderLayout`LINEUSTART\"\>"},
          {"\<\"java`awt`BorderLayout`NORTH\"\>"},
          {"\<\"java`awt`BorderLayout`PAGEUEND\"\>"},
          {"\<\"java`awt`BorderLayout`PAGEUSTART\"\>"},
          {"\<\"java`awt`BorderLayout`SOUTH\"\>"},
          {"\<\"java`awt`BorderLayout`WEST\"\>"},
          {"\<\"java`awt`Color`BITMASK\"\>"},
          {"\<\"java`awt`Color`black\"\>"},
          {"\<\"java`awt`Color`BLACK\"\>"},
          {"\<\"java`awt`Color`blue\"\>"},
          {"\<\"java`awt`Color`BLUE\"\>"},
          {"\<\"java`awt`Color`cyan\"\>"},
          {"\<\"java`awt`Color`CYAN\"\>"},
          {"\<\"java`awt`Color`darkGray\"\>"},
          {"\<\"java`awt`Color`DARKUGRAY\"\>"},
          {"\<\"java`awt`Color`decode\"\>"},
          {"\<\"java`awt`Color`getColor\"\>"},
          {"\<\"java`awt`Color`getHSBColor\"\>"},
          {"\<\"java`awt`Color`gray\"\>"},
          {"\<\"java`awt`Color`GRAY\"\>"},
          {"\<\"java`awt`Color`green\"\>"},
          {"\<\"java`awt`Color`GREEN\"\>"},
          {"\<\"java`awt`Color`HSBtoRGB\"\>"},
          {"\<\"java`awt`Color`JPrivate`BITMASK\"\>"},
          {"\<\"java`awt`Color`JPrivate`black\"\>"},
          {"\<\"java`awt`Color`JPrivate`BLACK\"\>"},
          {"\<\"java`awt`Color`JPrivate`blue\"\>"},
          {"\<\"java`awt`Color`JPrivate`BLUE\"\>"},
          {"\<\"java`awt`Color`JPrivate`brighter\"\>"},
          {"\<\"java`awt`Color`JPrivate`createContext\"\>"},
          {"\<\"java`awt`Color`JPrivate`cyan\"\>"},
          {"\<\"java`awt`Color`JPrivate`CYAN\"\>"},
          {"\<\"java`awt`Color`JPrivate`darker\"\>"},
          {"\<\"java`awt`Color`JPrivate`darkGray\"\>"},
          {"\<\"java`awt`Color`JPrivate`DARKUGRAY\"\>"},
          {"\<\"java`awt`Color`JPrivate`decode\"\>"},
          {"\<\"java`awt`Color`JPrivate`equals\"\>"},
          {"\<\"java`awt`Color`JPrivate`getAlpha\"\>"},
          {"\<\"java`awt`Color`JPrivate`getBlue\"\>"},
          {"\<\"java`awt`Color`JPrivate`getColor\"\>"},
          {"\<\"java`awt`Color`JPrivate`getColorComponents\"\>"},
          {"\<\"java`awt`Color`JPrivate`getColorSpace\"\>"},
          {"\<\"java`awt`Color`JPrivate`getComponents\"\>"},
          {"\<\"java`awt`Color`JPrivate`getGreen\"\>"},
          {"\<\"java`awt`Color`JPrivate`getHSBColor\"\>"},
          {"\<\"java`awt`Color`JPrivate`getRed\"\>"},
          {"\<\"java`awt`Color`JPrivate`getRGB\"\>"},
          {"\<\"java`awt`Color`JPrivate`getRGBColorComponents\"\>"},
          {"\<\"java`awt`Color`JPrivate`getRGBComponents\"\>"},
          {"\<\"java`awt`Color`JPrivate`getTransparency\"\>"},
          {"\<\"java`awt`Color`JPrivate`gray\"\>"},
          {"\<\"java`awt`Color`JPrivate`GRAY\"\>"},
          {"\<\"java`awt`Color`JPrivate`green\"\>"},
          {"\<\"java`awt`Color`JPrivate`GREEN\"\>"},
          {"\<\"java`awt`Color`JPrivate`hashCode\"\>"},
          {"\<\"java`awt`Color`JPrivate`HSBtoRGB\"\>"},
          {"\<\"java`awt`Color`JPrivate`lightGray\"\>"},
          {"\<\"java`awt`Color`JPrivate`LIGHTUGRAY\"\>"},
          {"\<\"java`awt`Color`JPrivate`magenta\"\>"},
          {"\<\"java`awt`Color`JPrivate`MAGENTA\"\>"},
          {"\<\"java`awt`Color`JPrivate`OPAQUE\"\>"},
          {"\<\"java`awt`Color`JPrivate`orange\"\>"},
          {"\<\"java`awt`Color`JPrivate`ORANGE\"\>"},
          {"\<\"java`awt`Color`JPrivate`pink\"\>"},
          {"\<\"java`awt`Color`JPrivate`PINK\"\>"},
          {"\<\"java`awt`Color`JPrivate`red\"\>"},
          {"\<\"java`awt`Color`JPrivate`RED\"\>"},
          {"\<\"java`awt`Color`JPrivate`RGBtoHSB\"\>"},
          {"\<\"java`awt`Color`JPrivate`toString\"\>"},
          {"\<\"java`awt`Color`JPrivate`TRANSLUCENT\"\>"},
          {"\<\"java`awt`Color`JPrivate`white\"\>"},
          {"\<\"java`awt`Color`JPrivate`WHITE\"\>"},
          {"\<\"java`awt`Color`JPrivate`yellow\"\>"},
          {"\<\"java`awt`Color`JPrivate`YELLOW\"\>"},
          {"\<\"java`awt`Color`lightGray\"\>"},
          {"\<\"java`awt`Color`LIGHTUGRAY\"\>"},
          {"\<\"java`awt`Color`magenta\"\>"},
          {"\<\"java`awt`Color`MAGENTA\"\>"},
          {"\<\"java`awt`Color`OPAQUE\"\>"},
          {"\<\"java`awt`Color`orange\"\>"},
          {"\<\"java`awt`Color`ORANGE\"\>"},
          {"\<\"java`awt`Color`pink\"\>"},
          {"\<\"java`awt`Color`PINK\"\>"},
          {"\<\"java`awt`Color`red\"\>"},
          {"\<\"java`awt`Color`RED\"\>"},
          {"\<\"java`awt`Color`RGBtoHSB\"\>"},
          {"\<\"java`awt`Color`TRANSLUCENT\"\>"},
          {"\<\"java`awt`Color`white\"\>"},
          {"\<\"java`awt`Color`WHITE\"\>"},
          {"\<\"java`awt`Color`yellow\"\>"},
          {"\<\"java`awt`Color`YELLOW\"\>"},
          {"\<\"java`awt`Component`ABORT\"\>"},
          {"\<\"java`awt`Component`ALLBITS\"\>"},
          {"\<\"java`awt`Component`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`ERROR\"\>"},
          {"\<\"java`awt`Component`FRAMEBITS\"\>"},
          {"\<\"java`awt`Component`HEIGHT\"\>"},
          {"\<\"java`awt`Component`JPrivate`ABORT\"\>"},
          {"\<\"java`awt`Component`JPrivate`action\"\>"},
          {"\<\"java`awt`Component`JPrivate`add\"\>"},
          {"\<\"java`awt`Component`JPrivate`addComponentListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addFocusListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addHierarchyBoundsListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addHierarchyListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addInputMethodListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addKeyListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addMouseListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addMouseMotionListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addMouseWheelListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`addNotify\"\>"},
          {"\<\"java`awt`Component`JPrivate`addPropertyChangeListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`ALLBITS\"\>"},
          {"\<\"java`awt`Component`JPrivate`applyComponentOrientation\"\>"},
          {"\<\"java`awt`Component`JPrivate`areFocusTraversalKeysSet\"\>"},
          {"\<\"java`awt`Component`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`JPrivate`bounds\"\>"},
          {"\<\"java`awt`Component`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`JPrivate`checkImage\"\>"},
          {"\<\"java`awt`Component`JPrivate`contains\"\>"},
          {"\<\"java`awt`Component`JPrivate`createImage\"\>"},
          {"\<\"java`awt`Component`JPrivate`createVolatileImage\"\>"},
          {"\<\"java`awt`Component`JPrivate`deliverEvent\"\>"},
          {"\<\"java`awt`Component`JPrivate`disable\"\>"},
          {"\<\"java`awt`Component`JPrivate`dispatchEvent\"\>"},
          {"\<\"java`awt`Component`JPrivate`doLayout\"\>"},
          {"\<\"java`awt`Component`JPrivate`enable\"\>"},
          {"\<\"java`awt`Component`JPrivate`enableInputMethods\"\>"},
          {"\<\"java`awt`Component`JPrivate`ERROR\"\>"},
          {"\<\"java`awt`Component`JPrivate`FRAMEBITS\"\>"},
          {"\<\"java`awt`Component`JPrivate`getAccessibleContext\"\>"},
          {"\<\"java`awt`Component`JPrivate`getAlignmentX\"\>"},
          {"\<\"java`awt`Component`JPrivate`getAlignmentY\"\>"},
          {"\<\"java`awt`Component`JPrivate`getBackground\"\>"},
          {"\<\"java`awt`Component`JPrivate`getBounds\"\>"},
          {"\<\"java`awt`Component`JPrivate`getColorModel\"\>"},
          {"\<\"java`awt`Component`JPrivate`getComponentAt\"\>"},
          {"\<\"java`awt`Component`JPrivate`getComponentListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getComponentOrientation\"\>"},
          {"\<\"java`awt`Component`JPrivate`getCursor\"\>"},
          {"\<\"java`awt`Component`JPrivate`getDropTarget\"\>"},
          {"\<\"java`awt`Component`JPrivate`getFocusCycleRootAncestor\"\>"},
          {"\<\"java`awt`Component`JPrivate`getFocusListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getFocusTraversalKeys\"\>"},
          {"\<\"java`awt`Component`JPrivate`getFocusTraversalKeysEnabled\"\>"}\
,
          {"\<\"java`awt`Component`JPrivate`getFont\"\>"},
          {"\<\"java`awt`Component`JPrivate`getFontMetrics\"\>"},
          {"\<\"java`awt`Component`JPrivate`getForeground\"\>"},
          {"\<\"java`awt`Component`JPrivate`getGraphics\"\>"},
          {"\<\"java`awt`Component`JPrivate`getGraphicsConfiguration\"\>"},
          {"\<\"java`awt`Component`JPrivate`getHeight\"\>"},
          {"\<\"java`awt`Component`JPrivate`getHierarchyBoundsListeners\"\>"},\

          {"\<\"java`awt`Component`JPrivate`getHierarchyListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getIgnoreRepaint\"\>"},
          {"\<\"java`awt`Component`JPrivate`getInputContext\"\>"},
          {"\<\"java`awt`Component`JPrivate`getInputMethodListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getInputMethodRequests\"\>"},
          {"\<\"java`awt`Component`JPrivate`getKeyListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getLocale\"\>"},
          {"\<\"java`awt`Component`JPrivate`getLocation\"\>"},
          {"\<\"java`awt`Component`JPrivate`getLocationOnScreen\"\>"},
          {"\<\"java`awt`Component`JPrivate`getMaximumSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`getMinimumSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`getMouseListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getMouseMotionListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getMouseWheelListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getName\"\>"},
          {"\<\"java`awt`Component`JPrivate`getParent\"\>"},
          {"\<\"java`awt`Component`JPrivate`getPeer\"\>"},
          {"\<\"java`awt`Component`JPrivate`getPreferredSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`getPropertyChangeListeners\"\>"},
          {"\<\"java`awt`Component`JPrivate`getSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`getToolkit\"\>"},
          {"\<\"java`awt`Component`JPrivate`getTreeLock\"\>"},
          {"\<\"java`awt`Component`JPrivate`getWidth\"\>"},
          {"\<\"java`awt`Component`JPrivate`getX\"\>"},
          {"\<\"java`awt`Component`JPrivate`getY\"\>"},
          {"\<\"java`awt`Component`JPrivate`gotFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`handleEvent\"\>"},
          {"\<\"java`awt`Component`JPrivate`hasFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`HEIGHT\"\>"},
          {"\<\"java`awt`Component`JPrivate`hide\"\>"},
          {"\<\"java`awt`Component`JPrivate`imageUpdate\"\>"},
          {"\<\"java`awt`Component`JPrivate`inside\"\>"},
          {"\<\"java`awt`Component`JPrivate`invalidate\"\>"},
          {"\<\"java`awt`Component`JPrivate`isBackgroundSet\"\>"},
          {"\<\"java`awt`Component`JPrivate`isCursorSet\"\>"},
          {"\<\"java`awt`Component`JPrivate`isDisplayable\"\>"},
          {"\<\"java`awt`Component`JPrivate`isDoubleBuffered\"\>"},
          {"\<\"java`awt`Component`JPrivate`isEnabled\"\>"},
          {"\<\"java`awt`Component`JPrivate`isFocusable\"\>"},
          {"\<\"java`awt`Component`JPrivate`isFocusCycleRoot\"\>"},
          {"\<\"java`awt`Component`JPrivate`isFocusOwner\"\>"},
          {"\<\"java`awt`Component`JPrivate`isFocusTraversable\"\>"},
          {"\<\"java`awt`Component`JPrivate`isFontSet\"\>"},
          {"\<\"java`awt`Component`JPrivate`isForegroundSet\"\>"},
          {"\<\"java`awt`Component`JPrivate`isLightweight\"\>"},
          {"\<\"java`awt`Component`JPrivate`isOpaque\"\>"},
          {"\<\"java`awt`Component`JPrivate`isShowing\"\>"},
          {"\<\"java`awt`Component`JPrivate`isValid\"\>"},
          {"\<\"java`awt`Component`JPrivate`isVisible\"\>"},
          {"\<\"java`awt`Component`JPrivate`keyDown\"\>"},
          {"\<\"java`awt`Component`JPrivate`keyUp\"\>"},
          {"\<\"java`awt`Component`JPrivate`layout\"\>"},
          {"\<\"java`awt`Component`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`JPrivate`list\"\>"},
          {"\<\"java`awt`Component`JPrivate`locate\"\>"},
          {"\<\"java`awt`Component`JPrivate`location\"\>"},
          {"\<\"java`awt`Component`JPrivate`lostFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`minimumSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseDown\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseDrag\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseEnter\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseExit\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseMove\"\>"},
          {"\<\"java`awt`Component`JPrivate`mouseUp\"\>"},
          {"\<\"java`awt`Component`JPrivate`move\"\>"},
          {"\<\"java`awt`Component`JPrivate`nextFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`paint\"\>"},
          {"\<\"java`awt`Component`JPrivate`paintAll\"\>"},
          {"\<\"java`awt`Component`JPrivate`postEvent\"\>"},
          {"\<\"java`awt`Component`JPrivate`preferredSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`prepareImage\"\>"},
          {"\<\"java`awt`Component`JPrivate`print\"\>"},
          {"\<\"java`awt`Component`JPrivate`printAll\"\>"},
          {"\<\"java`awt`Component`JPrivate`PROPERTIES\"\>"},
          {"\<\"java`awt`Component`JPrivate`remove\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeComponentListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeFocusListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeHierarchyBoundsListener\"\>\
"},
          {"\<\"java`awt`Component`JPrivate`removeHierarchyListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeInputMethodListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeKeyListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeMouseListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeMouseMotionListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeMouseWheelListener\"\>"},
          {"\<\"java`awt`Component`JPrivate`removeNotify\"\>"},
          {"\<\"java`awt`Component`JPrivate`removePropertyChangeListener\"\>"}\
,
          {"\<\"java`awt`Component`JPrivate`repaint\"\>"},
          {"\<\"java`awt`Component`JPrivate`requestFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`requestFocusInWindow\"\>"},
          {"\<\"java`awt`Component`JPrivate`reshape\"\>"},
          {"\<\"java`awt`Component`JPrivate`resize\"\>"},
          {"\<\"java`awt`Component`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`JPrivate`setBackground\"\>"},
          {"\<\"java`awt`Component`JPrivate`setBounds\"\>"},
          {"\<\"java`awt`Component`JPrivate`setComponentOrientation\"\>"},
          {"\<\"java`awt`Component`JPrivate`setCursor\"\>"},
          {"\<\"java`awt`Component`JPrivate`setDropTarget\"\>"},
          {"\<\"java`awt`Component`JPrivate`setEnabled\"\>"},
          {"\<\"java`awt`Component`JPrivate`setFocusable\"\>"},
          {"\<\"java`awt`Component`JPrivate`setFocusTraversalKeys\"\>"},
          {"\<\"java`awt`Component`JPrivate`setFocusTraversalKeysEnabled\"\>"}\
,
          {"\<\"java`awt`Component`JPrivate`setFont\"\>"},
          {"\<\"java`awt`Component`JPrivate`setForeground\"\>"},
          {"\<\"java`awt`Component`JPrivate`setIgnoreRepaint\"\>"},
          {"\<\"java`awt`Component`JPrivate`setLocale\"\>"},
          {"\<\"java`awt`Component`JPrivate`setLocation\"\>"},
          {"\<\"java`awt`Component`JPrivate`setName\"\>"},
          {"\<\"java`awt`Component`JPrivate`setSize\"\>"},
          {"\<\"java`awt`Component`JPrivate`setVisible\"\>"},
          {"\<\"java`awt`Component`JPrivate`show\"\>"},
          {"\<\"java`awt`Component`JPrivate`size\"\>"},
          {"\<\"java`awt`Component`JPrivate`SOMEBITS\"\>"},
          {"\<\"java`awt`Component`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`JPrivate`toString\"\>"},
          {"\<\"java`awt`Component`JPrivate`transferFocus\"\>"},
          {"\<\"java`awt`Component`JPrivate`transferFocusBackward\"\>"},
          {"\<\"java`awt`Component`JPrivate`transferFocusUpCycle\"\>"},
          {"\<\"java`awt`Component`JPrivate`update\"\>"},
          {"\<\"java`awt`Component`JPrivate`validate\"\>"},
          {"\<\"java`awt`Component`JPrivate`WIDTH\"\>"},
          {"\<\"java`awt`Component`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`PROPERTIES\"\>"},
          {"\<\"java`awt`Component`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`SOMEBITS\"\>"},
          {"\<\"java`awt`Component`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Component`WIDTH\"\>"},
          {"\<\"java`awt`Container`ABORT\"\>"},
          {"\<\"java`awt`Container`ALLBITS\"\>"},
          {"\<\"java`awt`Container`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`ERROR\"\>"},
          {"\<\"java`awt`Container`FRAMEBITS\"\>"},
          {"\<\"java`awt`Container`HEIGHT\"\>"},
          {"\<\"java`awt`Container`JPrivate`ABORT\"\>"},
          {"\<\"java`awt`Container`JPrivate`add\"\>"},
          {"\<\"java`awt`Container`JPrivate`addContainerListener\"\>"},
          {"\<\"java`awt`Container`JPrivate`addMouseListener\"\>"},
          {"\<\"java`awt`Container`JPrivate`addNotify\"\>"},
          {"\<\"java`awt`Container`JPrivate`addPropertyChangeListener\"\>"},
          {"\<\"java`awt`Container`JPrivate`ALLBITS\"\>"},
          {"\<\"java`awt`Container`JPrivate`applyComponentOrientation\"\>"},
          {"\<\"java`awt`Container`JPrivate`areFocusTraversalKeysSet\"\>"},
          {"\<\"java`awt`Container`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`JPrivate`countComponents\"\>"},
          {"\<\"java`awt`Container`JPrivate`createImage\"\>"},
          {"\<\"java`awt`Container`JPrivate`deliverEvent\"\>"},
          {"\<\"java`awt`Container`JPrivate`doLayout\"\>"},
          {"\<\"java`awt`Container`JPrivate`ERROR\"\>"},
          {"\<\"java`awt`Container`JPrivate`findComponentAt\"\>"},
          {"\<\"java`awt`Container`JPrivate`FRAMEBITS\"\>"},
          {"\<\"java`awt`Container`JPrivate`getAlignmentX\"\>"},
          {"\<\"java`awt`Container`JPrivate`getAlignmentY\"\>"},
          {"\<\"java`awt`Container`JPrivate`getComponent\"\>"},
          {"\<\"java`awt`Container`JPrivate`getComponentAt\"\>"},
          {"\<\"java`awt`Container`JPrivate`getComponentCount\"\>"},
          {"\<\"java`awt`Container`JPrivate`getComponents\"\>"},
          {"\<\"java`awt`Container`JPrivate`getContainerListeners\"\>"},
          {"\<\"java`awt`Container`JPrivate`getFocusTraversalKeys\"\>"},
          {"\<\"java`awt`Container`JPrivate`getFocusTraversalPolicy\"\>"},
          {"\<\"java`awt`Container`JPrivate`getInsets\"\>"},
          {"\<\"java`awt`Container`JPrivate`getLayout\"\>"},
          {"\<\"java`awt`Container`JPrivate`getListeners\"\>"},
          {"\<\"java`awt`Container`JPrivate`getMaximumSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`getMinimumSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`getPreferredSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`HEIGHT\"\>"},
          {"\<\"java`awt`Container`JPrivate`insets\"\>"},
          {"\<\"java`awt`Container`JPrivate`invalidate\"\>"},
          {"\<\"java`awt`Container`JPrivate`isAncestorOf\"\>"},
          {"\<\"java`awt`Container`JPrivate`isFocusCycleRoot\"\>"},
          {"\<\"java`awt`Container`JPrivate`isFocusTraversalPolicySet\"\>"},
          {"\<\"java`awt`Container`JPrivate`layout\"\>"},
          {"\<\"java`awt`Container`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`JPrivate`list\"\>"},
          {"\<\"java`awt`Container`JPrivate`locate\"\>"},
          {"\<\"java`awt`Container`JPrivate`minimumSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`paint\"\>"},
          {"\<\"java`awt`Container`JPrivate`paintComponents\"\>"},
          {"\<\"java`awt`Container`JPrivate`preferredSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`print\"\>"},
          {"\<\"java`awt`Container`JPrivate`printComponents\"\>"},
          {"\<\"java`awt`Container`JPrivate`PROPERTIES\"\>"},
          {"\<\"java`awt`Container`JPrivate`remove\"\>"},
          {"\<\"java`awt`Container`JPrivate`removeAll\"\>"},
          {"\<\"java`awt`Container`JPrivate`removeContainerListener\"\>"},
          {"\<\"java`awt`Container`JPrivate`removeNotify\"\>"},
          {"\<\"java`awt`Container`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`JPrivate`setBounds\"\>"},
          {"\<\"java`awt`Container`JPrivate`setFocusCycleRoot\"\>"},
          {"\<\"java`awt`Container`JPrivate`setFocusTraversalKeys\"\>"},
          {"\<\"java`awt`Container`JPrivate`setFocusTraversalPolicy\"\>"},
          {"\<\"java`awt`Container`JPrivate`setFont\"\>"},
          {"\<\"java`awt`Container`JPrivate`setLayout\"\>"},
          {"\<\"java`awt`Container`JPrivate`setLocation\"\>"},
          {"\<\"java`awt`Container`JPrivate`setSize\"\>"},
          {"\<\"java`awt`Container`JPrivate`setVisible\"\>"},
          {"\<\"java`awt`Container`JPrivate`SOMEBITS\"\>"},
          {"\<\"java`awt`Container`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`JPrivate`transferFocusBackward\"\>"},
          {"\<\"java`awt`Container`JPrivate`transferFocusDownCycle\"\>"},
          {"\<\"java`awt`Container`JPrivate`update\"\>"},
          {"\<\"java`awt`Container`JPrivate`validate\"\>"},
          {"\<\"java`awt`Container`JPrivate`WIDTH\"\>"},
          {"\<\"java`awt`Container`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`PROPERTIES\"\>"},
          {"\<\"java`awt`Container`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`SOMEBITS\"\>"},
          {"\<\"java`awt`Container`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Container`WIDTH\"\>"},
          {"\<\"java`awt`event`AdjustmentListener`JPrivate`\
adjustmentValueChanged\"\>"},
          {"\<\"java`awt`event`ComponentEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTURESIZED\"\>"},
          {"\<\"java`awt`event`ComponentEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`ComponentEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`ComponentEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`ACTIONUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`ComponentEvent`JPrivate`ADJUSTMENTUEVENTUMASK\"\
\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTUEVENTUMASK\"\
\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTUHIDDEN\"\>"},\

          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTURESIZED\"\>"}\
,
          {"\<\"java`awt`event`ComponentEvent`JPrivate`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`CONTAINERUEVENTUMASK\"\
\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`FOCUSUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`ComponentEvent`JPrivate`getComponent\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`\
HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`HIERARCHYUEVENTUMASK\"\
\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`\
INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`INVOCATIONUEVENTUMASK\"\
\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`MOUSEUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`ComponentEvent`JPrivate`\
MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`MOUSEUWHEELUEVENTUMASK\
\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`PAINTUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`ComponentEvent`JPrivate`paramString\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`WINDOWUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`ComponentEvent`JPrivate`\
WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`JPrivate`\
WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`ComponentEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`ComponentEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ALTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ALTUGRAPHUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ALTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON1UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON2UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`BUTTON3UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTURESIZED\"\>"},
          {"\<\"java`awt`event`InputEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`InputEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`CTRLUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`CTRLUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`getModifiersExText\"\>"},
          {"\<\"java`awt`event`InputEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ADJUSTMENTUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`InputEvent`JPrivate`ALTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ALTUGRAPHUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ALTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON1UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON2UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`BUTTON3UMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTUHIDDEN\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTURESIZED\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`consume\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`CONTAINERUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`InputEvent`JPrivate`CTRLUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`CTRLUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`getModifiers\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`getModifiersEx\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`getModifiersExText\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`getWhen\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`\
HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`HIERARCHYUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`InputEvent`JPrivate`INPUTUMETHODUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`InputEvent`JPrivate`INVOCATIONUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`InputEvent`JPrivate`isAltDown\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`isAltGraphDown\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`isConsumed\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`isControlDown\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`isMetaDown\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`isShiftDown\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`METAUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`METAUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`InputEvent`JPrivate`MOUSEUWHEELUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`InputEvent`JPrivate`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`SHIFTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`SHIFTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`InputEvent`JPrivate`WINDOWUSTATEUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`InputEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`METAUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`METAUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`InputEvent`SHIFTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`SHIFTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`InputEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ALTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ALTUGRAPHUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ALTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON1\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON1UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON2\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON2UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON3\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`BUTTON3UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTURESIZED\"\>"},
          {"\<\"java`awt`event`MouseEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`MouseEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`CTRLUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`CTRLUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`getModifiersExText\"\>"},
          {"\<\"java`awt`event`MouseEvent`getMouseModifiersText\"\>"},
          {"\<\"java`awt`event`MouseEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ACTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ADJUSTMENTUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`MouseEvent`JPrivate`ALTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ALTUGRAPHUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ALTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON1\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON1UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON2\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON2UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON3\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`BUTTON3UMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTUFIRST\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTUHIDDEN\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTULAST\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTUMOVED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTURESIZED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`COMPONENTUSHOWN\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`CONTAINERUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`MouseEvent`JPrivate`CTRLUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`CTRLUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`FOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getButton\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getClickCount\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getModifiersExText\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getMouseModifiersText\"\>"}\
,
          {"\<\"java`awt`event`MouseEvent`JPrivate`getPoint\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getX\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`getY\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`\
HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`HIERARCHYUEVENTUMASK\"\>"},\

          {"\<\"java`awt`event`MouseEvent`JPrivate`INPUTUMETHODUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`INVOCATIONUEVENTUMASK\"\>"}\
,
          {"\<\"java`awt`event`MouseEvent`JPrivate`isMetaDown\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`isPopupTrigger\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`ITEMUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`METAUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`METAUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUCLICKED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUDRAGGED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUENTERED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUEXITED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUFIRST\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEULAST\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUMOVED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUPRESSED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEURELEASED\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUWHEEL\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`MOUSEUWHEELUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`NOBUTTON\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`paramString\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`SHIFTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`SHIFTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`translatePoint\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`MouseEvent`JPrivate`WINDOWUSTATEUEVENTUMASK\"\>\
"},
          {"\<\"java`awt`event`MouseEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`METAUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`METAUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUCLICKED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUDRAGGED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUENTERED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUEXITED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUFIRST\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEULAST\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUMOVED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUPRESSED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEURELEASED\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUWHEEL\"\>"},
          {"\<\"java`awt`event`MouseEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`NOBUTTON\"\>"},
          {"\<\"java`awt`event`MouseEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"java`awt`event`MouseEvent`SHIFTUDOWNUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`SHIFTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"java`awt`event`MouseEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"java`awt`Frame`ABORT\"\>"},
          {"\<\"java`awt`Frame`ALLBITS\"\>"},
          {"\<\"java`awt`Frame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"java`awt`Frame`DEFAULTUCURSOR\"\>"},
          {"\<\"java`awt`Frame`ERROR\"\>"},
          {"\<\"java`awt`Frame`EURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`FRAMEBITS\"\>"},
          {"\<\"java`awt`Frame`getFrames\"\>"},
          {"\<\"java`awt`Frame`HANDUCURSOR\"\>"},
          {"\<\"java`awt`Frame`HEIGHT\"\>"},
          {"\<\"java`awt`Frame`ICONIFIED\"\>"},
          {"\<\"java`awt`Frame`JPrivate`ABORT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`addNotify\"\>"},
          {"\<\"java`awt`Frame`JPrivate`ALLBITS\"\>"},
          {"\<\"java`awt`Frame`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`CROSSHAIRUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`DEFAULTUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`ERROR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`EURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`FRAMEBITS\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getAccessibleContext\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getCursorType\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getExtendedState\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getFrames\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getIconImage\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getMaximizedBounds\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getMenuBar\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getState\"\>"},
          {"\<\"java`awt`Frame`JPrivate`getTitle\"\>"},
          {"\<\"java`awt`Frame`JPrivate`HANDUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`HEIGHT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`ICONIFIED\"\>"},
          {"\<\"java`awt`Frame`JPrivate`isResizable\"\>"},
          {"\<\"java`awt`Frame`JPrivate`isUndecorated\"\>"},
          {"\<\"java`awt`Frame`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`MAXIMIZEDUBOTH\"\>"},
          {"\<\"java`awt`Frame`JPrivate`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"java`awt`Frame`JPrivate`MAXIMIZEDUVERT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`MOVEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`NEURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`NORMAL\"\>"},
          {"\<\"java`awt`Frame`JPrivate`NURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`NWURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`PROPERTIES\"\>"},
          {"\<\"java`awt`Frame`JPrivate`remove\"\>"},
          {"\<\"java`awt`Frame`JPrivate`removeNotify\"\>"},
          {"\<\"java`awt`Frame`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setBounds\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setCursor\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setExtendedState\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setIconImage\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setLocation\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setMaximizedBounds\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setMenuBar\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setResizable\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setSize\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setState\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setTitle\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setUndecorated\"\>"},
          {"\<\"java`awt`Frame`JPrivate`setVisible\"\>"},
          {"\<\"java`awt`Frame`JPrivate`SEURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`SOMEBITS\"\>"},
          {"\<\"java`awt`Frame`JPrivate`SURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`SWURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`TEXTUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`JPrivate`WAITUCURSOR\"\>"},
          {"\<\"java`awt`Frame`JPrivate`WIDTH\"\>"},
          {"\<\"java`awt`Frame`JPrivate`WURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"java`awt`Frame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"java`awt`Frame`MAXIMIZEDUVERT\"\>"},
          {"\<\"java`awt`Frame`MOVEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`NEURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`NORMAL\"\>"},
          {"\<\"java`awt`Frame`NURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`NWURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`PROPERTIES\"\>"},
          {"\<\"java`awt`Frame`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`SEURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`SOMEBITS\"\>"},
          {"\<\"java`awt`Frame`SURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`SWURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Frame`TEXTUCURSOR\"\>"},
          {"\<\"java`awt`Frame`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Frame`WAITUCURSOR\"\>"},
          {"\<\"java`awt`Frame`WIDTH\"\>"},
          {"\<\"java`awt`Frame`WURESIZEUCURSOR\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`addRenderingHints\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`clip\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`draw\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`draw3DRect\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`drawGlyphVector\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`drawImage\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`drawRenderableImage\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`drawRenderedImage\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`drawString\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`fill\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`fill3DRect\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getBackground\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getComposite\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getDeviceConfiguration\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getFontRenderContext\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getPaint\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getRenderingHint\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getRenderingHints\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getStroke\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`getTransform\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`hit\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`rotate\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`scale\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setBackground\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setComposite\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setPaint\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setRenderingHint\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setRenderingHints\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setStroke\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`setTransform\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`shear\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`transform\"\>"},
          {"\<\"java`awt`Graphics2D`JPrivate`translate\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`clearRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`clipRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`copyArea\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`create\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`dispose\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`draw3DRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawArc\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawBytes\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawChars\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawImage\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawLine\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawOval\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawPolygon\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawPolyline\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawRoundRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`drawString\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fill3DRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fillArc\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fillOval\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fillPolygon\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fillRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`fillRoundRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`finalize\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getClip\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getClipBounds\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getClipRect\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getColor\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getFont\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`getFontMetrics\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`hitClip\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`setClip\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`setColor\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`setFont\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`setPaintMode\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`setXORMode\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`toString\"\>"},
          {"\<\"java`awt`Graphics`JPrivate`translate\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`addTileObserver\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`coerceData\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`copyData\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`createGraphics\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`flush\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getAlphaRaster\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getColorModel\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getData\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getGraphics\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getHeight\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getMinTileX\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getMinTileY\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getMinX\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getMinY\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getNumXTiles\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getNumYTiles\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getProperty\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getPropertyNames\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getRaster\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getRGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getSampleModel\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getSource\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getSources\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getSubimage\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getTile\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getTileGridXOffset\"\>"}\
,
          {"\<\"java`awt`image`BufferedImage`JPrivate`getTileGridYOffset\"\>"}\
,
          {"\<\"java`awt`image`BufferedImage`JPrivate`getTileHeight\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getTileWidth\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getType\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getWidth\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getWritableTile\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`getWritableTileIndices\"\
\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`hasTileWriters\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`isAlphaPremultiplied\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`isTileWritable\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`releaseWritableTile\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`removeTileObserver\"\>"}\
,
          {"\<\"java`awt`image`BufferedImage`JPrivate`SCALEUAREAUAVERAGING\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`SCALEUDEFAULT\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`SCALEUFAST\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`SCALEUREPLICATE\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`SCALEUSMOOTH\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`setData\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`setRGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`toString\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEU3BYTEUBGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEU4BYTEUABGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEU4BYTEUABGRUPRE\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUBINARY\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUGRAY\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUINDEXED\"\>"},\

          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUCUSTOM\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUINTUARGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUINTUARGBUPRE\"\>"},\

          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUINTUBGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUINTURGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTU555URGB\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTU565URGB\"\>\
"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"java`awt`image`BufferedImage`JPrivate`UndefinedProperty\"\>"},\

          {"\<\"java`awt`image`BufferedImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"java`awt`image`BufferedImage`SCALEUDEFAULT\"\>"},
          {"\<\"java`awt`image`BufferedImage`SCALEUFAST\"\>"},
          {"\<\"java`awt`image`BufferedImage`SCALEUREPLICATE\"\>"},
          {"\<\"java`awt`image`BufferedImage`SCALEUSMOOTH\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUCUSTOM\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUINTUARGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUINTUBGR\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUINTURGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"java`awt`image`BufferedImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"java`awt`image`BufferedImage`UndefinedProperty\"\>"},
          {"\<\"java`awt`Image`JPrivate`flush\"\>"},
          {"\<\"java`awt`Image`JPrivate`getGraphics\"\>"},
          {"\<\"java`awt`Image`JPrivate`getHeight\"\>"},
          {"\<\"java`awt`Image`JPrivate`getProperty\"\>"},
          {"\<\"java`awt`Image`JPrivate`getScaledInstance\"\>"},
          {"\<\"java`awt`Image`JPrivate`getSource\"\>"},
          {"\<\"java`awt`Image`JPrivate`getWidth\"\>"},
          {"\<\"java`awt`Image`JPrivate`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"java`awt`Image`JPrivate`SCALEUDEFAULT\"\>"},
          {"\<\"java`awt`Image`JPrivate`SCALEUFAST\"\>"},
          {"\<\"java`awt`Image`JPrivate`SCALEUREPLICATE\"\>"},
          {"\<\"java`awt`Image`JPrivate`SCALEUSMOOTH\"\>"},
          {"\<\"java`awt`Image`JPrivate`UndefinedProperty\"\>"},
          {"\<\"java`awt`Image`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"java`awt`Image`SCALEUDEFAULT\"\>"},
          {"\<\"java`awt`Image`SCALEUFAST\"\>"},
          {"\<\"java`awt`Image`SCALEUREPLICATE\"\>"},
          {"\<\"java`awt`Image`SCALEUSMOOTH\"\>"},
          {"\<\"java`awt`Image`UndefinedProperty\"\>"},
          {"\<\"java`awt`Scrollbar`ABORT\"\>"},
          {"\<\"java`awt`Scrollbar`ALLBITS\"\>"},
          {"\<\"java`awt`Scrollbar`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`ERROR\"\>"},
          {"\<\"java`awt`Scrollbar`FRAMEBITS\"\>"},
          {"\<\"java`awt`Scrollbar`HEIGHT\"\>"},
          {"\<\"java`awt`Scrollbar`HORIZONTAL\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`ABORT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`addAdjustmentListener\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`addNotify\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`ALLBITS\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`ERROR\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`FRAMEBITS\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getAccessibleContext\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getAdjustmentListeners\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getBlockIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getLineIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getListeners\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getMaximum\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getMinimum\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getOrientation\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getPageIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getUnitIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getValue\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getValueIsAdjusting\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getVisible\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`getVisibleAmount\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`HEIGHT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`HORIZONTAL\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`NOUORIENTATION\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`PROPERTIES\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`removeAdjustmentListener\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setBlockIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setLineIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setMaximum\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setMinimum\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setOrientation\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setPageIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setUnitIncrement\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setValue\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setValueIsAdjusting\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setValues\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`setVisibleAmount\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`SOMEBITS\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`VERTICAL\"\>"},
          {"\<\"java`awt`Scrollbar`JPrivate`WIDTH\"\>"},
          {"\<\"java`awt`Scrollbar`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`NOUORIENTATION\"\>"},
          {"\<\"java`awt`Scrollbar`PROPERTIES\"\>"},
          {"\<\"java`awt`Scrollbar`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`SOMEBITS\"\>"},
          {"\<\"java`awt`Scrollbar`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Scrollbar`VERTICAL\"\>"},
          {"\<\"java`awt`Scrollbar`WIDTH\"\>"},
          {"\<\"java`awt`Window`ABORT\"\>"},
          {"\<\"java`awt`Window`ALLBITS\"\>"},
          {"\<\"java`awt`Window`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`ERROR\"\>"},
          {"\<\"java`awt`Window`FRAMEBITS\"\>"},
          {"\<\"java`awt`Window`HEIGHT\"\>"},
          {"\<\"java`awt`Window`JPrivate`ABORT\"\>"},
          {"\<\"java`awt`Window`JPrivate`addNotify\"\>"},
          {"\<\"java`awt`Window`JPrivate`addPropertyChangeListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`addWindowFocusListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`addWindowListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`addWindowStateListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`ALLBITS\"\>"},
          {"\<\"java`awt`Window`JPrivate`applyResourceBundle\"\>"},
          {"\<\"java`awt`Window`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`JPrivate`createBufferStrategy\"\>"},
          {"\<\"java`awt`Window`JPrivate`dispose\"\>"},
          {"\<\"java`awt`Window`JPrivate`ERROR\"\>"},
          {"\<\"java`awt`Window`JPrivate`FRAMEBITS\"\>"},
          {"\<\"java`awt`Window`JPrivate`getAccessibleContext\"\>"},
          {"\<\"java`awt`Window`JPrivate`getBufferStrategy\"\>"},
          {"\<\"java`awt`Window`JPrivate`getFocusableWindowState\"\>"},
          {"\<\"java`awt`Window`JPrivate`getFocusCycleRootAncestor\"\>"},
          {"\<\"java`awt`Window`JPrivate`getFocusOwner\"\>"},
          {"\<\"java`awt`Window`JPrivate`getFocusTraversalKeys\"\>"},
          {"\<\"java`awt`Window`JPrivate`getGraphicsConfiguration\"\>"},
          {"\<\"java`awt`Window`JPrivate`getInputContext\"\>"},
          {"\<\"java`awt`Window`JPrivate`getListeners\"\>"},
          {"\<\"java`awt`Window`JPrivate`getLocale\"\>"},
          {"\<\"java`awt`Window`JPrivate`getMostRecentFocusOwner\"\>"},
          {"\<\"java`awt`Window`JPrivate`getOwnedWindows\"\>"},
          {"\<\"java`awt`Window`JPrivate`getOwner\"\>"},
          {"\<\"java`awt`Window`JPrivate`getToolkit\"\>"},
          {"\<\"java`awt`Window`JPrivate`getWarningString\"\>"},
          {"\<\"java`awt`Window`JPrivate`getWindowFocusListeners\"\>"},
          {"\<\"java`awt`Window`JPrivate`getWindowListeners\"\>"},
          {"\<\"java`awt`Window`JPrivate`getWindowStateListeners\"\>"},
          {"\<\"java`awt`Window`JPrivate`HEIGHT\"\>"},
          {"\<\"java`awt`Window`JPrivate`hide\"\>"},
          {"\<\"java`awt`Window`JPrivate`isActive\"\>"},
          {"\<\"java`awt`Window`JPrivate`isFocusableWindow\"\>"},
          {"\<\"java`awt`Window`JPrivate`isFocusCycleRoot\"\>"},
          {"\<\"java`awt`Window`JPrivate`isFocused\"\>"},
          {"\<\"java`awt`Window`JPrivate`isShowing\"\>"},
          {"\<\"java`awt`Window`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`JPrivate`pack\"\>"},
          {"\<\"java`awt`Window`JPrivate`postEvent\"\>"},
          {"\<\"java`awt`Window`JPrivate`PROPERTIES\"\>"},
          {"\<\"java`awt`Window`JPrivate`removeWindowFocusListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`removeWindowListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`removeWindowStateListener\"\>"},
          {"\<\"java`awt`Window`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`JPrivate`setBounds\"\>"},
          {"\<\"java`awt`Window`JPrivate`setCursor\"\>"},
          {"\<\"java`awt`Window`JPrivate`setFocusableWindowState\"\>"},
          {"\<\"java`awt`Window`JPrivate`setFocusCycleRoot\"\>"},
          {"\<\"java`awt`Window`JPrivate`setLocation\"\>"},
          {"\<\"java`awt`Window`JPrivate`setLocationRelativeTo\"\>"},
          {"\<\"java`awt`Window`JPrivate`setSize\"\>"},
          {"\<\"java`awt`Window`JPrivate`setVisible\"\>"},
          {"\<\"java`awt`Window`JPrivate`show\"\>"},
          {"\<\"java`awt`Window`JPrivate`SOMEBITS\"\>"},
          {"\<\"java`awt`Window`JPrivate`toBack\"\>"},
          {"\<\"java`awt`Window`JPrivate`toFront\"\>"},
          {"\<\"java`awt`Window`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`JPrivate`WIDTH\"\>"},
          {"\<\"java`awt`Window`LEFTUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`PROPERTIES\"\>"},
          {"\<\"java`awt`Window`RIGHTUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`SOMEBITS\"\>"},
          {"\<\"java`awt`Window`TOPUALIGNMENT\"\>"},
          {"\<\"java`awt`Window`WIDTH\"\>"},
          {"\<\"JavaBlock\"\>"},
          {"\<\"JavaClass\"\>"},
          {"\<\"JavaClassPath\"\>"},
          {"\<\"JavaGC\"\>"},
          {"\<\"java`lang`Object`JPrivate`equals\"\>"},
          {"\<\"java`lang`Object`JPrivate`getClass\"\>"},
          {"\<\"java`lang`Object`JPrivate`hashCode\"\>"},
          {"\<\"java`lang`Object`JPrivate`notify\"\>"},
          {"\<\"java`lang`Object`JPrivate`notifyAll\"\>"},
          {"\<\"java`lang`Object`JPrivate`toString\"\>"},
          {"\<\"java`lang`Object`JPrivate`wait\"\>"},
          {"\<\"java`lang`System`arraycopy\"\>"},
          {"\<\"java`lang`System`currentTimeMillis\"\>"},
          {"\<\"java`lang`System`err\"\>"},
          {"\<\"java`lang`System`exit\"\>"},
          {"\<\"java`lang`System`gc\"\>"},
          {"\<\"java`lang`System`getenv\"\>"},
          {"\<\"java`lang`System`getProperties\"\>"},
          {"\<\"java`lang`System`getProperty\"\>"},
          {"\<\"java`lang`System`getSecurityManager\"\>"},
          {"\<\"java`lang`System`identityHashCode\"\>"},
          {"\<\"java`lang`System`in\"\>"},
          {"\<\"java`lang`System`JPrivate`arraycopy\"\>"},
          {"\<\"java`lang`System`JPrivate`currentTimeMillis\"\>"},
          {"\<\"java`lang`System`JPrivate`err\"\>"},
          {"\<\"java`lang`System`JPrivate`exit\"\>"},
          {"\<\"java`lang`System`JPrivate`gc\"\>"},
          {"\<\"java`lang`System`JPrivate`getenv\"\>"},
          {"\<\"java`lang`System`JPrivate`getProperties\"\>"},
          {"\<\"java`lang`System`JPrivate`getProperty\"\>"},
          {"\<\"java`lang`System`JPrivate`getSecurityManager\"\>"},
          {"\<\"java`lang`System`JPrivate`identityHashCode\"\>"},
          {"\<\"java`lang`System`JPrivate`in\"\>"},
          {"\<\"java`lang`System`JPrivate`load\"\>"},
          {"\<\"java`lang`System`JPrivate`loadLibrary\"\>"},
          {"\<\"java`lang`System`JPrivate`mapLibraryName\"\>"},
          {"\<\"java`lang`System`JPrivate`out\"\>"},
          {"\<\"java`lang`System`JPrivate`runFinalization\"\>"},
          {"\<\"java`lang`System`JPrivate`runFinalizersOnExit\"\>"},
          {"\<\"java`lang`System`JPrivate`setErr\"\>"},
          {"\<\"java`lang`System`JPrivate`setIn\"\>"},
          {"\<\"java`lang`System`JPrivate`setOut\"\>"},
          {"\<\"java`lang`System`JPrivate`setProperties\"\>"},
          {"\<\"java`lang`System`JPrivate`setProperty\"\>"},
          {"\<\"java`lang`System`JPrivate`setSecurityManager\"\>"},
          {"\<\"java`lang`System`load\"\>"},
          {"\<\"java`lang`System`loadLibrary\"\>"},
          {"\<\"java`lang`System`mapLibraryName\"\>"},
          {"\<\"java`lang`System`out\"\>"},
          {"\<\"java`lang`System`runFinalization\"\>"},
          {"\<\"java`lang`System`runFinalizersOnExit\"\>"},
          {"\<\"java`lang`System`setErr\"\>"},
          {"\<\"java`lang`System`setIn\"\>"},
          {"\<\"java`lang`System`setOut\"\>"},
          {"\<\"java`lang`System`setProperties\"\>"},
          {"\<\"java`lang`System`setProperty\"\>"},
          {"\<\"java`lang`System`setSecurityManager\"\>"},
          {"\<\"JavaLink\"\>"},
          {"\<\"JavaNew\"\>"},
          {"\<\"JavaObject\"\>"},
          {"\<\"JavaObjectQ\"\>"},
          {"\<\"JavaObjectToExpression\"\>"},
          {"\<\"JavaShow\"\>"},
          {"\<\"JavaThrow\"\>"},
          {"\<\"JavaUILink\"\>"},
          {"\<\"java`util`EventObject`JPrivate`getSource\"\>"},
          {"\<\"java`util`EventObject`JPrivate`toString\"\>"},
          {"\<\"javax`swing`JComponent`ABORT\"\>"},
          {"\<\"javax`swing`JComponent`ALLBITS\"\>"},
          {"\<\"javax`swing`JComponent`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`ERROR\"\>"},
          {"\<\"javax`swing`JComponent`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JComponent`getDefaultLocale\"\>"},
          {"\<\"javax`swing`JComponent`HEIGHT\"\>"},
          {"\<\"javax`swing`JComponent`isLightweightComponent\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`ABORT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`add\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`addAncestorListener\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`addMouseListener\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`addNotify\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`addPropertyChangeListener\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`addVetoableChangeListener\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`ALLBITS\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`computeVisibleRect\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`contains\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`createImage\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`createToolTip\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`disable\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`enable\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`ERROR\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`firePropertyChange\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getAccessibleContext\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getActionForKeyStroke\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getActionMap\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getAlignmentX\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getAlignmentY\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getAncestorListeners\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getAutoscrolls\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getBorder\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getBounds\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getClientProperty\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getConditionForKeyStroke\"\>"}\
,
          {"\<\"javax`swing`JComponent`JPrivate`getDebugGraphicsOptions\"\>"},\

          {"\<\"javax`swing`JComponent`JPrivate`getDefaultLocale\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getGraphics\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getHeight\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getInputMap\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getInputVerifier\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getInsets\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getListeners\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getLocation\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getMaximumSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getMinimumSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getNextFocusableComponent\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`getPreferredSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getPropertyChangeListeners\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`getRegisteredKeyStrokes\"\>"},\

          {"\<\"javax`swing`JComponent`JPrivate`getRootPane\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getToolTipLocation\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getToolTipText\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getTopLevelAncestor\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getTransferHandler\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getUIClassID\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getVerifyInputWhenFocusTarget\
\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getVetoableChangeListeners\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`getVisibleRect\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getWidth\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getX\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`getY\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`grabFocus\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`HEIGHT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isDoubleBuffered\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isLightweightComponent\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isManagingFocus\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isMaximumSizeSet\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isMinimumSizeSet\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isOpaque\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isOptimizedDrawingEnabled\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`isPaintingTile\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isPreferredSizeSet\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isRequestFocusEnabled\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`isValidateRoot\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`paint\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`paintImmediately\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`print\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`printAll\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`PROPERTIES\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`putClientProperty\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`registerKeyboardAction\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`removeAncestorListener\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`removeNotify\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`removePropertyChangeListener\"\
\>"},
          {"\<\"javax`swing`JComponent`JPrivate`removeVetoableChangeListener\"\
\>"},
          {"\<\"javax`swing`JComponent`JPrivate`repaint\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`requestDefaultFocus\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`requestFocus\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`requestFocusInWindow\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`resetKeyboardActions\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`reshape\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`revalidate\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`scrollRectToVisible\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setActionMap\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setAlignmentX\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setAlignmentY\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setAutoscrolls\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setBackground\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setBorder\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setBounds\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setDebugGraphicsOptions\"\>"},\

          {"\<\"javax`swing`JComponent`JPrivate`setDefaultLocale\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setDoubleBuffered\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setEnabled\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setFont\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setForeground\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setInputMap\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setInputVerifier\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setLayout\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setMaximumSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setMinimumSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setNextFocusableComponent\"\>\
"},
          {"\<\"javax`swing`JComponent`JPrivate`setOpaque\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setPreferredSize\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setRequestFocusEnabled\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setToolTipText\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setTransferHandler\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setVerifyInputWhenFocusTarget\
\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`setVisible\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`SOMEBITS\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`UNDEFINEDUCONDITION\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`unregisterKeyboardAction\"\>"}\
,
          {"\<\"javax`swing`JComponent`JPrivate`update\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`updateUI\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`WHENUFOCUSED\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"javax`swing`JComponent`JPrivate`WIDTH\"\>"},
          {"\<\"javax`swing`JComponent`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`PROPERTIES\"\>"},
          {"\<\"javax`swing`JComponent`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`setDefaultLocale\"\>"},
          {"\<\"javax`swing`JComponent`SOMEBITS\"\>"},
          {"\<\"javax`swing`JComponent`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"javax`swing`JComponent`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JComponent`UNDEFINEDUCONDITION\"\>"},
          {"\<\"javax`swing`JComponent`WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>\
"},
          {"\<\"javax`swing`JComponent`WHENUFOCUSED\"\>"},
          {"\<\"javax`swing`JComponent`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"javax`swing`JComponent`WIDTH\"\>"},
          {"\<\"javax`swing`JFrame`ABORT\"\>"},
          {"\<\"javax`swing`JFrame`ALLBITS\"\>"},
          {"\<\"javax`swing`JFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`DISPOSEUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`DOUNOTHINGUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`ERROR\"\>"},
          {"\<\"javax`swing`JFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`EXITUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JFrame`getFrames\"\>"},
          {"\<\"javax`swing`JFrame`HANDUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`HEIGHT\"\>"},
          {"\<\"javax`swing`JFrame`HIDEUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`ICONIFIED\"\>"},
          {"\<\"javax`swing`JFrame`isDefaultLookAndFeelDecorated\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`ABORT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`ALLBITS\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`CROSSHAIRUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`DEFAULTUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`DISPOSEUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`DOUNOTHINGUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`ERROR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`EURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`EXITUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getAccessibleContext\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getContentPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getDefaultCloseOperation\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getFrames\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getGlassPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getJMenuBar\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getLayeredPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`getRootPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`HANDUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`HEIGHT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`HIDEUONUCLOSE\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`ICONIFIED\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`isDefaultLookAndFeelDecorated\"\>\
"},
          {"\<\"javax`swing`JFrame`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`MAXIMIZEDUBOTH\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`MAXIMIZEDUVERT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`MOVEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`NEURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`NORMAL\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`NURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`NWURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`PROPERTIES\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`remove\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setBounds\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setContentPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setDefaultCloseOperation\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setDefaultLookAndFeelDecorated\"\>\
"},
          {"\<\"javax`swing`JFrame`JPrivate`setGlassPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setJMenuBar\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setLayeredPane\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setLayout\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setResizable\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`setVisible\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`SEURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`SOMEBITS\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`SURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`SWURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`TEXTUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`update\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`WAITUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`WIDTH\"\>"},
          {"\<\"javax`swing`JFrame`JPrivate`WURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"javax`swing`JFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"javax`swing`JFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"javax`swing`JFrame`MOVEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`NORMAL\"\>"},
          {"\<\"javax`swing`JFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`PROPERTIES\"\>"},
          {"\<\"javax`swing`JFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`setDefaultLookAndFeelDecorated\"\>"},
          {"\<\"javax`swing`JFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`SOMEBITS\"\>"},
          {"\<\"javax`swing`JFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`TEXTUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JFrame`WAITUCURSOR\"\>"},
          {"\<\"javax`swing`JFrame`WIDTH\"\>"},
          {"\<\"javax`swing`JFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"javax`swing`JPanel`ABORT\"\>"},
          {"\<\"javax`swing`JPanel`ALLBITS\"\>"},
          {"\<\"javax`swing`JPanel`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`ERROR\"\>"},
          {"\<\"javax`swing`JPanel`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JPanel`getDefaultLocale\"\>"},
          {"\<\"javax`swing`JPanel`HEIGHT\"\>"},
          {"\<\"javax`swing`JPanel`isLightweightComponent\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`ABORT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`add\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`addMouseListener\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`ALLBITS\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`BOTTOMUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`CENTERUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`createImage\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`ERROR\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`FRAMEBITS\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`getAccessibleContext\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`getDefaultLocale\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`getUI\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`getUIClassID\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`HEIGHT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`isLightweightComponent\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`PROPERTIES\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`setBounds\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`setDefaultLocale\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`setLayout\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`setUI\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`SOMEBITS\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`UNDEFINEDUCONDITION\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`updateUI\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`WHENUFOCUSED\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"javax`swing`JPanel`JPrivate`WIDTH\"\>"},
          {"\<\"javax`swing`JPanel`LEFTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`PROPERTIES\"\>"},
          {"\<\"javax`swing`JPanel`RIGHTUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`setDefaultLocale\"\>"},
          {"\<\"javax`swing`JPanel`SOMEBITS\"\>"},
          {"\<\"javax`swing`JPanel`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"javax`swing`JPanel`TOPUALIGNMENT\"\>"},
          {"\<\"javax`swing`JPanel`UNDEFINEDUCONDITION\"\>"},
          {"\<\"javax`swing`JPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"javax`swing`JPanel`WHENUFOCUSED\"\>"},
          {"\<\"javax`swing`JPanel`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"javax`swing`JPanel`WIDTH\"\>"},
          {"\<\"JComponent`ABORT\"\>"},
          {"\<\"JComponent`ALLBITS\"\>"},
          {"\<\"JComponent`BOTTOMUALIGNMENT\"\>"},
          {"\<\"JComponent`CENTERUALIGNMENT\"\>"},
          {"\<\"JComponent`ERROR\"\>"},
          {"\<\"JComponent`FRAMEBITS\"\>"},
          {"\<\"JComponent`getDefaultLocale\"\>"},
          {"\<\"JComponent`HEIGHT\"\>"},
          {"\<\"JComponent`isLightweightComponent\"\>"},
          {"\<\"JComponent`LEFTUALIGNMENT\"\>"},
          {"\<\"JComponent`PROPERTIES\"\>"},
          {"\<\"JComponent`RIGHTUALIGNMENT\"\>"},
          {"\<\"JComponent`setDefaultLocale\"\>"},
          {"\<\"JComponent`SOMEBITS\"\>"},
          {"\<\"JComponent`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"JComponent`TOPUALIGNMENT\"\>"},
          {"\<\"JComponent`UNDEFINEDUCONDITION\"\>"},
          {"\<\"JComponent`WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"JComponent`WHENUFOCUSED\"\>"},
          {"\<\"JComponent`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"JComponent`WIDTH\"\>"},
          {"\<\"JFrame`ABORT\"\>"},
          {"\<\"JFrame`ALLBITS\"\>"},
          {"\<\"JFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"JFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"JFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"JFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"JFrame`DISPOSEUONUCLOSE\"\>"},
          {"\<\"JFrame`DOUNOTHINGUONUCLOSE\"\>"},
          {"\<\"JFrame`ERROR\"\>"},
          {"\<\"JFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`EXITUONUCLOSE\"\>"},
          {"\<\"JFrame`FRAMEBITS\"\>"},
          {"\<\"JFrame`getFrames\"\>"},
          {"\<\"JFrame`HANDUCURSOR\"\>"},
          {"\<\"JFrame`HEIGHT\"\>"},
          {"\<\"JFrame`HIDEUONUCLOSE\"\>"},
          {"\<\"JFrame`ICONIFIED\"\>"},
          {"\<\"JFrame`isDefaultLookAndFeelDecorated\"\>"},
          {"\<\"JFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"JFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"JFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"JFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"JFrame`MOVEUCURSOR\"\>"},
          {"\<\"JFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`NORMAL\"\>"},
          {"\<\"JFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`PROPERTIES\"\>"},
          {"\<\"JFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"JFrame`setDefaultLookAndFeelDecorated\"\>"},
          {"\<\"JFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`SOMEBITS\"\>"},
          {"\<\"JFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"JFrame`TEXTUCURSOR\"\>"},
          {"\<\"JFrame`TOPUALIGNMENT\"\>"},
          {"\<\"JFrame`WAITUCURSOR\"\>"},
          {"\<\"JFrame`WIDTH\"\>"},
          {"\<\"JFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"JLink`ArgumentTests`Private`allow\"\>"},
          {"\<\"JLink`ArgumentTests`Private`x\"\>"},
          {"\<\"JLink`CallJava`Private`a\"\>"},
          {"\<\"JLink`CallJava`Private`allLoadedClasses\"\>"},
          {"\<\"JLink`CallJava`Private`allowShortContext\"\>"},
          {"\<\"JLink`CallJava`Private`allowShortContext$\"\>"},
          {"\<\"JLink`CallJava`Private`alreadyLoaded\"\>"},
          {"\<\"JLink`CallJava`Private`alreadyLoaded$\"\>"},
          {"\<\"JLink`CallJava`Private`arg\"\>"},
          {"\<\"JLink`CallJava`Private`argc\"\>"},
          {"\<\"JLink`CallJava`Private`argc$\"\>"},
          {"\<\"JLink`CallJava`Private`argName\"\>"},
          {"\<\"JLink`CallJava`Private`argNames\"\>"},
          {"\<\"JLink`CallJava`Private`argNames$\"\>"},
          {"\<\"JLink`CallJava`Private`argName$\"\>"},
          {"\<\"JLink`CallJava`Private`argPairs\"\>"},
          {"\<\"JLink`CallJava`Private`argPairs$\"\>"},
          {"\<\"JLink`CallJava`Private`argPats\"\>"},
          {"\<\"JLink`CallJava`Private`argPats$\"\>"},
          {"\<\"JLink`CallJava`Private`args\"\>"},
          {"\<\"JLink`CallJava`Private`args$\"\>"},
          {"\<\"JLink`CallJava`Private`argType\"\>"},
          {"\<\"JLink`CallJava`Private`argTypes\"\>"},
          {"\<\"JLink`CallJava`Private`argTypesAndVals\"\>"},
          {"\<\"JLink`CallJava`Private`argTypes$\"\>"},
          {"\<\"JLink`CallJava`Private`argTypeToPattern\"\>"},
          {"\<\"JLink`CallJava`Private`argType$\"\>"},
          {"\<\"JLink`CallJava`Private`arg$1\"\>"},
          {"\<\"JLink`CallJava`Private`arg$10\"\>"},
          {"\<\"JLink`CallJava`Private`arg$11\"\>"},
          {"\<\"JLink`CallJava`Private`arg$12\"\>"},
          {"\<\"JLink`CallJava`Private`arg$13\"\>"},
          {"\<\"JLink`CallJava`Private`arg$14\"\>"},
          {"\<\"JLink`CallJava`Private`arg$15\"\>"},
          {"\<\"JLink`CallJava`Private`arg$16\"\>"},
          {"\<\"JLink`CallJava`Private`arg$17\"\>"},
          {"\<\"JLink`CallJava`Private`arg$18\"\>"},
          {"\<\"JLink`CallJava`Private`arg$19\"\>"},
          {"\<\"JLink`CallJava`Private`arg$2\"\>"},
          {"\<\"JLink`CallJava`Private`arg$20\"\>"},
          {"\<\"JLink`CallJava`Private`arg$21\"\>"},
          {"\<\"JLink`CallJava`Private`arg$22\"\>"},
          {"\<\"JLink`CallJava`Private`arg$23\"\>"},
          {"\<\"JLink`CallJava`Private`arg$24\"\>"},
          {"\<\"JLink`CallJava`Private`arg$25\"\>"},
          {"\<\"JLink`CallJava`Private`arg$26\"\>"},
          {"\<\"JLink`CallJava`Private`arg$27\"\>"},
          {"\<\"JLink`CallJava`Private`arg$28\"\>"},
          {"\<\"JLink`CallJava`Private`arg$29\"\>"},
          {"\<\"JLink`CallJava`Private`arg$3\"\>"},
          {"\<\"JLink`CallJava`Private`arg$30\"\>"},
          {"\<\"JLink`CallJava`Private`arg$31\"\>"},
          {"\<\"JLink`CallJava`Private`arg$32\"\>"},
          {"\<\"JLink`CallJava`Private`arg$33\"\>"},
          {"\<\"JLink`CallJava`Private`arg$34\"\>"},
          {"\<\"JLink`CallJava`Private`arg$35\"\>"},
          {"\<\"JLink`CallJava`Private`arg$36\"\>"},
          {"\<\"JLink`CallJava`Private`arg$37\"\>"},
          {"\<\"JLink`CallJava`Private`arg$38\"\>"},
          {"\<\"JLink`CallJava`Private`arg$39\"\>"},
          {"\<\"JLink`CallJava`Private`arg$4\"\>"},
          {"\<\"JLink`CallJava`Private`arg$40\"\>"},
          {"\<\"JLink`CallJava`Private`arg$5\"\>"},
          {"\<\"JLink`CallJava`Private`arg$6\"\>"},
          {"\<\"JLink`CallJava`Private`arg$7\"\>"},
          {"\<\"JLink`CallJava`Private`arg$8\"\>"},
          {"\<\"JLink`CallJava`Private`arg$9\"\>"},
          {"\<\"JLink`CallJava`Private`arrayDepth\"\>"},
          {"\<\"JLink`CallJava`Private`arrayDepth$\"\>"},
          {"\<\"JLink`CallJava`Private`arrayType\"\>"},
          {"\<\"JLink`CallJava`Private`arrayType$\"\>"},
          {"\<\"JLink`CallJava`Private`atLeastOneStatic\"\>"},
          {"\<\"JLink`CallJava`Private`atLeastOneStatic$\"\>"},
          {"\<\"JLink`CallJava`Private`b\"\>"},
          {"\<\"JLink`CallJava`Private`c\"\>"},
          {"\<\"JLink`CallJava`Private`c1\"\>"},
          {"\<\"JLink`CallJava`Private`c2\"\>"},
          {"\<\"JLink`CallJava`Private`cacheInstanceFunc\"\>"},
          {"\<\"JLink`CallJava`Private`callJava\"\>"},
          {"\<\"JLink`CallJava`Private`callOnLoadClassMethod\"\>"},
          {"\<\"JLink`CallJava`Private`callOnUnloadClassMethod\"\>"},
          {"\<\"JLink`CallJava`Private`checkFieldResult\"\>"},
          {"\<\"JLink`CallJava`Private`checkMethodResult\"\>"},
          {"\<\"JLink`CallJava`Private`class\"\>"},
          {"\<\"JLink`CallJava`Private`classContext\"\>"},
          {"\<\"JLink`CallJava`Private`classContext$\"\>"},
          {"\<\"JLink`CallJava`Private`classes\"\>"},
          {"\<\"JLink`CallJava`Private`classes$\"\>"},
          {"\<\"JLink`CallJava`Private`classFromName\"\>"},
          {"\<\"JLink`CallJava`Private`classIndex\"\>"},
          {"\<\"JLink`CallJava`Private`classIndexFromName\"\>"},
          {"\<\"JLink`CallJava`Private`classIndex$\"\>"},
          {"\<\"JLink`CallJava`Private`className\"\>"},
          {"\<\"JLink`CallJava`Private`clearAllClassContexts\"\>"},
          {"\<\"JLink`CallJava`Private`clearOutClassContext\"\>"},
          {"\<\"JLink`CallJava`Private`cls\"\>"},
          {"\<\"JLink`CallJava`Private`clsIndex\"\>"},
          {"\<\"JLink`CallJava`Private`clsName\"\>"},
          {"\<\"JLink`CallJava`Private`clsName$\"\>"},
          {"\<\"JLink`CallJava`Private`cls$\"\>"},
          {"\<\"JLink`CallJava`Private`complexClass\"\>"},
          {"\<\"JLink`CallJava`Private`complexClassName\"\>"},
          {"\<\"JLink`CallJava`Private`complexClass$\"\>"},
          {"\<\"JLink`CallJava`Private`contextNameFromClassIndex\"\>"},
          {"\<\"JLink`CallJava`Private`createArgPairs\"\>"},
          {"\<\"JLink`CallJava`Private`createConstructorStubs\"\>"},
          {"\<\"JLink`CallJava`Private`createCtorDef\"\>"},
          {"\<\"JLink`CallJava`Private`createFieldDef\"\>"},
          {"\<\"JLink`CallJava`Private`createFieldStubs\"\>"},
          {"\<\"JLink`CallJava`Private`createJavaClass\"\>"},
          {"\<\"JLink`CallJava`Private`createMethodDef\"\>"},
          {"\<\"JLink`CallJava`Private`createMethodStubs\"\>"},
          {"\<\"JLink`CallJava`Private`ctorList\"\>"},
          {"\<\"JLink`CallJava`Private`ctorListForNonObjectDups\"\>"},
          {"\<\"JLink`CallJava`Private`ctorListForNonObjectDups$\"\>"},
          {"\<\"JLink`CallJava`Private`ctorListForObjectDups\"\>"},
          {"\<\"JLink`CallJava`Private`ctorListForObjectDups$\"\>"},
          {"\<\"JLink`CallJava`Private`ctorList$\"\>"},
          {"\<\"JLink`CallJava`Private`ctorRecs\"\>"},
          {"\<\"JLink`CallJava`Private`ctorRecs$\"\>"},
          {"\<\"JLink`CallJava`Private`ctors\"\>"},
          {"\<\"JLink`CallJava`Private`ctorsWithObjects\"\>"},
          {"\<\"JLink`CallJava`Private`ctorsWithObjects$\"\>"},
          {"\<\"JLink`CallJava`Private`ctorsWithoutObjects\"\>"},
          {"\<\"JLink`CallJava`Private`ctorsWithoutObjects$\"\>"},
          {"\<\"JLink`CallJava`Private`ctxt\"\>"},
          {"\<\"JLink`CallJava`Private`ctxt$\"\>"},
          {"\<\"JLink`CallJava`Private`curClsIndex\"\>"},
          {"\<\"JLink`CallJava`Private`curClsIndex$\"\>"},
          {"\<\"JLink`CallJava`Private`d\"\>"},
          {"\<\"JLink`CallJava`Private`decs\"\>"},
          {"\<\"JLink`CallJava`Private`decs$\"\>"},
          {"\<\"JLink`CallJava`Private`destroyLoadedClassInfo\"\>"},
          {"\<\"JLink`CallJava`Private`dups\"\>"},
          {"\<\"JLink`CallJava`Private`dups$\"\>"},
          {"\<\"JLink`CallJava`Private`e\"\>"},
          {"\<\"JLink`CallJava`Private`equivs\"\>"},
          {"\<\"JLink`CallJava`Private`e$\"\>"},
          {"\<\"JLink`CallJava`Private`f\"\>"},
          {"\<\"JLink`CallJava`Private`field\"\>"},
          {"\<\"JLink`CallJava`Private`fieldCall\"\>"},
          {"\<\"JLink`CallJava`Private`fieldName\"\>"},
          {"\<\"JLink`CallJava`Private`fieldNames\"\>"},
          {"\<\"JLink`CallJava`Private`fieldNames$\"\>"},
          {"\<\"JLink`CallJava`Private`fieldName$\"\>"},
          {"\<\"JLink`CallJava`Private`fieldRecs\"\>"},
          {"\<\"JLink`CallJava`Private`fieldRecs$\"\>"},
          {"\<\"JLink`CallJava`Private`fields\"\>"},
          {"\<\"JLink`CallJava`Private`fieldTag\"\>"},
          {"\<\"JLink`CallJava`Private`field$\"\>"},
          {"\<\"JLink`CallJava`Private`findName\"\>"},
          {"\<\"JLink`CallJava`Private`fmt\"\>"},
          {"\<\"JLink`CallJava`Private`fmt$\"\>"},
          {"\<\"JLink`CallJava`Private`heldName\"\>"},
          {"\<\"JLink`CallJava`Private`i\"\>"},
          {"\<\"JLink`CallJava`Private`index\"\>"},
          {"\<\"JLink`CallJava`Private`index$\"\>"},
          {"\<\"JLink`CallJava`Private`indices\"\>"},
          {"\<\"JLink`CallJava`Private`indices$\"\>"},
          {"\<\"JLink`CallJava`Private`instance\"\>"},
          {"\<\"JLink`CallJava`Private`instanceFunc\"\>"},
          {"\<\"JLink`CallJava`Private`instance$\"\>"},
          {"\<\"JLink`CallJava`Private`instFunc\"\>"},
          {"\<\"JLink`CallJava`Private`interfaceQFromIndex\"\>"},
          {"\<\"JLink`CallJava`Private`isBeingLoadedAsComplexClass\"\>"},
          {"\<\"JLink`CallJava`Private`isInterface\"\>"},
          {"\<\"JLink`CallJava`Private`isInterface$\"\>"},
          {"\<\"JLink`CallJava`Private`isJavaStaticSymbol\"\>"},
          {"\<\"JLink`CallJava`Private`isLoadedClass\"\>"},
          {"\<\"JLink`CallJava`Private`isMethod\"\>"},
          {"\<\"JLink`CallJava`Private`isPreemptive\"\>"},
          {"\<\"JLink`CallJava`Private`i$\"\>"},
          {"\<\"JLink`CallJava`Private`javaConstructor\"\>"},
          {"\<\"JLink`CallJava`Private`javaField\"\>"},
          {"\<\"JLink`CallJava`Private`javaMethod\"\>"},
          {"\<\"JLink`CallJava`Private`javaNames\"\>"},
          {"\<\"JLink`CallJava`Private`javaNames$\"\>"},
          {"\<\"JLink`CallJava`Private`javaNew\"\>"},
          {"\<\"JLink`CallJava`Private`jc\"\>"},
          {"\<\"JLink`CallJava`Private`jc$\"\>"},
          {"\<\"JLink`CallJava`Private`jlinkExternalCall\"\>"},
          {"\<\"JLink`CallJava`Private`lc\"\>"},
          {"\<\"JLink`CallJava`Private`lc$\"\>"},
          {"\<\"JLink`CallJava`Private`legalClassName\"\>"},
          {"\<\"JLink`CallJava`Private`legalClassName$\"\>"},
          {"\<\"JLink`CallJava`Private`link\"\>"},
          {"\<\"JLink`CallJava`Private`loadedClasses\"\>"},
          {"\<\"JLink`CallJava`Private`looksLikeModuleVar\"\>"},
          {"\<\"JLink`CallJava`Private`looksLikeModuleVar$\"\>"},
          {"\<\"JLink`CallJava`Private`lookupInstanceFunc\"\>"},
          {"\<\"JLink`CallJava`Private`makeStaticFieldDefs\"\>"},
          {"\<\"JLink`CallJava`Private`meth\"\>"},
          {"\<\"JLink`CallJava`Private`methListForNonObjectDups\"\>"},
          {"\<\"JLink`CallJava`Private`methListForNonObjectDups$\"\>"},
          {"\<\"JLink`CallJava`Private`methListForObjectDups\"\>"},
          {"\<\"JLink`CallJava`Private`methListForObjectDups$\"\>"},
          {"\<\"JLink`CallJava`Private`methName\"\>"},
          {"\<\"JLink`CallJava`Private`methNames\"\>"},
          {"\<\"JLink`CallJava`Private`methNames$\"\>"},
          {"\<\"JLink`CallJava`Private`methName$\"\>"},
          {"\<\"JLink`CallJava`Private`methodCall\"\>"},
          {"\<\"JLink`CallJava`Private`methRecs\"\>"},
          {"\<\"JLink`CallJava`Private`methRecs$\"\>"},
          {"\<\"JLink`CallJava`Private`meths\"\>"},
          {"\<\"JLink`CallJava`Private`methsWithObjects\"\>"},
          {"\<\"JLink`CallJava`Private`methsWithObjects$\"\>"},
          {"\<\"JLink`CallJava`Private`methsWithoutObjects\"\>"},
          {"\<\"JLink`CallJava`Private`methsWithoutObjects$\"\>"},
          {"\<\"JLink`CallJava`Private`meth$\"\>"},
          {"\<\"JLink`CallJava`Private`n\"\>"},
          {"\<\"JLink`CallJava`Private`name\"\>"},
          {"\<\"JLink`CallJava`Private`nameLen\"\>"},
          {"\<\"JLink`CallJava`Private`nameLen$\"\>"},
          {"\<\"JLink`CallJava`Private`nameStr\"\>"},
          {"\<\"JLink`CallJava`Private`nameStr$\"\>"},
          {"\<\"JLink`CallJava`Private`name$\"\>"},
          {"\<\"JLink`CallJava`Private`nms\"\>"},
          {"\<\"JLink`CallJava`Private`nms$\"\>"},
          {"\<\"JLink`CallJava`Private`nonDups\"\>"},
          {"\<\"JLink`CallJava`Private`nonDups$\"\>"},
          {"\<\"JLink`CallJava`Private`n$\"\>"},
          {"\<\"JLink`CallJava`Private`obj\"\>"},
          {"\<\"JLink`CallJava`Private`objSupplyingClassLoader\"\>"},
          {"\<\"JLink`CallJava`Private`obj$\"\>"},
          {"\<\"JLink`CallJava`Private`opts\"\>"},
          {"\<\"JLink`CallJava`Private`p\"\>"},
          {"\<\"JLink`CallJava`Private`packet\"\>"},
          {"\<\"JLink`CallJava`Private`parentClass\"\>"},
          {"\<\"JLink`CallJava`Private`parentClass$\"\>"},
          {"\<\"JLink`CallJava`Private`parentClsIndex\"\>"},
          {"\<\"JLink`CallJava`Private`parentClsIndex$\"\>"},
          {"\<\"JLink`CallJava`Private`pat\"\>"},
          {"\<\"JLink`CallJava`Private`patternFunc\"\>"},
          {"\<\"JLink`CallJava`Private`patternFunc$\"\>"},
          {"\<\"JLink`CallJava`Private`pat$\"\>"},
          {"\<\"JLink`CallJava`Private`pctxt\"\>"},
          {"\<\"JLink`CallJava`Private`pctxt$\"\>"},
          {"\<\"JLink`CallJava`Private`pickWidest\"\>"},
          {"\<\"JLink`CallJava`Private`pkt\"\>"},
          {"\<\"JLink`CallJava`Private`privSym\"\>"},
          {"\<\"JLink`CallJava`Private`privSym$\"\>"},
          {"\<\"JLink`CallJava`Private`prot\"\>"},
          {"\<\"JLink`CallJava`Private`removeClass\"\>"},
          {"\<\"JLink`CallJava`Private`res\"\>"},
          {"\<\"JLink`CallJava`Private`result\"\>"},
          {"\<\"JLink`CallJava`Private`resultFunc\"\>"},
          {"\<\"JLink`CallJava`Private`resultFunc$\"\>"},
          {"\<\"JLink`CallJava`Private`res$\"\>"},
          {"\<\"JLink`CallJava`Private`returnedClassName\"\>"},
          {"\<\"JLink`CallJava`Private`returnedClassName$\"\>"},
          {"\<\"JLink`CallJava`Private`s\"\>"},
          {"\<\"JLink`CallJava`Private`setField\"\>"},
          {"\<\"JLink`CallJava`Private`shortClassContext\"\>"},
          {"\<\"JLink`CallJava`Private`shortClassContextFromClassContext\"\>"}\
,
          {"\<\"JLink`CallJava`Private`shortClassContext$\"\>"},
          {"\<\"JLink`CallJava`Private`shortCtxt\"\>"},
          {"\<\"JLink`CallJava`Private`shortCtxt$\"\>"},
          {"\<\"JLink`CallJava`Private`staticField\"\>"},
          {"\<\"JLink`CallJava`Private`staticsVisible\"\>"},
          {"\<\"JLink`CallJava`Private`staticsVisible$\"\>"},
          {"\<\"JLink`CallJava`Private`storeClass\"\>"},
          {"\<\"JLink`CallJava`Private`sums\"\>"},
          {"\<\"JLink`CallJava`Private`sums$\"\>"},
          {"\<\"JLink`CallJava`Private`sym\"\>"},
          {"\<\"JLink`CallJava`Private`symStr\"\>"},
          {"\<\"JLink`CallJava`Private`sym$\"\>"},
          {"\<\"JLink`CallJava`Private`tag\"\>"},
          {"\<\"JLink`CallJava`Private`tag$\"\>"},
          {"\<\"JLink`CallJava`Private`toContextName\"\>"},
          {"\<\"JLink`CallJava`Private`toLegalName\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEARRAY1\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEARRAY2\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEARRAY3\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEBAD\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEBIGDECIMAL\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEBIGINTEGER\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEBOOLEAN\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEBYTE\"\>"},
          {"\<\"JLink`CallJava`Private`TYPECHAR\"\>"},
          {"\<\"JLink`CallJava`Private`TYPECOMPLEX\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEDOUBLE\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEDOUBLEORINT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEEXPR\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEFLOAT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEFLOATORINT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEINT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPELONG\"\>"},
          {"\<\"JLink`CallJava`Private`TYPEOBJECT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPESHORT\"\>"},
          {"\<\"JLink`CallJava`Private`TYPESTRING\"\>"},
          {"\<\"JLink`CallJava`Private`usesShortContext\"\>"},
          {"\<\"JLink`CallJava`Private`useTypeChecking\"\>"},
          {"\<\"JLink`CallJava`Private`useTypeChecking$\"\>"},
          {"\<\"JLink`CallJava`Private`usingShortContext\"\>"},
          {"\<\"JLink`CallJava`Private`usingShortContext$\"\>"},
          {"\<\"JLink`CallJava`Private`val\"\>"},
          {"\<\"JLink`CallJava`Private`val$\"\>"},
          {"\<\"JLink`CallJava`Private`warnForDups\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn1\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn1$\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn2\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn2$\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn3\"\>"},
          {"\<\"JLink`CallJava`Private`wasOn3$\"\>"},
          {"\<\"JLink`CallJava`Private`widest\"\>"},
          {"\<\"JLink`CallJava`Private`widest$\"\>"},
          {"\<\"JLink`CallJava`Private`x\"\>"},
          {"\<\"JLink`CallJava`Private`x$\"\>"},
          {"\<\"JLink`CallJava`Private`$argNames\"\>"},
          {"\<\"JLink`CallJava`Private`$byRef\"\>"},
          {"\<\"JLink`CallJava`Private`$externalCallLink\"\>"},
          {"\<\"JLink`CallJava`Private`$inPreemptiveCallToJava\"\>"},
          {"\<\"JLink`CallJava`Private`$instanceFuncCache\"\>"},
          {"\<\"JLink`CallJava`Private`$isNestedLoad\"\>"},
          {"\<\"JLink`Debug`Private`action\"\>"},
          {"\<\"JLink`Debug`Private`e\"\>"},
          {"\<\"JLink`Debug`Private`expr\"\>"},
          {"\<\"JLink`Debug`Private`exprs\"\>"},
          {"\<\"JLink`Debug`Private`e$\"\>"},
          {"\<\"JLink`Debug`Private`lev\"\>"},
          {"\<\"JLink`Debug`Private`t\"\>"},
          {"\<\"JLink`Debug`Private`test\"\>"},
          {"\<\"JLink`Debug`Private`tst\"\>"},
          {"\<\"JLink`EvaluateTo`Private`cellExpr\"\>"},
          {"\<\"JLink`EvaluateTo`Private`cellOpts\"\>"},
          {"\<\"JLink`EvaluateTo`Private`e\"\>"},
          {"\<\"JLink`EvaluateTo`Private`expr\"\>"},
          {"\<\"JLink`EvaluateTo`Private`fmt\"\>"},
          {"\<\"JLink`EvaluateTo`Private`format\"\>"},
          {"\<\"JLink`EvaluateTo`Private`frm\"\>"},
          {"\<\"JLink`EvaluateTo`Private`opts\"\>"},
          {"\<\"JLink`EvaluateTo`Private`pageWidth\"\>"},
          {"\<\"JLink`EvaluateTo`Private`ps\"\>"},
          {"\<\"JLink`EvaluateTo`Private`pWidth\"\>"},
          {"\<\"JLink`EvaluateTo`Private`result\"\>"},
          {"\<\"JLink`EvaluateTo`Private`useFE\"\>"},
          {"\<\"JLink`Exceptions`Private`a\"\>"},
          {"\<\"JLink`Exceptions`Private`a$\"\>"},
          {"\<\"JLink`Exceptions`Private`e\"\>"},
          {"\<\"JLink`Exceptions`Private`excHandler\"\>"},
          {"\<\"JLink`Exceptions`Private`excHandler$\"\>"},
          {"\<\"JLink`Exceptions`Private`handleDirtyException\"\>"},
          {"\<\"JLink`Exceptions`Private`handlePostException\"\>"},
          {"\<\"JLink`Exceptions`Private`isPost\"\>"},
          {"\<\"JLink`Exceptions`Private`junk\"\>"},
          {"\<\"JLink`Exceptions`Private`junk$\"\>"},
          {"\<\"JLink`Exceptions`Private`link\"\>"},
          {"\<\"JLink`Exceptions`Private`oldMsgPrePrint\"\>"},
          {"\<\"JLink`Exceptions`Private`readException\"\>"},
          {"\<\"JLink`Exceptions`Private`readManualResult\"\>"},
          {"\<\"JLink`Exceptions`Private`reportException\"\>"},
          {"\<\"JLink`Exceptions`Private`res\"\>"},
          {"\<\"JLink`Exceptions`Private`res$\"\>"},
          {"\<\"JLink`Exceptions`Private`str\"\>"},
          {"\<\"JLink`Exceptions`Private`str$\"\>"},
          {"\<\"JLink`Exceptions`Private`$internalJavaExceptionHandler\"\>"},
          {"\<\"JLink`FrontEndServer`Private`cmd\"\>"},
          {"\<\"JLink`FrontEndServer`Private`cmdLine\"\>"},
          {"\<\"JLink`FrontEndServer`Private`expr\"\>"},
          {"\<\"JLink`FrontEndServer`Private`feInitFunc\"\>"},
          {"\<\"JLink`FrontEndServer`Private`fePath\"\>"},
          {"\<\"JLink`FrontEndServer`Private`flags\"\>"},
          {"\<\"JLink`FrontEndServer`Private`forceLaunch\"\>"},
          {"\<\"JLink`FrontEndServer`Private`kernelHasUseFrontEnd\"\>"},
          {"\<\"JLink`FrontEndServer`Private`launchFlags\"\>"},
          {"\<\"JLink`FrontEndServer`Private`nbOpts\"\>"},
          {"\<\"JLink`FrontEndServer`Private`nbs\"\>"},
          {"\<\"JLink`FrontEndServer`Private`opts\"\>"},
          {"\<\"JLink`FrontEndServer`Private`parts\"\>"},
          {"\<\"JLink`FrontEndServer`Private`preventUnsafeFEShutdown\"\>"},
          {"\<\"JLink`FrontEndServer`Private`$externalFELink\"\>"},
          {"\<\"JLink`Information`$CreationDate\"\>"},
          {"\<\"JLink`Information`$CreationID\"\>"},
          {"\<\"JLink`Information`$ReleaseNumber\"\>"},
          {"\<\"JLink`Information`$Version\"\>"},
          {"\<\"JLink`Information`$VersionNumber\"\>"},
          {"\<\"JLink`InstallJava`Private`a\"\>"},
          {"\<\"JLink`InstallJava`Private`appDirs\"\>"},
          {"\<\"JLink`InstallJava`Private`appPaths\"\>"},
          {"\<\"JLink`InstallJava`Private`args\"\>"},
          {"\<\"JLink`InstallJava`Private`args$\"\>"},
          {"\<\"JLink`InstallJava`Private`cmdLine\"\>"},
          {"\<\"JLink`InstallJava`Private`cmdLine$\"\>"},
          {"\<\"JLink`InstallJava`Private`command\"\>"},
          {"\<\"JLink`InstallJava`Private`cp\"\>"},
          {"\<\"JLink`InstallJava`Private`CP\"\>"},
          {"\<\"JLink`InstallJava`Private`cpSep\"\>"},
          {"\<\"JLink`InstallJava`Private`cpSep$\"\>"},
          {"\<\"JLink`InstallJava`Private`cpSpec\"\>"},
          {"\<\"JLink`InstallJava`Private`cpSpec$\"\>"},
          {"\<\"JLink`InstallJava`Private`CP$\"\>"},
          {"\<\"JLink`InstallJava`Private`createCommandLine\"\>"},
          {"\<\"JLink`InstallJava`Private`DispatchToJava\"\>"},
          {"\<\"JLink`InstallJava`Private`e\"\>"},
          {"\<\"JLink`InstallJava`Private`err\"\>"},
          {"\<\"JLink`InstallJava`Private`err$\"\>"},
          {"\<\"JLink`InstallJava`Private`extraArgs\"\>"},
          {"\<\"JLink`InstallJava`Private`extraArgs$\"\>"},
          {"\<\"JLink`InstallJava`Private`e$\"\>"},
          {"\<\"JLink`InstallJava`Private`filterOptions\"\>"},
          {"\<\"JLink`InstallJava`Private`initJava\"\>"},
          {"\<\"JLink`InstallJava`Private`InstallJavaInternalOLD\"\>"},
          {"\<\"JLink`InstallJava`Private`InstallToInternalLink\"\>"},
          {"\<\"JLink`InstallJava`Private`isParentLink\"\>"},
          {"\<\"JLink`InstallJava`Private`isParentLink$\"\>"},
          {"\<\"JLink`InstallJava`Private`javaCmd\"\>"},
          {"\<\"JLink`InstallJava`Private`javaCmd$\"\>"},
          {"\<\"JLink`InstallJava`Private`javaDirs\"\>"},
          {"\<\"JLink`InstallJava`Private`jlinkDefineInternal\"\>"},
          {"\<\"JLink`InstallJava`Private`jlinkInternalCall\"\>"},
          {"\<\"JLink`InstallJava`Private`jlinkPath\"\>"},
          {"\<\"JLink`InstallJava`Private`jlinkPath$\"\>"},
          {"\<\"JLink`InstallJava`Private`jvmArgs\"\>"},
          {"\<\"JLink`InstallJava`Private`jvmArgs$\"\>"},
          {"\<\"JLink`InstallJava`Private`launcherLink\"\>"},
          {"\<\"JLink`InstallJava`Private`launcherLink$\"\>"},
          {"\<\"JLink`InstallJava`Private`link\"\>"},
          {"\<\"JLink`InstallJava`Private`linkSwitchPostFunc\"\>"},
          {"\<\"JLink`InstallJava`Private`linkSwitchPreFunc\"\>"},
          {"\<\"JLink`InstallJava`Private`link$\"\>"},
          {"\<\"JLink`InstallJava`Private`loop\"\>"},
          {"\<\"JLink`InstallJava`Private`macLink\"\>"},
          {"\<\"JLink`InstallJava`Private`macLink$\"\>"},
          {"\<\"JLink`InstallJava`Private`n\"\>"},
          {"\<\"JLink`InstallJava`Private`oldFrontEnd\"\>"},
          {"\<\"JLink`InstallJava`Private`options\"\>"},
          {"\<\"JLink`InstallJava`Private`opts\"\>"},
          {"\<\"JLink`InstallJava`Private`p\"\>"},
          {"\<\"JLink`InstallJava`Private`packet\"\>"},
          {"\<\"JLink`InstallJava`Private`pat\"\>"},
          {"\<\"JLink`InstallJava`Private`pat$\"\>"},
          {"\<\"JLink`InstallJava`Private`pkt\"\>"},
          {"\<\"JLink`InstallJava`Private`prefsSpec\"\>"},
          {"\<\"JLink`InstallJava`Private`prefsSpec$\"\>"},
          {"\<\"JLink`InstallJava`Private`prot\"\>"},
          {"\<\"JLink`InstallJava`Private`prot$\"\>"},
          {"\<\"JLink`InstallJava`Private`res\"\>"},
          {"\<\"JLink`InstallJava`Private`resetMathematica\"\>"},
          {"\<\"JLink`InstallJava`Private`result\"\>"},
          {"\<\"JLink`InstallJava`Private`result$\"\>"},
          {"\<\"JLink`InstallJava`Private`setupUILink\"\>"},
          {"\<\"JLink`InstallJava`Private`splitClasspath\"\>"},
          {"\<\"JLink`InstallJava`Private`str\"\>"},
          {"\<\"JLink`InstallJava`Private`strm\"\>"},
          {"\<\"JLink`InstallJava`Private`str$\"\>"},
          {"\<\"JLink`InstallJava`Private`tes\"\>"},
          {"\<\"JLink`InstallJava`Private`thisPkgPath\"\>"},
          {"\<\"JLink`InstallJava`Private`thisPkgPath$\"\>"},
          {"\<\"JLink`InstallJava`Private`uiLink\"\>"},
          {"\<\"JLink`InstallJava`Private`useUILink\"\>"},
          {"\<\"JLink`InstallJava`Private`useUILinkQ\"\>"},
          {"\<\"JLink`InstallJava`Private`useUILink$\"\>"},
          {"\<\"JLink`InstallJava`Private`$disablePrefs\"\>"},
          {"\<\"JLink`InstallJava`Private`$InternalLink\"\>"},
          {"\<\"JLink`InstallJava`Private`$jlink\"\>"},
          {"\<\"JLink`InstallJava`Private`$uilink\"\>"},
          {"\<\"JLink`JavaBlock`Private`e\"\>"},
          {"\<\"JLink`JavaBlock`Private`keep\"\>"},
          {"\<\"JLink`JavaBlock`Private`keep$\"\>"},
          {"\<\"JLink`JavaBlock`Private`keptObjectsSlatedForRelease\"\>"},
          {"\<\"JLink`JavaBlock`Private`keptObjectsSlatedForRelease$\"\>"},
          {"\<\"JLink`JavaBlock`Private`man\"\>"},
          {"\<\"JLink`JavaBlock`Private`nsyms\"\>"},
          {"\<\"JLink`JavaBlock`Private`nsyms$\"\>"},
          {"\<\"JLink`JavaBlock`Private`obj\"\>"},
          {"\<\"JLink`JavaBlock`Private`objs\"\>"},
          {"\<\"JLink`JavaBlock`Private`opts\"\>"},
          {"\<\"JLink`JavaBlock`Private`prevBlockRecord\"\>"},
          {"\<\"JLink`JavaBlock`Private`prevBlockRecord$\"\>"},
          {"\<\"JLink`JavaBlock`Private`release\"\>"},
          {"\<\"JLink`JavaBlock`Private`release$\"\>"},
          {"\<\"JLink`JavaBlock`Private`res\"\>"},
          {"\<\"JLink`JavaBlock`Private`result\"\>"},
          {"\<\"JLink`JavaBlock`Private`res$\"\>"},
          {"\<\"JLink`JavaBlock`Private`syms\"\>"},
          {"\<\"JLink`JavaBlock`Private`$javaBlockRecord\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`a\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`e\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`i\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`mjo1\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`mjo2\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`mjo3\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`obj\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`part\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`result\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`s\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`t\"\>"},
          {"\<\"JLink`MakeJavaObject`Private`x\"\>"},
          {"\<\"JLink`Misc`Private`applet\"\>"},
          {"\<\"JLink`Misc`Private`classIndex\"\>"},
          {"\<\"JLink`Misc`Private`cls\"\>"},
          {"\<\"JLink`Misc`Private`clsName\"\>"},
          {"\<\"JLink`Misc`Private`cls$\"\>"},
          {"\<\"JLink`Misc`Private`console\"\>"},
          {"\<\"JLink`Misc`Private`console$\"\>"},
          {"\<\"JLink`Misc`Private`defaults\"\>"},
          {"\<\"JLink`Misc`Private`doModal\"\>"},
          {"\<\"JLink`Misc`Private`e\"\>"},
          {"\<\"JLink`Misc`Private`endModal\"\>"},
          {"\<\"JLink`Misc`Private`exc\"\>"},
          {"\<\"JLink`Misc`Private`getClassLoader\"\>"},
          {"\<\"JLink`Misc`Private`handlerMappings\"\>"},
          {"\<\"JLink`Misc`Private`host\"\>"},
          {"\<\"JLink`Misc`Private`interfaces\"\>"},
          {"\<\"JLink`Misc`Private`interfaces$\"\>"},
          {"\<\"JLink`Misc`Private`intf\"\>"},
          {"\<\"JLink`Misc`Private`intfs\"\>"},
          {"\<\"JLink`Misc`Private`invHandler\"\>"},
          {"\<\"JLink`Misc`Private`invHandler$\"\>"},
          {"\<\"JLink`Misc`Private`isFirstTime\"\>"},
          {"\<\"JLink`Misc`Private`isJava\"\>"},
          {"\<\"JLink`Misc`Private`isJava$\"\>"},
          {"\<\"JLink`Misc`Private`isNET\"\>"},
          {"\<\"JLink`Misc`Private`isNET$\"\>"},
          {"\<\"JLink`Misc`Private`jc\"\>"},
          {"\<\"JLink`Misc`Private`jl\"\>"},
          {"\<\"JLink`Misc`Private`link\"\>"},
          {"\<\"JLink`Misc`Private`locs\"\>"},
          {"\<\"JLink`Misc`Private`msg\"\>"},
          {"\<\"JLink`Misc`Private`obj\"\>"},
          {"\<\"JLink`Misc`Private`obj1\"\>"},
          {"\<\"JLink`Misc`Private`obj2\"\>"},
          {"\<\"JLink`Misc`Private`optName\"\>"},
          {"\<\"JLink`Misc`Private`optNames\"\>"},
          {"\<\"JLink`Misc`Private`optNameStrings\"\>"},
          {"\<\"JLink`Misc`Private`optNameStrings$\"\>"},
          {"\<\"JLink`Misc`Private`opts\"\>"},
          {"\<\"JLink`Misc`Private`params\"\>"},
          {"\<\"JLink`Misc`Private`port\"\>"},
          {"\<\"JLink`Misc`Private`proxy\"\>"},
          {"\<\"JLink`Misc`Private`proxy$\"\>"},
          {"\<\"JLink`Misc`Private`put\"\>"},
          {"\<\"JLink`Misc`Private`releaseAllObjects\"\>"},
          {"\<\"JLink`Misc`Private`res\"\>"},
          {"\<\"JLink`Misc`Private`result\"\>"},
          {"\<\"JLink`Misc`Private`setCapture\"\>"},
          {"\<\"JLink`Misc`Private`setFirstTime\"\>"},
          {"\<\"JLink`Misc`Private`setLocation\"\>"},
          {"\<\"JLink`Misc`Private`setSize\"\>"},
          {"\<\"JLink`Misc`Private`stringifiedOptionDefaults\"\>"},
          {"\<\"JLink`Misc`Private`stringifiedOptionDefaults$\"\>"},
          {"\<\"JLink`Misc`Private`stringifiedOptionSettings\"\>"},
          {"\<\"JLink`Misc`Private`stringifiedOptionSettings$\"\>"},
          {"\<\"JLink`Misc`Private`strms\"\>"},
          {"\<\"JLink`Misc`Private`wnd\"\>"},
          {"\<\"JLink`Misc`Private`x\"\>"},
          {"\<\"JLink`Misc`Private`$complexClass\"\>"},
          {"\<\"JLink`Objects`JavaObject16777217\"\>"},
          {"\<\"JLink`Objects`JavaObject281470698520577\"\>"},
          {"\<\"JLink`Objects`JavaObject300312535498753\"\>"},
          {"\<\"JLink`Objects`JavaObject4294967297\"\>"},
          {"\<\"JLink`Package`addToJavaBlock\"\>"},
          {"\<\"JLink`Package`allow\"\>"},
          {"\<\"JLink`Package`argCount\"\>"},
          {"\<\"JLink`Package`args\"\>"},
          {"\<\"JLink`Package`Assert\"\>"},
          {"\<\"JLink`Package`AssertAction\"\>"},
          {"\<\"JLink`Package`AsyncInstall\"\>"},
          {"\<\"JLink`Package`autoClassPath\"\>"},
          {"\<\"JLink`Package`autoException\"\>"},
          {"\<\"JLink`Package`callAllUnloadClassMethods\"\>"},
          {"\<\"JLink`Package`class\"\>"},
          {"\<\"JLink`Package`classFromIndex\"\>"},
          {"\<\"JLink`Package`classIndex\"\>"},
          {"\<\"JLink`Package`classIndexFromClass\"\>"},
          {"\<\"JLink`Package`classIndexFromInstance\"\>"},
          {"\<\"JLink`Package`className\"\>"},
          {"\<\"JLink`Package`classNameFromClass\"\>"},
          {"\<\"JLink`Package`classNameFromIndex\"\>"},
          {"\<\"JLink`Package`clearComplexClass\"\>"},
          {"\<\"JLink`Package`clearJavaDefs\"\>"},
          {"\<\"JLink`Package`contextIndependentOptions\"\>"},
          {"\<\"JLink`Package`createInstanceDefs\"\>"},
          {"\<\"JLink`Package`DebugPrint\"\>"},
          {"\<\"JLink`Package`dir\"\>"},
          {"\<\"JLink`Package`dirs\"\>"},
          {"\<\"JLink`Package`enteringModal\"\>"},
          {"\<\"JLink`Package`exc\"\>"},
          {"\<\"JLink`Package`force\"\>"},
          {"\<\"JLink`Package`getActiveJavaLink\"\>"},
          {"\<\"JLink`Package`handleCleanException\"\>"},
          {"\<\"JLink`Package`indices\"\>"},
          {"\<\"JLink`Package`inherited\"\>"},
          {"\<\"JLink`Package`InstallJavaInternal\"\>"},
          {"\<\"JLink`Package`instance\"\>"},
          {"\<\"JLink`Package`instances\"\>"},
          {"\<\"JLink`Package`isBigDecimal\"\>"},
          {"\<\"JLink`Package`isBigDecimalArray2\"\>"},
          {"\<\"JLink`Package`isBigDecimalArray3\"\>"},
          {"\<\"JLink`Package`isBigDecimalList\"\>"},
          {"\<\"JLink`Package`isBigInteger\"\>"},
          {"\<\"JLink`Package`isBigIntegerArray2\"\>"},
          {"\<\"JLink`Package`isBigIntegerArray3\"\>"},
          {"\<\"JLink`Package`isBigIntegerList\"\>"},
          {"\<\"JLink`Package`isComplex\"\>"},
          {"\<\"JLink`Package`isComplexArray2\"\>"},
          {"\<\"JLink`Package`isComplexArray3\"\>"},
          {"\<\"JLink`Package`isComplexClass\"\>"},
          {"\<\"JLink`Package`isComplexList\"\>"},
          {"\<\"JLink`Package`isExprArray2\"\>"},
          {"\<\"JLink`Package`isExprArray3\"\>"},
          {"\<\"JLink`Package`isExprList\"\>"},
          {"\<\"JLink`Package`isIntegerArray2\"\>"},
          {"\<\"JLink`Package`isIntegerArray3\"\>"},
          {"\<\"JLink`Package`isIntegerList\"\>"},
          {"\<\"JLink`Package`isJavaBigDecimalArray\"\>"},
          {"\<\"JLink`Package`isJavaBigIntegerArray\"\>"},
          {"\<\"JLink`Package`isJavaBooleanArray\"\>"},
          {"\<\"JLink`Package`isJavaComplexArray\"\>"},
          {"\<\"JLink`Package`isJavaExprArray\"\>"},
          {"\<\"JLink`Package`isJavaIntegerArray\"\>"},
          {"\<\"JLink`Package`isJavaObjectArray\"\>"},
          {"\<\"JLink`Package`isJavaRealArray\"\>"},
          {"\<\"JLink`Package`isJavaStringArray\"\>"},
          {"\<\"JLink`Package`isNumberArray2\"\>"},
          {"\<\"JLink`Package`isNumberArray3\"\>"},
          {"\<\"JLink`Package`isNumberList\"\>"},
          {"\<\"JLink`Package`isObjectArray2\"\>"},
          {"\<\"JLink`Package`isObjectArray3\"\>"},
          {"\<\"JLink`Package`isObjectList\"\>"},
          {"\<\"JLink`Package`isPreemptiveKernel\"\>"},
          {"\<\"JLink`Package`isRealArray2\"\>"},
          {"\<\"JLink`Package`isRealArray3\"\>"},
          {"\<\"JLink`Package`isRealList\"\>"},
          {"\<\"JLink`Package`isServiceFrontEnd\"\>"},
          {"\<\"JLink`Package`isString\"\>"},
          {"\<\"JLink`Package`isStringArray2\"\>"},
          {"\<\"JLink`Package`isStringArray3\"\>"},
          {"\<\"JLink`Package`isStringList\"\>"},
          {"\<\"JLink`Package`issueNoDefaultCtorMessage\"\>"},
          {"\<\"JLink`Package`isTrueFalseArray2\"\>"},
          {"\<\"JLink`Package`isTrueFalseArray3\"\>"},
          {"\<\"JLink`Package`isTrueFalseList\"\>"},
          {"\<\"JLink`Package`jAddToClassPath\"\>"},
          {"\<\"JLink`Package`jAllowRaggedArrays\"\>"},
          {"\<\"JLink`Package`jAllowUIComputations\"\>"},
          {"\<\"JLink`Package`jCallJava\"\>"},
          {"\<\"JLink`Package`jClassPath\"\>"},
          {"\<\"JLink`Package`jConnectToFEServer\"\>"},
          {"\<\"JLink`Package`jDisconnectToFEServer\"\>"},
          {"\<\"JLink`Package`jForcePolling\"\>"},
          {"\<\"JLink`Package`jGC\"\>"},
          {"\<\"JLink`Package`jGetComplex\"\>"},
          {"\<\"JLink`Package`jGetConsole\"\>"},
          {"\<\"JLink`Package`jGetException\"\>"},
          {"\<\"JLink`Package`jInstanceOf\"\>"},
          {"\<\"JLink`Package`jlinkDefineExternal\"\>"},
          {"\<\"JLink`Package`jLoadClass\"\>"},
          {"\<\"JLink`Package`jOnLoadClass\"\>"},
          {"\<\"JLink`Package`jOnUnloadClass\"\>"},
          {"\<\"JLink`Package`jPeekClasses\"\>"},
          {"\<\"JLink`Package`jPeekObjects\"\>"},
          {"\<\"JLink`Package`jReflect\"\>"},
          {"\<\"JLink`Package`jReleaseAllObjects\"\>"},
          {"\<\"JLink`Package`jReleaseObject\"\>"},
          {"\<\"JLink`Package`jSameQ\"\>"},
          {"\<\"JLink`Package`jSetComplex\"\>"},
          {"\<\"JLink`Package`jSetUserDir\"\>"},
          {"\<\"JLink`Package`jShow\"\>"},
          {"\<\"JLink`Package`jThrow\"\>"},
          {"\<\"JLink`Package`jUILink\"\>"},
          {"\<\"JLink`Package`jUIThreadWaitingQ\"\>"},
          {"\<\"JLink`Package`jUnloadClass\"\>"},
          {"\<\"JLink`Package`jVal\"\>"},
          {"\<\"JLink`Package`jYieldTime\"\>"},
          {"\<\"JLink`Package`linkName\"\>"},
          {"\<\"JLink`Package`loadClassAndCreateInstanceDefs\"\>"},
          {"\<\"JLink`Package`loadClassFromJava\"\>"},
          {"\<\"JLink`Package`manualException\"\>"},
          {"\<\"JLink`Package`millis\"\>"},
          {"\<\"JLink`Package`msg\"\>"},
          {"\<\"JLink`Package`myLinkReadyQ\"\>"},
          {"\<\"JLink`Package`name\"\>"},
          {"\<\"JLink`Package`obj\"\>"},
          {"\<\"JLink`Package`obj1\"\>"},
          {"\<\"JLink`Package`obj2\"\>"},
          {"\<\"JLink`Package`objSupplyingClassLoader\"\>"},
          {"\<\"JLink`Package`osIsClassicMac\"\>"},
          {"\<\"JLink`Package`osIsMacOSX\"\>"},
          {"\<\"JLink`Package`osIsWindows\"\>"},
          {"\<\"JLink`Package`parentClassIndexFromClassIndex\"\>"},
          {"\<\"JLink`Package`prepareForManualReturn\"\>"},
          {"\<\"JLink`Package`prot\"\>"},
          {"\<\"JLink`Package`protocol\"\>"},
          {"\<\"JLink`Package`resetJavaBlock\"\>"},
          {"\<\"JLink`Package`searchForJars\"\>"},
          {"\<\"JLink`Package`Trigger\"\>"},
          {"\<\"JLink`Package`type\"\>"},
          {"\<\"JLink`Package`Verify\"\>"},
          {"\<\"JLink`Package`VerifyAction\"\>"},
          {"\<\"JLink`Package`wnd\"\>"},
          {"\<\"JLink`Package`yielder\"\>"},
          {"\<\"JLink`Package`$allowRaggedArrays\"\>"},
          {"\<\"JLink`Package`$AssertAction\"\>"},
          {"\<\"JLink`Package`$Debug\"\>"},
          {"\<\"JLink`Package`$DebugCommandLine\"\>"},
          {"\<\"JLink`Package`$DebugDups\"\>"},
          {"\<\"JLink`Package`$DebugExceptions\"\>"},
          {"\<\"JLink`Package`$DebugLevel\"\>"},
          {"\<\"JLink`Package`$inPreemptiveCallFromJava\"\>"},
          {"\<\"JLink`Package`$jlinkDir\"\>"},
          {"\<\"JLink`Package`$VerifyAction\"\>"},
          {"\<\"JLink`Reflection`Private`a\"\>"},
          {"\<\"JLink`Reflection`Private`a$\"\>"},
          {"\<\"JLink`Reflection`Private`b\"\>"},
          {"\<\"JLink`Reflection`Private`b$\"\>"},
          {"\<\"JLink`Reflection`Private`cls\"\>"},
          {"\<\"JLink`Reflection`Private`clsName\"\>"},
          {"\<\"JLink`Reflection`Private`cls$\"\>"},
          {"\<\"JLink`Reflection`Private`ctors\"\>"},
          {"\<\"JLink`Reflection`Private`d\"\>"},
          {"\<\"JLink`Reflection`Private`decl\"\>"},
          {"\<\"JLink`Reflection`Private`dropPrefixes\"\>"},
          {"\<\"JLink`Reflection`Private`d$\"\>"},
          {"\<\"JLink`Reflection`Private`extractName\"\>"},
          {"\<\"JLink`Reflection`Private`fields\"\>"},
          {"\<\"JLink`Reflection`Private`ignoreCase\"\>"},
          {"\<\"JLink`Reflection`Private`ignoreCase$\"\>"},
          {"\<\"JLink`Reflection`Private`includeInherited\"\>"},
          {"\<\"JLink`Reflection`Private`inherit\"\>"},
          {"\<\"JLink`Reflection`Private`inherit$\"\>"},
          {"\<\"JLink`Reflection`Private`isField\"\>"},
          {"\<\"JLink`Reflection`Private`isFinal\"\>"},
          {"\<\"JLink`Reflection`Private`isFinal$\"\>"},
          {"\<\"JLink`Reflection`Private`isStatic\"\>"},
          {"\<\"JLink`Reflection`Private`isStatic$\"\>"},
          {"\<\"JLink`Reflection`Private`methods\"\>"},
          {"\<\"JLink`Reflection`Private`obj\"\>"},
          {"\<\"JLink`Reflection`Private`opts\"\>"},
          {"\<\"JLink`Reflection`Private`parenPos\"\>"},
          {"\<\"JLink`Reflection`Private`parenPos$\"\>"},
          {"\<\"JLink`Reflection`Private`pat\"\>"},
          {"\<\"JLink`Reflection`Private`periodPos\"\>"},
          {"\<\"JLink`Reflection`Private`periodPos$\"\>"},
          {"\<\"JLink`Reflection`Private`s\"\>"},
          {"\<\"JLink`Reflection`Private`shortenNames\"\>"},
          {"\<\"JLink`Reflection`Private`sortOnName\"\>"},
          {"\<\"JLink`Reflection`Private`spacePos\"\>"},
          {"\<\"JLink`Reflection`Private`spacePositions\"\>"},
          {"\<\"JLink`Reflection`Private`spacePositions$\"\>"},
          {"\<\"JLink`Reflection`Private`spacePos$\"\>"},
          {"\<\"JLink`Reflection`Private`str\"\>"},
          {"\<\"JLink`Reflection`Private`str$\"\>"},
          {"\<\"JLink`Reflection`Private`x\"\>"},
          {"\<\"JLink`Sharing`Private`a\"\>"},
          {"\<\"JLink`Sharing`Private`activeLink\"\>"},
          {"\<\"JLink`Sharing`Private`b\"\>"},
          {"\<\"JLink`Sharing`Private`box\"\>"},
          {"\<\"JLink`Sharing`Private`c\"\>"},
          {"\<\"JLink`Sharing`Private`cleanupEnterExprSyntaxError\"\>"},
          {"\<\"JLink`Sharing`Private`cleanupEnterTextSyntaxError\"\>"},
          {"\<\"JLink`Sharing`Private`code\"\>"},
          {"\<\"JLink`Sharing`Private`createLinkInfo\"\>"},
          {"\<\"JLink`Sharing`Private`curLink\"\>"},
          {"\<\"JLink`Sharing`Private`curLink$\"\>"},
          {"\<\"JLink`Sharing`Private`dead\"\>"},
          {"\<\"JLink`Sharing`Private`deadPos\"\>"},
          {"\<\"JLink`Sharing`Private`deadPos$\"\>"},
          {"\<\"JLink`Sharing`Private`destroyServerNb\"\>"},
          {"\<\"JLink`Sharing`Private`destroySyntaxRule\"\>"},
          {"\<\"JLink`Sharing`Private`doPeriodical\"\>"},
          {"\<\"JLink`Sharing`Private`e\"\>"},
          {"\<\"JLink`Sharing`Private`endFEMode\"\>"},
          {"\<\"JLink`Sharing`Private`enterExpr\"\>"},
          {"\<\"JLink`Sharing`Private`enterText\"\>"},
          {"\<\"JLink`Sharing`Private`evaluator\"\>"},
          {"\<\"JLink`Sharing`Private`evaluatorName\"\>"},
          {"\<\"JLink`Sharing`Private`evaluatorName$\"\>"},
          {"\<\"JLink`Sharing`Private`evaluator$\"\>"},
          {"\<\"JLink`Sharing`Private`expr\"\>"},
          {"\<\"JLink`Sharing`Private`e$\"\>"},
          {"\<\"JLink`Sharing`Private`fe\"\>"},
          {"\<\"JLink`Sharing`Private`fes\"\>"},
          {"\<\"JLink`Sharing`Private`fesThatWillRemain\"\>"},
          {"\<\"JLink`Sharing`Private`fesThatWillRemain$\"\>"},
          {"\<\"JLink`Sharing`Private`feToksForThisLink\"\>"},
          {"\<\"JLink`Sharing`Private`feToksForThisLink$\"\>"},
          {"\<\"JLink`Sharing`Private`fe$\"\>"},
          {"\<\"JLink`Sharing`Private`getFrontEndObject\"\>"},
          {"\<\"JLink`Sharing`Private`getLink\"\>"},
          {"\<\"JLink`Sharing`Private`getTokenList\"\>"},
          {"\<\"JLink`Sharing`Private`goToFE\"\>"},
          {"\<\"JLink`Sharing`Private`goToLink\"\>"},
          {"\<\"JLink`Sharing`Private`goToLinkSyntaxError\"\>"},
          {"\<\"JLink`Sharing`Private`goToLoopback\"\>"},
          {"\<\"JLink`Sharing`Private`goToLoopbackFirstTime\"\>"},
          {"\<\"JLink`Sharing`Private`goToLoopbackImplementation\"\>"},
          {"\<\"JLink`Sharing`Private`goToOther\"\>"},
          {"\<\"JLink`Sharing`Private`id\"\>"},
          {"\<\"JLink`Sharing`Private`ids\"\>"},
          {"\<\"JLink`Sharing`Private`id$\"\>"},
          {"\<\"JLink`Sharing`Private`inst\"\>"},
          {"\<\"JLink`Sharing`Private`inStr\"\>"},
          {"\<\"JLink`Sharing`Private`isFE\"\>"},
          {"\<\"JLink`Sharing`Private`javaAvailable\"\>"},
          {"\<\"JLink`Sharing`Private`l\"\>"},
          {"\<\"JLink`Sharing`Private`last\"\>"},
          {"\<\"JLink`Sharing`Private`li\"\>"},
          {"\<\"JLink`Sharing`Private`lineNum\"\>"},
          {"\<\"JLink`Sharing`Private`lineNumber\"\>"},
          {"\<\"JLink`Sharing`Private`lineNum$\"\>"},
          {"\<\"JLink`Sharing`Private`link\"\>"},
          {"\<\"JLink`Sharing`Private`linkForThisTok\"\>"},
          {"\<\"JLink`Sharing`Private`linkForThisTok$\"\>"},
          {"\<\"JLink`Sharing`Private`linkInfo\"\>"},
          {"\<\"JLink`Sharing`Private`linkName\"\>"},
          {"\<\"JLink`Sharing`Private`linkName$\"\>"},
          {"\<\"JLink`Sharing`Private`linkResult\"\>"},
          {"\<\"JLink`Sharing`Private`linkResult$\"\>"},
          {"\<\"JLink`Sharing`Private`links\"\>"},
          {"\<\"JLink`Sharing`Private`linkStr\"\>"},
          {"\<\"JLink`Sharing`Private`links$\"\>"},
          {"\<\"JLink`Sharing`Private`linkToPointAt\"\>"},
          {"\<\"JLink`Sharing`Private`lnk\"\>"},
          {"\<\"JLink`Sharing`Private`lnk$\"\>"},
          {"\<\"JLink`Sharing`Private`loopIsParentLink\"\>"},
          {"\<\"JLink`Sharing`Private`mainLoop\"\>"},
          {"\<\"JLink`Sharing`Private`matchingRecPosition\"\>"},
          {"\<\"JLink`Sharing`Private`matchingRecPosition$\"\>"},
          {"\<\"JLink`Sharing`Private`mergeLinkInfo\"\>"},
          {"\<\"JLink`Sharing`Private`nbOpts\"\>"},
          {"\<\"JLink`Sharing`Private`nbOpts$\"\>"},
          {"\<\"JLink`Sharing`Private`netAvailable\"\>"},
          {"\<\"JLink`Sharing`Private`netLink\"\>"},
          {"\<\"JLink`Sharing`Private`netLink$\"\>"},
          {"\<\"JLink`Sharing`Private`new\"\>"},
          {"\<\"JLink`Sharing`Private`newEvalNames\"\>"},
          {"\<\"JLink`Sharing`Private`newEvalNames$\"\>"},
          {"\<\"JLink`Sharing`Private`newLinkInfoRec\"\>"},
          {"\<\"JLink`Sharing`Private`newLinkInfoRec$\"\>"},
          {"\<\"JLink`Sharing`Private`newLinkName\"\>"},
          {"\<\"JLink`Sharing`Private`newLinkName$\"\>"},
          {"\<\"JLink`Sharing`Private`old\"\>"},
          {"\<\"JLink`Sharing`Private`opts\"\>"},
          {"\<\"JLink`Sharing`Private`origEvalNames\"\>"},
          {"\<\"JLink`Sharing`Private`origEvalNames$\"\>"},
          {"\<\"JLink`Sharing`Private`p\"\>"},
          {"\<\"JLink`Sharing`Private`pairs\"\>"},
          {"\<\"JLink`Sharing`Private`parentLinkIsFE\"\>"},
          {"\<\"JLink`Sharing`Private`parentLinkIsFE$\"\>"},
          {"\<\"JLink`Sharing`Private`per\"\>"},
          {"\<\"JLink`Sharing`Private`per$\"\>"},
          {"\<\"JLink`Sharing`Private`pkt\"\>"},
          {"\<\"JLink`Sharing`Private`pos\"\>"},
          {"\<\"JLink`Sharing`Private`pos$\"\>"},
          {"\<\"JLink`Sharing`Private`preemptiveShareKernel\"\>"},
          {"\<\"JLink`Sharing`Private`preemptiveUnshareKernel\"\>"},
          {"\<\"JLink`Sharing`Private`prompt\"\>"},
          {"\<\"JLink`Sharing`Private`Prompt\"\>"},
          {"\<\"JLink`Sharing`Private`prompt$\"\>"},
          {"\<\"JLink`Sharing`Private`protocol\"\>"},
          {"\<\"JLink`Sharing`Private`protocol$\"\>"},
          {"\<\"JLink`Sharing`Private`purge\"\>"},
          {"\<\"JLink`Sharing`Private`p$\"\>"},
          {"\<\"JLink`Sharing`Private`recs\"\>"},
          {"\<\"JLink`Sharing`Private`removeDeadLinks\"\>"},
          {"\<\"JLink`Sharing`Private`removeToken\"\>"},
          {"\<\"JLink`Sharing`Private`result\"\>"},
          {"\<\"JLink`Sharing`Private`result$\"\>"},
          {"\<\"JLink`Sharing`Private`savedOut\"\>"},
          {"\<\"JLink`Sharing`Private`savedOut$\"\>"},
          {"\<\"JLink`Sharing`Private`secs\"\>"},
          {"\<\"JLink`Sharing`Private`sendInputNamePkt\"\>"},
          {"\<\"JLink`Sharing`Private`sendLoopContents\"\>"},
          {"\<\"JLink`Sharing`Private`serverNb\"\>"},
          {"\<\"JLink`Sharing`Private`serverNbs\"\>"},
          {"\<\"JLink`Sharing`Private`serverNbs$\"\>"},
          {"\<\"JLink`Sharing`Private`serverNb$\"\>"},
          {"\<\"JLink`Sharing`Private`servicePeriodicals\"\>"},
          {"\<\"JLink`Sharing`Private`serviceShareFrontEnd\"\>"},
          {"\<\"JLink`Sharing`Private`serviceUnshareFrontEnd\"\>"},
          {"\<\"JLink`Sharing`Private`setupServerNb\"\>"},
          {"\<\"JLink`Sharing`Private`setupSyntaxRule\"\>"},
          {"\<\"JLink`Sharing`Private`suppressPacket\"\>"},
          {"\<\"JLink`Sharing`Private`syntaxErrorType\"\>"},
          {"\<\"JLink`Sharing`Private`theseFes\"\>"},
          {"\<\"JLink`Sharing`Private`theseFes$\"\>"},
          {"\<\"JLink`Sharing`Private`tmpOut\"\>"},
          {"\<\"JLink`Sharing`Private`tok\"\>"},
          {"\<\"JLink`Sharing`Private`tokList\"\>"},
          {"\<\"JLink`Sharing`Private`toks\"\>"},
          {"\<\"JLink`Sharing`Private`toks$\"\>"},
          {"\<\"JLink`Sharing`Private`tok$\"\>"},
          {"\<\"JLink`Sharing`Private`unshKernel\"\>"},
          {"\<\"JLink`Sharing`Private`wasOn\"\>"},
          {"\<\"JLink`Sharing`Private`$fes\"\>"},
          {"\<\"JLink`Sharing`Private`$forceTCP\"\>"},
          {"\<\"JLink`Sharing`Private`$loop\"\>"},
          {"\<\"JLink`Sharing`Private`$nextShareKernelToken\"\>"},
          {"\<\"JLink`Sharing`Private`$periodicalLink\"\>"},
          {"\<\"JLink`Sharing`Private`$periodicals\"\>"},
          {"\<\"JLink`Sharing`Private`$prompt\"\>"},
          {"\<\"JLink`Sharing`Private`$serverNb\"\>"},
          {"\<\"JLink`Sharing`Private`$shareFrontEndTokens\"\>"},
          {"\<\"JLink`Sharing`Private`$SleepInterval\"\>"},
          {"\<\"Join\"\>"},
          {"\<\"JordanDecomposition\"\>"},
          {"\<\"JPanel`ABORT\"\>"},
          {"\<\"JPanel`ALLBITS\"\>"},
          {"\<\"JPanel`BOTTOMUALIGNMENT\"\>"},
          {"\<\"JPanel`CENTERUALIGNMENT\"\>"},
          {"\<\"JPanel`ERROR\"\>"},
          {"\<\"JPanel`FRAMEBITS\"\>"},
          {"\<\"JPanel`getDefaultLocale\"\>"},
          {"\<\"JPanel`HEIGHT\"\>"},
          {"\<\"JPanel`isLightweightComponent\"\>"},
          {"\<\"JPanel`LEFTUALIGNMENT\"\>"},
          {"\<\"JPanel`PROPERTIES\"\>"},
          {"\<\"JPanel`RIGHTUALIGNMENT\"\>"},
          {"\<\"JPanel`setDefaultLocale\"\>"},
          {"\<\"JPanel`SOMEBITS\"\>"},
          {"\<\"JPanel`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"JPanel`TOPUALIGNMENT\"\>"},
          {"\<\"JPanel`UNDEFINEDUCONDITION\"\>"},
          {"\<\"JPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"JPanel`WHENUFOCUSED\"\>"},
          {"\<\"JPanel`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"JPanel`WIDTH\"\>"},
          {"\<\"JVMArguments\"\>"},
          {"\<\"K\"\>"},
          {"\<\"KeepJavaObject\"\>"},
          {"\<\"KeepObjects\"\>"},
          {"\<\"KernelSharedQ\"\>"},
          {"\<\"Khinchin\"\>"},
          {"\<\"KleinInvariantJ\"\>"},
          {"\<\"KroneckerDelta\"\>"},
          {"\<\"Label\"\>"},
          {"\<\"label1\"\>"},
          {"\<\"label2\"\>"},
          {"\<\"label3\"\>"},
          {"\<\"label4\"\>"},
          {"\<\"label5\"\>"},
          {"\<\"LaguerreL\"\>"},
          {"\<\"Language\"\>"},
          {"\<\"LanguageCategory\"\>"},
          {"\<\"LaplaceTransform\"\>"},
          {"\<\"Larger\"\>"},
          {"\<\"Last\"\>"},
          {"\<\"LatticeReduce\"\>"},
          {"\<\"Launch\"\>"},
          {"\<\"LayoutInformation\"\>"},
          {"\<\"LCM\"\>"},
          {"\<\"LeafCount\"\>"},
          {"\<\"Left\"\>"},
          {"\<\"LegendreP\"\>"},
          {"\<\"LegendreQ\"\>"},
          {"\<\"LegendreType\"\>"},
          {"\<\"Length\"\>"},
          {"\<\"LerchPhi\"\>"},
          {"\<\"Less\"\>"},
          {"\<\"LessEqual\"\>"},
          {"\<\"LetterCharacter\"\>"},
          {"\<\"LetterQ\"\>"},
          {"\<\"Level\"\>"},
          {"\<\"Lexicographic\"\>"},
          {"\<\"LicenseID\"\>"},
          {"\<\"Lighting\"\>"},
          {"\<\"LightSources\"\>"},
          {"\<\"Limit\"\>"},
          {"\<\"LimitsPositioning\"\>"},
          {"\<\"LimitsPositioningTokens\"\>"},
          {"\<\"Limit`t\"\>"},
          {"\<\"Line\"\>"},
          {"\<\"LinearAlgebra`Arnoldi\"\>"},
          {"\<\"LinearAlgebra`BLAS`ASUM\"\>"},
          {"\<\"LinearAlgebra`BLAS`AXPY\"\>"},
          {"\<\"LinearAlgebra`BLAS`COPY\"\>"},
          {"\<\"LinearAlgebra`BLAS`DOT\"\>"},
          {"\<\"LinearAlgebra`BLAS`DOTC\"\>"},
          {"\<\"LinearAlgebra`BLAS`DOTU\"\>"},
          {"\<\"LinearAlgebra`BLAS`GEMM\"\>"},
          {"\<\"LinearAlgebra`BLAS`GEMV\"\>"},
          {"\<\"LinearAlgebra`BLAS`GER\"\>"},
          {"\<\"LinearAlgebra`BLAS`GERC\"\>"},
          {"\<\"LinearAlgebra`BLAS`GERU\"\>"},
          {"\<\"LinearAlgebra`BLAS`HERK\"\>"},
          {"\<\"LinearAlgebra`BLAS`IAMAX\"\>"},
          {"\<\"LinearAlgebra`BLAS`NestedPart\"\>"},
          {"\<\"LinearAlgebra`BLAS`NRM2\"\>"},
          {"\<\"LinearAlgebra`BLAS`ROT\"\>"},
          {"\<\"LinearAlgebra`BLAS`ROTG\"\>"},
          {"\<\"LinearAlgebra`BLAS`SCAL\"\>"},
          {"\<\"LinearAlgebra`BLAS`SWAP\"\>"},
          {"\<\"LinearAlgebra`BLAS`SYRK\"\>"},
          {"\<\"LinearAlgebra`BLAS`TestArgument\"\>"},
          {"\<\"LinearAlgebra`BLAS`TRMM\"\>"},
          {"\<\"LinearAlgebra`BLAS`TRMV\"\>"},
          {"\<\"LinearAlgebra`BLAS`TRSM\"\>"},
          {"\<\"LinearAlgebra`BLAS`TRSV\"\>"},
          {"\<\"LinearAlgebra`Direct\"\>"},
          {"\<\"LinearAlgebra`Implementations`InversePermutation\"\>"},
          {"\<\"LinearAlgebra`Implementations`PermutationQ\"\>"},
          {"\<\"LinearAlgebra`LAPACK`ComputedParams\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEBAK\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEBAL\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GECON\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEEQU\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEEV\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEHRD\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEQP3\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GEQRF\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GERFS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GESV\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GESVX\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GETRF\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GETRI\"\>"},
          {"\<\"LinearAlgebra`LAPACK`GETRS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`HSEQR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LACON\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LACPY\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LADIV\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LAHRD\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LALN2\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LAMCH\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LANGE\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LANHS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LANTR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LANV2\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LAPY2\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LAQGE\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARF\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARFB\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARFG\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARFT\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARFX\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LARTG\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LASCL\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LASET\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LASSQ\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LASWP\"\>"},
          {"\<\"LinearAlgebra`LAPACK`LATRS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`ORGHR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`ORGQR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`ORMQR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`PermutationToPivot\"\>"},
          {"\<\"LinearAlgebra`LAPACK`PivotToPermutation\"\>"},
          {"\<\"LinearAlgebra`LAPACK`POSV\"\>"},
          {"\<\"LinearAlgebra`LAPACK`POTRF\"\>"},
          {"\<\"LinearAlgebra`LAPACK`POTRS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`SYTRF\"\>"},
          {"\<\"LinearAlgebra`LAPACK`SYTRS\"\>"},
          {"\<\"LinearAlgebra`LAPACK`TREVC\"\>"},
          {"\<\"LinearAlgebra`LAPACK`TRTRI\"\>"},
          {"\<\"LinearAlgebra`LAPACK`UNGHR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`UNGQR\"\>"},
          {"\<\"LinearAlgebra`LAPACK`UNMQR\"\>"},
          {"\<\"LinearAlgebra`LeastSquares\"\>"},
          {"\<\"LinearAlgebra`LinearSolve`IterativeRefinement\"\>"},
          {"\<\"LinearAlgebra`LinearSolve`IterativeRefinementLinearSolve\"\>"}\
,
          {"\<\"LinearAlgebra`LinearSolve`Krylov\"\>"},
          {"\<\"LinearAlgebra`MatrixCayleyTransform\"\>"},
          {"\<\"LinearAlgebra`MatrixConditionNumber\"\>"},
          {"\<\"LinearAlgebra`MatrixPolynomial\"\>"},
          {"\<\"LinearAlgebra`Private`MatrixScale\"\>"},
          {"\<\"LinearAlgebra`Private`MatrixScalingFactor\"\>"},
          {"\<\"LinearAlgebra`VandermondeInverse\"\>"},
          {"\<\"LinearAlgebra`VandermondeMatrix\"\>"},
          {"\<\"LinearAlgebra`VandermondeResidual\"\>"},
          {"\<\"LinearAlgebra`VandermondeSolve\"\>"},
          {"\<\"LinearProgramming\"\>"},
          {"\<\"LinearSolve\"\>"},
          {"\<\"LinearSolveFunction\"\>"},
          {"\<\"LineBreak\"\>"},
          {"\<\"LinebreakAdjustments\"\>"},
          {"\<\"LineBreakWithin\"\>"},
          {"\<\"LineForm\"\>"},
          {"\<\"LineIndent\"\>"},
          {"\<\"LineSpacing\"\>"},
          {"\<\"LineWrapParts\"\>"},
          {"\<\"LinkActivate\"\>"},
          {"\<\"LinkClose\"\>"},
          {"\<\"LinkConnect\"\>"},
          {"\<\"LinkConnectedQ\"\>"},
          {"\<\"LinkCreate\"\>"},
          {"\<\"LinkError\"\>"},
          {"\<\"LinkFlush\"\>"},
          {"\<\"LinkHost\"\>"},
          {"\<\"LinkInterrupt\"\>"},
          {"\<\"LinkLaunch\"\>"},
          {"\<\"LinkMode\"\>"},
          {"\<\"LinkObject\"\>"},
          {"\<\"LinkOpen\"\>"},
          {"\<\"LinkOptions\"\>"},
          {"\<\"LinkPatterns\"\>"},
          {"\<\"LinkProtocol\"\>"},
          {"\<\"LinkRead\"\>"},
          {"\<\"LinkReadHeld\"\>"},
          {"\<\"LinkReadyQ\"\>"},
          {"\<\"Links\"\>"},
          {"\<\"LinkWrite\"\>"},
          {"\<\"LinkWriteHeld\"\>"},
          {"\<\"List\"\>"},
          {"\<\"Listable\"\>"},
          {"\<\"ListContourPlot\"\>"},
          {"\<\"ListConvolve\"\>"},
          {"\<\"ListCorrelate\"\>"},
          {"\<\"ListDensityPlot\"\>"},
          {"\<\"Listen\"\>"},
          {"\<\"ListInterpolation\"\>"},
          {"\<\"ListPlay\"\>"},
          {"\<\"ListPlot\"\>"},
          {"\<\"ListPlot3D\"\>"},
          {"\<\"ListQ\"\>"},
          {"\<\"Literal\"\>"},
          {"\<\"LiteralSearch\"\>"},
          {"\<\"load\"\>"},
          {"\<\"LoadClass\"\>"},
          {"\<\"LoadJavaClass\"\>"},
          {"\<\"loadLibrary\"\>"},
          {"\<\"Locked\"\>"},
          {"\<\"Log\"\>"},
          {"\<\"LogGamma\"\>"},
          {"\<\"LogicalExpand\"\>"},
          {"\<\"LogIntegral\"\>"},
          {"\<\"LongestMatch\"\>"},
          {"\<\"LongForm\"\>"},
          {"\<\"Loopback\"\>"},
          {"\<\"LowerCaseQ\"\>"},
          {"\<\"LUBackSubstitution\"\>"},
          {"\<\"LUDecomposition\"\>"},
          {"\<\"MachineID\"\>"},
          {"\<\"MachineName\"\>"},
          {"\<\"MachineNumberQ\"\>"},
          {"\<\"MachinePrecision\"\>"},
          {"\<\"MacintoshSystemPageSetup\"\>"},
          {"\<\"Magenta\"\>"},
          {"\<\"Magnification\"\>"},
          {"\<\"MainSolve\"\>"},
          {"\<\"MakeBoxes\"\>"},
          {"\<\"MakeExpression\"\>"},
          {"\<\"MakeJavaExpr\"\>"},
          {"\<\"MakeJavaObject\"\>"},
          {"\<\"MakeRules\"\>"},
          {"\<\"MantissaExponent\"\>"},
          {"\<\"Manual\"\>"},
          {"\<\"Map\"\>"},
          {"\<\"MapAll\"\>"},
          {"\<\"MapAt\"\>"},
          {"\<\"MapIndexed\"\>"},
          {"\<\"mapLibraryName\"\>"},
          {"\<\"MapThread\"\>"},
          {"\<\"MatchLocalNameQ\"\>"},
          {"\<\"MatchLocalNames\"\>"},
          {"\<\"MatchQ\"\>"},
          {"\<\"MathematicaModel`create\"\>"},
          {"\<\"MathematicaNotation\"\>"},
          {"\<\"mathFrame\"\>"},
          {"\<\"MathFrame`ABORT\"\>"},
          {"\<\"MathFrame`ALLBITS\"\>"},
          {"\<\"MathFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"MathFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"MathFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"MathFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"MathFrame`ERROR\"\>"},
          {"\<\"MathFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`FRAMEBITS\"\>"},
          {"\<\"MathFrame`getFrames\"\>"},
          {"\<\"MathFrame`HANDUCURSOR\"\>"},
          {"\<\"MathFrame`HEIGHT\"\>"},
          {"\<\"MathFrame`ICONIFIED\"\>"},
          {"\<\"MathFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"MathFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"MathFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"MathFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"MathFrame`MOVEUCURSOR\"\>"},
          {"\<\"MathFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`NORMAL\"\>"},
          {"\<\"MathFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`PROPERTIES\"\>"},
          {"\<\"MathFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"MathFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`SOMEBITS\"\>"},
          {"\<\"MathFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"MathFrame`TEXTUCURSOR\"\>"},
          {"\<\"MathFrame`TOPUALIGNMENT\"\>"},
          {"\<\"MathFrame`WAITUCURSOR\"\>"},
          {"\<\"MathFrame`WIDTH\"\>"},
          {"\<\"MathFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"MathGraphicsJPanel`ABORT\"\>"},
          {"\<\"MathGraphicsJPanel`ALLBITS\"\>"},
          {"\<\"MathGraphicsJPanel`BOTTOMUALIGNMENT\"\>"},
          {"\<\"MathGraphicsJPanel`CENTERUALIGNMENT\"\>"},
          {"\<\"MathGraphicsJPanel`ERROR\"\>"},
          {"\<\"MathGraphicsJPanel`FRAMEBITS\"\>"},
          {"\<\"MathGraphicsJPanel`getDefaultLocale\"\>"},
          {"\<\"MathGraphicsJPanel`GRAPHICS\"\>"},
          {"\<\"MathGraphicsJPanel`HEIGHT\"\>"},
          {"\<\"MathGraphicsJPanel`isLightweightComponent\"\>"},
          {"\<\"MathGraphicsJPanel`LEFTUALIGNMENT\"\>"},
          {"\<\"MathGraphicsJPanel`PROPERTIES\"\>"},
          {"\<\"MathGraphicsJPanel`RIGHTUALIGNMENT\"\>"},
          {"\<\"MathGraphicsJPanel`setDefaultLocale\"\>"},
          {"\<\"MathGraphicsJPanel`SOMEBITS\"\>"},
          {"\<\"MathGraphicsJPanel`TOOLUTIPUTEXTUKEY\"\>"},
          {"\<\"MathGraphicsJPanel`TOPUALIGNMENT\"\>"},
          {"\<\"MathGraphicsJPanel`TYPESET\"\>"},
          {"\<\"MathGraphicsJPanel`UNDEFINEDUCONDITION\"\>"},
          {"\<\"MathGraphicsJPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT\"\>"},
          {"\<\"MathGraphicsJPanel`WHENUFOCUSED\"\>"},
          {"\<\"MathGraphicsJPanel`WHENUINUFOCUSEDUWINDOW\"\>"},
          {"\<\"MathGraphicsJPanel`WIDTH\"\>"},
          {"\<\"MathieuC\"\>"},
          {"\<\"MathieuCharacteristicA\"\>"},
          {"\<\"MathieuCharacteristicB\"\>"},
          {"\<\"MathieuCharacteristicExponent\"\>"},
          {"\<\"MathieuCPrime\"\>"},
          {"\<\"MathieuS\"\>"},
          {"\<\"MathieuSPrime\"\>"},
          {"\<\"MathJFrame`ABORT\"\>"},
          {"\<\"MathJFrame`ALLBITS\"\>"},
          {"\<\"MathJFrame`BOTTOMUALIGNMENT\"\>"},
          {"\<\"MathJFrame`CENTERUALIGNMENT\"\>"},
          {"\<\"MathJFrame`CROSSHAIRUCURSOR\"\>"},
          {"\<\"MathJFrame`DEFAULTUCURSOR\"\>"},
          {"\<\"MathJFrame`DISPOSEUONUCLOSE\"\>"},
          {"\<\"MathJFrame`DOUNOTHINGUONUCLOSE\"\>"},
          {"\<\"MathJFrame`ERROR\"\>"},
          {"\<\"MathJFrame`EURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`EXITUONUCLOSE\"\>"},
          {"\<\"MathJFrame`FRAMEBITS\"\>"},
          {"\<\"MathJFrame`getFrames\"\>"},
          {"\<\"MathJFrame`HANDUCURSOR\"\>"},
          {"\<\"MathJFrame`HEIGHT\"\>"},
          {"\<\"MathJFrame`HIDEUONUCLOSE\"\>"},
          {"\<\"MathJFrame`ICONIFIED\"\>"},
          {"\<\"MathJFrame`isDefaultLookAndFeelDecorated\"\>"},
          {"\<\"MathJFrame`LEFTUALIGNMENT\"\>"},
          {"\<\"MathJFrame`MAXIMIZEDUBOTH\"\>"},
          {"\<\"MathJFrame`MAXIMIZEDUHORIZ\"\>"},
          {"\<\"MathJFrame`MAXIMIZEDUVERT\"\>"},
          {"\<\"MathJFrame`MOVEUCURSOR\"\>"},
          {"\<\"MathJFrame`NEURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`NORMAL\"\>"},
          {"\<\"MathJFrame`NURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`NWURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`PROPERTIES\"\>"},
          {"\<\"MathJFrame`RIGHTUALIGNMENT\"\>"},
          {"\<\"MathJFrame`setDefaultLookAndFeelDecorated\"\>"},
          {"\<\"MathJFrame`SEURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`SOMEBITS\"\>"},
          {"\<\"MathJFrame`SURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`SWURESIZEUCURSOR\"\>"},
          {"\<\"MathJFrame`TEXTUCURSOR\"\>"},
          {"\<\"MathJFrame`TOPUALIGNMENT\"\>"},
          {"\<\"MathJFrame`WAITUCURSOR\"\>"},
          {"\<\"MathJFrame`WIDTH\"\>"},
          {"\<\"MathJFrame`WURESIZEUCURSOR\"\>"},
          {"\<\"MathLink`AddSharingLink\"\>"},
          {"\<\"MathLink`AllowPreemptive\"\>"},
          {"\<\"MathLink`CallFrontEnd\"\>"},
          {"\<\"MathLink`CallFrontEndHeld\"\>"},
          {"\<\"MathLink`CreateFrontEndLink\"\>"},
          {"\<\"MathLink`CreateFrontEndLinkProtocol\"\>"},
          {"\<\"MathLink`CreateFrontEndLinks\"\>"},
          {"\<\"MathLink`EnablePreemptiveFunctions\"\>"},
          {"\<\"MathLink`FrontEndBlock\"\>"},
          {"\<\"MathLink`GetMessageLink\"\>"},
          {"\<\"MathLink`ImmediateStart\"\>"},
          {"\<\"MathLink`Information`$InterfaceNumber\"\>"},
          {"\<\"MathLink`Information`$RevisionNumber\"\>"},
          {"\<\"MathLink`IsNotebookFrontEnd\"\>"},
          {"\<\"MathLink`IsPreemptive\"\>"},
          {"\<\"MathLink`LinkAddInterruptMessageHandler\"\>"},
          {"\<\"MathLink`LinkDeviceInformation\"\>"},
          {"\<\"MathLink`LinkGetPrintFullSymbols\"\>"},
          {"\<\"MathLink`LinkRemoveInterruptMessageHandler\"\>"},
          {"\<\"MathLink`LinkRemoveYieldFunction\"\>"},
          {"\<\"MathLink`LinkSetPrintFullSymbols\"\>"},
          {"\<\"MathLink`LinkSwitchPost\"\>"},
          {"\<\"MathLink`LinkSwitchPre\"\>"},
          {"\<\"MathLink`MainLoopIdleEvaluation\"\>"},
          {"\<\"MathLink`NotebookFrontEndLinkQ\"\>"},
          {"\<\"MathLink`RemoveSharingLink\"\>"},
          {"\<\"MathLink`RestoreFrontEnd\"\>"},
          {"\<\"MathLink`SetFrontEnd\"\>"},
          {"\<\"MathLink`SetMessageLink\"\>"},
          {"\<\"MathLink`SetServiceFrontEnd\"\>"},
          {"\<\"MathLink`SharingLinks\"\>"},
          {"\<\"MathLink`$PreemptiveLink\"\>"},
          {"\<\"MathLink`$ServiceLink\"\>"},
          {"\<\"MathLink`$SlaveLink\"\>"},
          {"\<\"MathMLForm\"\>"},
          {"\<\"MathMLText\"\>"},
          {"\<\"mathPanel\"\>"},
          {"\<\"MatrixExp\"\>"},
          {"\<\"MatrixForm\"\>"},
          {"\<\"MatrixPower\"\>"},
          {"\<\"MatrixQ\"\>"},
          {"\<\"MatrixRank\"\>"},
          {"\<\"Max\"\>"},
          {"\<\"MaxBend\"\>"},
          {"\<\"Maximize\"\>"},
          {"\<\"MaxIterations\"\>"},
          {"\<\"MaxMemoryUsed\"\>"},
          {"\<\"MaxPlotPoints\"\>"},
          {"\<\"MaxPoints\"\>"},
          {"\<\"MaxRecursion\"\>"},
          {"\<\"MaxStepFraction\"\>"},
          {"\<\"MaxSteps\"\>"},
          {"\<\"MaxStepSize\"\>"},
          {"\<\"Mean\"\>"},
          {"\<\"Median\"\>"},
          {"\<\"MeijerG\"\>"},
          {"\<\"MemberQ\"\>"},
          {"\<\"MemoryConstrained\"\>"},
          {"\<\"MemoryInUse\"\>"},
          {"\<\"MenuPacket\"\>"},
          {"\<\"Mesh\"\>"},
          {"\<\"MeshRange\"\>"},
          {"\<\"MeshStyle\"\>"},
          {"\<\"Message\"\>"},
          {"\<\"MessageList\"\>"},
          {"\<\"MessageName\"\>"},
          {"\<\"MessageOptions\"\>"},
          {"\<\"MessagePacket\"\>"},
          {"\<\"Messages\"\>"},
          {"\<\"MessagesNotebook\"\>"},
          {"\<\"MetaCharacters\"\>"},
          {"\<\"Method\"\>"},
          {"\<\"MethodFunction\"\>"},
          {"\<\"MethodOptions\"\>"},
          {"\<\"Methods\"\>"},
          {"\<\"Min\"\>"},
          {"\<\"minAgent\"\>"},
          {"\<\"minAgent$\"\>"},
          {"\<\"minDist\"\>"},
          {"\<\"minDist$\"\>"},
          {"\<\"Minimize\"\>"},
          {"\<\"Minors\"\>"},
          {"\<\"MinRecursion\"\>"},
          {"\<\"MinSize\"\>"},
          {"\<\"Minus\"\>"},
          {"\<\"MLFS`Close\"\>"},
          {"\<\"MLFS`CopyDirectory\"\>"},
          {"\<\"MLFS`CopyFile\"\>"},
          {"\<\"MLFS`CreateDirectory\"\>"},
          {"\<\"MLFS`DeleteDirectory\"\>"},
          {"\<\"MLFS`DeleteFile\"\>"},
          {"\<\"MLFS`FileByteCount\"\>"},
          {"\<\"MLFS`FileDate\"\>"},
          {"\<\"MLFS`FileNames\"\>"},
          {"\<\"MLFS`FileType\"\>"},
          {"\<\"MLFS`Get\"\>"},
          {"\<\"MLFS`OpenAppend\"\>"},
          {"\<\"MLFS`OpenRead\"\>"},
          {"\<\"MLFS`OpenWrite\"\>"},
          {"\<\"MLFS`Put\"\>"},
          {"\<\"MLFS`PutAppend\"\>"},
          {"\<\"MLFS`Read\"\>"},
          {"\<\"MLFS`RenameDirectory\"\>"},
          {"\<\"MLFS`RenameFile\"\>"},
          {"\<\"MLFS`SetFileDate\"\>"},
          {"\<\"MLFS`SetStreamPosition\"\>"},
          {"\<\"MLFS`StreamPosition\"\>"},
          {"\<\"MLFS`WriteString\"\>"},
          {"\<\"mml\"\>"},
          {"\<\"Mod\"\>"},
          {"\<\"Mode\"\>"},
          {"\<\"Modular\"\>"},
          {"\<\"ModularLambda\"\>"},
          {"\<\"Module\"\>"},
          {"\<\"Modulus\"\>"},
          {"\<\"MoebiusMu\"\>"},
          {"\<\"MonomialOrder\"\>"},
          {"\<\"MonteCarlo\"\>"},
          {"\<\"Most\"\>"},
          {"\<\"motion\"\>"},
          {"\<\"motion0\"\>"},
          {"\<\"MouseEvent`ACTIONUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`ADJUSTMENTUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`ALTUDOWNUMASK\"\>"},
          {"\<\"MouseEvent`ALTUGRAPHUDOWNUMASK\"\>"},
          {"\<\"MouseEvent`ALTUGRAPHUMASK\"\>"},
          {"\<\"MouseEvent`ALTUMASK\"\>"},
          {"\<\"MouseEvent`BUTTON1\"\>"},
          {"\<\"MouseEvent`BUTTON1UDOWNUMASK\"\>"},
          {"\<\"MouseEvent`BUTTON1UMASK\"\>"},
          {"\<\"MouseEvent`BUTTON2\"\>"},
          {"\<\"MouseEvent`BUTTON2UDOWNUMASK\"\>"},
          {"\<\"MouseEvent`BUTTON2UMASK\"\>"},
          {"\<\"MouseEvent`BUTTON3\"\>"},
          {"\<\"MouseEvent`BUTTON3UDOWNUMASK\"\>"},
          {"\<\"MouseEvent`BUTTON3UMASK\"\>"},
          {"\<\"MouseEvent`COMPONENTUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`COMPONENTUFIRST\"\>"},
          {"\<\"MouseEvent`COMPONENTUHIDDEN\"\>"},
          {"\<\"MouseEvent`COMPONENTULAST\"\>"},
          {"\<\"MouseEvent`COMPONENTUMOVED\"\>"},
          {"\<\"MouseEvent`COMPONENTURESIZED\"\>"},
          {"\<\"MouseEvent`COMPONENTUSHOWN\"\>"},
          {"\<\"MouseEvent`CONTAINERUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`CTRLUDOWNUMASK\"\>"},
          {"\<\"MouseEvent`CTRLUMASK\"\>"},
          {"\<\"MouseEvent`FOCUSUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`getModifiersExText\"\>"},
          {"\<\"MouseEvent`getMouseModifiersText\"\>"},
          {"\<\"MouseEvent`HIERARCHYUBOUNDSUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`HIERARCHYUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`INPUTUMETHODUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`INVOCATIONUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`ITEMUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`KEYUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`METAUDOWNUMASK\"\>"},
          {"\<\"MouseEvent`METAUMASK\"\>"},
          {"\<\"MouseEvent`MOUSEUCLICKED\"\>"},
          {"\<\"MouseEvent`MOUSEUDRAGGED\"\>"},
          {"\<\"MouseEvent`MOUSEUENTERED\"\>"},
          {"\<\"MouseEvent`MOUSEUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`MOUSEUEXITED\"\>"},
          {"\<\"MouseEvent`MOUSEUFIRST\"\>"},
          {"\<\"MouseEvent`MOUSEULAST\"\>"},
          {"\<\"MouseEvent`MOUSEUMOTIONUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`MOUSEUMOVED\"\>"},
          {"\<\"MouseEvent`MOUSEUPRESSED\"\>"},
          {"\<\"MouseEvent`MOUSEURELEASED\"\>"},
          {"\<\"MouseEvent`MOUSEUWHEEL\"\>"},
          {"\<\"MouseEvent`MOUSEUWHEELUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`NOBUTTON\"\>"},
          {"\<\"MouseEvent`PAINTUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`RESERVEDUIDUMAX\"\>"},
          {"\<\"MouseEvent`SHIFTUDOWNUMASK\"\>"},
          {"\<\"MouseEvent`SHIFTUMASK\"\>"},
          {"\<\"MouseEvent`TEXTUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`WINDOWUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`WINDOWUFOCUSUEVENTUMASK\"\>"},
          {"\<\"MouseEvent`WINDOWUSTATEUEVENTUMASK\"\>"},
          {"\<\"mouseOffset\"\>"},
          {"\<\"mouseOffset$\"\>"},
          {"\<\"MousePointerNote\"\>"},
          {"\<\"mousePressedFunc\"\>"},
          {"\<\"MultiDimensional\"\>"},
          {"\<\"MultilaunchWarning\"\>"},
          {"\<\"MultilineFunction\"\>"},
          {"\<\"Multinomial\"\>"},
          {"\<\"MultiplicativeOrder\"\>"},
          {"\<\"Multiplicity\"\>"},
          {"\<\"MultivariateResultant`DixonResultant\"\>"},
          {"\<\"MultivariateResultant`MacaulayResultant\"\>"},
          {"\<\"MultivariateResultant`ResultantSystems\"\>"},
          {"\<\"MultivariateResultant`UResultant\"\>"},
          {"\<\"N\"\>"},
          {"\<\"NameQ\"\>"},
          {"\<\"Names\"\>"},
          {"\<\"Nand\"\>"},
          {"\<\"NBernoulliB\"\>"},
          {"\<\"NDSolve\"\>"},
          {"\<\"NDSolve`Adams\"\>"},
          {"\<\"NDSolve`BaderSequenceFunction\"\>"},
          {"\<\"NDSolve`BDF\"\>"},
          {"\<\"NDSolve`BulirschSequenceFunction\"\>"},
          {"\<\"NDSolve`Chasing\"\>"},
          {"\<\"NDSolve`Chasing`Implementation`ChaseInitialConditions\"\>"},
          {"\<\"NDSolve`Chasing`NonlinearChasing\"\>"},
          {"\<\"NDSolve`Composition\"\>"},
          {"\<\"NDSolve`ConsistentCoefficientsQ\"\>"},
          {"\<\"NDSolve`CreateMethodData\"\>"},
          {"\<\"NDSolve`CreateWorkspace\"\>"},
          {"\<\"NDSolve`CreateWorkspaceList\"\>"},
          {"\<\"NDSolve`CubicHermite\"\>"},
          {"\<\"NDSolve`DCayleyInverse\"\>"},
          {"\<\"NDSolve`DExpInverse\"\>"},
          {"\<\"NDSolve`DExpInverseCoefficients\"\>"},
          {"\<\"NDSolve`DoubleStep\"\>"},
          {"\<\"NDSolve`EmbeddedExplicitRungeKuttaCoefficients\"\>"},
          {"\<\"NDSolve`EstimateStartingStep\"\>"},
          {"\<\"NDSolve`EventLocator\"\>"},
          {"\<\"NDSolve`EventLocator`BracketEvent\"\>"},
          {"\<\"NDSolve`EventLocator`Brent\"\>"},
          {"\<\"NDSolve`ExplicitEuler\"\>"},
          {"\<\"NDSolve`ExplicitMidpoint\"\>"},
          {"\<\"NDSolve`ExplicitModifiedMidpoint\"\>"},
          {"\<\"NDSolve`ExplicitRungeKutta\"\>"},
          {"\<\"NDSolve`Extrapolation\"\>"},
          {"\<\"NDSolve`FiniteDifferenceDerivative\"\>"},
          {"\<\"NDSolve`FiniteDifferenceDerivativeFunction\"\>"},
          {"\<\"NDSolve`FiniteDifferenceDerivativeFunction`Grid\"\>"},
          {"\<\"NDSolve`FixedPoint\"\>"},
          {"\<\"NDSolve`FixedStep\"\>"},
          {"\<\"NDSolve`GetDefaultDifferenceOrder\"\>"},
          {"\<\"NDSolve`GetMethodOptionValues\"\>"},
          {"\<\"NDSolve`GMRES\"\>"},
          {"\<\"NDSolve`HairerOstermannSequenceFunction\"\>"},
          {"\<\"NDSolve`HarmonicSequenceFunction\"\>"},
          {"\<\"NDSolve`IDA\"\>"},
          {"\<\"NDSolve`ImplicitRungeKutta\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaAdjointCoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaCoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaGaussCoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaLobattoIIIACoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaLobattoIIIBCoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaLobattoIIICCoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaRadauIACoefficients\"\>"},
          {"\<\"NDSolve`ImplicitRungeKuttaRadauIIACoefficients\"\>"},
          {"\<\"NDSolve`InitializeMethod\"\>"},
          {"\<\"NDSolve`InitializeSubmethod\"\>"},
          {"\<\"NDSolve`InitializeSubmethods\"\>"},
          {"\<\"NDSolve`InvokeMethod\"\>"},
          {"\<\"NDSolve`Iterate\"\>"},
          {"\<\"NDSolve`LinearlyImplicitEuler\"\>"},
          {"\<\"NDSolve`LinearlyImplicitMidpoint\"\>"},
          {"\<\"NDSolve`LinearlyImplicitModifiedMidpoint\"\>"},
          {"\<\"NDSolve`LocalInterpolation\"\>"},
          {"\<\"NDSolve`LocallyExact\"\>"},
          {"\<\"NDSolve`LocalSeries\"\>"},
          {"\<\"NDSolve`LSODA\"\>"},
          {"\<\"NDSolve`MethodData\"\>"},
          {"\<\"NDSolve`MethodOfLines\"\>"},
          {"\<\"NDSolve`MethodOfLines`TensorProductGrid\"\>"},
          {"\<\"NDSolve`MethodSymbol\"\>"},
          {"\<\"NDSolve`Newton\"\>"},
          {"\<\"NDSolve`Newton`Band\"\>"},
          {"\<\"NDSolve`NumericalFunctionToEquations\"\>"},
          {"\<\"NDSolve`OptimalRoundingSequenceFunction\"\>"},
          {"\<\"NDSolve`OrthogonalProjection\"\>"},
          {"\<\"NDSolve`Private`TestIVPCopy\"\>"},
          {"\<\"NDSolve`ProcessEquations\"\>"},
          {"\<\"NDSolve`ProcessOptionNames\"\>"},
          {"\<\"NDSolve`ProcessSolutions\"\>"},
          {"\<\"NDSolve`Projection\"\>"},
          {"\<\"NDSolve`Reinitialize\"\>"},
          {"\<\"NDSolve`ReinitializeVector\"\>"},
          {"\<\"NDSolve`RombergSequenceFunction\"\>"},
          {"\<\"NDSolve`SamePrecisionQ\"\>"},
          {"\<\"NDSolve`ScaledVectorNorm\"\>"},
          {"\<\"NDSolve`Splitting\"\>"},
          {"\<\"NDSolve`StateData\"\>"},
          {"\<\"NDSolve`StateData`ProcessExpression\"\>"},
          {"\<\"NDSolve`StiffnessSwitching\"\>"},
          {"\<\"NDSolve`StiffnessTest\"\>"},
          {"\<\"NDSolve`StiffnessTestOptionValues\"\>"},
          {"\<\"NDSolve`StringName\"\>"},
          {"\<\"NDSolve`SymmetricCompositionCoefficients\"\>"},
          {"\<\"NDSolve`SymmetricCompositionSymmetricMethodCoefficients\"\>"},\

          {"\<\"NDSolve`SymplecticPartitionedRungeKutta\"\>"},
          {"\<\"NDSolve`SymplecticPartitionedRungeKuttaCoefficients\"\>"},
          {"\<\"NDSolve`TestImplicitSolver\"\>"},
          {"\<\"NDSolve`ToSymbol\"\>"},
          {"\<\"NDSolve`ValidNumericalFunctionQ\"\>"},
          {"\<\"NDSolve`ValidScaledVectorNormQ\"\>"},
          {"\<\"NDSolve`$EventSolution\"\>"},
          {"\<\"NDSolve`$NDSolveVersion\"\>"},
          {"\<\"NeedCurrentFrontEndPackagePacket\"\>"},
          {"\<\"NeedCurrentFrontEndSymbolsPacket\"\>"},
          {"\<\"Needs\"\>"},
          {"\<\"Negative\"\>"},
          {"\<\"Nest\"\>"},
          {"\<\"NestedScriptRules\"\>"},
          {"\<\"NestList\"\>"},
          {"\<\"NestWhile\"\>"},
          {"\<\"NestWhileList\"\>"},
          {"\<\"NETLink`NETLink\"\>"},
          {"\<\"NETLink`NETObjectQ\"\>"},
          {"\<\"NETLink`Package`nAllowUIComputations\"\>"},
          {"\<\"NETLink`Package`nConnectToFEServer\"\>"},
          {"\<\"NETLink`Package`nDisconnectToFEServer\"\>"},
          {"\<\"NETLink`Package`nShareKernel\"\>"},
          {"\<\"NevilleThetaC\"\>"},
          {"\<\"NevilleThetaD\"\>"},
          {"\<\"NevilleThetaN\"\>"},
          {"\<\"NevilleThetaS\"\>"},
          {"\<\"Newton\"\>"},
          {"\<\"Next\"\>"},
          {"\<\"NHoldAll\"\>"},
          {"\<\"NHoldFirst\"\>"},
          {"\<\"NHoldRest\"\>"},
          {"\<\"NIntegrate\"\>"},
          {"\<\"NIntegrate`OscNInt`OscNInt\"\>"},
          {"\<\"NMaximize\"\>"},
          {"\<\"NMinimize\"\>"},
          {"\<\"NMinimize`DifferentialEvolution\"\>"},
          {"\<\"NMinimize`NelderMead\"\>"},
          {"\<\"NMinimize`NonlinearInteriorPoint\"\>"},
          {"\<\"NMinimize`RandomSearch\"\>"},
          {"\<\"NMinimize`SimulatedAnnealing\"\>"},
          {"\<\"NonAssociative\"\>"},
          {"\<\"NonCommutativeMultiply\"\>"},
          {"\<\"NonConstants\"\>"},
          {"\<\"None\"\>"},
          {"\<\"NonNegative\"\>"},
          {"\<\"NonPositive\"\>"},
          {"\<\"Nor\"\>"},
          {"\<\"Norm\"\>"},
          {"\<\"Normal\"\>"},
          {"\<\"NormalGrouping\"\>"},
          {"\<\"NormalSelection\"\>"},
          {"\<\"NormFunction\"\>"},
          {"\<\"Not\"\>"},
          {"\<\"Notebook\"\>"},
          {"\<\"NotebookApply\"\>"},
          {"\<\"NotebookAutoSave\"\>"},
          {"\<\"NotebookClose\"\>"},
          {"\<\"NotebookConvert\"\>"},
          {"\<\"NotebookConvertSettings\"\>"},
          {"\<\"NotebookCreate\"\>"},
          {"\<\"NotebookCreateReturnObject\"\>"},
          {"\<\"NotebookDefault\"\>"},
          {"\<\"NotebookDelete\"\>"},
          {"\<\"NotebookDirectory\"\>"},
          {"\<\"NotebookFind\"\>"},
          {"\<\"NotebookFindReturnObject\"\>"},
          {"\<\"NotebookGet\"\>"},
          {"\<\"NotebookGetLayoutInformationPacket\"\>"},
          {"\<\"NotebookGetMisspellingsPacket\"\>"},
          {"\<\"NotebookInformation\"\>"},
          {"\<\"NotebookLocate\"\>"},
          {"\<\"NotebookObject\"\>"},
          {"\<\"NotebookOpen\"\>"},
          {"\<\"NotebookOpenReturnObject\"\>"},
          {"\<\"NotebookPath\"\>"},
          {"\<\"NotebookPrint\"\>"},
          {"\<\"NotebookPut\"\>"},
          {"\<\"NotebookPutReturnObject\"\>"},
          {"\<\"NotebookRead\"\>"},
          {"\<\"NotebookResetGeneratedCells\"\>"},
          {"\<\"Notebooks\"\>"},
          {"\<\"NotebookSave\"\>"},
          {"\<\"NotebookSaveAs\"\>"},
          {"\<\"NotebookSelection\"\>"},
          {"\<\"NotebookSetupLayoutInformationPacket\"\>"},
          {"\<\"NotebooksMenu\"\>"},
          {"\<\"NotebookWrite\"\>"},
          {"\<\"NotElement\"\>"},
          {"\<\"NProduct\"\>"},
          {"\<\"NProductExtraFactors\"\>"},
          {"\<\"NProductFactors\"\>"},
          {"\<\"NRoots\"\>"},
          {"\<\"NSolve\"\>"},
          {"\<\"NSum\"\>"},
          {"\<\"NSumExtraTerms\"\>"},
          {"\<\"NSumTerms\"\>"},
          {"\<\"Null\"\>"},
          {"\<\"NullRecords\"\>"},
          {"\<\"NullSpace\"\>"},
          {"\<\"NullWords\"\>"},
          {"\<\"numAgents\"\>"},
          {"\<\"numAgents0\"\>"},
          {"\<\"numAgentsUser\"\>"},
          {"\<\"Number\"\>"},
          {"\<\"NumberForm\"\>"},
          {"\<\"NumberFormat\"\>"},
          {"\<\"NumberMarks\"\>"},
          {"\<\"NumberMultiplier\"\>"},
          {"\<\"NumberPadding\"\>"},
          {"\<\"NumberPoint\"\>"},
          {"\<\"NumberQ\"\>"},
          {"\<\"NumberSeparator\"\>"},
          {"\<\"NumberSigns\"\>"},
          {"\<\"NumberString\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`Algebraic\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`AlgebraicIntegerQ\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`AlgebraicNumberDenominator\
\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`AlgebraicNumberNorm\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`AlgebraicNumberTrace\"\>"},\

          {"\<\"NumberTheory`AlgebraicNumberFields`AlgebraicUnitQ\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`FundamentalUnits\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`IntegralBasis\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`MinimalPolynomial\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`NormRepresentatives\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`\
NumberFieldCharacteristicPolynomial\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`NumberFieldDiscriminant\"\>\
"},
          {"\<\"NumberTheory`AlgebraicNumberFields`NumberFieldNorm\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`NumberFieldRegulator\"\>"},\

          {"\<\"NumberTheory`AlgebraicNumberFields`NumberFieldSignature\"\>"},\

          {"\<\"NumberTheory`AlgebraicNumberFields`NumberFieldTrace\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`RootOfUnityQ\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`RootsOfUnity\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`SmallestField\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`ToCommonField\"\>"},
          {"\<\"NumberTheory`AlgebraicNumberFields`ToNumberFieldElement\"\>"},\

          {"\<\"NumberTheory`PrimePower\"\>"},
          {"\<\"NumberTheory`PrimitiveRootQ\"\>"},
          {"\<\"numCollisions\"\>"},
          {"\<\"numCollisions$\"\>"},
          {"\<\"Numerator\"\>"},
          {"\<\"NumericalMath`FixedPrecisionEvaluate\"\>"},
          {"\<\"NumericalMath`$NumberBits\"\>"},
          {"\<\"NumericFunction\"\>"},
          {"\<\"NumericQ\"\>"},
          {"\<\"NValues\"\>"},
          {"\<\"O\"\>"},
          {"\<\"OddQ\"\>"},
          {"\<\"Off\"\>"},
          {"\<\"offscreen\"\>"},
          {"\<\"OffScreenImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"OffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"OffScreenImage`SCALEUFAST\"\>"},
          {"\<\"OffScreenImage`SCALEUREPLICATE\"\>"},
          {"\<\"OffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"OffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"OffScreenImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"OffScreenImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"OffScreenImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"OffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"OffScreenImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"OffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"OffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"OffScreenImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"OffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"OffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"OffScreenImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"OffScreenImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"OffScreenImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"OffScreenImage`UndefinedProperty\"\>"},
          {"\<\"offSet\"\>"},
          {"\<\"Offset\"\>"},
          {"\<\"OLEData\"\>"},
          {"\<\"On\"\>"},
          {"\<\"OneIdentity\"\>"},
          {"\<\"OneStepRowReduction\"\>"},
          {"\<\"Open\"\>"},
          {"\<\"OpenAppend\"\>"},
          {"\<\"OpenFunctionInspectorPacket\"\>"},
          {"\<\"OpenRead\"\>"},
          {"\<\"OpenSpecialOptions\"\>"},
          {"\<\"OpenTemporary\"\>"},
          {"\<\"OpenWrite\"\>"},
          {"\<\"Operate\"\>"},
          {"\<\"Optimization`InternalModifiedCholesky\"\>"},
          {"\<\"OptimizationLevel\"\>"},
          {"\<\"Optimization`LinearProgramming`\
CheckDualLinearProgrammingSolution\"\>"},
          {"\<\"Optimization`LinearProgramming`DualLinearProgrammingNM\"\>"},
          {"\<\"Optimization`LinearProgramming`InteriorPoint\"\>"},
          {"\<\"Optimization`LinearProgramming`LinearProgrammingCaller\"\>"},
          {"\<\"Optimization`LinearProgramming`Private`MPS2LP\"\>"},
          {"\<\"Optimization`LinearProgramming`Simplex\"\>"},
          {"\<\"Optimization`LinearProgramming`TryLinearProgramming\"\>"},
          {"\<\"Optimization`LineSearch\"\>"},
          {"\<\"Optimization`LineSearch`Backtracking\"\>"},
          {"\<\"Optimization`ModifiedCholeskyDecomposition\"\>"},
          {"\<\"Optimization`MPSData`MPSData\"\>"},
          {"\<\"Optimization`NonlinearInteriorPoint\"\>"},
          {"\<\"Optimization`TrustRegion\"\>"},
          {"\<\"Optional\"\>"},
          {"\<\"OptionInspectorSettings\"\>"},
          {"\<\"OptionQ\"\>"},
          {"\<\"Options\"\>"},
          {"\<\"OptionsPacket\"\>"},
          {"\<\"OptionValueBox\"\>"},
          {"\<\"OptionValueBoxOptions\"\>"},
          {"\<\"opts\"\>"},
          {"\<\"Or\"\>"},
          {"\<\"Orange\"\>"},
          {"\<\"Order\"\>"},
          {"\<\"OrderedQ\"\>"},
          {"\<\"Ordering\"\>"},
          {"\<\"Orderless\"\>"},
          {"\<\"Oscillatory\"\>"},
          {"\<\"out\"\>"},
          {"\<\"Out\"\>"},
          {"\<\"Outer\"\>"},
          {"\<\"OutputAutoOverwrite\"\>"},
          {"\<\"OutputForm\"\>"},
          {"\<\"OutputFormData\"\>"},
          {"\<\"OutputGrouping\"\>"},
          {"\<\"OutputMathEditExpression\"\>"},
          {"\<\"OutputNamePacket\"\>"},
          {"\<\"OutputStream\"\>"},
          {"\<\"OutputToOutputForm\"\>"},
          {"\<\"OutputToStandardForm\"\>"},
          {"\<\"Over\"\>"},
          {"\<\"Overflow\"\>"},
          {"\<\"Overlaps\"\>"},
          {"\<\"Overscript\"\>"},
          {"\<\"OverscriptBox\"\>"},
          {"\<\"OverscriptBoxOptions\"\>"},
          {"\<\"OwnValues\"\>"},
          {"\<\"PaddedForm\"\>"},
          {"\<\"PadLeft\"\>"},
          {"\<\"PadRight\"\>"},
          {"\<\"PageBreakAbove\"\>"},
          {"\<\"PageBreakBelow\"\>"},
          {"\<\"PageBreakWithin\"\>"},
          {"\<\"PageFooterLines\"\>"},
          {"\<\"PageFooters\"\>"},
          {"\<\"PageHeaderLines\"\>"},
          {"\<\"PageHeaders\"\>"},
          {"\<\"PageHeight\"\>"},
          {"\<\"PageWidth\"\>"},
          {"\<\"PalettePath\"\>"},
          {"\<\"panelFrameSizeX\"\>"},
          {"\<\"panelFrameSizeY\"\>"},
          {"\<\"PaperWidth\"\>"},
          {"\<\"ParagraphIndent\"\>"},
          {"\<\"ParagraphSpacing\"\>"},
          {"\<\"ParameterVariables\"\>"},
          {"\<\"ParametricPlot\"\>"},
          {"\<\"ParametricPlot3D\"\>"},
          {"\<\"ParentClass\"\>"},
          {"\<\"ParentConnect\"\>"},
          {"\<\"ParentDirectory\"\>"},
          {"\<\"ParentForm\"\>"},
          {"\<\"Parenthesize\"\>"},
          {"\<\"Part\"\>"},
          {"\<\"Partition\"\>"},
          {"\<\"PartitionsP\"\>"},
          {"\<\"PartitionsQ\"\>"},
          {"\<\"PasteBoxFormInlineCells\"\>"},
          {"\<\"Path\"\>"},
          {"\<\"Pattern\"\>"},
          {"\<\"PatternTest\"\>"},
          {"\<\"Pause\"\>"},
          {"\<\"PeekClasses\"\>"},
          {"\<\"PeekObjects\"\>"},
          {"\<\"Periodical\"\>"},
          {"\<\"Periodicals\"\>"},
          {"\<\"PeriodicInterpolation\"\>"},
          {"\<\"Permutations\"\>"},
          {"\<\"Pi\"\>"},
          {"\<\"Pick\"\>"},
          {"\<\"Piecewise\"\>"},
          {"\<\"PiecewiseExpand\"\>"},
          {"\<\"Pink\"\>"},
          {"\<\"Pivoting\"\>"},
          {"\<\"PixelConstrained\"\>"},
          {"\<\"Placeholder\"\>"},
          {"\<\"Plain\"\>"},
          {"\<\"Play\"\>"},
          {"\<\"PlayRange\"\>"},
          {"\<\"Plot\"\>"},
          {"\<\"Plot3D\"\>"},
          {"\<\"Plot3Matrix\"\>"},
          {"\<\"PlotDivision\"\>"},
          {"\<\"PlotJoined\"\>"},
          {"\<\"PlotLabel\"\>"},
          {"\<\"PlotPoints\"\>"},
          {"\<\"PlotRange\"\>"},
          {"\<\"PlotRegion\"\>"},
          {"\<\"PlotStyle\"\>"},
          {"\<\"Plus\"\>"},
          {"\<\"Pochhammer\"\>"},
          {"\<\"Point\"\>"},
          {"\<\"PointForm\"\>"},
          {"\<\"PointSize\"\>"},
          {"\<\"PolyGamma\"\>"},
          {"\<\"Polygon\"\>"},
          {"\<\"PolygonIntersections\"\>"},
          {"\<\"PolyLog\"\>"},
          {"\<\"PolynomialForm\"\>"},
          {"\<\"PolynomialGCD\"\>"},
          {"\<\"PolynomialLCM\"\>"},
          {"\<\"PolynomialMod\"\>"},
          {"\<\"PolynomialQ\"\>"},
          {"\<\"PolynomialQuotient\"\>"},
          {"\<\"PolynomialReduce\"\>"},
          {"\<\"PolynomialRemainder\"\>"},
          {"\<\"Polynomials\"\>"},
          {"\<\"Position\"\>"},
          {"\<\"Positive\"\>"},
          {"\<\"Postfix\"\>"},
          {"\<\"PostScript\"\>"},
          {"\<\"Power\"\>"},
          {"\<\"PowerExpand\"\>"},
          {"\<\"PowerMod\"\>"},
          {"\<\"PowerModList\"\>"},
          {"\<\"Precedence\"\>"},
          {"\<\"PrecedenceForm\"\>"},
          {"\<\"Precision\"\>"},
          {"\<\"PrecisionGoal\"\>"},
          {"\<\"PreDecrement\"\>"},
          {"\<\"PreferencesPath\"\>"},
          {"\<\"Prefix\"\>"},
          {"\<\"PreIncrement\"\>"},
          {"\<\"Prepend\"\>"},
          {"\<\"PrependTo\"\>"},
          {"\<\"PreserveStyleSheet\"\>"},
          {"\<\"Previous\"\>"},
          {"\<\"PrimaryPlaceholder\"\>"},
          {"\<\"Prime\"\>"},
          {"\<\"PrimePi\"\>"},
          {"\<\"PrimeQ\"\>"},
          {"\<\"Primes\"\>"},
          {"\<\"PrincipalValue\"\>"},
          {"\<\"Print\"\>"},
          {"\<\"PrintAction\"\>"},
          {"\<\"PrintForm\"\>"},
          {"\<\"PrintingCopies\"\>"},
          {"\<\"PrintingOptions\"\>"},
          {"\<\"PrintingPageRange\"\>"},
          {"\<\"PrintingStartingPageNumber\"\>"},
          {"\<\"PrintingStyleEnvironment\"\>"},
          {"\<\"PrintPrecision\"\>"},
          {"\<\"PrivateCellOptions\"\>"},
          {"\<\"PrivateEvaluationOptions\"\>"},
          {"\<\"PrivateFontOptions\"\>"},
          {"\<\"PrivateNotebookOptions\"\>"},
          {"\<\"PrivatePaths\"\>"},
          {"\<\"probeFrame\"\>"},
          {"\<\"probeFrameX\"\>"},
          {"\<\"probeFrameXDim\"\>"},
          {"\<\"probeFrameXDim$\"\>"},
          {"\<\"probeFrameX$\"\>"},
          {"\<\"probeFrameY\"\>"},
          {"\<\"probeFrameYDim\"\>"},
          {"\<\"probeFrameYDim$\"\>"},
          {"\<\"probeFrameY$\"\>"},
          {"\<\"probeLayout\"\>"},
          {"\<\"Product\"\>"},
          {"\<\"ProductLog\"\>"},
          {"\<\"programName\"\>"},
          {"\<\"programName$\"\>"},
          {"\<\"Prolog\"\>"},
          {"\<\"PromptForm\"\>"},
          {"\<\"Protect\"\>"},
          {"\<\"Protected\"\>"},
          {"\<\"Proxy`newProxyInstance\"\>"},
          {"\<\"PseudoInverse\"\>"},
          {"\<\"Purple\"\>"},
          {"\<\"Put\"\>"},
          {"\<\"PutAppend\"\>"},
          {"\<\"QRDecomposition\"\>"},
          {"\<\"Quantifier`LocalVariable\"\>"},
          {"\<\"Quantifier`LocalVariable$1\"\>"},
          {"\<\"Quantifier`LocalVariable$10\"\>"},
          {"\<\"Quantifier`LocalVariable$2\"\>"},
          {"\<\"Quantifier`LocalVariable$3\"\>"},
          {"\<\"Quantifier`LocalVariable$4\"\>"},
          {"\<\"Quantifier`LocalVariable$5\"\>"},
          {"\<\"Quantifier`LocalVariable$6\"\>"},
          {"\<\"Quantifier`LocalVariable$7\"\>"},
          {"\<\"Quantifier`LocalVariable$8\"\>"},
          {"\<\"Quantifier`LocalVariable$9\"\>"},
          {"\<\"Quantile\"\>"},
          {"\<\"Quartics\"\>"},
          {"\<\"QuasiMonteCarlo\"\>"},
          {"\<\"QuasiNewton\"\>"},
          {"\<\"Quit\"\>"},
          {"\<\"QuitJava\"\>"},
          {"\<\"Quotient\"\>"},
          {"\<\"RadicalBox\"\>"},
          {"\<\"RadicalBoxOptions\"\>"},
          {"\<\"Random\"\>"},
          {"\<\"RandomSeed\"\>"},
          {"\<\"Range\"\>"},
          {"\<\"Raster\"\>"},
          {"\<\"RasterArray\"\>"},
          {"\<\"Rational\"\>"},
          {"\<\"RationalFunctions\"\>"},
          {"\<\"Rationalize\"\>"},
          {"\<\"Rationals\"\>"},
          {"\<\"Raw\"\>"},
          {"\<\"RawData\"\>"},
          {"\<\"RawMedium\"\>"},
          {"\<\"Re\"\>"},
          {"\<\"Read\"\>"},
          {"\<\"ReadList\"\>"},
          {"\<\"ReadProtected\"\>"},
          {"\<\"Real\"\>"},
          {"\<\"RealBlockForm\"\>"},
          {"\<\"RealDigits\"\>"},
          {"\<\"Reals\"\>"},
          {"\<\"Reap\"\>"},
          {"\<\"Record\"\>"},
          {"\<\"RecordLists\"\>"},
          {"\<\"RecordSeparators\"\>"},
          {"\<\"Rectangle\"\>"},
          {"\<\"Red\"\>"},
          {"\<\"Reduce\"\>"},
          {"\<\"Reduce`AnalyticMinimize\"\>"},
          {"\<\"Reduce`AnnotatedPolynomial\"\>"},
          {"\<\"Reduce`BQDReduce\"\>"},
          {"\<\"Reduce`CADAlgVar\"\>"},
          {"\<\"Reduce`CADPoint\"\>"},
          {"\<\"Reduce`CADVar\"\>"},
          {"\<\"Reduce`CongruenceReduce\"\>"},
          {"\<\"Reduce`CPInstance\"\>"},
          {"\<\"Reduce`CPReduce\"\>"},
          {"\<\"Reduce`Discontinuities\"\>"},
          {"\<\"Reduce`DISieve\"\>"},
          {"\<\"Reduce`ExpandReduce\"\>"},
          {"\<\"Reduce`FindMatrixIndices\"\>"},
          {"\<\"Reduce`FindNegativeValue\"\>"},
          {"\<\"Reduce`InertIm\"\>"},
          {"\<\"Reduce`InertPower\"\>"},
          {"\<\"Reduce`InertRe\"\>"},
          {"\<\"Reduce`InexactPoint\"\>"},
          {"\<\"Reduce`IntegerRoots\"\>"},
          {"\<\"Reduce`LinearDiophantineSolve\"\>"},
          {"\<\"Reduce`MinAuxVar\"\>"},
          {"\<\"Reduce`ModReduce\"\>"},
          {"\<\"Reduce`NaturalLinearSolve\"\>"},
          {"\<\"Reduce`NonlinearDiophantineReduce\"\>"},
          {"\<\"Reduce`ParamCleanup\"\>"},
          {"\<\"Reduce`PrepElem\"\>"},
          {"\<\"Reduce`ProductExp\"\>"},
          {"\<\"Reduce`QuadNormRepresentatives\"\>"},
          {"\<\"Reduce`RationalNumberQ\"\>"},
          {"\<\"Reduce`RChineseRemainder\"\>"},
          {"\<\"Reduce`RealAlgDec\"\>"},
          {"\<\"Reduce`ReduceInstance\"\>"},
          {"\<\"Reduce`ReduceToRules\"\>"},
          {"\<\"Reduce`ReduceVar\"\>"},
          {"\<\"Reduce`SolutionQ\"\>"},
          {"\<\"Reduce`SortAnswer\"\>"},
          {"\<\"Reduce`SqrtMod2k\"\>"},
          {"\<\"Reduce`SqrtModpk\"\>"},
          {"\<\"Reduce`SumOfSquaresReps\"\>"},
          {"\<\"Reduce`ThueReduce\"\>"},
          {"\<\"Reduce`ToDNF\"\>"},
          {"\<\"Reduce`ToRationalNumber\"\>"},
          {"\<\"Reduce`TranscendentalReduce\"\>"},
          {"\<\"Reduce`TryDivisibility\"\>"},
          {"\<\"Reduce`UniqueParameters\"\>"},
          {"\<\"Reduce`UnivariateOptimize\"\>"},
          {"\<\"Reduce`ZeroDimRealSol\"\>"},
          {"\<\"Refine\"\>"},
          {"\<\"Refresh\"\>"},
          {"\<\"RegularExpression\"\>"},
          {"\<\"Reinstall\"\>"},
          {"\<\"ReinstallJava\"\>"},
          {"\<\"Relative\"\>"},
          {"\<\"Release\"\>"},
          {"\<\"ReleaseHold\"\>"},
          {"\<\"ReleaseJavaObject\"\>"},
          {"\<\"ReleaseObject\"\>"},
          {"\<\"Remove\"\>"},
          {"\<\"Removed\"\>"},
          {"\<\"RemovePeriodical\"\>"},
          {"\<\"RenameDirectory\"\>"},
          {"\<\"RenameFile\"\>"},
          {"\<\"RenderAll\"\>"},
          {"\<\"RenderingOptions\"\>"},
          {"\<\"Repeated\"\>"},
          {"\<\"RepeatedNull\"\>"},
          {"\<\"RepeatedString\"\>"},
          {"\<\"Replace\"\>"},
          {"\<\"ReplaceAll\"\>"},
          {"\<\"ReplaceHeldPart\"\>"},
          {"\<\"ReplaceList\"\>"},
          {"\<\"ReplacePart\"\>"},
          {"\<\"ReplaceRepeated\"\>"},
          {"\<\"Rescale\"\>"},
          {"\<\"ResetDirectory\"\>"},
          {"\<\"ResetMenusPacket\"\>"},
          {"\<\"Residue\"\>"},
          {"\<\"Resolve\"\>"},
          {"\<\"Rest\"\>"},
          {"\<\"RestartJava\"\>"},
          {"\<\"Resultant\"\>"},
          {"\<\"ResumePacket\"\>"},
          {"\<\"Return\"\>"},
          {"\<\"ReturnAsJavaObject\"\>"},
          {"\<\"ReturnExpressionPacket\"\>"},
          {"\<\"ReturnInputFormPacket\"\>"},
          {"\<\"ReturnPacket\"\>"},
          {"\<\"ReturnTextPacket\"\>"},
          {"\<\"Reverse\"\>"},
          {"\<\"RGBColor\"\>"},
          {"\<\"RiemannSiegelTheta\"\>"},
          {"\<\"RiemannSiegelZ\"\>"},
          {"\<\"Right\"\>"},
          {"\<\"Root\"\>"},
          {"\<\"RootReduce\"\>"},
          {"\<\"Roots\"\>"},
          {"\<\"RootSum\"\>"},
          {"\<\"RotateLabel\"\>"},
          {"\<\"RotateLeft\"\>"},
          {"\<\"RotateRight\"\>"},
          {"\<\"Round\"\>"},
          {"\<\"Row\"\>"},
          {"\<\"RowAlignments\"\>"},
          {"\<\"RowBox\"\>"},
          {"\<\"RowLines\"\>"},
          {"\<\"RowMinHeight\"\>"},
          {"\<\"RowReduce\"\>"},
          {"\<\"RowsEqual\"\>"},
          {"\<\"RowSpacings\"\>"},
          {"\<\"RSolve\"\>"},
          {"\<\"RSolve`qRSolve\"\>"},
          {"\<\"RSolve`RSolve2Order1NonlinearODEs\"\>"},
          {"\<\"RSolve`RSolveBoundaryValueProblem\"\>"},
          {"\<\"RSolve`RSolveCoreNilpotentDecomposition\"\>"},
          {"\<\"RSolve`\
RSolveDegreeBoundForPolynomialSolutionsOfLinearFirstOrderODEs\"\>"},
          {"\<\"RSolve`RSolveDelta\"\>"},
          {"\<\"RSolve`RSolveDenominatorsOfRationalSolutions\"\>"},
          {"\<\"RSolve`RSolveDispatchFirstOrderODEs\"\>"},
          {"\<\"RSolve`RSolveDispatchODE\"\>"},
          {"\<\"RSolve`RSolveDispatchPDE\"\>"},
          {"\<\"RSolve`RSolveFirstOrderODE\"\>"},
          {"\<\"RSolve`RSolveFirstOrderODEs\"\>"},
          {"\<\"RSolve`RSolveFlatten\"\>"},
          {"\<\"RSolve`RSolveHigherOrderODE\"\>"},
          {"\<\"RSolve`RSolveLinearExactODE\"\>"},
          {"\<\"RSolve`RSolveLinearFirstOrderDAEs\"\>"},
          {"\<\"RSolve`RSolveLinearHomogeneousWithConstantCoefficients\"\>"},
          {"\<\"RSolve`RSolveLinearWithRationalCoefficients\"\>"},
          {"\<\"RSolve`RSolveMethodOfUndeterminedCoefficients\"\>"},
          {"\<\"RSolve`RSolveNonZeroQ\"\>"},
          {"\<\"RSolve`RSolveOuter\"\>"},
          {"\<\"RSolve`RSolveParser\"\>"},
          {"\<\"RSolve`RSolvePDE\"\>"},
          {"\<\"RSolve`RSolvePFQTypeSolutions\"\>"},
          {"\<\"RSolve`RSolveProduct\"\>"},
          {"\<\"RSolve`RSolveRationalQ\"\>"},
          {"\<\"RSolve`RSolveRationalSolutions\"\>"},
          {"\<\"RSolve`RSolveRationalSolutionsOfLinearFirstOrderODEs\"\>"},
          {"\<\"RSolve`RSolveSecondOrderODE\"\>"},
          {"\<\"RSolve`RSolveSpecialLinearSecondOrderODE\"\>"},
          {"\<\"RSolve`RSolveSuccessiveReductionOfOrder\"\>"},
          {"\<\"RSolve`RSolveSum\"\>"},
          {"\<\"RSolve`RSolveToPureFunction\"\>"},
          {"\<\"RSolve`RSolveTransformations\"\>"},
          {"\<\"RSolve`RSolveValuation\"\>"},
          {"\<\"RSolve`RSolveVariationOfParameters\"\>"},
          {"\<\"RSolve`RSolveZeroQ\"\>"},
          {"\<\"RSolve`$RSolveLeafCountConstraint\"\>"},
          {"\<\"Rule\"\>"},
          {"\<\"RuleCondition\"\>"},
          {"\<\"RuleDelayed\"\>"},
          {"\<\"RuleForm\"\>"},
          {"\<\"RulerUnits\"\>"},
          {"\<\"Run\"\>"},
          {"\<\"runFinalization\"\>"},
          {"\<\"runFinalizersOnExit\"\>"},
          {"\<\"RunThrough\"\>"},
          {"\<\"RuntimeTools`AddMessageBreaks\"\>"},
          {"\<\"RuntimeTools`AddwatchBreaks\"\>"},
          {"\<\"RuntimeTools`BreakEnable\"\>"},
          {"\<\"RuntimeTools`BreakNow\"\>"},
          {"\<\"RuntimeTools`ChangeBreakpoint\"\>"},
          {"\<\"RuntimeTools`DebugAbort\"\>"},
          {"\<\"RuntimeTools`DebugFinish\"\>"},
          {"\<\"RuntimeTools`DebugHandle\"\>"},
          {"\<\"RuntimeTools`DebugNext\"\>"},
          {"\<\"RuntimeTools`DebugOff\"\>"},
          {"\<\"RuntimeTools`DebugOn\"\>"},
          {"\<\"RuntimeTools`DebugStep\"\>"},
          {"\<\"RuntimeTools`DropMessageBreaks\"\>"},
          {"\<\"RuntimeTools`DropWatchBreaks\"\>"},
          {"\<\"RuntimeTools`EvaluationStack\"\>"},
          {"\<\"RuntimeTools`EvaluationStackBlock\"\>"},
          {"\<\"RuntimeTools`ExecutionState\"\>"},
          {"\<\"RuntimeTools`GetBreakpoints\"\>"},
          {"\<\"RuntimeTools`GetMessageBreaks\"\>"},
          {"\<\"RuntimeTools`GetTagInformation\"\>"},
          {"\<\"RuntimeTools`GetTags\"\>"},
          {"\<\"RuntimeTools`GetWatchBreaks\"\>"},
          {"\<\"RuntimeTools`LockedStack\"\>"},
          {"\<\"RuntimeTools`Profile\"\>"},
          {"\<\"RuntimeTools`ProfileFunction\"\>"},
          {"\<\"RuntimeTools`SetBreakpoints\"\>"},
          {"\<\"RuntimeTools`SetExecutionState\"\>"},
          {"\<\"RuntimeTools`SetExpressionWatchpoints\"\>"},
          {"\<\"RuntimeTools`SetMessageBreaks\"\>"},
          {"\<\"RuntimeTools`SetRuntimeMode\"\>"},
          {"\<\"RuntimeTools`SetWatchBreaks\"\>"},
          {"\<\"RuntimeTools`TagNull\"\>"},
          {"\<\"RuntimeTools`TagToExpr\"\>"},
          {"\<\"RuntimeTools`TagToExprs\"\>"},
          {"\<\"RuntimeTools`TimeLimit\"\>"},
          {"\<\"RuntimeTools`ToolsInitialize\"\>"},
          {"\<\"RuntimeTools`ToolsUninitialize\"\>"},
          {"\<\"RuntimeTools`ToTag\"\>"},
          {"\<\"RuntimeTools`Tracing\"\>"},
          {"\<\"RuntimeTools`TreeSize\"\>"},
          {"\<\"SameObjectQ\"\>"},
          {"\<\"SameQ\"\>"},
          {"\<\"SameTest\"\>"},
          {"\<\"SampleDepth\"\>"},
          {"\<\"SampledSoundFunction\"\>"},
          {"\<\"SampledSoundList\"\>"},
          {"\<\"SampleRate\"\>"},
          {"\<\"Save\"\>"},
          {"\<\"Saveable\"\>"},
          {"\<\"SaveAutoDelete\"\>"},
          {"\<\"Scaled\"\>"},
          {"\<\"Scan\"\>"},
          {"\<\"scheduleMethodBeginning\"\>"},
          {"\<\"SchurDecomposition\"\>"},
          {"\<\"ScientificForm\"\>"},
          {"\<\"ScreenRectangle\"\>"},
          {"\<\"ScreenStyleEnvironment\"\>"},
          {"\<\"ScriptBaselineShifts\"\>"},
          {"\<\"ScriptLevel\"\>"},
          {"\<\"ScriptMinSize\"\>"},
          {"\<\"ScriptRules\"\>"},
          {"\<\"ScriptSizeMultipliers\"\>"},
          {"\<\"Scrollbar`ABORT\"\>"},
          {"\<\"Scrollbar`ALLBITS\"\>"},
          {"\<\"Scrollbar`BOTTOMUALIGNMENT\"\>"},
          {"\<\"Scrollbar`CENTERUALIGNMENT\"\>"},
          {"\<\"Scrollbar`ERROR\"\>"},
          {"\<\"Scrollbar`FRAMEBITS\"\>"},
          {"\<\"Scrollbar`HEIGHT\"\>"},
          {"\<\"Scrollbar`HORIZONTAL\"\>"},
          {"\<\"Scrollbar`LEFTUALIGNMENT\"\>"},
          {"\<\"Scrollbar`NOUORIENTATION\"\>"},
          {"\<\"Scrollbar`PROPERTIES\"\>"},
          {"\<\"Scrollbar`RIGHTUALIGNMENT\"\>"},
          {"\<\"Scrollbar`SOMEBITS\"\>"},
          {"\<\"Scrollbar`TOPUALIGNMENT\"\>"},
          {"\<\"Scrollbar`VERTICAL\"\>"},
          {"\<\"Scrollbar`WIDTH\"\>"},
          {"\<\"ScrollingOptions\"\>"},
          {"\<\"scrollPos\"\>"},
          {"\<\"ScrollPosition\"\>"},
          {"\<\"Sec\"\>"},
          {"\<\"Sech\"\>"},
          {"\<\"Second\"\>"},
          {"\<\"SectionGrouping\"\>"},
          {"\<\"SeedRandom\"\>"},
          {"\<\"Select\"\>"},
          {"\<\"Selectable\"\>"},
          {"\<\"SelectedNotebook\"\>"},
          {"\<\"Selection\"\>"},
          {"\<\"SelectionAnimate\"\>"},
          {"\<\"SelectionCell\"\>"},
          {"\<\"SelectionCellCreateCell\"\>"},
          {"\<\"SelectionCellDefaultStyle\"\>"},
          {"\<\"SelectionCellParentStyle\"\>"},
          {"\<\"SelectionCreateCell\"\>"},
          {"\<\"SelectionDuplicateCell\"\>"},
          {"\<\"SelectionEvaluate\"\>"},
          {"\<\"SelectionEvaluateCreateCell\"\>"},
          {"\<\"SelectionMove\"\>"},
          {"\<\"SelectionSetStyle\"\>"},
          {"\<\"SelectionStrategy\"\>"},
          {"\<\"SendFontInformationToKernel\"\>"},
          {"\<\"Sequence\"\>"},
          {"\<\"SequenceForm\"\>"},
          {"\<\"SequenceHold\"\>"},
          {"\<\"SequenceLimit\"\>"},
          {"\<\"Series\"\>"},
          {"\<\"SeriesCoefficient\"\>"},
          {"\<\"SeriesData\"\>"},
          {"\<\"ServiceJava\"\>"},
          {"\<\"SessionTime\"\>"},
          {"\<\"Set\"\>"},
          {"\<\"SetAccuracy\"\>"},
          {"\<\"setAlignment\"\>"},
          {"\<\"SetAttributes\"\>"},
          {"\<\"setBounds\"\>"},
          {"\<\"SetBoxFormNamesPacket\"\>"},
          {"\<\"setColor\"\>"},
          {"\<\"SetComplexClass\"\>"},
          {"\<\"SetDelayed\"\>"},
          {"\<\"SetDirectory\"\>"},
          {"\<\"setEditable\"\>"},
          {"\<\"setErr\"\>"},
          {"\<\"SetEvaluationNotebook\"\>"},
          {"\<\"SetField\"\>"},
          {"\<\"SetFileDate\"\>"},
          {"\<\"SetFileLoadingContext\"\>"},
          {"\<\"setHandler\"\>"},
          {"\<\"setImage\"\>"},
          {"\<\"setIn\"\>"},
          {"\<\"SetInternetProxy\"\>"},
          {"\<\"setLayout\"\>"},
          {"\<\"setModal\"\>"},
          {"\<\"SetNotebookStatusLine\"\>"},
          {"\<\"SetOptions\"\>"},
          {"\<\"SetOptionsPacket\"\>"},
          {"\<\"setOut\"\>"},
          {"\<\"SetPeriodicalInterval\"\>"},
          {"\<\"SetPersistentFrontEnd\"\>"},
          {"\<\"SetPrecision\"\>"},
          {"\<\"setProperties\"\>"},
          {"\<\"setProperty\"\>"},
          {"\<\"setResizable\"\>"},
          {"\<\"setSecurityManager\"\>"},
          {"\<\"SetSelectedNotebook\"\>"},
          {"\<\"SetSpeechParametersPacket\"\>"},
          {"\<\"SetStreamPosition\"\>"},
          {"\<\"setText\"\>"},
          {"\<\"SetValue\"\>"},
          {"\<\"setVisible\"\>"},
          {"\<\"Shading\"\>"},
          {"\<\"Shallow\"\>"},
          {"\<\"Share\"\>"},
          {"\<\"ShareFrontEnd\"\>"},
          {"\<\"ShareKernel\"\>"},
          {"\<\"SharingLinks\"\>"},
          {"\<\"SharingPrompt\"\>"},
          {"\<\"Short\"\>"},
          {"\<\"ShortestMatch\"\>"},
          {"\<\"Show\"\>"},
          {"\<\"ShowAutoStyles\"\>"},
          {"\<\"ShowCellBracket\"\>"},
          {"\<\"ShowCellLabel\"\>"},
          {"\<\"ShowCellTags\"\>"},
          {"\<\"ShowClosedCellArea\"\>"},
          {"\<\"ShowContents\"\>"},
          {"\<\"ShowCursorTracker\"\>"},
          {"\<\"ShowGroupOpenCloseIcon\"\>"},
          {"\<\"ShowJavaConsole\"\>"},
          {"\<\"ShowPageBreaks\"\>"},
          {"\<\"ShowSelection\"\>"},
          {"\<\"ShowShortBoxForm\"\>"},
          {"\<\"ShowSpecialCharacters\"\>"},
          {"\<\"ShowStringCharacters\"\>"},
          {"\<\"ShrinkWrapBoundingBox\"\>"},
          {"\<\"Sign\"\>"},
          {"\<\"Signature\"\>"},
          {"\<\"SignPadding\"\>"},
          {"\<\"Simplify\"\>"},
          {"\<\"Simplify`Expand0F3\"\>"},
          {"\<\"Simplify`Expand1F2\"\>"},
          {"\<\"Simplify`ExpandHypergeometric2F1\"\>"},
          {"\<\"Simplify`FunctionExpandRules\"\>"},
          {"\<\"Simplify`GPElement\"\>"},
          {"\<\"Simplify`IneqBounds\"\>"},
          {"\<\"Simplify`InertIntegrate\"\>"},
          {"\<\"Simplify`InertProduct\"\>"},
          {"\<\"Simplify`InertSum\"\>"},
          {"\<\"Simplify`InfinitePiecewiseRepresent\"\>"},
          {"\<\"Simplify`PiecewiseGerm\"\>"},
          {"\<\"Simplify`PiecewiseIntegrate\"\>"},
          {"\<\"Simplify`PiecewiseNIntegrate\"\>"},
          {"\<\"Simplify`PWCOND\"\>"},
          {"\<\"Simplify`PWPlotCases\"\>"},
          {"\<\"Simplify`PWToIntervals\"\>"},
          {"\<\"Simplify`SearchNumberTheory\"\>"},
          {"\<\"Simplify`SimplifyAuxVar\"\>"},
          {"\<\"Simplify`SimplifyBessel\"\>"},
          {"\<\"Simplify`SimplifyFibonacci\"\>"},
          {"\<\"Simplify`SimplifyGamma\"\>"},
          {"\<\"Simplify`SimplifyHypergeometricPFQ\"\>"},
          {"\<\"Simplify`SimplifyInequalities\"\>"},
          {"\<\"Simplify`SimplifyPolyGamma\"\>"},
          {"\<\"Simplify`SimplifyPolyLog\"\>"},
          {"\<\"Simplify`SimplifyPseudoFunctions\"\>"},
          {"\<\"Simplify`SimplifyZeta\"\>"},
          {"\<\"Simulate\"\>"},
          {"\<\"Sin\"\>"},
          {"\<\"SingleLetterItalics\"\>"},
          {"\<\"SingularityDepth\"\>"},
          {"\<\"SingularValueDecomposition\"\>"},
          {"\<\"SingularValueList\"\>"},
          {"\<\"SingularValues\"\>"},
          {"\<\"Sinh\"\>"},
          {"\<\"SinhIntegral\"\>"},
          {"\<\"SinIntegral\"\>"},
          {"\<\"SixJSymbol\"\>"},
          {"\<\"size\"\>"},
          {"\<\"sizeMax\"\>"},
          {"\<\"sizeMax$\"\>"},
          {"\<\"sizeMin\"\>"},
          {"\<\"sizeMin$\"\>"},
          {"\<\"size$\"\>"},
          {"\<\"Skeleton\"\>"},
          {"\<\"Skip\"\>"},
          {"\<\"slider\"\>"},
          {"\<\"sliderFrame\"\>"},
          {"\<\"sliderFrameX\"\>"},
          {"\<\"sliderFrameXDim\"\>"},
          {"\<\"sliderFrameY\"\>"},
          {"\<\"sliderFrameYDim\"\>"},
          {"\<\"sliderFunc\"\>"},
          {"\<\"sliderLayout\"\>"},
          {"\<\"sliderListener\"\>"},
          {"\<\"Slot\"\>"},
          {"\<\"SlotSequence\"\>"},
          {"\<\"Smaller\"\>"},
          {"\<\"Socket\"\>"},
          {"\<\"Solve\"\>"},
          {"\<\"Solve`a\"\>"},
          {"\<\"SolveAlways\"\>"},
          {"\<\"Solve`Auxiliary\"\>"},
          {"\<\"Solve`b\"\>"},
          {"\<\"Solve`c\"\>"},
          {"\<\"Solve`d\"\>"},
          {"\<\"SolveDelayed\"\>"},
          {"\<\"Solve`DirInf\"\>"},
          {"\<\"Solve`ElimVar\"\>"},
          {"\<\"Solve`f\"\>"},
          {"\<\"Solve`g\"\>"},
          {"\<\"Solve`h\"\>"},
          {"\<\"Solve`InvFun\"\>"},
          {"\<\"Solve`InvFunVar\"\>"},
          {"\<\"Solve`k\"\>"},
          {"\<\"Solve`ParamEqual\"\>"},
          {"\<\"Solve`ParamUnequal\"\>"},
          {"\<\"Solve`ParmVar\"\>"},
          {"\<\"Solve`RadVar\"\>"},
          {"\<\"Solve`RecipVar\"\>"},
          {"\<\"Solve`RootsAuxVar\"\>"},
          {"\<\"Solve`SolvVar\"\>"},
          {"\<\"Solve`Temp1Var\"\>"},
          {"\<\"Solve`Temp2Var\"\>"},
          {"\<\"Solve`w\"\>"},
          {"\<\"Solve`ZeroTestHead\"\>"},
          {"\<\"Sort\"\>"},
          {"\<\"Sound\"\>"},
          {"\<\"SoundAndGraphics\"\>"},
          {"\<\"Sow\"\>"},
          {"\<\"Space\"\>"},
          {"\<\"SpaceForm\"\>"},
          {"\<\"SpanAdjustments\"\>"},
          {"\<\"SpanCharacterRounding\"\>"},
          {"\<\"SpanLineThickness\"\>"},
          {"\<\"SpanMaxSize\"\>"},
          {"\<\"SpanMinSize\"\>"},
          {"\<\"SpanningCharacters\"\>"},
          {"\<\"SpanSymmetric\"\>"},
          {"\<\"Sparse\"\>"},
          {"\<\"SparseArray\"\>"},
          {"\<\"SparseArray`Arnoldi\"\>"},
          {"\<\"SparseArray`BlockArray\"\>"},
          {"\<\"SparseArray`BlockTriangularOrdering\"\>"},
          {"\<\"SparseArray`BreadthFirstSearch\"\>"},
          {"\<\"SparseArray`Equal\"\>"},
          {"\<\"SparseArray`GraphDistance\"\>"},
          {"\<\"SparseArray`GraphDistanceMatrix\"\>"},
          {"\<\"SparseArray`GraphPlacement\"\>"},
          {"\<\"SparseArray`GraphPlacement3D\"\>"},
          {"\<\"SparseArray`HermitianQ\"\>"},
          {"\<\"SparseArray`HighDimensionalEmbedding\"\>"},
          {"\<\"SparseArray`KrylovLinearSolve\"\>"},
          {"\<\"SparseArray`LayeredDrawing\"\>"},
          {"\<\"SparseArray`MaximalBipartiteMatching\"\>"},
          {"\<\"SparseArray`MaximalIndependentVertexSet\"\>"},
          {"\<\"SparseArray`MaximalMatching\"\>"},
          {"\<\"SparseArray`MinCut\"\>"},
          {"\<\"SparseArray`Multilevel\"\>"},
          {"\<\"SparseArray`NestedDissection\"\>"},
          {"\<\"SparseArray`Private`GraphPlot\"\>"},
          {"\<\"SparseArray`Private`GraphPlot3D\"\>"},
          {"\<\"SparseArray`PseudoDiameter\"\>"},
          {"\<\"SparseArray`RadialDrawing\"\>"},
          {"\<\"SparseArray`RecursionMethod\"\>"},
          {"\<\"SparseArray`SpanningTree\"\>"},
          {"\<\"SparseArray`SparseArrayDimensions\"\>"},
          {"\<\"SparseArray`SparseArrayFlatten\"\>"},
          {"\<\"SparseArray`SparseArrayJoin\"\>"},
          {"\<\"SparseArray`SparseArrayOp\"\>"},
          {"\<\"SparseArray`SparseArrayRemoveDiagonal\"\>"},
          {"\<\"SparseArray`SparseArrayScalingFactors\"\>"},
          {"\<\"SparseArray`SparseArrayTensorRank\"\>"},
          {"\<\"SparseArray`SparseIdentityArray\"\>"},
          {"\<\"SparseArray`SparseLUDecomposition\"\>"},
          {"\<\"SparseArray`SparseMatrixApplyILU\"\>"},
          {"\<\"SparseArray`SparseMatrixILU\"\>"},
          {"\<\"SparseArray`SparseRuleForm\"\>"},
          {"\<\"SparseArray`SpringElectricalModel\"\>"},
          {"\<\"SparseArray`SpringEnergy\"\>"},
          {"\<\"SparseArray`SpringModel\"\>"},
          {"\<\"SparseArray`StronglyConnectedComponents\"\>"},
          {"\<\"SparseArray`SVDArnoldi\"\>"},
          {"\<\"SparseArray`SymmetricQ\"\>"},
          {"\<\"SparseArray`ToTriangular\"\>"},
          {"\<\"SparseArray`TreeQ\"\>"},
          {"\<\"SparseArray`VectorToDiagonalSparseArray\"\>"},
          {"\<\"SpeakTextPacket\"\>"},
          {"\<\"speedBnd\"\>"},
          {"\<\"speedBndLarge\"\>"},
          {"\<\"speedBndSmall\"\>"},
          {"\<\"speedBnd$\"\>"},
          {"\<\"SpellingCorrection\"\>"},
          {"\<\"SpellingDictionaries\"\>"},
          {"\<\"SpellingDictionariesPath\"\>"},
          {"\<\"SpellingOptions\"\>"},
          {"\<\"SpellingSuggestionsPacket\"\>"},
          {"\<\"Spherical\"\>"},
          {"\<\"SphericalHarmonicY\"\>"},
          {"\<\"SphericalRegion\"\>"},
          {"\<\"Splice\"\>"},
          {"\<\"Split\"\>"},
          {"\<\"Sqrt\"\>"},
          {"\<\"SqrtBox\"\>"},
          {"\<\"SqrtBoxOptions\"\>"},
          {"\<\"Stack\"\>"},
          {"\<\"StackBegin\"\>"},
          {"\<\"StackComplete\"\>"},
          {"\<\"StackInhibit\"\>"},
          {"\<\"StandardDeviation\"\>"},
          {"\<\"StandardForm\"\>"},
          {"\<\"start\"\>"},
          {"\<\"StartingStepSize\"\>"},
          {"\<\"StartJava\"\>"},
          {"\<\"StartOfLine\"\>"},
          {"\<\"StartOfString\"\>"},
          {"\<\"StartupSound\"\>"},
          {"\<\"StaticsVisible\"\>"},
          {"\<\"Statistics`ClusterAnalysis`Agglomerate\"\>"},
          {"\<\"Statistics`ClusterAnalysis`BrayCurtisDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`CanberraDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`Cluster\"\>"},
          {"\<\"Statistics`ClusterAnalysis`CorrelationDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`CosineAngleDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`DiceDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`DirectAgglomerate\"\>"},
          {"\<\"Statistics`ClusterAnalysis`DistanceFunction\"\>"},
          {"\<\"Statistics`ClusterAnalysis`DistanceMatrix\"\>"},
          {"\<\"Statistics`ClusterAnalysis`EditDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`EuclideanDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters\"\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`DispersionFromData\"\>\
"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`\
DispersionFromDCMatrix\"\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`FindClustersDispatch\"\
\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`KMediodsUpdate\"\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`MediodsFromData\"\>"},\

          {"\<\"Statistics`ClusterAnalysis`FindClusters`MediodsFromDCMatrix\"\
\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`PAMUpdate\"\>"},
          {"\<\"Statistics`ClusterAnalysis`FindClusters`\
SilhouetteFromDCMatrix\"\>"},
          {"\<\"Statistics`ClusterAnalysis`JaccardDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`Linkage\"\>"},
          {"\<\"Statistics`ClusterAnalysis`ManhattanDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`MatchingDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`RogersTanimotoDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`RussleRaoDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`SokalSneathDissimilarity\"\>"},
          {"\<\"Statistics`ClusterAnalysis`SquaredEuclideanDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`SupDistance\"\>"},
          {"\<\"Statistics`ClusterAnalysis`YuleDissimilarity\"\>"},
          {"\<\"step\"\>"},
          {"\<\"StepMonitor\"\>"},
          {"\<\"StieltjesGamma\"\>"},
          {"\<\"StirlingS1\"\>"},
          {"\<\"StirlingS2\"\>"},
          {"\<\"StoppingTest\"\>"},
          {"\<\"straightLine\"\>"},
          {"\<\"StreamPosition\"\>"},
          {"\<\"Streams\"\>"},
          {"\<\"String\"\>"},
          {"\<\"StringBreak\"\>"},
          {"\<\"StringByteCount\"\>"},
          {"\<\"StringCases\"\>"},
          {"\<\"StringCount\"\>"},
          {"\<\"StringDrop\"\>"},
          {"\<\"StringExpression\"\>"},
          {"\<\"StringForm\"\>"},
          {"\<\"StringFreeQ\"\>"},
          {"\<\"StringInsert\"\>"},
          {"\<\"StringJoin\"\>"},
          {"\<\"StringLength\"\>"},
          {"\<\"StringMatchQ\"\>"},
          {"\<\"StringPattern`CountCapGrInRegExp\"\>"},
          {"\<\"StringPattern`Lexer`ChangeLexerState\"\>"},
          {"\<\"StringPattern`Lexer`IfLexerState\"\>"},
          {"\<\"StringPattern`Lexer`Lexer\"\>"},
          {"\<\"StringPattern`LongestCommonSubsequence\"\>"},
          {"\<\"StringPattern`PatternConvert\"\>"},
          {"\<\"StringPosition\"\>"},
          {"\<\"StringQ\"\>"},
          {"\<\"StringReplace\"\>"},
          {"\<\"StringReplaceList\"\>"},
          {"\<\"StringReplacePart\"\>"},
          {"\<\"StringReverse\"\>"},
          {"\<\"StringSkeleton\"\>"},
          {"\<\"StringSplit\"\>"},
          {"\<\"StringTake\"\>"},
          {"\<\"StringToStream\"\>"},
          {"\<\"StripBoxes\"\>"},
          {"\<\"StripWrapperBoxes\"\>"},
          {"\<\"StructuredSelection\"\>"},
          {"\<\"StruveH\"\>"},
          {"\<\"StruveL\"\>"},
          {"\<\"Stub\"\>"},
          {"\<\"StyleBox\"\>"},
          {"\<\"StyleBoxAutoDelete\"\>"},
          {"\<\"StyleBoxOptions\"\>"},
          {"\<\"StyleData\"\>"},
          {"\<\"StyleDefinitions\"\>"},
          {"\<\"StyleForm\"\>"},
          {"\<\"StyleMenuListing\"\>"},
          {"\<\"StyleNameDialogSettings\"\>"},
          {"\<\"StylePrint\"\>"},
          {"\<\"StyleSheetPath\"\>"},
          {"\<\"Subresultants\"\>"},
          {"\<\"Subscript\"\>"},
          {"\<\"SubscriptBox\"\>"},
          {"\<\"SubscriptBoxOptions\"\>"},
          {"\<\"Subscripted\"\>"},
          {"\<\"Subsets\"\>"},
          {"\<\"Subsuperscript\"\>"},
          {"\<\"SubsuperscriptBox\"\>"},
          {"\<\"SubsuperscriptBoxOptions\"\>"},
          {"\<\"Subtract\"\>"},
          {"\<\"SubtractFrom\"\>"},
          {"\<\"SubValues\"\>"},
          {"\<\"SugarCube\"\>"},
          {"\<\"Sum\"\>"},
          {"\<\"Sum`SumAccurate\"\>"},
          {"\<\"Sum`SumCompleteApart\"\>"},
          {"\<\"Sum`SumHypergeometricTerm\"\>"},
          {"\<\"Sum`SumNonZeroQ\"\>"},
          {"\<\"Sum`SumPolynomialExponentialFunction\"\>"},
          {"\<\"Sum`SumPolynomialFunction\"\>"},
          {"\<\"Sum`SumRationalFunction\"\>"},
          {"\<\"Sum`SumRationalQ\"\>"},
          {"\<\"Sum`SumSimplifyHypergeometricTerm\"\>"},
          {"\<\"Sum`SumZeroQ\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`\
getAccelerationThreshold\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
getAccelerationThreshold\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`getGraphics\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`getSnapshot\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
getSourceSurfaceData\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
initAcceleratedBackground\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
rasterChanged\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`rasterStolen\
\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
restoreContents\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
SCALEUAREAUAVERAGING\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
SCALEUDEFAULT\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUFAST\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
SCALEUREPLICATE\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUSMOOTH\
\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEU3BYTEUBGR\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEU4BYTEUABGR\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUBYTEUBINARY\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUBYTEUGRAY\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUBYTEUINDEXED\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUCUSTOM\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUINTUARGB\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUINTUARGBUPRE\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTUBGR\
\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTURGB\
\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUUSHORTU555URGB\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUUSHORTU565URGB\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUUSHORTUGRAY\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
UndefinedProperty\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`JPrivate`validate\"\>\
"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`SCALEUAREAUAVERAGING\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`SCALEUFAST\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`SCALEUREPLICATE\"\>"},\

          {"\<\"sun`awt`image`AcceleratedOffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEU4BYTEUABGR\"\>"},\

          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEU4BYTEUABGRUPRE\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUBINARY\"\>"}\
,
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUINDEXED\"\>\
"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUARGBUPRE\"\>\
"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTU555URGB\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTU565URGB\"\
\>"},
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTUGRAY\"\>"}\
,
          {"\<\"sun`awt`image`AcceleratedOffScreenImage`UndefinedProperty\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`createGraphics\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`getGraphics\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`getSource\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`getSourceSurfaceData\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`initBackground\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`restoreContents\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`SCALEUAREAUAVERAGING\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`SCALEUDEFAULT\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`SCALEUFAST\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`SCALEUREPLICATE\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`SCALEUSMOOTH\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEU3BYTEUBGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEU4BYTEUABGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEU4BYTEUABGRUPRE\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUBINARY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUGRAY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUINDEXED\"\>"},\

          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUCUSTOM\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUARGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUARGBUPRE\"\>"},\

          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUBGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUINTURGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTU555URGB\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTU565URGB\"\>\
"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`JPrivate`UndefinedProperty\"\>"},\

          {"\<\"sun`awt`image`OffScreenImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`SCALEUFAST\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`SCALEUREPLICATE\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"sun`awt`image`OffScreenImage`UndefinedProperty\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`getAccelerationThreshold\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`displayChanged\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`flush\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
getAccelerationThreshold\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`getGraphics\"\>"}\
,
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
initAcceleratedBackground\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`paletteChanged\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`restoreContents\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
SCALEUAREAUAVERAGING\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUDEFAULT\"\>\
"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUFAST\"\>"},\

          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUREPLICATE\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUSMOOTH\"\>\
"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEU3BYTEUBGR\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEU4BYTEUABGR\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUBYTEUBINARY\
\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUBYTEUGRAY\"\
\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
TYPEUBYTEUINDEXED\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUCUSTOM\"\>"}\
,
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTUARGB\"\>\
"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
TYPEUINTUARGBUPRE\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTUBGR\"\>\
"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTURGB\"\>\
"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
TYPEUUSHORTU555URGB\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
TYPEUUSHORTU565URGB\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUUSHORTUGRAY\
\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`JPrivate`\
UndefinedProperty\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`SCALEUAREAUAVERAGING\"\>"}\
,
          {"\<\"sun`awt`windows`Win32OffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`SCALEUFAST\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`SCALEUREPLICATE\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEU4BYTEUABGRUPRE\"\>"},\

          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTU555URGB\"\>"},\

          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTU565URGB\"\>"},\

          {"\<\"sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"sun`awt`windows`Win32OffScreenImage`UndefinedProperty\"\>"},
          {"\<\"SunGraphics2D`CLIPUDEVICE\"\>"},
          {"\<\"SunGraphics2D`CLIPURECTANGULAR\"\>"},
          {"\<\"SunGraphics2D`CLIPUSHAPE\"\>"},
          {"\<\"SunGraphics2D`COMPUALPHA\"\>"},
          {"\<\"SunGraphics2D`COMPUCUSTOM\"\>"},
          {"\<\"SunGraphics2D`COMPUISCOPY\"\>"},
          {"\<\"SunGraphics2D`COMPUXOR\"\>"},
          {"\<\"SunGraphics2D`isRotated\"\>"},
          {"\<\"SunGraphics2D`makeFontMetrics\"\>"},
          {"\<\"SunGraphics2D`metricsCache\"\>"},
          {"\<\"SunGraphics2D`MinPenSizeAASquared\"\>"},
          {"\<\"SunGraphics2D`MinPenSizeSquared\"\>"},
          {"\<\"SunGraphics2D`PAINTUSINGLECOLOR\"\>"},
          {"\<\"SunGraphics2D`PAINTUSOLIDCOLOR\"\>"},
          {"\<\"SunGraphics2D`PAINTUTILE\"\>"},
          {"\<\"SunGraphics2D`STROKEUCUSTOM\"\>"},
          {"\<\"SunGraphics2D`STROKEUTHIN\"\>"},
          {"\<\"SunGraphics2D`STROKEUWIDE\"\>"},
          {"\<\"SunGraphics2D`TRANSFORMUGENERIC\"\>"},
          {"\<\"SunGraphics2D`TRANSFORMUISIDENT\"\>"},
          {"\<\"SunGraphics2D`TRANSFORMUTRANSLATEONLY\"\>"},
          {"\<\"SunGraphics2D`TRANSFORMUTRANSLATESCALE\"\>"},
          {"\<\"SunGraphics2D`XRGBModel\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`CLIPUDEVICE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`CLIPURECTANGULAR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`CLIPUSHAPE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`COMPUALPHA\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`COMPUCUSTOM\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`COMPUISCOPY\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`COMPUXOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`isRotated\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`addRenderingHints\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`alphafill\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`antialiasHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`backgroundColor\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`checkFontInfo\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`clearRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`clip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`clipRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`clipRegion\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`clipState\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`CLIPUDEVICE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`CLIPURECTANGULAR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`CLIPUSHAPE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`cloneTransform\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`complexTransform\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`composite\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`compositeState\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`COMPUALPHA\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`COMPUCUSTOM\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`COMPUISCOPY\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`COMPUXOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`constrain\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`constrainClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`constrainX\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`constrainY\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`convertRaster\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`copyArea\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`copyImage\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`create\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`dispose\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`draw\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawArc\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawBytes\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawChars\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawGlyphVector\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawImage\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawLine\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawOval\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawpipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawPolygon\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawPolyline\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawRenderableImage\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawRenderedImage\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawRoundRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`drawString\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fill\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillArc\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillComp\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillOval\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillpipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillPolygon\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fillRoundRect\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`finalize\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`fontInfo\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`foregroundColor\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getBackground\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getClipBounds\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getColor\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getCompClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getComposite\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getDeviceColorModel\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getDeviceConfiguration\"\>"}\
,
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getFont\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getFontMetrics\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getFontRenderContext\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getPaint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getRenderingHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getRenderingHints\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getStroke\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getSurfaceData\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`getTransform\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`hints\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`hit\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`hitClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`imageComp\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`imagepipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`interpolationHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`isRotated\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`lastGlyphVectorFontInfo\"\>\
"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`loops\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`makeFontMetrics\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`metricsCache\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`MinPenSizeAASquared\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`MinPenSizeSquared\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`paint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`paintState\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`PAINTUSINGLECOLOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`PAINTUSOLIDCOLOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`PAINTUTILE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`pixel\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`renderHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`rgb\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`rotate\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`scale\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setBackground\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setColor\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setComposite\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setDevClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setFont\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setPaint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setPaintMode\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setRenderingHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setRenderingHints\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setStroke\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setTransform\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`setXORMode\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`shapepipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`shear\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`stroke\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`strokeHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`strokeState\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`STROKEUCUSTOM\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`STROKEUTHIN\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`STROKEUWIDE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`surfaceData\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`textAntialiasHint\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`textpipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`transform\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`transformState\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUGENERIC\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUISIDENT\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUTRANSLATEONLY\"\>\
"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUTRANSLATESCALE\"\>\
"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`translate\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`transX\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`transY\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`untransformShape\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`usrClip\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`validatePipe\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`JPrivate`XRGBModel\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`makeFontMetrics\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`metricsCache\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`MinPenSizeAASquared\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`MinPenSizeSquared\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`PAINTUSINGLECOLOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`PAINTUSOLIDCOLOR\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`PAINTUTILE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`STROKEUCUSTOM\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`STROKEUTHIN\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`STROKEUWIDE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`TRANSFORMUGENERIC\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`TRANSFORMUISIDENT\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`TRANSFORMUTRANSLATEONLY\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`TRANSFORMUTRANSLATESCALE\"\>"},
          {"\<\"sun`java2d`SunGraphics2D`XRGBModel\"\>"},
          {"\<\"Superscript\"\>"},
          {"\<\"SuperscriptBox\"\>"},
          {"\<\"SuperscriptBoxOptions\"\>"},
          {"\<\"SurfaceColor\"\>"},
          {"\<\"SurfaceGraphics\"\>"},
          {"\<\"SuspendPacket\"\>"},
          {"\<\"Switch\"\>"},
          {"\<\"SylvesterMatrix\"\>"},
          {"\<\"Symbol\"\>"},
          {"\<\"SymbolicProduct`SymbolicProduct\"\>"},
          {"\<\"SymbolicSum`SymbolicSum\"\>"},
          {"\<\"SymbolName\"\>"},
          {"\<\"Syntax\"\>"},
          {"\<\"SyntaxForm\"\>"},
          {"\<\"SyntaxLength\"\>"},
          {"\<\"SyntaxPacket\"\>"},
          {"\<\"SyntaxQ\"\>"},
          {"\<\"System`ComplexExpand`AbsExpr\"\>"},
          {"\<\"System`ComplexExpand`ArgExpr\"\>"},
          {"\<\"System`ComplexExpand`ConjugateExpr\"\>"},
          {"\<\"System`ComplexExpand`ReImExpr\"\>"},
          {"\<\"System`ComplexExpand`ReImFail\"\>"},
          {"\<\"System`ComplexExpand`SignExpr\"\>"},
          {"\<\"System`Convert`CommonDump`boxes\"\>"},
          {"\<\"System`Convert`CommonDump`contents\"\>"},
          {"\<\"System`Convert`CommonDump`EliminateRepetition\"\>"},
          {"\<\"System`Convert`CommonDump`EmbeddedStringWithLinearSyntaxQ\"\>\
"},
          {"\<\"System`Convert`CommonDump`form\"\>"},
          {"\<\"System`Convert`CommonDump`GetStyleSheet\"\>"},
          {"\<\"System`Convert`CommonDump`Recursive\"\>"},
          {"\<\"System`Convert`CommonDump`RemoveLinearSyntax\"\>"},
          {"\<\"System`Convert`CommonDump`style\"\>"},
          {"\<\"System`Convert`MathMLDump`annotations\"\>"},
          {"\<\"System`Convert`MathMLDump`boxOptions\"\>"},
          {"\<\"System`Convert`MathMLDump`boxStructureQ\"\>"},
          {"\<\"System`Convert`MathMLDump`chooseAndMakeAnnotation\"\>"},
          {"\<\"System`Convert`MathMLDump`mathMLExport\"\>"},
          {"\<\"System`Convert`MathMLDump`mathMLImport\"\>"},
          {"\<\"System`Convert`MathMLDump`stripBoxes\"\>"},
          {"\<\"System`Convert`MLStringDataDump`LetterLikeQ\"\>"},
          {"\<\"System`Convert`MLStringDataDump`OperatorQ\"\>"},
          {"\<\"System`Convert`MLStringDataDump`$\
PrivateCharacterToUnicodeEntities\"\>"},
          {"\<\"System`Convert`MLStringDataDump`$UnicodeToHTML4Entities\"\>"},\

          {"\<\"System`Convert`MLStringDataDump`$UnicodeToMathML1Entities\"\>\
"},
          {"\<\"System`Convert`MLStringDataDump`$UnicodeToMathML2Entities\"\>\
"},
          {"\<\"System`Convert`NotebookMLDump`ExpressionMLGet\"\>"},
          {"\<\"System`Convert`NotebookMLDump`ExpressionMLSave\"\>"},
          {"\<\"System`Convert`NotebookMLDump`exprmlGet\"\>"},
          {"\<\"System`Convert`NotebookMLDump`exprmlSave\"\>"},
          {"\<\"System`Convert`NotebookMLDump`nbmlGet\"\>"},
          {"\<\"System`Convert`NotebookMLDump`nbmlSave\"\>"},
          {"\<\"System`Convert`NotebookMLDump`NotebookMLGet\"\>"},
          {"\<\"System`Convert`NotebookMLDump`NotebookMLSave\"\>"},
          {"\<\"System`Convert`SVGDump`ExportSVGZ\"\>"},
          {"\<\"System`Convert`SVGDump`ImportSVGZ\"\>"},
          {"\<\"System`Convert`SVGDump`svgGet\"\>"},
          {"\<\"System`Convert`SVGDump`SVGGet\"\>"},
          {"\<\"System`Convert`SVGDump`svgSave\"\>"},
          {"\<\"System`Convert`SVGDump`SVGSave\"\>"},
          {"\<\"System`Convert`TableDump`ComplexTableFormat\"\>"},
          {"\<\"System`Convert`TableDump`CSVFormat\"\>"},
          {"\<\"System`Convert`TableDump`FromCForm\"\>"},
          {"\<\"System`Convert`TableDump`ParseElement\"\>"},
          {"\<\"System`Convert`TableDump`StringCSVFormat\"\>"},
          {"\<\"System`Convert`TableDump`TableFormat\"\>"},
          {"\<\"System`Convert`TableDump`TryDate\"\>"},
          {"\<\"System`Convert`XMLDump`ExportSymbolicXML\"\>"},
          {"\<\"System`Convert`XMLDump`ExportXML\"\>"},
          {"\<\"System`Convert`XMLDump`ImportXML\"\>"},
          {"\<\"System`Convert`XMLDump`symbolicXMLExport\"\>"},
          {"\<\"System`Convert`XMLDump`symbolicXMLImport\"\>"},
          {"\<\"System`Convert`XMLDump`WriteSymbolicXML\"\>"},
          {"\<\"System`CrossDump`m\"\>"},
          {"\<\"System`CrossDump`m$\"\>"},
          {"\<\"System`CrossDump`n\"\>"},
          {"\<\"System`CrossDump`n$\"\>"},
          {"\<\"System`CrossDump`test\"\>"},
          {"\<\"System`CrossDump`test$\"\>"},
          {"\<\"System`CrossDump`vList\"\>"},
          {"\<\"System`Dump`a\"\>"},
          {"\<\"System`Dump`A\"\>"},
          {"\<\"System`Dump`addmessagebutton\"\>"},
          {"\<\"System`Dump`addmessagebuttons\"\>"},
          {"\<\"System`Dump`allowprotect\"\>"},
          {"\<\"System`Dump`allowprotect$\"\>"},
          {"\<\"System`Dump`AllSyms\"\>"},
          {"\<\"System`Dump`alltags\"\>"},
          {"\<\"System`Dump`alltags$\"\>"},
          {"\<\"System`Dump`any\"\>"},
          {"\<\"System`Dump`applyUsageStyles\"\>"},
          {"\<\"System`Dump`arg\"\>"},
          {"\<\"System`Dump`arg1\"\>"},
          {"\<\"System`Dump`arg1$\"\>"},
          {"\<\"System`Dump`arg2\"\>"},
          {"\<\"System`Dump`arg2$\"\>"},
          {"\<\"System`Dump`argname\"\>"},
          {"\<\"System`Dump`args\"\>"},
          {"\<\"System`Dump`args$\"\>"},
          {"\<\"System`Dump`ArgumentCount`ArgCountBetween\"\>"},
          {"\<\"System`Dump`ArgumentCount`ArgCountEitherOr\"\>"},
          {"\<\"System`Dump`ArgumentCount`ArgCountMore\"\>"},
          {"\<\"System`Dump`ArgumentCount`ArgCountSpecific\"\>"},
          {"\<\"System`Dump`ArgumentCount`count1\"\>"},
          {"\<\"System`Dump`ArgumentCount`count2\"\>"},
          {"\<\"System`Dump`ArgumentCount`expected\"\>"},
          {"\<\"System`Dump`ArgumentCount`head\"\>"},
          {"\<\"System`Dump`ArgumentCount`len\"\>"},
          {"\<\"System`Dump`ArgumentCount`max\"\>"},
          {"\<\"System`Dump`ArgumentCount`min\"\>"},
          {"\<\"System`Dump`ArgumentCount`received\"\>"},
          {"\<\"System`Dump`asp\"\>"},
          {"\<\"System`Dump`asp$\"\>"},
          {"\<\"System`Dump`AutoLoad\"\>"},
          {"\<\"System`Dump`axes\"\>"},
          {"\<\"System`Dump`axes$\"\>"},
          {"\<\"System`Dump`a$\"\>"},
          {"\<\"System`Dump`b\"\>"},
          {"\<\"System`Dump`B\"\>"},
          {"\<\"System`Dump`base\"\>"},
          {"\<\"System`Dump`binary\"\>"},
          {"\<\"System`Dump`binary$\"\>"},
          {"\<\"System`Dump`bitmap\"\>"},
          {"\<\"System`Dump`Bitmap\"\>"},
          {"\<\"System`Dump`body\"\>"},
          {"\<\"System`Dump`box\"\>"},
          {"\<\"System`Dump`box$\"\>"},
          {"\<\"System`Dump`breakblanksstring\"\>"},
          {"\<\"System`Dump`butsizes\"\>"},
          {"\<\"System`Dump`butsizes$\"\>"},
          {"\<\"System`Dump`button\"\>"},
          {"\<\"System`Dump`buttoncontentstructure\"\>"},
          {"\<\"System`Dump`buttonstyle\"\>"},
          {"\<\"System`Dump`buttonstyleoptions\"\>"},
          {"\<\"System`Dump`buttonstyle$\"\>"},
          {"\<\"System`Dump`b$\"\>"},
          {"\<\"System`Dump`c\"\>"},
          {"\<\"System`Dump`c1\"\>"},
          {"\<\"System`Dump`c2\"\>"},
          {"\<\"System`Dump`cells\"\>"},
          {"\<\"System`Dump`cellstyleoptions\"\>"},
          {"\<\"System`Dump`channel\"\>"},
          {"\<\"System`Dump`chars\"\>"},
          {"\<\"System`Dump`CheckBoolean\"\>"},
          {"\<\"System`Dump`checkFEfilesystemQ\"\>"},
          {"\<\"System`Dump`CheckGopt\"\>"},
          {"\<\"System`Dump`CheckPositive\"\>"},
          {"\<\"System`Dump`CheckSymbolQ\"\>"},
          {"\<\"System`Dump`chi\"\>"},
          {"\<\"System`Dump`chi$\"\>"},
          {"\<\"System`Dump`cleanname\"\>"},
          {"\<\"System`Dump`cleanname$\"\>"},
          {"\<\"System`Dump`ClearUsageStyles\"\>"},
          {"\<\"System`Dump`cmd\"\>"},
          {"\<\"System`Dump`cnames\"\>"},
          {"\<\"System`Dump`cnames$\"\>"},
          {"\<\"System`Dump`comm\"\>"},
          {"\<\"System`Dump`command\"\>"},
          {"\<\"System`Dump`con\"\>"},
          {"\<\"System`Dump`ConnectToExternalPackage\"\>"},
          {"\<\"System`Dump`constructbutton\"\>"},
          {"\<\"System`Dump`constructgroups\"\>"},
          {"\<\"System`Dump`cont\"\>"},
          {"\<\"System`Dump`cont1\"\>"},
          {"\<\"System`Dump`cont1$\"\>"},
          {"\<\"System`Dump`cont2\"\>"},
          {"\<\"System`Dump`cont2$\"\>"},
          {"\<\"System`Dump`context\"\>"},
          {"\<\"System`Dump`conts\"\>"},
          {"\<\"System`Dump`conts$\"\>"},
          {"\<\"System`Dump`convertcell\"\>"},
          {"\<\"System`Dump`convertexpr\"\>"},
          {"\<\"System`Dump`corder\"\>"},
          {"\<\"System`Dump`crest\"\>"},
          {"\<\"System`Dump`ctags\"\>"},
          {"\<\"System`Dump`ctags$\"\>"},
          {"\<\"System`Dump`currstys\"\>"},
          {"\<\"System`Dump`d\"\>"},
          {"\<\"System`Dump`dat\"\>"},
          {"\<\"System`Dump`data\"\>"},
          {"\<\"System`Dump`ddx\"\>"},
          {"\<\"System`Dump`ddx$\"\>"},
          {"\<\"System`Dump`DeactivateMessages\"\>"},
          {"\<\"System`Dump`DeactivateReadProtected\"\>"},
          {"\<\"System`Dump`defaults\"\>"},
          {"\<\"System`Dump`defaults$\"\>"},
          {"\<\"System`Dump`defined\"\>"},
          {"\<\"System`Dump`defineLinkObject\"\>"},
          {"\<\"System`Dump`delta\"\>"},
          {"\<\"System`Dump`den\"\>"},
          {"\<\"System`Dump`den$\"\>"},
          {"\<\"System`Dump`DGTest\"\>"},
          {"\<\"System`Dump`dig\"\>"},
          {"\<\"System`Dump`digit\"\>"},
          {"\<\"System`Dump`digitcountcore\"\>"},
          {"\<\"System`Dump`digits\"\>"},
          {"\<\"System`Dump`DisplayInternal\"\>"},
          {"\<\"System`Dump`DisplayInternal0\"\>"},
          {"\<\"System`Dump`DisplayToGIFOptions\"\>"},
          {"\<\"System`Dump`dist\"\>"},
          {"\<\"System`Dump`doinformation\"\>"},
          {"\<\"System`Dump`dOpts\"\>"},
          {"\<\"System`Dump`dx\"\>"},
          {"\<\"System`Dump`dx$\"\>"},
          {"\<\"System`Dump`dy\"\>"},
          {"\<\"System`Dump`dy$\"\>"},
          {"\<\"System`Dump`e\"\>"},
          {"\<\"System`Dump`EditDef\"\>"},
          {"\<\"System`Dump`EditInAux\"\>"},
          {"\<\"System`Dump`EditIO\"\>"},
          {"\<\"System`Dump`EditString\"\>"},
          {"\<\"System`Dump`eh\"\>"},
          {"\<\"System`Dump`end\"\>"},
          {"\<\"System`Dump`end$\"\>"},
          {"\<\"System`Dump`eps\"\>"},
          {"\<\"System`Dump`epsString\"\>"},
          {"\<\"System`Dump`EvalIO\"\>"},
          {"\<\"System`Dump`expandall\"\>"},
          {"\<\"System`Dump`expandAll\"\>"},
          {"\<\"System`Dump`expandDenominator\"\>"},
          {"\<\"System`Dump`expandNumerator\"\>"},
          {"\<\"System`Dump`ExportToGIF\"\>"},
          {"\<\"System`Dump`exppatt\"\>"},
          {"\<\"System`Dump`expr\"\>"},
          {"\<\"System`Dump`expvect\"\>"},
          {"\<\"System`Dump`ExternalAnswer\"\>"},
          {"\<\"System`Dump`extractSizeFromEPS\"\>"},
          {"\<\"System`Dump`extras\"\>"},
          {"\<\"System`Dump`extras$\"\>"},
          {"\<\"System`Dump`e$\"\>"},
          {"\<\"System`Dump`f\"\>"},
          {"\<\"System`Dump`fc\"\>"},
          {"\<\"System`Dump`feflag\"\>"},
          {"\<\"System`Dump`feflag$\"\>"},
          {"\<\"System`Dump`feGIFData\"\>"},
          {"\<\"System`Dump`feGIFData$\"\>"},
          {"\<\"System`Dump`file\"\>"},
          {"\<\"System`Dump`filename\"\>"},
          {"\<\"System`Dump`fileOrPipe\"\>"},
          {"\<\"System`Dump`file$\"\>"},
          {"\<\"System`Dump`FilterOptions\"\>"},
          {"\<\"System`Dump`firstnumberfromstring\"\>"},
          {"\<\"System`Dump`fixcelltags\"\>"},
          {"\<\"System`Dump`fixfile\"\>"},
          {"\<\"System`Dump`fixmessagename\"\>"},
          {"\<\"System`Dump`fixmessagestring\"\>"},
          {"\<\"System`Dump`fixname\"\>"},
          {"\<\"System`Dump`fixremaps\"\>"},
          {"\<\"System`Dump`fmt\"\>"},
          {"\<\"System`Dump`fmtpatt\"\>"},
          {"\<\"System`Dump`fn\"\>"},
          {"\<\"System`Dump`fname\"\>"},
          {"\<\"System`Dump`format\"\>"},
          {"\<\"System`Dump`formatcode\"\>"},
          {"\<\"System`Dump`formatflag\"\>"},
          {"\<\"System`Dump`formatusage\"\>"},
          {"\<\"System`Dump`ForwardCheckFunction\"\>"},
          {"\<\"System`Dump`ForwardContext\"\>"},
          {"\<\"System`Dump`found\"\>"},
          {"\<\"System`Dump`found$\"\>"},
          {"\<\"System`Dump`fu\"\>"},
          {"\<\"System`Dump`fullname\"\>"},
          {"\<\"System`Dump`fullname$\"\>"},
          {"\<\"System`Dump`fulltag\"\>"},
          {"\<\"System`Dump`fulltag$\"\>"},
          {"\<\"System`Dump`f$\"\>"},
          {"\<\"System`Dump`g\"\>"},
          {"\<\"System`Dump`generategridcell\"\>"},
          {"\<\"System`Dump`generateinfocells\"\>"},
          {"\<\"System`Dump`generaterandomtag\"\>"},
          {"\<\"System`Dump`getbuttonsize\"\>"},
          {"\<\"System`Dump`getFEfile\"\>"},
          {"\<\"System`Dump`getfileinprivatecontext\"\>"},
          {"\<\"System`Dump`getfulldefinitioncells\"\>"},
          {"\<\"System`Dump`GetMatrix\"\>"},
          {"\<\"System`Dump`GetMesh\"\>"},
          {"\<\"System`Dump`getnbcacheoffset\"\>"},
          {"\<\"System`Dump`getRefGuide\"\>"},
          {"\<\"System`Dump`getusagecellfromRefGuide\"\>"},
          {"\<\"System`Dump`getvalidmessagenames\"\>"},
          {"\<\"System`Dump`GetYesNo\"\>"},
          {"\<\"System`Dump`globalsym\"\>"},
          {"\<\"System`Dump`globalsym$\"\>"},
          {"\<\"System`Dump`goodsymbolQ\"\>"},
          {"\<\"System`Dump`gopts\"\>"},
          {"\<\"System`Dump`grid\"\>"},
          {"\<\"System`Dump`grid$\"\>"},
          {"\<\"System`Dump`groups\"\>"},
          {"\<\"System`Dump`groups$\"\>"},
          {"\<\"System`Dump`GRTest\"\>"},
          {"\<\"System`Dump`GTest\"\>"},
          {"\<\"System`Dump`g$\"\>"},
          {"\<\"System`Dump`h\"\>"},
          {"\<\"System`Dump`halftag\"\>"},
          {"\<\"System`Dump`halftag$\"\>"},
          {"\<\"System`Dump`heldsyms\"\>"},
          {"\<\"System`Dump`h$\"\>"},
          {"\<\"System`Dump`i\"\>"},
          {"\<\"System`Dump`imppatt\"\>"},
          {"\<\"System`Dump`inames\"\>"},
          {"\<\"System`Dump`InitializeRasterLink\"\>"},
          {"\<\"System`Dump`inname\"\>"},
          {"\<\"System`Dump`input\"\>"},
          {"\<\"System`Dump`iOffset\"\>"},
          {"\<\"System`Dump`ipiz2\"\>"},
          {"\<\"System`Dump`ipiz2$\"\>"},
          {"\<\"System`Dump`iResolution\"\>"},
          {"\<\"System`Dump`iRotated\"\>"},
          {"\<\"System`Dump`iSize\"\>"},
          {"\<\"System`Dump`i$\"\>"},
          {"\<\"System`Dump`j\"\>"},
          {"\<\"System`Dump`j$\"\>"},
          {"\<\"System`Dump`k\"\>"},
          {"\<\"System`Dump`keywords\"\>"},
          {"\<\"System`Dump`k$\"\>"},
          {"\<\"System`Dump`l\"\>"},
          {"\<\"System`Dump`lcoptions\"\>"},
          {"\<\"System`Dump`lcoptions$\"\>"},
          {"\<\"System`Dump`len\"\>"},
          {"\<\"System`Dump`lens\"\>"},
          {"\<\"System`Dump`lens$\"\>"},
          {"\<\"System`Dump`len$\"\>"},
          {"\<\"System`Dump`lev\"\>"},
          {"\<\"System`Dump`lev$\"\>"},
          {"\<\"System`Dump`lf\"\>"},
          {"\<\"System`Dump`lf$\"\>"},
          {"\<\"System`Dump`line\"\>"},
          {"\<\"System`Dump`lines\"\>"},
          {"\<\"System`Dump`link\"\>"},
          {"\<\"System`Dump`LinkOpenWithArgs\"\>"},
          {"\<\"System`Dump`linkPatterns\"\>"},
          {"\<\"System`Dump`LinkQuote\"\>"},
          {"\<\"System`Dump`LinksHelper\"\>"},
          {"\<\"System`Dump`link$\"\>"},
          {"\<\"System`Dump`lis\"\>"},
          {"\<\"System`Dump`localRasterValue\"\>"},
          {"\<\"System`Dump`locked\"\>"},
          {"\<\"System`Dump`longform\"\>"},
          {"\<\"System`Dump`l$\"\>"},
          {"\<\"System`Dump`m\"\>"},
          {"\<\"System`Dump`makeBytes\"\>"},
          {"\<\"System`Dump`makegrid\"\>"},
          {"\<\"System`Dump`MakeRectangles\"\>"},
          {"\<\"System`Dump`makesymbolbuttoncore\"\>"},
          {"\<\"System`Dump`makesymbolbuttons\"\>"},
          {"\<\"System`Dump`matchnames\"\>"},
          {"\<\"System`Dump`matchnames$\"\>"},
          {"\<\"System`Dump`MathEditor\"\>"},
          {"\<\"System`Dump`max\"\>"},
          {"\<\"System`Dump`medit\"\>"},
          {"\<\"System`Dump`mesh\"\>"},
          {"\<\"System`Dump`mesh$\"\>"},
          {"\<\"System`Dump`mess\"\>"},
          {"\<\"System`Dump`messagenamecache\"\>"},
          {"\<\"System`Dump`messageopts\"\>"},
          {"\<\"System`Dump`messageopts$\"\>"},
          {"\<\"System`Dump`messages\"\>"},
          {"\<\"System`Dump`messagetocellcontents\"\>"},
          {"\<\"System`Dump`messagetocells\"\>"},
          {"\<\"System`Dump`messconts\"\>"},
          {"\<\"System`Dump`messconts$\"\>"},
          {"\<\"System`Dump`mess$\"\>"},
          {"\<\"System`Dump`mFile\"\>"},
          {"\<\"System`Dump`min\"\>"},
          {"\<\"System`Dump`mName\"\>"},
          {"\<\"System`Dump`mName1\"\>"},
          {"\<\"System`Dump`mod\"\>"},
          {"\<\"System`Dump`mod$\"\>"},
          {"\<\"System`Dump`msgs\"\>"},
          {"\<\"System`Dump`m$\"\>"},
          {"\<\"System`Dump`n\"\>"},
          {"\<\"System`Dump`na\"\>"},
          {"\<\"System`Dump`name\"\>"},
          {"\<\"System`Dump`name1\"\>"},
          {"\<\"System`Dump`name1$\"\>"},
          {"\<\"System`Dump`name2\"\>"},
          {"\<\"System`Dump`names\"\>"},
          {"\<\"System`Dump`names$\"\>"},
          {"\<\"System`Dump`name$\"\>"},
          {"\<\"System`Dump`nb\"\>"},
          {"\<\"System`Dump`nbops\"\>"},
          {"\<\"System`Dump`nbops$\"\>"},
          {"\<\"System`Dump`nc\"\>"},
          {"\<\"System`Dump`newcont\"\>"},
          {"\<\"System`Dump`newcont$\"\>"},
          {"\<\"System`Dump`newdata\"\>"},
          {"\<\"System`Dump`newdata$\"\>"},
          {"\<\"System`Dump`NotList\"\>"},
          {"\<\"System`Dump`NoValuesTest\"\>"},
          {"\<\"System`Dump`npatt\"\>"},
          {"\<\"System`Dump`nt\"\>"},
          {"\<\"System`Dump`NTest\"\>"},
          {"\<\"System`Dump`num\"\>"},
          {"\<\"System`Dump`num1\"\>"},
          {"\<\"System`Dump`num2\"\>"},
          {"\<\"System`Dump`num$\"\>"},
          {"\<\"System`Dump`nx\"\>"},
          {"\<\"System`Dump`nx$\"\>"},
          {"\<\"System`Dump`ny\"\>"},
          {"\<\"System`Dump`ny$\"\>"},
          {"\<\"System`Dump`n$\"\>"},
          {"\<\"System`Dump`o1\"\>"},
          {"\<\"System`Dump`o2\"\>"},
          {"\<\"System`Dump`obj\"\>"},
          {"\<\"System`Dump`offd\"\>"},
          {"\<\"System`Dump`offd1\"\>"},
          {"\<\"System`Dump`offset\"\>"},
          {"\<\"System`Dump`offx\"\>"},
          {"\<\"System`Dump`offx$\"\>"},
          {"\<\"System`Dump`offy\"\>"},
          {"\<\"System`Dump`offy$\"\>"},
          {"\<\"System`Dump`ok\"\>"},
          {"\<\"System`Dump`ok$\"\>"},
          {"\<\"System`Dump`OldAutoLoad\"\>"},
          {"\<\"System`Dump`oldcont\"\>"},
          {"\<\"System`Dump`oldcontextpath\"\>"},
          {"\<\"System`Dump`oldcontextpath$\"\>"},
          {"\<\"System`Dump`oldconts\"\>"},
          {"\<\"System`Dump`oldconts$\"\>"},
          {"\<\"System`Dump`oldValue\"\>"},
          {"\<\"System`Dump`opt\"\>"},
          {"\<\"System`Dump`options\"\>"},
          {"\<\"System`Dump`optpat\"\>"},
          {"\<\"System`Dump`optpat$\"\>"},
          {"\<\"System`Dump`opts\"\>"},
          {"\<\"System`Dump`opts$\"\>"},
          {"\<\"System`Dump`orderfun\"\>"},
          {"\<\"System`Dump`other\"\>"},
          {"\<\"System`Dump`outputinfo\"\>"},
          {"\<\"System`Dump`outStream\"\>"},
          {"\<\"System`Dump`outStream$\"\>"},
          {"\<\"System`Dump`OverrideFE\"\>"},
          {"\<\"System`Dump`p\"\>"},
          {"\<\"System`Dump`packet\"\>"},
          {"\<\"System`Dump`pat\"\>"},
          {"\<\"System`Dump`pat1\"\>"},
          {"\<\"System`Dump`pat2\"\>"},
          {"\<\"System`Dump`pats\"\>"},
          {"\<\"System`Dump`pat$\"\>"},
          {"\<\"System`Dump`plrng\"\>"},
          {"\<\"System`Dump`plrng$\"\>"},
          {"\<\"System`Dump`prim\"\>"},
          {"\<\"System`Dump`prompt\"\>"},
          {"\<\"System`Dump`prot\"\>"},
          {"\<\"System`Dump`protected\"\>"},
          {"\<\"System`Dump`protected$\"\>"},
          {"\<\"System`Dump`proto\"\>"},
          {"\<\"System`Dump`PutGIF\"\>"},
          {"\<\"System`Dump`quote\"\>"},
          {"\<\"System`Dump`quotedname\"\>"},
          {"\<\"System`Dump`quotedname$\"\>"},
          {"\<\"System`Dump`r\"\>"},
          {"\<\"System`Dump`r1\"\>"},
          {"\<\"System`Dump`r2\"\>"},
          {"\<\"System`Dump`randomtag\"\>"},
          {"\<\"System`Dump`randtag\"\>"},
          {"\<\"System`Dump`randtag$\"\>"},
          {"\<\"System`Dump`readcell\"\>"},
          {"\<\"System`Dump`ReadIO\"\>"},
          {"\<\"System`Dump`reallygetRefGuide\"\>"},
          {"\<\"System`Dump`reap\"\>"},
          {"\<\"System`Dump`ReapBinaryRead\"\>"},
          {"\<\"System`Dump`reap$\"\>"},
          {"\<\"System`Dump`rec\"\>"},
          {"\<\"System`Dump`rect\"\>"},
          {"\<\"System`Dump`rec$\"\>"},
          {"\<\"System`Dump`reducename\"\>"},
          {"\<\"System`Dump`reformatdefinition\"\>"},
          {"\<\"System`Dump`res\"\>"},
          {"\<\"System`Dump`resfile\"\>"},
          {"\<\"System`Dump`resol\"\>"},
          {"\<\"System`Dump`resp\"\>"},
          {"\<\"System`Dump`rest\"\>"},
          {"\<\"System`Dump`result\"\>"},
          {"\<\"System`Dump`result$\"\>"},
          {"\<\"System`Dump`res$\"\>"},
          {"\<\"System`Dump`rng\"\>"},
          {"\<\"System`Dump`rotated\"\>"},
          {"\<\"System`Dump`rx\"\>"},
          {"\<\"System`Dump`rx$\"\>"},
          {"\<\"System`Dump`ry\"\>"},
          {"\<\"System`Dump`ry$\"\>"},
          {"\<\"System`Dump`r$\"\>"},
          {"\<\"System`Dump`s\"\>"},
          {"\<\"System`Dump`scale\"\>"},
          {"\<\"System`Dump`SendTwoNumbers\"\>"},
          {"\<\"System`Dump`serialnumber\"\>"},
          {"\<\"System`Dump`SetUsageStyles\"\>"},
          {"\<\"System`Dump`sfname\"\>"},
          {"\<\"System`Dump`sfname$\"\>"},
          {"\<\"System`Dump`ShadowFunction\"\>"},
          {"\<\"System`Dump`shi\"\>"},
          {"\<\"System`Dump`shi$\"\>"},
          {"\<\"System`Dump`size\"\>"},
          {"\<\"System`Dump`sname\"\>"},
          {"\<\"System`Dump`sName\"\>"},
          {"\<\"System`Dump`sourcecont\"\>"},
          {"\<\"System`Dump`sourcecontext\"\>"},
          {"\<\"System`Dump`sp\"\>"},
          {"\<\"System`Dump`space\"\>"},
          {"\<\"System`Dump`SpaceCheck\"\>"},
          {"\<\"System`Dump`spat\"\>"},
          {"\<\"System`Dump`splitstring\"\>"},
          {"\<\"System`Dump`spx\"\>"},
          {"\<\"System`Dump`spy\"\>"},
          {"\<\"System`Dump`sp$\"\>"},
          {"\<\"System`Dump`ssofar\"\>"},
          {"\<\"System`Dump`ssofar$\"\>"},
          {"\<\"System`Dump`stm\"\>"},
          {"\<\"System`Dump`stmp\"\>"},
          {"\<\"System`Dump`stmp$\"\>"},
          {"\<\"System`Dump`str\"\>"},
          {"\<\"System`Dump`stream\"\>"},
          {"\<\"System`Dump`StreamFileName\"\>"},
          {"\<\"System`Dump`streamhead\"\>"},
          {"\<\"System`Dump`stream$\"\>"},
          {"\<\"System`Dump`stringpatternQ\"\>"},
          {"\<\"System`Dump`stripwhitespace\"\>"},
          {"\<\"System`Dump`strm\"\>"},
          {"\<\"System`Dump`StrmTest\"\>"},
          {"\<\"System`Dump`strm$\"\>"},
          {"\<\"System`Dump`stub1\"\>"},
          {"\<\"System`Dump`stub1$\"\>"},
          {"\<\"System`Dump`stub2\"\>"},
          {"\<\"System`Dump`stub2$\"\>"},
          {"\<\"System`Dump`stylename\"\>"},
          {"\<\"System`Dump`sym\"\>"},
          {"\<\"System`Dump`symbols\"\>"},
          {"\<\"System`Dump`symname\"\>"},
          {"\<\"System`Dump`symname$\"\>"},
          {"\<\"System`Dump`symnew\"\>"},
          {"\<\"System`Dump`syms\"\>"},
          {"\<\"System`Dump`sym$\"\>"},
          {"\<\"System`Dump`synt\"\>"},
          {"\<\"System`Dump`synt$\"\>"},
          {"\<\"System`Dump`s$\"\>"},
          {"\<\"System`Dump`t\"\>"},
          {"\<\"System`Dump`tag\"\>"},
          {"\<\"System`Dump`tagname\"\>"},
          {"\<\"System`Dump`tagname$\"\>"},
          {"\<\"System`Dump`targetnb\"\>"},
          {"\<\"System`Dump`targetnb$\"\>"},
          {"\<\"System`Dump`TestBase\"\>"},
          {"\<\"System`Dump`TestDCArgs\"\>"},
          {"\<\"System`Dump`TestDig\"\>"},
          {"\<\"System`Dump`TestIntegerList\"\>"},
          {"\<\"System`Dump`TestIntegerListThrow\"\>"},
          {"\<\"System`Dump`TestLoad\"\>"},
          {"\<\"System`Dump`TestN\"\>"},
          {"\<\"System`Dump`TextualCompact\"\>"},
          {"\<\"System`Dump`ThrowBinaryRead\"\>"},
          {"\<\"System`Dump`ThrowBinaryWrite\"\>"},
          {"\<\"System`Dump`tickPosition\"\>"},
          {"\<\"System`Dump`tmp\"\>"},
          {"\<\"System`Dump`tmpboxes\"\>"},
          {"\<\"System`Dump`tmpboxes$\"\>"},
          {"\<\"System`Dump`tmpeps\"\>"},
          {"\<\"System`Dump`tmpfile\"\>"},
          {"\<\"System`Dump`tmpfname\"\>"},
          {"\<\"System`Dump`tmpstr\"\>"},
          {"\<\"System`Dump`tmpstr$\"\>"},
          {"\<\"System`Dump`tmp$\"\>"},
          {"\<\"System`Dump`tresult\"\>"},
          {"\<\"System`Dump`trig\"\>"},
          {"\<\"System`Dump`trig$\"\>"},
          {"\<\"System`Dump`trim\"\>"},
          {"\<\"System`Dump`trueCharEnc\"\>"},
          {"\<\"System`Dump`trueCharEnc$\"\>"},
          {"\<\"System`Dump`txt1\"\>"},
          {"\<\"System`Dump`txt2\"\>"},
          {"\<\"System`Dump`TypesetCompact\"\>"},
          {"\<\"System`Dump`TypesetMessagesQ\"\>"},
          {"\<\"System`Dump`uFile\"\>"},
          {"\<\"System`Dump`UninstallHelper\"\>"},
          {"\<\"System`Dump`unset\"\>"},
          {"\<\"System`Dump`UsageCells\"\>"},
          {"\<\"System`Dump`UsagePrint\"\>"},
          {"\<\"System`Dump`UsageStyles\"\>"},
          {"\<\"System`Dump`UseExportFormatQ\"\>"},
          {"\<\"System`Dump`val\"\>"},
          {"\<\"System`Dump`vals\"\>"},
          {"\<\"System`Dump`vals$\"\>"},
          {"\<\"System`Dump`value\"\>"},
          {"\<\"System`Dump`vc\"\>"},
          {"\<\"System`Dump`vc$\"\>"},
          {"\<\"System`Dump`w\"\>"},
          {"\<\"System`Dump`wasOn\"\>"},
          {"\<\"System`Dump`wasOn$\"\>"},
          {"\<\"System`Dump`width\"\>"},
          {"\<\"System`Dump`width$\"\>"},
          {"\<\"System`Dump`winmag\"\>"},
          {"\<\"System`Dump`winmag$\"\>"},
          {"\<\"System`Dump`winsize\"\>"},
          {"\<\"System`Dump`winsize$\"\>"},
          {"\<\"System`Dump`writeArguments\"\>"},
          {"\<\"System`Dump`writeBytes\"\>"},
          {"\<\"System`Dump`WriteDef\"\>"},
          {"\<\"System`Dump`w$\"\>"},
          {"\<\"System`Dump`x\"\>"},
          {"\<\"System`Dump`x0\"\>"},
          {"\<\"System`Dump`x1\"\>"},
          {"\<\"System`Dump`xmax\"\>"},
          {"\<\"System`Dump`xmax$\"\>"},
          {"\<\"System`Dump`xmin\"\>"},
          {"\<\"System`Dump`xmin$\"\>"},
          {"\<\"System`Dump`x$\"\>"},
          {"\<\"System`Dump`y\"\>"},
          {"\<\"System`Dump`ymax\"\>"},
          {"\<\"System`Dump`ymax$\"\>"},
          {"\<\"System`Dump`ymin\"\>"},
          {"\<\"System`Dump`ymin$\"\>"},
          {"\<\"System`Dump`y$\"\>"},
          {"\<\"System`Dump`z\"\>"},
          {"\<\"System`Dump`zmax\"\>"},
          {"\<\"System`Dump`zmax$\"\>"},
          {"\<\"System`Dump`zmin\"\>"},
          {"\<\"System`Dump`zmin$\"\>"},
          {"\<\"System`Dump`$AutoLoad\"\>"},
          {"\<\"System`Dump`$badsystemsyms\"\>"},
          {"\<\"System`Dump`$cachedLanguage\"\>"},
          {"\<\"System`Dump`$experimentalanddevelopersyms\"\>"},
          {"\<\"System`Dump`$extendedmessageoptions\"\>"},
          {"\<\"System`Dump`$extendedmessageoptionsnames\"\>"},
          {"\<\"System`Dump`$FontPath\"\>"},
          {"\<\"System`Dump`$holdlist\"\>"},
          {"\<\"System`Dump`$knownpackages\"\>"},
          {"\<\"System`Dump`$MessagesInHelpBrowserAreKnown\"\>"},
          {"\<\"System`Dump`$OldMessageLocation\"\>"},
          {"\<\"System`Dump`$usagestylepatterns\"\>"},
          {"\<\"System`Dump`$usagestyles\"\>"},
          {"\<\"System`Dump`$$Dummy\"\>"},
          {"\<\"SystemException\"\>"},
          {"\<\"System`exit\"\>"},
          {"\<\"System`FEDump`allNotebooks\"\>"},
          {"\<\"System`FEDump`allNotebooks$\"\>"},
          {"\<\"System`FEDump`arg\"\>"},
          {"\<\"System`FEDump`args\"\>"},
          {"\<\"System`FEDump`boxes\"\>"},
          {"\<\"System`FEDump`category\"\>"},
          {"\<\"System`FEDump`CheckFileSystem\"\>"},
          {"\<\"System`FEDump`cnt\"\>"},
          {"\<\"System`FEDump`command\"\>"},
          {"\<\"System`FEDump`compnames\"\>"},
          {"\<\"System`FEDump`data\"\>"},
          {"\<\"System`FEDump`dir\"\>"},
          {"\<\"System`FEDump`elems\"\>"},
          {"\<\"System`FEDump`EqualizeCase\"\>"},
          {"\<\"System`FEDump`expr\"\>"},
          {"\<\"System`FEDump`f\"\>"},
          {"\<\"System`FEDump`fe\"\>"},
          {"\<\"System`FEDump`feLink\"\>"},
          {"\<\"System`FEDump`file\"\>"},
          {"\<\"System`FEDump`filename\"\>"},
          {"\<\"System`FEDump`filename$\"\>"},
          {"\<\"System`FEDump`formatType\"\>"},
          {"\<\"System`FEDump`formatType$\"\>"},
          {"\<\"System`FEDump`fromFileName\"\>"},
          {"\<\"System`FEDump`FrontEndQ\"\>"},
          {"\<\"System`FEDump`FrontEndValue\"\>"},
          {"\<\"System`FEDump`head\"\>"},
          {"\<\"System`FEDump`id\"\>"},
          {"\<\"System`FEDump`insertSeparatorsAmongstList\"\>"},
          {"\<\"System`FEDump`key\"\>"},
          {"\<\"System`FEDump`l\"\>"},
          {"\<\"System`FEDump`l1\"\>"},
          {"\<\"System`FEDump`l2\"\>"},
          {"\<\"System`FEDump`list\"\>"},
          {"\<\"System`FEDump`markup\"\>"},
          {"\<\"System`FEDump`messageopts\"\>"},
          {"\<\"System`FEDump`messageopts$\"\>"},
          {"\<\"System`FEDump`name\"\>"},
          {"\<\"System`FEDump`nbFileName\"\>"},
          {"\<\"System`FEDump`nbheads\"\>"},
          {"\<\"System`FEDump`nbName\"\>"},
          {"\<\"System`FEDump`nbName$\"\>"},
          {"\<\"System`FEDump`nbObj\"\>"},
          {"\<\"System`FEDump`nbTitle\"\>"},
          {"\<\"System`FEDump`newMessageOptions\"\>"},
          {"\<\"System`FEDump`newname\"\>"},
          {"\<\"System`FEDump`newName\"\>"},
          {"\<\"System`FEDump`newvers\"\>"},
          {"\<\"System`FEDump`NonOptionArgCount\"\>"},
          {"\<\"System`FEDump`NoResult\"\>"},
          {"\<\"System`FEDump`note\"\>"},
          {"\<\"System`FEDump`notebook\"\>"},
          {"\<\"System`FEDump`notebookNameMatchQ\"\>"},
          {"\<\"System`FEDump`oldMessageOptions\"\>"},
          {"\<\"System`FEDump`option\"\>"},
          {"\<\"System`FEDump`options\"\>"},
          {"\<\"System`FEDump`optlist\"\>"},
          {"\<\"System`FEDump`opts\"\>"},
          {"\<\"System`FEDump`other\"\>"},
          {"\<\"System`FEDump`otherboxes\"\>"},
          {"\<\"System`FEDump`outputForm\"\>"},
          {"\<\"System`FEDump`outputForm$\"\>"},
          {"\<\"System`FEDump`p\"\>"},
          {"\<\"System`FEDump`paddingElement\"\>"},
          {"\<\"System`FEDump`paddingElements\"\>"},
          {"\<\"System`FEDump`processBoxesForMathML\"\>"},
          {"\<\"System`FEDump`r\"\>"},
          {"\<\"System`FEDump`resnames\"\>"},
          {"\<\"System`FEDump`restopts\"\>"},
          {"\<\"System`FEDump`result\"\>"},
          {"\<\"System`FEDump`result$\"\>"},
          {"\<\"System`FEDump`s\"\>"},
          {"\<\"System`FEDump`seconds\"\>"},
          {"\<\"System`FEDump`select\"\>"},
          {"\<\"System`FEDump`setconvertoptions\"\>"},
          {"\<\"System`FEDump`sf\"\>"},
          {"\<\"System`FEDump`sf$\"\>"},
          {"\<\"System`FEDump`style\"\>"},
          {"\<\"System`FEDump`tag\"\>"},
          {"\<\"System`FEDump`tempnb\"\>"},
          {"\<\"System`FEDump`title\"\>"},
          {"\<\"System`FEDump`title$\"\>"},
          {"\<\"System`FEDump`transformProcessedBoxesToMathML\"\>"},
          {"\<\"System`FEDump`unit\"\>"},
          {"\<\"System`FEDump`usernb\"\>"},
          {"\<\"System`FEDump`varName\"\>"},
          {"\<\"System`FEDump`wasProtected\"\>"},
          {"\<\"System`FEDump`x\"\>"},
          {"\<\"System`FEDump`$validNotebookHeads\"\>"},
          {"\<\"System`FEDump`$validNotebookHeadsPattern\"\>"},
          {"\<\"SystemHelpPath\"\>"},
          {"\<\"System`IntegerPartitionsDump`n\"\>"},
          {"\<\"System`IntegerPartitionsDump`pp\"\>"},
          {"\<\"System`IntegerPartitionsDump`pq\"\>"},
          {"\<\"System`InterpolatingFunction`Grid\"\>"},
          {"\<\"System`InterpolatingFunction`ValuesOnGrid\"\>"},
          {"\<\"System`LanguageEnhancements`a\"\>"},
          {"\<\"System`LanguageEnhancements`e\"\>"},
          {"\<\"System`LanguageEnhancements`finalLevelOrder\"\>"},
          {"\<\"System`LanguageEnhancements`finalLevelOrder$\"\>"},
          {"\<\"System`LanguageEnhancements`flatSet\"\>"},
          {"\<\"System`LanguageEnhancements`flatSet$\"\>"},
          {"\<\"System`LanguageEnhancements`lengths\"\>"},
          {"\<\"System`LanguageEnhancements`lengths$\"\>"},
          {"\<\"System`LanguageEnhancements`m\"\>"},
          {"\<\"System`LanguageEnhancements`mergedAtTop\"\>"},
          {"\<\"System`LanguageEnhancements`mergedAtTop$\"\>"},
          {"\<\"System`LanguageEnhancements`mm\"\>"},
          {"\<\"System`LanguageEnhancements`mm$\"\>"},
          {"\<\"System`LanguageEnhancements`m$\"\>"},
          {"\<\"System`LanguageEnhancements`n\"\>"},
          {"\<\"System`LanguageEnhancements`neg\"\>"},
          {"\<\"System`LanguageEnhancements`neg$\"\>"},
          {"\<\"System`LanguageEnhancements`nn\"\>"},
          {"\<\"System`LanguageEnhancements`nn$\"\>"},
          {"\<\"System`LanguageEnhancements`permAfter\"\>"},
          {"\<\"System`LanguageEnhancements`permAfter$\"\>"},
          {"\<\"System`LanguageEnhancements`permBefore\"\>"},
          {"\<\"System`LanguageEnhancements`permBefore$\"\>"},
          {"\<\"System`LanguageEnhancements`R\"\>"},
          {"\<\"System`LanguageEnhancements`R$\"\>"},
          {"\<\"System`LanguageEnhancements`s\"\>"},
          {"\<\"System`LanguageEnhancements`setsOfLevels\"\>"},
          {"\<\"System`LanguageEnhancements`setsOfLevels$\"\>"},
          {"\<\"System`LanguageEnhancements`setsToMerge\"\>"},
          {"\<\"System`LanguageEnhancements`startLevels\"\>"},
          {"\<\"System`LanguageEnhancements`startLevels$\"\>"},
          {"\<\"System`LanguageEnhancements`tempTensor\"\>"},
          {"\<\"System`LanguageEnhancements`tempTensor$\"\>"},
          {"\<\"System`LanguageEnhancements`tensor\"\>"},
          {"\<\"System`LanguageEnhancements`toodeep\"\>"},
          {"\<\"System`LanguageEnhancements`toodeep$\"\>"},
          {"\<\"System`LanguageEnhancements`u\"\>"},
          {"\<\"System`LanguageEnhancements`union\"\>"},
          {"\<\"System`LanguageEnhancements`union$\"\>"},
          {"\<\"System`LanguageEnhancements`unscathedLevels\"\>"},
          {"\<\"System`LanguageEnhancements`unscathedLevels$\"\>"},
          {"\<\"System`LanguageEnhancements`u$\"\>"},
          {"\<\"System`LanguageEnhancements`ValidSetsQ\"\>"},
          {"\<\"System`LaplaceTransformDump`f\"\>"},
          {"\<\"System`LaplaceTransformDump`inverse\"\>"},
          {"\<\"System`LaplaceTransformDump`inverse$\"\>"},
          {"\<\"System`LaplaceTransformDump`m\"\>"},
          {"\<\"System`LaplaceTransformDump`s\"\>"},
          {"\<\"System`LaplaceTransformDump`t\"\>"},
          {"\<\"System`LaplaceTransformDump`t1\"\>"},
          {"\<\"System`LaplaceTransformDump`t1$\"\>"},
          {"\<\"System`Private`Accumulate\"\>"},
          {"\<\"System`Private`AlgebraicNumberQ\"\>"},
          {"\<\"System`Private`ApproxRoots\"\>"},
          {"\<\"System`Private`AssumptionAccess\"\>"},
          {"\<\"System`Private`AssumptionsExp\"\>"},
          {"\<\"System`Private`auto\"\>"},
          {"\<\"System`Private`binary\"\>"},
          {"\<\"System`Private`CFunctionInterpolation\"\>"},
          {"\<\"System`Private`check\"\>"},
          {"\<\"System`Private`Cholesky\"\>"},
          {"\<\"System`Private`CodeAddress\"\>"},
          {"\<\"System`Private`ColorMap\"\>"},
          {"\<\"System`Private`CompileLocal1\"\>"},
          {"\<\"System`Private`CompileLocal2\"\>"},
          {"\<\"System`Private`CompileLocal3\"\>"},
          {"\<\"System`Private`CompileLocal4\"\>"},
          {"\<\"System`Private`CompileLocal5\"\>"},
          {"\<\"System`Private`CompileSymbol\"\>"},
          {"\<\"System`Private`ComplexRoots\"\>"},
          {"\<\"System`Private`cont\"\>"},
          {"\<\"System`Private`ConvertToSymbols\"\>"},
          {"\<\"System`Private`CRCTGI\"\>"},
          {"\<\"System`Private`CyclotomicQ\"\>"},
          {"\<\"System`Private`D\"\>"},
          {"\<\"System`Private`dir\"\>"},
          {"\<\"System`Private`DummyId\"\>"},
          {"\<\"System`Private`DummySequence\"\>"},
          {"\<\"System`Private`ExpandFileName\"\>"},
          {"\<\"System`Private`extra\"\>"},
          {"\<\"System`Private`file\"\>"},
          {"\<\"System`Private`FindField\"\>"},
          {"\<\"System`Private`FindFile\"\>"},
          {"\<\"System`Private`fn\"\>"},
          {"\<\"System`Private`FullOptions3D\"\>"},
          {"\<\"System`Private`GBConvert\"\>"},
          {"\<\"System`Private`GCDcfLCMCancel\"\>"},
          {"\<\"System`Private`GetFieldData\"\>"},
          {"\<\"System`Private`GetInputHeld\"\>"},
          {"\<\"System`Private`heldSyms\"\>"},
          {"\<\"System`Private`heldSyms$\"\>"},
          {"\<\"System`Private`InputFormNumberMarks\"\>"},
          {"\<\"System`Private`IntegerDummy\"\>"},
          {"\<\"System`Private`InternalInverseErf\"\>"},
          {"\<\"System`Private`InternalSeries\"\>"},
          {"\<\"System`Private`InternalSpace\"\>"},
          {"\<\"System`Private`InternSequence\"\>"},
          {"\<\"System`Private`IsolatingSets\"\>"},
          {"\<\"System`Private`LargeDegreePolynomialMod\"\>"},
          {"\<\"System`Private`LinearInequalityReduce\"\>"},
          {"\<\"System`Private`loadInitFile\"\>"},
          {"\<\"System`Private`MakeValidRoot\"\>"},
          {"\<\"System`Private`MatchBox\"\>"},
          {"\<\"System`Private`MaxPiecewiseCasesMessage\"\>"},
          {"\<\"System`Private`NCacheKey\"\>"},
          {"\<\"System`Private`NewerDate\"\>"},
          {"\<\"System`Private`newsyms\"\>"},
          {"\<\"System`Private`NRelPrimeQ\"\>"},
          {"\<\"System`Private`NRoot\"\>"},
          {"\<\"System`Private`NRRoot\"\>"},
          {"\<\"System`Private`NRRoots\"\>"},
          {"\<\"System`Private`O\"\>"},
          {"\<\"System`Private`oldContextPath\"\>"},
          {"\<\"System`Private`OldReduce\"\>"},
          {"\<\"System`Private`origFrontEnd\"\>"},
          {"\<\"System`Private`PackedDisable\"\>"},
          {"\<\"System`Private`PackedList\"\>"},
          {"\<\"System`Private`pFile\"\>"},
          {"\<\"System`Private`PLt\"\>"},
          {"\<\"System`Private`PolyModInverse\"\>"},
          {"\<\"System`Private`pow\"\>"},
          {"\<\"System`Private`PrimitiveRoot\"\>"},
          {"\<\"System`Private`PTest\"\>"},
          {"\<\"System`Private`QuadraticRoot\"\>"},
          {"\<\"System`Private`RadicalVar\"\>"},
          {"\<\"System`Private`RealBignumRoots\"\>"},
          {"\<\"System`Private`RealRootQ\"\>"},
          {"\<\"System`Private`RealRoots\"\>"},
          {"\<\"System`Private`ReImPair\"\>"},
          {"\<\"System`Private`ResetTagCCs\"\>"},
          {"\<\"System`Private`RestoreAllValues\"\>"},
          {"\<\"System`Private`RootIsolatingPoints\"\>"},
          {"\<\"System`Private`RRoot\"\>"},
          {"\<\"System`Private`RuleHashTable\"\>"},
          {"\<\"System`Private`RuleTable\"\>"},
          {"\<\"System`Private`SaveAllValues\"\>"},
          {"\<\"System`Private`SeriesSingularityHandler\"\>"},
          {"\<\"System`Private`SetSymbolAttributes\"\>"},
          {"\<\"System`Private`SimplifyScaledArg\"\>"},
          {"\<\"System`Private`SmallQuadraticValues\"\>"},
          {"\<\"System`Private`StringTurnedIntoStream\"\>"},
          {"\<\"System`Private`test\"\>"},
          {"\<\"System`Private`TestGccLengthBug\"\>"},
          {"\<\"System`Private`tmp\"\>"},
          {"\<\"System`Private`tmp$\"\>"},
          {"\<\"System`Private`UnivariatePolynomialMod\"\>"},
          {"\<\"System`Private`UnivPolys\"\>"},
          {"\<\"System`Private`UpUnset\"\>"},
          {"\<\"System`Private`UsingOldVTs\"\>"},
          {"\<\"System`Private`ValidQ\"\>"},
          {"\<\"System`Private`ValueList\"\>"},
          {"\<\"System`Private`values\"\>"},
          {"\<\"System`Private`ValueTable\"\>"},
          {"\<\"System`Private`VerbatimSameQ\"\>"},
          {"\<\"System`Private`ZetaDerivative\"\>"},
          {"\<\"System`Private`$AutoLoad\"\>"},
          {"\<\"System`Private`$cachedRefGuide\"\>"},
          {"\<\"System`Private`$cachedRefGuideOffset\"\>"},
          {"\<\"System`Private`$ForceRebuild\"\>"},
          {"\<\"System`Private`$Gradient\"\>"},
          {"\<\"System`Private`$GraphicsHeader\"\>"},
          {"\<\"System`Private`$IndentSuffix\"\>"},
          {"\<\"System`Private`$InitsLoaded\"\>"},
          {"\<\"System`Private`$InputFileName\"\>"},
          {"\<\"System`Private`$MessagesDir\"\>"},
          {"\<\"System`Private`$nbFormatType\"\>"},
          {"\<\"System`Private`$nbFrontEndQ\"\>"},
          {"\<\"System`Private`$nbOpts\"\>"},
          {"\<\"System`Private`$nbSystemPrint\"\>"},
          {"\<\"System`Private`$prevWasFE\"\>"},
          {"\<\"System`Private`$PrintLoad\"\>"},
          {"\<\"System`Private`$PSRenderOptions\"\>"},
          {"\<\"System`Private`$RasterLink\"\>"},
          {"\<\"System`Private`$SetCCMaxCCEnabled\"\>"},
          {"\<\"System`Private`$SystemFileDir\"\>"},
          {"\<\"System`Private`$SystemPrint\"\>"},
          {"\<\"System`Private`$SystemPrintInput\"\>"},
          {"\<\"System`Private`$TagCCsEnabled\"\>"},
          {"\<\"System`Private`$TextAlter\"\>"},
          {"\<\"System`Private`$Unset\"\>"},
          {"\<\"System`Private`$$Failure2\"\>"},
          {"\<\"System`Private`$$ParenForm\"\>"},
          {"\<\"SystemStub\"\>"},
          {"\<\"sz0\"\>"},
          {"\<\"sz0$\"\>"},
          {"\<\"Tab\"\>"},
          {"\<\"TabFilling\"\>"},
          {"\<\"Table\"\>"},
          {"\<\"TableAlignments\"\>"},
          {"\<\"TableDepth\"\>"},
          {"\<\"TableDirections\"\>"},
          {"\<\"TableForm\"\>"},
          {"\<\"TableHeadings\"\>"},
          {"\<\"TableSpacing\"\>"},
          {"\<\"TabSpacings\"\>"},
          {"\<\"TagBox\"\>"},
          {"\<\"TagBoxOptions\"\>"},
          {"\<\"TaggingRules\"\>"},
          {"\<\"TagSet\"\>"},
          {"\<\"TagSetDelayed\"\>"},
          {"\<\"TagStyle\"\>"},
          {"\<\"TagUnset\"\>"},
          {"\<\"Take\"\>"},
          {"\<\"Tan\"\>"},
          {"\<\"Tanh\"\>"},
          {"\<\"TargetFunctions\"\>"},
          {"\<\"Temporary\"\>"},
          {"\<\"TemporaryVariable\"\>"},
          {"\<\"TensorQ\"\>"},
          {"\<\"TensorRank\"\>"},
          {"\<\"TeXForm\"\>"},
          {"\<\"TeXSave\"\>"},
          {"\<\"Text\"\>"},
          {"\<\"TextAlignment\"\>"},
          {"\<\"TextBoundingBox\"\>"},
          {"\<\"TextData\"\>"},
          {"\<\"textField1\"\>"},
          {"\<\"textField2\"\>"},
          {"\<\"textField3\"\>"},
          {"\<\"textField4\"\>"},
          {"\<\"textField5\"\>"},
          {"\<\"TextForm\"\>"},
          {"\<\"TextJustification\"\>"},
          {"\<\"TextLine\"\>"},
          {"\<\"TextPacket\"\>"},
          {"\<\"TextParagraph\"\>"},
          {"\<\"TextRendering\"\>"},
          {"\<\"TextStyle\"\>"},
          {"\<\"Thickness\"\>"},
          {"\<\"ThisLink\"\>"},
          {"\<\"Thread\"\>"},
          {"\<\"ThreeJSymbol\"\>"},
          {"\<\"Through\"\>"},
          {"\<\"Throw\"\>"},
          {"\<\"Ticks\"\>"},
          {"\<\"TimeConstrained\"\>"},
          {"\<\"TimeConstraint\"\>"},
          {"\<\"Times\"\>"},
          {"\<\"TimesBy\"\>"},
          {"\<\"TimeUsed\"\>"},
          {"\<\"TimeVariable\"\>"},
          {"\<\"TimeZone\"\>"},
          {"\<\"Timing\"\>"},
          {"\<\"TitleGrouping\"\>"},
          {"\<\"tNow\"\>"},
          {"\<\"ToBoxes\"\>"},
          {"\<\"ToCharacterCode\"\>"},
          {"\<\"ToColor\"\>"},
          {"\<\"ToDate\"\>"},
          {"\<\"ToExpression\"\>"},
          {"\<\"ToFileName\"\>"},
          {"\<\"Together\"\>"},
          {"\<\"Toggle\"\>"},
          {"\<\"ToggleFalse\"\>"},
          {"\<\"ToHeldExpression\"\>"},
          {"\<\"TokenWords\"\>"},
          {"\<\"Tolerance\"\>"},
          {"\<\"ToLowerCase\"\>"},
          {"\<\"TooBig\"\>"},
          {"\<\"Top\"\>"},
          {"\<\"ToRadicals\"\>"},
          {"\<\"ToRules\"\>"},
          {"\<\"ToString\"\>"},
          {"\<\"Total\"\>"},
          {"\<\"TotalHeight\"\>"},
          {"\<\"TotalWidth\"\>"},
          {"\<\"ToUpperCase\"\>"},
          {"\<\"Tr\"\>"},
          {"\<\"Trace\"\>"},
          {"\<\"TraceAbove\"\>"},
          {"\<\"TraceAction\"\>"},
          {"\<\"TraceBackward\"\>"},
          {"\<\"TraceDepth\"\>"},
          {"\<\"TraceDialog\"\>"},
          {"\<\"TraceForward\"\>"},
          {"\<\"TraceInternal\"\>"},
          {"\<\"TraceLevel\"\>"},
          {"\<\"TraceOff\"\>"},
          {"\<\"TraceOn\"\>"},
          {"\<\"TraceOriginal\"\>"},
          {"\<\"TracePrint\"\>"},
          {"\<\"TraceScan\"\>"},
          {"\<\"TraditionalForm\"\>"},
          {"\<\"TraditionalFunctionNotation\"\>"},
          {"\<\"TraditionalNotation\"\>"},
          {"\<\"TraditionalOrder\"\>"},
          {"\<\"TransformationFunctions\"\>"},
          {"\<\"TransparentColor\"\>"},
          {"\<\"Transpose\"\>"},
          {"\<\"Trapezoidal\"\>"},
          {"\<\"TreeForm\"\>"},
          {"\<\"Trig\"\>"},
          {"\<\"TrigExpand\"\>"},
          {"\<\"TrigFactor\"\>"},
          {"\<\"TrigFactorList\"\>"},
          {"\<\"TrigReduce\"\>"},
          {"\<\"TrigToExp\"\>"},
          {"\<\"True\"\>"},
          {"\<\"TrueQ\"\>"},
          {"\<\"Tuples\"\>"},
          {"\<\"type\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
addSimEventListener\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
clearMediaProducers\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
clearPropertyListeners\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireBooleanPropertyEvent\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireNumericPropertyEvent\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireObjectPropertyEvent\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`fireSimEvent\"\>\
"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireStringPropertyEvent\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`generateNewSeed\
\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`getController\"\
\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
getMediaProducers\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
getModelManipulator\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
getParameterDescriptors\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
getPropertiesValues\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`getRngSeed\"\>"}\
,
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`getTickCount\"\>\
"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`pause\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
registerDisplaySurface\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
registerMediaProducer\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`\
removeSimEventListener\"\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`setController\"\
\>"},
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`setRngSeed\"\>"}\
,
          {"\<\"uchicago`src`sim`engine`SimModelImpl`JPrivate`stop\"\>"},
          {"\<\"UnAlias\"\>"},
          {"\<\"Underflow\"\>"},
          {"\<\"Underoverscript\"\>"},
          {"\<\"UnderoverscriptBox\"\>"},
          {"\<\"UnderoverscriptBoxOptions\"\>"},
          {"\<\"Underscript\"\>"},
          {"\<\"UnderscriptBox\"\>"},
          {"\<\"UnderscriptBoxOptions\"\>"},
          {"\<\"UndocumentedTestFEParserPacket\"\>"},
          {"\<\"UndocumentedTestGetSelectionPacket\"\>"},
          {"\<\"Unequal\"\>"},
          {"\<\"Unevaluated\"\>"},
          {"\<\"Uninstall\"\>"},
          {"\<\"UninstallJava\"\>"},
          {"\<\"Union\"\>"},
          {"\<\"Unique\"\>"},
          {"\<\"UnitStep\"\>"},
          {"\<\"Unprotect\"\>"},
          {"\<\"UnsameQ\"\>"},
          {"\<\"Unset\"\>"},
          {"\<\"UnshareFrontEnd\"\>"},
          {"\<\"UnshareKernel\"\>"},
          {"\<\"Up\"\>"},
          {"\<\"Update\"\>"},
          {"\<\"UpperCaseQ\"\>"},
          {"\<\"UpSet\"\>"},
          {"\<\"UpSetDelayed\"\>"},
          {"\<\"UpValues\"\>"},
          {"\<\"URL\"\>"},
          {"\<\"UseFrontEnd\"\>"},
          {"\<\"UseTypeChecking\"\>"},
          {"\<\"Using\"\>"},
          {"\<\"V2Get\"\>"},
          {"\<\"Val\"\>"},
          {"\<\"Value\"\>"},
          {"\<\"ValueBox\"\>"},
          {"\<\"ValueBoxOptions\"\>"},
          {"\<\"ValueForm\"\>"},
          {"\<\"ValueQ\"\>"},
          {"\<\"Variables\"\>"},
          {"\<\"Variance\"\>"},
          {"\<\"VectorQ\"\>"},
          {"\<\"Verbatim\"\>"},
          {"\<\"Verbose\"\>"},
          {"\<\"VerboseConvertToPostScriptPacket\"\>"},
          {"\<\"VerifyConvergence\"\>"},
          {"\<\"VerifySolutions\"\>"},
          {"\<\"Version\"\>"},
          {"\<\"VersionNumber\"\>"},
          {"\<\"Vertical\"\>"},
          {"\<\"VerticalForm\"\>"},
          {"\<\"ViewCenter\"\>"},
          {"\<\"ViewPoint\"\>"},
          {"\<\"ViewPointSelectorSettings\"\>"},
          {"\<\"ViewVertical\"\>"},
          {"\<\"Visible\"\>"},
          {"\<\"VisibleCell\"\>"},
          {"\<\"vx\"\>"},
          {"\<\"vx$\"\>"},
          {"\<\"vy\"\>"},
          {"\<\"vy$\"\>"},
          {"\<\"WeierstrassHalfPeriods\"\>"},
          {"\<\"WeierstrassInvariants\"\>"},
          {"\<\"WeierstrassP\"\>"},
          {"\<\"WeierstrassPPrime\"\>"},
          {"\<\"WeierstrassSigma\"\>"},
          {"\<\"WeierstrassZeta\"\>"},
          {"\<\"Which\"\>"},
          {"\<\"While\"\>"},
          {"\<\"White\"\>"},
          {"\<\"Whitespace\"\>"},
          {"\<\"WhitespaceCharacter\"\>"},
          {"\<\"Win32OffScreenImage`getAccelerationThreshold\"\>"},
          {"\<\"Win32OffScreenImage`SCALEUAREAUAVERAGING\"\>"},
          {"\<\"Win32OffScreenImage`SCALEUDEFAULT\"\>"},
          {"\<\"Win32OffScreenImage`SCALEUFAST\"\>"},
          {"\<\"Win32OffScreenImage`SCALEUREPLICATE\"\>"},
          {"\<\"Win32OffScreenImage`SCALEUSMOOTH\"\>"},
          {"\<\"Win32OffScreenImage`TYPEU3BYTEUBGR\"\>"},
          {"\<\"Win32OffScreenImage`TYPEU4BYTEUABGR\"\>"},
          {"\<\"Win32OffScreenImage`TYPEU4BYTEUABGRUPRE\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUBYTEUBINARY\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUBYTEUGRAY\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUBYTEUINDEXED\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUCUSTOM\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUINTUARGB\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUINTUARGBUPRE\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUINTUBGR\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUINTURGB\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUUSHORTU555URGB\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUUSHORTU565URGB\"\>"},
          {"\<\"Win32OffScreenImage`TYPEUUSHORTUGRAY\"\>"},
          {"\<\"Win32OffScreenImage`UndefinedProperty\"\>"},
          {"\<\"Window`ABORT\"\>"},
          {"\<\"Window`ALLBITS\"\>"},
          {"\<\"Window`BOTTOMUALIGNMENT\"\>"},
          {"\<\"Window`CENTERUALIGNMENT\"\>"},
          {"\<\"WindowClickSelect\"\>"},
          {"\<\"WindowElements\"\>"},
          {"\<\"Window`ERROR\"\>"},
          {"\<\"WindowFloating\"\>"},
          {"\<\"WindowFrame\"\>"},
          {"\<\"Window`FRAMEBITS\"\>"},
          {"\<\"WindowFrameElements\"\>"},
          {"\<\"Window`HEIGHT\"\>"},
          {"\<\"Window`LEFTUALIGNMENT\"\>"},
          {"\<\"WindowMargins\"\>"},
          {"\<\"WindowMovable\"\>"},
          {"\<\"Window`PROPERTIES\"\>"},
          {"\<\"Window`RIGHTUALIGNMENT\"\>"},
          {"\<\"WindowSize\"\>"},
          {"\<\"Window`SOMEBITS\"\>"},
          {"\<\"WindowTitle\"\>"},
          {"\<\"WindowToolbars\"\>"},
          {"\<\"Window`TOPUALIGNMENT\"\>"},
          {"\<\"Window`WIDTH\"\>"},
          {"\<\"WindowWidth\"\>"},
          {"\<\"With\"\>"},
          {"\<\"Word\"\>"},
          {"\<\"WordBoundary\"\>"},
          {"\<\"WordCharacter\"\>"},
          {"\<\"WordSearch\"\>"},
          {"\<\"WordSeparators\"\>"},
          {"\<\"WorkingPrecision\"\>"},
          {"\<\"Write\"\>"},
          {"\<\"WriteString\"\>"},
          {"\<\"WynnDegree\"\>"},
          {"\<\"x\"\>"},
          {"\<\"x0\"\>"},
          {"\<\"x0$\"\>"},
          {"\<\"xM\"\>"},
          {"\<\"XMLElement\"\>"},
          {"\<\"XML`FromSymbolicXML\"\>"},
          {"\<\"XML`MathML`BoxesToMathML\"\>"},
          {"\<\"XML`MathML`BoxesToSymbolicMathML\"\>"},
          {"\<\"XML`MathML`ExpressionToMathML\"\>"},
          {"\<\"XML`MathML`ExpressionToSymbolicMathML\"\>"},
          {"\<\"XML`MathML`MathMLToBoxes\"\>"},
          {"\<\"XML`MathML`MathMLToExpression\"\>"},
          {"\<\"XML`MathML`SymbolicMathMLToBoxes\"\>"},
          {"\<\"XML`MathML`SymbolicMathMLToExpression\"\>"},
          {"\<\"XML`MathML`Symbols`Cardinality\"\>"},
          {"\<\"XML`MathML`Symbols`CartesianProduct\"\>"},
          {"\<\"XML`MathML`Symbols`Codomain\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedIntegrate\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedLimit\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedList\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedMax\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedMin\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedProduct\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedSet\"\>"},
          {"\<\"XML`MathML`Symbols`ConditionedSum\"\>"},
          {"\<\"XML`MathML`Symbols`CovariantDerivativeIndex\"\>"},
          {"\<\"XML`MathML`Symbols`Declare\"\>"},
          {"\<\"XML`MathML`Symbols`DerivativeIndex\"\>"},
          {"\<\"XML`MathML`Symbols`Divides\"\>"},
          {"\<\"XML`MathML`Symbols`Domain\"\>"},
          {"\<\"XML`MathML`Symbols`DomainIntegrate\"\>"},
          {"\<\"XML`MathML`Symbols`DomainOfApplication\"\>"},
          {"\<\"XML`MathML`Symbols`DomainProduct\"\>"},
          {"\<\"XML`MathML`Symbols`DomainSum\"\>"},
          {"\<\"XML`MathML`Symbols`Image\"\>"},
          {"\<\"XML`MathML`Symbols`IndefiniteProduct\"\>"},
          {"\<\"XML`MathML`Symbols`IndefiniteSum\"\>"},
          {"\<\"XML`MathML`Symbols`IntervalClosed\"\>"},
          {"\<\"XML`MathML`Symbols`IntervalClosedOpen\"\>"},
          {"\<\"XML`MathML`Symbols`IntervalOpen\"\>"},
          {"\<\"XML`MathML`Symbols`IntervalOpenClosed\"\>"},
          {"\<\"XML`MathML`Symbols`Moment\"\>"},
          {"\<\"XML`MathML`Symbols`MomentAbout\"\>"},
          {"\<\"XML`MathML`Symbols`Multiscripts\"\>"},
          {"\<\"XML`NotebookML`ExpressionToSymbolicExpressionML\"\>"},
          {"\<\"XML`NotebookML`NotebookToSymbolicNotebookML\"\>"},
          {"\<\"XML`NotebookML`SymbolicExpressionMLToExpression\"\>"},
          {"\<\"XML`NotebookML`SymbolicNotebookMLToNotebook\"\>"},
          {"\<\"XMLObject\"\>"},
          {"\<\"XML`Parser`InitializeXMLParser\"\>"},
          {"\<\"XML`Parser`ReleaseXMLParser\"\>"},
          {"\<\"XML`Parser`XMLGet\"\>"},
          {"\<\"XML`Parser`XMLGetString\"\>"},
          {"\<\"XML`Parser`XMLParser\"\>"},
          {"\<\"XML`RawXML\"\>"},
          {"\<\"XML`SVG`GraphicsToSVG\"\>"},
          {"\<\"XML`SVG`GraphicsToSymbolicSVG\"\>"},
          {"\<\"XML`SVG`SVGToGraphics\"\>"},
          {"\<\"XML`SVG`SymbolicSVGToGraphics\"\>"},
          {"\<\"XML`SymbolicXMLErrors\"\>"},
          {"\<\"XML`SymbolicXMLQ\"\>"},
          {"\<\"XML`ToCompactXML\"\>"},
          {"\<\"XML`ToSymbolicXML\"\>"},
          {"\<\"XML`ToVerboseXML\"\>"},
          {"\<\"Xor\"\>"},
          {"\<\"xPos\"\>"},
          {"\<\"xPos$\"\>"},
          {"\<\"xs0\"\>"},
          {"\<\"xs0$\"\>"},
          {"\<\"xSpeed\"\>"},
          {"\<\"xSpeed$\"\>"},
          {"\<\"x$\"\>"},
          {"\<\"y\"\>"},
          {"\<\"y0\"\>"},
          {"\<\"y0$\"\>"},
          {"\<\"Yellow\"\>"},
          {"\<\"yM\"\>"},
          {"\<\"yPos\"\>"},
          {"\<\"yPos$\"\>"},
          {"\<\"ys0\"\>"},
          {"\<\"ys0$\"\>"},
          {"\<\"ySpeed\"\>"},
          {"\<\"ySpeed$\"\>"},
          {"\<\"y$\"\>"},
          {"\<\"ZeroShape\"\>"},
          {"\<\"ZeroTest\"\>"},
          {"\<\"ZeroWidthTimes\"\>"},
          {"\<\"Zeta\"\>"},
          {"\<\"ZTransform\"\>"},
          {"\<\"$\"\>"},
          {"\<\"$Aborted\"\>"},
          {"\<\"$AddOnsDirectory\"\>"},
          {"\<\"$AnimationDisplayFunction\"\>"},
          {"\<\"$AnimationFunction\"\>"},
          {"\<\"$Assumptions\"\>"},
          {"\<\"$BaseDirectory\"\>"},
          {"\<\"$BatchInput\"\>"},
          {"\<\"$BatchOutput\"\>"},
          {"\<\"$BoxForms\"\>"},
          {"\<\"$ByteOrdering\"\>"},
          {"\<\"$CharacterEncoding\"\>"},
          {"\<\"$CommandLine\"\>"},
          {"\<\"$ConditionHold\"\>"},
          {"\<\"$Context\"\>"},
          {"\<\"$ContextPath\"\>"},
          {"\<\"$CreationDate\"\>"},
          {"\<\"$CurrentLink\"\>"},
          {"\<\"$DefaultFont\"\>"},
          {"\<\"$DefaultImageFormat\"\>"},
          {"\<\"$DefaultPath\"\>"},
          {"\<\"$Display\"\>"},
          {"\<\"$DisplayFunction\"\>"},
          {"\<\"$DumpDates\"\>"},
          {"\<\"$DumpSupported\"\>"},
          {"\<\"$Echo\"\>"},
          {"\<\"$Epilog\"\>"},
          {"\<\"$ExportEncodings\"\>"},
          {"\<\"$ExportFormats\"\>"},
          {"\<\"$ExtraClassPath\"\>"},
          {"\<\"$Failed\"\>"},
          {"\<\"$FormatType\"\>"},
          {"\<\"$FrontEnd\"\>"},
          {"\<\"$FrontEndInitializationFunction\"\>"},
          {"\<\"$FrontEndLaunchCommand\"\>"},
          {"\<\"$HistoryLength\"\>"},
          {"\<\"$HomeDirectory\"\>"},
          {"\<\"$IgnoreEOF\"\>"},
          {"\<\"$ImportEncodings\"\>"},
          {"\<\"$ImportFormats\"\>"},
          {"\<\"$InitialDirectory\"\>"},
          {"\<\"$Input\"\>"},
          {"\<\"$Inspector\"\>"},
          {"\<\"$InstallationDate\"\>"},
          {"\<\"$InstallationDirectory\"\>"},
          {"\<\"$InterfaceEnvironment\"\>"},
          {"\<\"$IterationLimit\"\>"},
          {"\<\"$JavaExceptionHandler\"\>"},
          {"\<\"$Language\"\>"},
          {"\<\"$LaunchDirectory\"\>"},
          {"\<\"$LicenseExpirationDate\"\>"},
          {"\<\"$LicenseID\"\>"},
          {"\<\"$LicenseProcesses\"\>"},
          {"\<\"$LicenseServer\"\>"},
          {"\<\"$Line\"\>"},
          {"\<\"$Linked\"\>"},
          {"\<\"$LinkSupported\"\>"},
          {"\<\"$MachineDomain\"\>"},
          {"\<\"$MachineEpsilon\"\>"},
          {"\<\"$MachineID\"\>"},
          {"\<\"$MachineName\"\>"},
          {"\<\"$MachinePrecision\"\>"},
          {"\<\"$MachineType\"\>"},
          {"\<\"$MaxExtraPrecision\"\>"},
          {"\<\"$MaxLicenseProcesses\"\>"},
          {"\<\"$MaxMachineNumber\"\>"},
          {"\<\"$MaxNumber\"\>"},
          {"\<\"$MaxPiecewiseCases\"\>"},
          {"\<\"$MaxPrecision\"\>"},
          {"\<\"$MaxRootDegree\"\>"},
          {"\<\"$MessageList\"\>"},
          {"\<\"$MessagePrePrint\"\>"},
          {"\<\"$Messages\"\>"},
          {"\<\"$MinMachineNumber\"\>"},
          {"\<\"$MinNumber\"\>"},
          {"\<\"$MinPrecision\"\>"},
          {"\<\"$ModuleNumber\"\>"},
          {"\<\"$NetworkLicense\"\>"},
          {"\<\"$NewMessage\"\>"},
          {"\<\"$NewSymbol\"\>"},
          {"\<\"$Notebooks\"\>"},
          {"\<\"$NumberMarks\"\>"},
          {"\<\"$Off\"\>"},
          {"\<\"$OperatingSystem\"\>"},
          {"\<\"$Output\"\>"},
          {"\<\"$OutputForms\"\>"},
          {"\<\"$Packages\"\>"},
          {"\<\"$ParentLink\"\>"},
          {"\<\"$ParentProcessID\"\>"},
          {"\<\"$PasswordFile\"\>"},
          {"\<\"$Path\"\>"},
          {"\<\"$PathnameSeparator\"\>"},
          {"\<\"$PipeSupported\"\>"},
          {"\<\"$Post\"\>"},
          {"\<\"$Pre\"\>"},
          {"\<\"$PreferencesDirectory\"\>"},
          {"\<\"$PrePrint\"\>"},
          {"\<\"$PreRead\"\>"},
          {"\<\"$PrintForms\"\>"},
          {"\<\"$PrintLiteral\"\>"},
          {"\<\"$ProcessID\"\>"},
          {"\<\"$ProcessorType\"\>"},
          {"\<\"$ProductInformation\"\>"},
          {"\<\"$ProgramName\"\>"},
          {"\<\"$PSDirectDisplay\"\>"},
          {"\<\"$RandomState\"\>"},
          {"\<\"$RasterFunction\"\>"},
          {"\<\"$RecursionLimit\"\>"},
          {"\<\"$RelaxedTypeChecking\"\>"},
          {"\<\"$ReleaseNumber\"\>"},
          {"\<\"$RootDirectory\"\>"},
          {"\<\"$SessionID\"\>"},
          {"\<\"$SetParentLink\"\>"},
          {"\<\"$SoundDisplay\"\>"},
          {"\<\"$SoundDisplayFunction\"\>"},
          {"\<\"$SuppressInputFormHeads\"\>"},
          {"\<\"$SyntaxHandler\"\>"},
          {"\<\"$System\"\>"},
          {"\<\"$SystemCharacterEncoding\"\>"},
          {"\<\"$SystemID\"\>"},
          {"\<\"$TemporaryPrefix\"\>"},
          {"\<\"$TextStyle\"\>"},
          {"\<\"$ThisPeriodical\"\>"},
          {"\<\"$TimeUnit\"\>"},
          {"\<\"$TopDirectory\"\>"},
          {"\<\"$TraceOff\"\>"},
          {"\<\"$TraceOn\"\>"},
          {"\<\"$TracePattern\"\>"},
          {"\<\"$TracePostAction\"\>"},
          {"\<\"$TracePreAction\"\>"},
          {"\<\"$Urgent\"\>"},
          {"\<\"$UserAddOnsDirectory\"\>"},
          {"\<\"$UserBaseDirectory\"\>"},
          {"\<\"$UserName\"\>"},
          {"\<\"$Version\"\>"},
          {"\<\"$VersionNumber\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"a", "Abort", "AbortProtect", "Above", "Abs", "Absolute", 
        "AbsoluteDashing", "AbsoluteOptions", "AbsolutePointSize", 
        "AbsoluteThickness", "AbsoluteTime", "AbsoluteTiming", 
        "AcceleratedOffScreenImage`getAccelerationThreshold", 
        "AcceleratedOffScreenImage`SCALEUAREAUAVERAGING", 
        "AcceleratedOffScreenImage`SCALEUDEFAULT", 
        "AcceleratedOffScreenImage`SCALEUFAST", 
        "AcceleratedOffScreenImage`SCALEUREPLICATE", 
        "AcceleratedOffScreenImage`SCALEUSMOOTH", 
        "AcceleratedOffScreenImage`TYPEU3BYTEUBGR", 
        "AcceleratedOffScreenImage`TYPEU4BYTEUABGR", 
        "AcceleratedOffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "AcceleratedOffScreenImage`TYPEUBYTEUBINARY", 
        "AcceleratedOffScreenImage`TYPEUBYTEUGRAY", 
        "AcceleratedOffScreenImage`TYPEUBYTEUINDEXED", 
        "AcceleratedOffScreenImage`TYPEUCUSTOM", 
        "AcceleratedOffScreenImage`TYPEUINTUARGB", 
        "AcceleratedOffScreenImage`TYPEUINTUARGBUPRE", 
        "AcceleratedOffScreenImage`TYPEUINTUBGR", 
        "AcceleratedOffScreenImage`TYPEUINTURGB", 
        "AcceleratedOffScreenImage`TYPEUUSHORTU555URGB", 
        "AcceleratedOffScreenImage`TYPEUUSHORTU565URGB", 
        "AcceleratedOffScreenImage`TYPEUUSHORTUGRAY", 
        "AcceleratedOffScreenImage`UndefinedProperty", "AccountingForm", 
        "Accuracy", "AccuracyGoal", "Active", "ActiveItem", "add", 
        "addAdjustmentListener", "addMouseListener", "AddOnHelpPath", 
        "AddPeriodical", "AddTo", "AddToClassPath", "AdjustmentBox", 
        "AdjustmentBoxOptions", "After", "agent", "agentRules", "agents", 
        "agentsL", "agentsL1", "agentsL1$", "AiryAi", "AiryAiPrime", "AiryBi",
         "AiryBiPrime", "Algebra`FactorSquareFreeModList", "Algebra`Horner", 
        "AlgebraicRules", "AlgebraicRulesData", "Algebraics", 
        "Algebraics`Private`AlgebraicsCode", 
        "Algebraics`Private`ANProperties", 
        "Algebraics`Private`NFDiscriminant", 
        "Algebraics`Private`NFFundamentalUnits", 
        "Algebraics`Private`NFIntegralBasis", "Algebraics`Private`NFNormReps",
         "Algebraics`Private`NFRegulator", 
        "Algebraics`Private`NFRootsOfUnity", 
        "Algebraics`Private`NFToCommonField", 
        "Algebraics`Private`ToNFElement", "Algebra`MatrixPowerMod", 
        "Algebra`PartialSquareFreeDecompositionModList", 
        "Algebra`PolynomialDerivativeModList", 
        "Algebra`PolynomialDivisionModList", 
        "Algebra`PolynomialExtendedGCDModList", 
        "Algebra`PolynomialFactorModList", "Algebra`PolynomialGCDModList", 
        "Algebra`PolynomialMakeMonicModList", 
        "Algebra`PolynomialMinusModList", "Algebra`PolynomialPlusModList", 
        "Algebra`PolynomialPowerMod", "Algebra`PolynomialPowerModList", 
        "Algebra`PolynomialPthRootModList", 
        "Algebra`PolynomialQuotientModList", 
        "Algebra`PolynomialRemainderModList", 
        "Algebra`PolynomialSubtractModList", "Algebra`PolynomialTimesModList",
         "Algebra`ReduciblePolynomialModListQ", 
        "Algebra`SquareFreeDecompositionModList", "Algebra`SquareFreeModQ", 
        "Algebra`SquareFreePartModList", 
        "Algebra`SymmetricPolynomials`SymmetricPolynomial", 
        "Algebra`SymmetricPolynomials`SymmetricReduction", "Alias", 
        "AlignmentMarker", "All", "AllowInlineCells", "AllowRaggedArrays", 
        "AllowScriptLevelChange", "AllowShortContext", "Alternatives", 
        "AmbientLight", "Analytic", "AnchoredSearch", "And", 
        "AnimationCycleOffset", "AnimationCycleRepetitions", 
        "AnimationDirection", "AnimationDisplayTime", 
        "anl`jlink`MathematicaModel`create", 
        "anl`jlink`MathematicaModel`JPrivate`addDisplay", 
        "anl`jlink`MathematicaModel`JPrivate`begin", 
        "anl`jlink`MathematicaModel`JPrivate`create", 
        "anl`jlink`MathematicaModel`JPrivate`getInitParam", 
        "anl`jlink`MathematicaModel`JPrivate`getName", 
        "anl`jlink`MathematicaModel`JPrivate`getSchedule", 
        "anl`jlink`MathematicaModel`JPrivate`scheduleMethodAt", 
        "anl`jlink`MathematicaModel`JPrivate`scheduleMethodAtInterval", 
        "anl`jlink`MathematicaModel`JPrivate`scheduleMethodBeginning", 
        "anl`jlink`MathematicaModel`JPrivate`setup", 
        "anl`jlink`MathematicaModel`JPrivate`start", "Apart", 
        "ApartSquareFree", "AppellF1", "Append", "AppendTo", "AppletViewer", 
        "Apply", "ArcCos", "ArcCosh", "ArcCot", "ArcCoth", "ArcCsc", 
        "ArcCsch", "ArcSec", "ArcSech", "ArcSin", "ArcSinh", "ArcTan", 
        "ArcTanh", "Arg", "ArgumentCountQ", "ArithmeticGeometricMean", 
        "Array", "arraycopy", "ArrayDepth", "ArrayPlot", "ArrayQ", 
        "ArrayRules", "Arrow", "aSelected", "aSelected0", "aSelected$", 
        "AspectRatio", "AspectRatioFixed", "Assuming", "Assumptions", 
        "Assumptions`AAlgebraicQ", "Assumptions`AAssumedIneqQ", 
        "Assumptions`AAssumedQ", "Assumptions`ABooleanQ", 
        "Assumptions`AComplexQ", "Assumptions`AEvenQ", 
        "Assumptions`AImpossibleIneqQ", "Assumptions`AInfSup", 
        "Assumptions`AIntegerQ", "Assumptions`AllAssumptions", 
        "Assumptions`AMathIneqs", "Assumptions`AMod", "Assumptions`ANegative",
         "Assumptions`ANonNegative", "Assumptions`ANonPositive", 
        "Assumptions`AOddQ", "Assumptions`APositive", "Assumptions`APrimeQ", 
        "Assumptions`ARationalQ", "Assumptions`ARealQ", "Assumptions`ASign", 
        "Assumptions`AssumedFalse", "Assumptions`AUnequalQ", 
        "Assumptions`AWeakSign", "AssumptionsDump`e", "AssumptionsDump`f", 
        "AssumptionsDump`ineqs", "AssumptionsDump`m", "AssumptionsDump`vals", 
        "AssumptionsDump`var", "AssumptionsDump`vars", "AtomQ", "Attributes", 
        "AutoDelete", "AutoEvaluateEvents", "AutoGeneratedPackage", 
        "AutoIndent", "AutoIndentSpacings", "AutoItalicWords", "AutoloadPath",
         "Automatic", "AutoOpenNotebooks", "AutoOpenPalettes", "AutoScroll", 
        "AutoSpacing", "AutoStyleOptions", "AWTEvent`ACTIONUEVENTUMASK", 
        "AWTEvent`ADJUSTMENTUEVENTUMASK", "AWTEvent`COMPONENTUEVENTUMASK", 
        "AWTEvent`CONTAINERUEVENTUMASK", "AWTEvent`FOCUSUEVENTUMASK", 
        "AWTEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "AWTEvent`HIERARCHYUEVENTUMASK", "AWTEvent`INPUTUMETHODUEVENTUMASK", 
        "AWTEvent`INVOCATIONUEVENTUMASK", "AWTEvent`ITEMUEVENTUMASK", 
        "AWTEvent`KEYUEVENTUMASK", "AWTEvent`MOUSEUEVENTUMASK", 
        "AWTEvent`MOUSEUMOTIONUEVENTUMASK", "AWTEvent`MOUSEUWHEELUEVENTUMASK",
         "AWTEvent`PAINTUEVENTUMASK", "AWTEvent`RESERVEDUIDUMAX", 
        "AWTEvent`TEXTUEVENTUMASK", "AWTEvent`WINDOWUEVENTUMASK", 
        "AWTEvent`WINDOWUFOCUSUEVENTUMASK", 
        "AWTEvent`WINDOWUSTATEUEVENTUMASK", "Axes", "AxesEdge", "AxesLabel", 
        "AxesOrigin", "AxesStyle", "Axis", "a$", "Background", 
        "BackgroundTasksSettings", "Backsubstitution", "Backward", "BaseForm",
         "Baseline", "Before", "Begin", "BeginDialogPacket", 
        "BeginFrontEndInteractionPacket", "BeginJavaBlock", "BeginPackage", 
        "Below", "BernoulliB", "BesselI", "BesselJ", "BesselK", "BesselY", 
        "Beta", "BetaRegularized", "BezoutMatrix", "BinaryFormat", 
        "BinaryGet", "BinaryRead", "BinaryReadList", "BinaryWrite", 
        "Binomial", "BitAnd", "BitNot", "BitOr", "BitXor", "Black", "Blank", 
        "BlankForm", "BlankNullSequence", "BlankSequence", "Block", "Blue", 
        "Boole", "Booleans", "BorderLayout`AFTERULASTULINE", 
        "BorderLayout`AFTERULINEUENDS", "BorderLayout`BEFOREUFIRSTULINE", 
        "BorderLayout`BEFOREULINEUBEGINS", "BorderLayout`CENTER", 
        "BorderLayout`EAST", "BorderLayout`LINEUEND", 
        "BorderLayout`LINEUSTART", "BorderLayout`NORTH", 
        "BorderLayout`PAGEUEND", "BorderLayout`PAGEUSTART", 
        "BorderLayout`SOUTH", "BorderLayout`WEST", "Bottom", "Bounds", "Box", 
        "BoxBaselineShift", "BoxData", "BoxDimensions", "Boxed", "BoxForm`a", 
        "BoxForm`AddCommas", "BoxForm`AddOptions", 
        "BoxForm`AddTraditionalFunction", "BoxForm`apat", "BoxForm`apat$", 
        "BoxForm`arg", "BoxForm`args", "BoxForm`args$", "BoxForm`arguments", 
        "BoxForm`arguments$", "BoxForm`arg$", "BoxForm`AssembleFunctionCall", 
        "BoxForm`a$", "BoxForm`b", "BoxForm`base", "BoxForm`base$", 
        "BoxForm`binary", "BoxForm`binary$", "BoxForm`BoxArgument", 
        "BoxForm`boxexpr", "BoxForm`boxexpr$", "BoxForm`BoxFormAutoLoad", 
        "BoxForm`BoxFormAutoLoadOld", "BoxForm`b$", "BoxForm`Comma", 
        "BoxForm`CommaPat", "BoxForm`CommaSeparated", "BoxForm`CommaSepArgsQ",
         "BoxForm`cont", "BoxForm`ConvertForm", "BoxForm`CountCommaArgs", 
        "BoxForm`default", "BoxForm`defaultVal", "BoxForm`denom", 
        "BoxForm`derivOperator", "BoxForm`derivOperator$", "BoxForm`e", 
        "BoxForm`elems", "BoxForm`elems$", "BoxForm`else", "BoxForm`else$", 
        "BoxForm`entry", "BoxForm`entry$", "BoxForm`expr", "BoxForm`exprs", 
        "BoxForm`ext", "BoxForm`ExtractArgsSansCommas", "BoxForm`e$", 
        "BoxForm`f", "BoxForm`feLink", "BoxForm`file", "BoxForm`filename", 
        "BoxForm`filename$", "BoxForm`fmt", "BoxForm`fn", 
        "BoxFormFormatTypes", "BoxForm`fpat", "BoxForm`fpat$", 
        "BoxForm`FromTrad", "BoxForm`FrontEndObject", "BoxForm`fTypeset", 
        "BoxForm`fTypeset$", "BoxForm`FuncIntBox", "BoxForm`f$", 
        "BoxForm`GetCommaSepArgs", "BoxForm`GetOtherSepArgs", "BoxForm`grid", 
        "BoxForm`grid$", "BoxForm`h", "BoxForm`head", "BoxForm`head$", 
        "BoxForm`heldDir", "BoxForm`heldDir$", "BoxForm`HeldIntegerQ", 
        "BoxForm`HeldNonOptionQ", "BoxForm`HeldNumberQ", 
        "BoxForm`HeldOptionQ", "BoxForm`HeldRealNumberQ", 
        "BoxForm`HeldSymbolQ", "BoxForm`h$", "BoxForm`id", 
        "BoxForm`insertCommas", "BoxForm`insertCommas$", 
        "BoxForm`Intercalate", "BoxForm`interp", "BoxForm`iter", 
        "BoxForm`leftAbove", "BoxForm`leftBelow", "BoxForm`list", 
        "BoxForm`list$", "BoxForm`loading", "BoxForm`ls", "BoxForm`ls$", 
        "BoxForm`MakeCommaSepArgs", "BoxForm`makeinfixform", 
        "BoxForm`MakeInfixForm", "BoxForm`MakeInterpretationBox", 
        "BoxForm`MakeTraditionalBoxes", "BoxForm`MakeTraditionalExpression", 
        "BoxForm`many", "BoxForm`matrix", "BoxForm`multiple", 
        "BoxForm`multiple$", "BoxForm`Multiscript", "BoxForm`n", 
        "BoxForm`name", "BoxForm`nbName", "BoxForm`nbObj", "BoxForm`newsyms", 
        "BoxForm`newsyms$", "BoxForm`numer", "BoxForm`n$", "BoxForm`object", 
        "BoxForm`old", "BoxForm`OperatorList", "BoxForm`OperatorName", 
        "BoxForm`opts", "BoxForm`orders", "BoxForm`ordersTypeset", 
        "BoxForm`ordersTypeset$", "BoxForm`other", "BoxForm`other$", 
        "BoxForm`patts", "BoxForm`pFile", "BoxForm`pFile$", 
        "BoxForm`PiecewiseDefault", "BoxForm`PiecewiseMakeExpression", 
        "BoxForm`protected", "BoxForm`prots", "BoxForm`Quote", "BoxForm`r", 
        "BoxForm`ReplaceOperatorList", "BoxForm`RestoreValues", 
        "BoxForm`rightAbove", "BoxForm`rightBelow", "BoxForm`r$", "BoxForm`s",
         "BoxForm`SaveValues", "BoxForm`sep", "BoxForm`separator", 
        "BoxForm`SimulateMultiscriptBox", "BoxForm`singleton", 
        "BoxForm`singleton$", "BoxForm`SmartScriptBox", "BoxForm`sub", 
        "BoxForm`subopts", "BoxForm`subopts$", "BoxForm`subscript", 
        "BoxForm`subscript$", "BoxForm`sub$", "BoxForm`sup", "BoxForm`super", 
        "BoxForm`sup$", "BoxForm`syms", "BoxForm`s$", "BoxForm`t", 
        "BoxForm`TagBoxConstant", "BoxForm`test", "BoxForm`TestSyms", 
        "BoxForm`test$", "BoxForm`TopLevelMakeExpression", "BoxForm`ToTrad", 
        "BoxForm`type", "BoxForm`typeset", "BoxForm`typesetDefault", 
        "BoxForm`typesetDefault$", "BoxForm`typesetEntries", 
        "BoxForm`typesetEntries$", "BoxForm`typesetForm", 
        "BoxForm`typesetForm$", "BoxForm`t$", "BoxForm`UltimateHead", 
        "BoxForm`val", "BoxForm`vals", "BoxForm`valsToConds", 
        "BoxForm`values", "BoxForm`values$", "BoxForm`val$", 
        "BoxForm`wasProt", "BoxForm`wasProtected", "BoxForm`wasProtected$", 
        "BoxForm`x", "BoxForm`x$", "BoxForm`z", "BoxForm`z$", "BoxFrame", 
        "BoxMargins", "BoxRatios", "BoxRegion", "BoxStyle", "Break", "Brown", 
        "BrowserCategoryLoad`BrowserCategory", 
        "BrowserCategoryLoad`Delimiter", "BrowserCategoryLoad`Item", 
        "BrowserCategoryLoad`None", "Buchberger", 
        "BufferedImage`SCALEUAREAUAVERAGING", "BufferedImage`SCALEUDEFAULT", 
        "BufferedImage`SCALEUFAST", "BufferedImage`SCALEUREPLICATE", 
        "BufferedImage`SCALEUSMOOTH", "BufferedImage`TYPEU3BYTEUBGR", 
        "BufferedImage`TYPEU4BYTEUABGR", "BufferedImage`TYPEU4BYTEUABGRUPRE", 
        "BufferedImage`TYPEUBYTEUBINARY", "BufferedImage`TYPEUBYTEUGRAY", 
        "BufferedImage`TYPEUBYTEUINDEXED", "BufferedImage`TYPEUCUSTOM", 
        "BufferedImage`TYPEUINTUARGB", "BufferedImage`TYPEUINTUARGBUPRE", 
        "BufferedImage`TYPEUINTUBGR", "BufferedImage`TYPEUINTURGB", 
        "BufferedImage`TYPEUUSHORTU555URGB", 
        "BufferedImage`TYPEUUSHORTU565URGB", "BufferedImage`TYPEUUSHORTUGRAY",
         "BufferedImage`UndefinedProperty", "Button", "ButtonBox", 
        "ButtonBoxOptions", "ButtonCell", "ButtonContents", "ButtonData", 
        "ButtonEvaluator", "ButtonExpandable", "ButtonFrame", 
        "ButtonFunction", "ButtonMargins", "ButtonMinHeight", "ButtonNote", 
        "ButtonNotebook", "ButtonSource", "ButtonStyle", 
        "ButtonStyleMenuListing", "ByRef", "Byte", "ByteCount", 
        "ByteOrdering", "C", "CallPacket", "Cancel", "CarmichaelLambda", 
        "Cases", "Catalan", "Catch", "Ceiling", "Cell", "CellAutoOverwrite", 
        "CellBaseline", "CellBoundingBox", "CellBracketOptions", 
        "CellContents", "CellDingbat", "CellEditDuplicate", 
        "CellElementsBoundingBox", "CellElementSpacings", 
        "CellEvaluationDuplicate", "CellFrame", "CellFrameColor", 
        "CellFrameLabelMargins", "CellFrameLabels", "CellFrameMargins", 
        "CellGroup", "CellGroupData", "CellGrouping", "CellGroupingRules", 
        "CellHorizontalScrolling", "CellLabel", "CellLabelAutoDelete", 
        "CellLabelMargins", "CellLabelPositioning", "CellMargins", 
        "CellObject", "CellOpen", "CellPasswords", "CellPrint", "CellSize", 
        "CellStyle", "CellTags", "CellularAutomaton", "Center", "CForm", 
        "Character", "CharacterEncoding", "CharacterEncodingsPath", 
        "CharacteristicPolynomial", "CharacterRange", "Characters", 
        "ChebyshevT", "ChebyshevU", "Check", "CheckAbort", "CheckAll", 
        "CholeskyDecomposition", "Chop", "Circle", "ClassName", "ClassPath", 
        "Clear", "ClearAll", "ClearAttributes", "ClebschGordan", "Clip", 
        "ClipboardNotebook", "ClipFill", "Close", "Closed", "CloseFrontEnd", 
        "ClosingAutoSave", "CMYKColor", "Coefficient", "CoefficientArrays", 
        "CoefficientDomain", "CoefficientList", "CofactorExpansion", 
        "Collect", "collision", "collision0", "ColonForm", "color", 
        "Color`BITMASK", "Color`black", "Color`BLACK", "Color`blue", 
        "Color`BLUE", "Color`cyan", "Color`CYAN", "Color`darkGray", 
        "Color`DARKUGRAY", "Color`decode", "ColorFunction", 
        "ColorFunctionScaling", "Color`getColor", "Color`getHSBColor", 
        "Color`gray", "Color`GRAY", "Color`green", "Color`GREEN", 
        "Color`HSBtoRGB", "Color`lightGray", "Color`LIGHTUGRAY", 
        "Color`magenta", "Color`MAGENTA", "Color`OPAQUE", "Color`orange", 
        "Color`ORANGE", "ColorOutput", "Color`pink", "Color`PINK", 
        "Color`red", "Color`RED", "Color`RGBtoHSB", "ColorRules", 
        "ColorSelectorSettings", "Color`TRANSLUCENT", "Color`white", 
        "Color`WHITE", "Color`yellow", "Color`YELLOW", "color$", "Column", 
        "ColumnAlignments", "ColumnForm", "ColumnLines", "ColumnsEqual", 
        "ColumnSpacings", "ColumnWidths", "CommandLine", 
        "CommonDefaultFormatTypes", "Compile", "Compile`AutoVar11", 
        "Compile`AutoVar21", "Compiled", "CompiledFunction", 
        "Compile`FunctionVariable", "CompileOptimizations", 
        "Compile`SetIterate", "Compile`Variable", "Complement", 
        "CompletionsListPacket", "Complex", "Complexes", "ComplexExpand", 
        "ComplexInfinity", "ComplexityFunction", "Component`ABORT", 
        "Component`ALLBITS", "Component`BOTTOMUALIGNMENT", 
        "Component`CENTERUALIGNMENT", "Component`ERROR", 
        "ComponentEvent`ACTIONUEVENTUMASK", 
        "ComponentEvent`ADJUSTMENTUEVENTUMASK", 
        "ComponentEvent`COMPONENTUEVENTUMASK", 
        "ComponentEvent`COMPONENTUFIRST", "ComponentEvent`COMPONENTUHIDDEN", 
        "ComponentEvent`COMPONENTULAST", "ComponentEvent`COMPONENTUMOVED", 
        "ComponentEvent`COMPONENTURESIZED", "ComponentEvent`COMPONENTUSHOWN", 
        "ComponentEvent`CONTAINERUEVENTUMASK", 
        "ComponentEvent`FOCUSUEVENTUMASK", 
        "ComponentEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "ComponentEvent`HIERARCHYUEVENTUMASK", 
        "ComponentEvent`INPUTUMETHODUEVENTUMASK", 
        "ComponentEvent`INVOCATIONUEVENTUMASK", 
        "ComponentEvent`ITEMUEVENTUMASK", "ComponentEvent`KEYUEVENTUMASK", 
        "ComponentEvent`MOUSEUEVENTUMASK", 
        "ComponentEvent`MOUSEUMOTIONUEVENTUMASK", 
        "ComponentEvent`MOUSEUWHEELUEVENTUMASK", 
        "ComponentEvent`PAINTUEVENTUMASK", "ComponentEvent`RESERVEDUIDUMAX", 
        "ComponentEvent`TEXTUEVENTUMASK", "ComponentEvent`WINDOWUEVENTUMASK", 
        "ComponentEvent`WINDOWUFOCUSUEVENTUMASK", 
        "ComponentEvent`WINDOWUSTATEUEVENTUMASK", "Component`FRAMEBITS", 
        "Component`HEIGHT", "Component`LEFTUALIGNMENT", 
        "Component`PROPERTIES", "Component`RIGHTUALIGNMENT", 
        "Component`SOMEBITS", "Component`TOPUALIGNMENT", "Component`WIDTH", 
        "Compose", "ComposeList", "ComposeSeries", "Composition", 
        "CompoundExpression", "computeClosest", "computeCollision", 
        "com`wolfram`jlink`MathFrame`ABORT", 
        "com`wolfram`jlink`MathFrame`ALLBITS", 
        "com`wolfram`jlink`MathFrame`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`MathFrame`DEFAULTUCURSOR", 
        "com`wolfram`jlink`MathFrame`ERROR", 
        "com`wolfram`jlink`MathFrame`EURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`FRAMEBITS", 
        "com`wolfram`jlink`MathFrame`getFrames", 
        "com`wolfram`jlink`MathFrame`HANDUCURSOR", 
        "com`wolfram`jlink`MathFrame`HEIGHT", 
        "com`wolfram`jlink`MathFrame`ICONIFIED", 
        "com`wolfram`jlink`MathFrame`JPrivate`ABORT", 
        "com`wolfram`jlink`MathFrame`JPrivate`ALLBITS", 
        "com`wolfram`jlink`MathFrame`JPrivate`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`JPrivate`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`JPrivate`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`DEFAULTUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`ERROR", 
        "com`wolfram`jlink`MathFrame`JPrivate`EURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`FRAMEBITS", 
        "com`wolfram`jlink`MathFrame`JPrivate`getFrames", 
        "com`wolfram`jlink`MathFrame`JPrivate`HANDUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`HEIGHT", 
        "com`wolfram`jlink`MathFrame`JPrivate`ICONIFIED", 
        "com`wolfram`jlink`MathFrame`JPrivate`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`MathFrame`JPrivate`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`MathFrame`JPrivate`MOVEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`NORMAL", 
        "com`wolfram`jlink`MathFrame`JPrivate`NURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`onClose", 
        "com`wolfram`jlink`MathFrame`JPrivate`PROPERTIES", 
        "com`wolfram`jlink`MathFrame`JPrivate`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`JPrivate`setLocation", 
        "com`wolfram`jlink`MathFrame`JPrivate`setModal", 
        "com`wolfram`jlink`MathFrame`JPrivate`setSize", 
        "com`wolfram`jlink`MathFrame`JPrivate`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`SOMEBITS", 
        "com`wolfram`jlink`MathFrame`JPrivate`SURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`TEXTUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`JPrivate`WAITUCURSOR", 
        "com`wolfram`jlink`MathFrame`JPrivate`WIDTH", 
        "com`wolfram`jlink`MathFrame`JPrivate`WURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`MathFrame`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`MathFrame`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`MathFrame`MOVEUCURSOR", 
        "com`wolfram`jlink`MathFrame`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`NORMAL", 
        "com`wolfram`jlink`MathFrame`NURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`PROPERTIES", 
        "com`wolfram`jlink`MathFrame`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`SOMEBITS", 
        "com`wolfram`jlink`MathFrame`SURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathFrame`TEXTUCURSOR", 
        "com`wolfram`jlink`MathFrame`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathFrame`WAITUCURSOR", 
        "com`wolfram`jlink`MathFrame`WIDTH", 
        "com`wolfram`jlink`MathFrame`WURESIZEUCURSOR", 
        "com`wolfram`jlink`MathGraphicsJPanel`ABORT", 
        "com`wolfram`jlink`MathGraphicsJPanel`ALLBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`ERROR", 
        "com`wolfram`jlink`MathGraphicsJPanel`FRAMEBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`getDefaultLocale", 
        "com`wolfram`jlink`MathGraphicsJPanel`GRAPHICS", 
        "com`wolfram`jlink`MathGraphicsJPanel`HEIGHT", 
        "com`wolfram`jlink`MathGraphicsJPanel`isLightweightComponent", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ABORT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`addMouseListener", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ALLBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`createImage", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`ERROR", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`FRAMEBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getDefaultLocale", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getImage", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getImageType", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getMathCommand", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`getUsesFE", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
getUsesTraditionalForm", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`GRAPHICS", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`HEIGHT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
isLightweightComponent", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`paintComponent", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`PROPERTIES", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`recompute", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`repaintNow", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setBounds", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setDefaultLocale", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setImage", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setImageType", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setLink", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setMathCommand", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`setUsesFE", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
setUsesTraditionalForm", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`SOMEBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`TOOLUTIPUTEXTUKEY", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`TYPESET", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`UNDEFINEDUCONDITION", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`WHENUFOCUSED", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`\
WHENUINUFOCUSEDUWINDOW", 
        "com`wolfram`jlink`MathGraphicsJPanel`JPrivate`WIDTH", 
        "com`wolfram`jlink`MathGraphicsJPanel`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`PROPERTIES", 
        "com`wolfram`jlink`MathGraphicsJPanel`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`setDefaultLocale", 
        "com`wolfram`jlink`MathGraphicsJPanel`SOMEBITS", 
        "com`wolfram`jlink`MathGraphicsJPanel`TOOLUTIPUTEXTUKEY", 
        "com`wolfram`jlink`MathGraphicsJPanel`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`TYPESET", 
        "com`wolfram`jlink`MathGraphicsJPanel`UNDEFINEDUCONDITION", 
        "com`wolfram`jlink`MathGraphicsJPanel`\
WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "com`wolfram`jlink`MathGraphicsJPanel`WHENUFOCUSED", 
        "com`wolfram`jlink`MathGraphicsJPanel`WHENUINUFOCUSEDUWINDOW", 
        "com`wolfram`jlink`MathGraphicsJPanel`WIDTH", 
        "com`wolfram`jlink`MathJFrame`ABORT", 
        "com`wolfram`jlink`MathJFrame`ALLBITS", 
        "com`wolfram`jlink`MathJFrame`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`MathJFrame`DEFAULTUCURSOR", 
        "com`wolfram`jlink`MathJFrame`DISPOSEUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`DOUNOTHINGUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`ERROR", 
        "com`wolfram`jlink`MathJFrame`EURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`EXITUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`FRAMEBITS", 
        "com`wolfram`jlink`MathJFrame`getFrames", 
        "com`wolfram`jlink`MathJFrame`HANDUCURSOR", 
        "com`wolfram`jlink`MathJFrame`HEIGHT", 
        "com`wolfram`jlink`MathJFrame`HIDEUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`ICONIFIED", 
        "com`wolfram`jlink`MathJFrame`isDefaultLookAndFeelDecorated", 
        "com`wolfram`jlink`MathJFrame`JPrivate`ABORT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`ALLBITS", 
        "com`wolfram`jlink`MathJFrame`JPrivate`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`CENTERUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`DEFAULTUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`DISPOSEUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`JPrivate`DOUNOTHINGUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`JPrivate`ERROR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`EURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`EXITUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`JPrivate`FRAMEBITS", 
        "com`wolfram`jlink`MathJFrame`JPrivate`getContentPane", 
        "com`wolfram`jlink`MathJFrame`JPrivate`getFrames", 
        "com`wolfram`jlink`MathJFrame`JPrivate`HANDUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`HEIGHT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`HIDEUONUCLOSE", 
        "com`wolfram`jlink`MathJFrame`JPrivate`ICONIFIED", 
        "com`wolfram`jlink`MathJFrame`JPrivate`isDefaultLookAndFeelDecorated",
         "com`wolfram`jlink`MathJFrame`JPrivate`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`MathJFrame`JPrivate`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`MOVEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`NORMAL", 
        "com`wolfram`jlink`MathJFrame`JPrivate`NURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`onClose", 
        "com`wolfram`jlink`MathJFrame`JPrivate`PROPERTIES", 
        "com`wolfram`jlink`MathJFrame`JPrivate`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`setBounds", 
        "com`wolfram`jlink`MathJFrame`JPrivate`\
setDefaultLookAndFeelDecorated", 
        "com`wolfram`jlink`MathJFrame`JPrivate`setModal", 
        "com`wolfram`jlink`MathJFrame`JPrivate`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`SOMEBITS", 
        "com`wolfram`jlink`MathJFrame`JPrivate`SURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`TEXTUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`JPrivate`WAITUCURSOR", 
        "com`wolfram`jlink`MathJFrame`JPrivate`WIDTH", 
        "com`wolfram`jlink`MathJFrame`JPrivate`WURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`LEFTUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`MathJFrame`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`MathJFrame`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`MathJFrame`MOVEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`NORMAL", 
        "com`wolfram`jlink`MathJFrame`NURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`PROPERTIES", 
        "com`wolfram`jlink`MathJFrame`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`setDefaultLookAndFeelDecorated", 
        "com`wolfram`jlink`MathJFrame`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`SOMEBITS", 
        "com`wolfram`jlink`MathJFrame`SURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`MathJFrame`TEXTUCURSOR", 
        "com`wolfram`jlink`MathJFrame`TOPUALIGNMENT", 
        "com`wolfram`jlink`MathJFrame`WAITUCURSOR", 
        "com`wolfram`jlink`MathJFrame`WIDTH", 
        "com`wolfram`jlink`MathJFrame`WURESIZEUCURSOR", 
        "com`wolfram`jlink`MathListener`JPrivate`setHandler", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`mouseClicked", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`mouseEntered", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`mouseExited", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`mousePressed", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`mouseReleased", 
        "com`wolfram`jlink`MathMouseListener`JPrivate`setHandler", 
        "com`wolfram`jlink`ObjectMaker`makeBooleanArray", 
        "com`wolfram`jlink`ObjectMaker`makeBooleanArray2", 
        "com`wolfram`jlink`ObjectMaker`makeBooleanArray3", 
        "com`wolfram`jlink`ObjectMaker`makeDoubleArray", 
        "com`wolfram`jlink`ObjectMaker`makeDoubleArray2", 
        "com`wolfram`jlink`ObjectMaker`makeDoubleArray3", 
        "com`wolfram`jlink`ObjectMaker`makeExpr", 
        "com`wolfram`jlink`ObjectMaker`makeIntArray", 
        "com`wolfram`jlink`ObjectMaker`makeIntArray2", 
        "com`wolfram`jlink`ObjectMaker`makeIntArray3", 
        "com`wolfram`jlink`ObjectMaker`makeObjectArray", 
        "com`wolfram`jlink`ObjectMaker`makeObjectArray2", 
        "com`wolfram`jlink`ObjectMaker`makeObjectArray3", 
        "com`wolfram`jlink`ObjectMaker`makeStringArray", 
        "com`wolfram`jlink`ObjectMaker`makeStringArray2", 
        "com`wolfram`jlink`ObjectMaker`makeStringArray3", 
        "com`wolfram`jlink`ui`ConsoleWindow`ABORT", 
        "com`wolfram`jlink`ui`ConsoleWindow`ALLBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`CENTERUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`DEFAULTUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`ERROR", 
        "com`wolfram`jlink`ui`ConsoleWindow`EURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`FRAMEBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`getFrames", 
        "com`wolfram`jlink`ui`ConsoleWindow`getInstance", 
        "com`wolfram`jlink`ui`ConsoleWindow`HANDUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`HEIGHT", 
        "com`wolfram`jlink`ui`ConsoleWindow`ICONIFIED", 
        "com`wolfram`jlink`ui`ConsoleWindow`isFirstTime", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ABORT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ALLBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`BOTTOMUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`CENTERUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`CROSSHAIRUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`DEFAULTUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ERROR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`EURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`FRAMEBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`getFrames", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`getInstance", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`HANDUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`HEIGHT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`ICONIFIED", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`isFirstTime", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`LEFTUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`MOVEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NONE", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NORMAL", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`PROPERTIES", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setCapture", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setFirstTime", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setLocation", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setMaxLines", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`setSize", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SOMEBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`STDERR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`STDOUT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`TEXTUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`TOPUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WAITUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WIDTH", 
        "com`wolfram`jlink`ui`ConsoleWindow`JPrivate`WURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`LEFTUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUBOTH", 
        "com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUHORIZ", 
        "com`wolfram`jlink`ui`ConsoleWindow`MAXIMIZEDUVERT", 
        "com`wolfram`jlink`ui`ConsoleWindow`MOVEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`NEURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`NONE", 
        "com`wolfram`jlink`ui`ConsoleWindow`NORMAL", 
        "com`wolfram`jlink`ui`ConsoleWindow`NURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`NWURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`PROPERTIES", 
        "com`wolfram`jlink`ui`ConsoleWindow`RIGHTUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`setCapture", 
        "com`wolfram`jlink`ui`ConsoleWindow`setFirstTime", 
        "com`wolfram`jlink`ui`ConsoleWindow`setMaxLines", 
        "com`wolfram`jlink`ui`ConsoleWindow`SEURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`SOMEBITS", 
        "com`wolfram`jlink`ui`ConsoleWindow`STDERR", 
        "com`wolfram`jlink`ui`ConsoleWindow`STDOUT", 
        "com`wolfram`jlink`ui`ConsoleWindow`SURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`SWURESIZEUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`TEXTUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`TOPUALIGNMENT", 
        "com`wolfram`jlink`ui`ConsoleWindow`WAITUCURSOR", 
        "com`wolfram`jlink`ui`ConsoleWindow`WIDTH", 
        "com`wolfram`jlink`ui`ConsoleWindow`WURESIZEUCURSOR", "Condition", 
        "ConfigurationPath", "Conjugate", "ConjugateTranspose", "Connect", 
        "ConnectToFrontEnd", "ConsoleMessage", "ConsoleMessagePacket", 
        "ConsolePrint", "ConsoleWindow`ABORT", "ConsoleWindow`ALLBITS", 
        "ConsoleWindow`BOTTOMUALIGNMENT", "ConsoleWindow`CENTERUALIGNMENT", 
        "ConsoleWindow`CROSSHAIRUCURSOR", "ConsoleWindow`DEFAULTUCURSOR", 
        "ConsoleWindow`ERROR", "ConsoleWindow`EURESIZEUCURSOR", 
        "ConsoleWindow`FRAMEBITS", "ConsoleWindow`getFrames", 
        "ConsoleWindow`getInstance", "ConsoleWindow`HANDUCURSOR", 
        "ConsoleWindow`HEIGHT", "ConsoleWindow`ICONIFIED", 
        "ConsoleWindow`isFirstTime", "ConsoleWindow`LEFTUALIGNMENT", 
        "ConsoleWindow`MAXIMIZEDUBOTH", "ConsoleWindow`MAXIMIZEDUHORIZ", 
        "ConsoleWindow`MAXIMIZEDUVERT", "ConsoleWindow`MOVEUCURSOR", 
        "ConsoleWindow`NEURESIZEUCURSOR", "ConsoleWindow`NONE", 
        "ConsoleWindow`NORMAL", "ConsoleWindow`NURESIZEUCURSOR", 
        "ConsoleWindow`NWURESIZEUCURSOR", "ConsoleWindow`PROPERTIES", 
        "ConsoleWindow`RIGHTUALIGNMENT", "ConsoleWindow`setCapture", 
        "ConsoleWindow`setFirstTime", "ConsoleWindow`setMaxLines", 
        "ConsoleWindow`SEURESIZEUCURSOR", "ConsoleWindow`SOMEBITS", 
        "ConsoleWindow`STDERR", "ConsoleWindow`STDOUT", 
        "ConsoleWindow`SURESIZEUCURSOR", "ConsoleWindow`SWURESIZEUCURSOR", 
        "ConsoleWindow`TEXTUCURSOR", "ConsoleWindow`TOPUALIGNMENT", 
        "ConsoleWindow`WAITUCURSOR", "ConsoleWindow`WIDTH", 
        "ConsoleWindow`WURESIZEUCURSOR", "Constant", "Constants", 
        "ConstrainedMax", "ConstrainedMin", "Constructors", "Container`ABORT",
         "Container`ALLBITS", "Container`BOTTOMUALIGNMENT", 
        "Container`CENTERUALIGNMENT", "Container`ERROR", 
        "Container`FRAMEBITS", "Container`HEIGHT", "Container`LEFTUALIGNMENT",
         "Container`PROPERTIES", "Container`RIGHTUALIGNMENT", 
        "Container`SOMEBITS", "Container`TOPUALIGNMENT", "Container`WIDTH", 
        "contentFrame", "contentPane", "ContentsBoundingBox", 
        "contentSliderFrame", "Context", "Contexts", "ContextToFilename", 
        "ContextToFileName", "Continuation", "Continue", "ContinuedFraction", 
        "ContourGraphics", "ContourLines", "ContourPlot", "Contours", 
        "ContourShading", "ContourSmoothing", "ContourStyle", "controller", 
        "Conversion`LineBoundingBox", "Conversion`LineSpacing", 
        "Conversion`LineWrapBox", "ConversionOptions", "ConversionRules", 
        "Conversion`TeXStringsToTextMode", "Convert`TeX`BoxesToTeX", 
        "Convert`TeX`ExpressionToTeX", "Convert`TeX`TeXToBoxes", 
        "Convert`TeX`TeXToExpression", "ConvertToBitmapPacket", 
        "ConvertToCellExpression", "ConvertToPostScript", 
        "ConvertToPostScriptPacket", "Copyable", "CopyDirectory", "CopyFile", 
        "Cos", "Cosh", "CoshIntegral", "CosIntegral", "Cot", "Coth", "Count", 
        "CounterAssignments", "CounterBox", "CounterBoxOptions", 
        "CounterEvaluator", "CounterFunction", "CounterIncrements", 
        "CounterStyle", "CounterStyleMenuListing", "CreateDirectory", 
        "createImage", "CreatePalettePacket", "createSliderWindow", "Cross", 
        "Csc", "Csch", "Cubics", "Cuboid", "CurrentlySpeakingPacket", 
        "currentTimeMillis", "Cyan", "Cyclotomic", "CylindricalDecomposition",
         "D", "DampingFactor", "Dashing", "DataRange", "dataUpdata", "Date", 
        "Debug", "Debugger`BreakEnable", "Debugger`DebugAbort", 
        "Debugger`DebugFinish", "Debugger`DebugHandle", "Debugger`DebugNext", 
        "Debugger`DebugOff", "Debugger`DebugOn", "Debugger`DebugStep", 
        "Debugger`EvaluationStack", "Debugger`GetBreakpoints", 
        "Debugger`GetTags", "Debugger`SetBreakpoints", 
        "Debugger`SetExpressionWatchpoints", "Debugger`Tracing", "DebugTag", 
        "Debug`$ExamineCode", "Decimal", "DeclarePackage", "Decompose", 
        "Decrement", "DedekindEta", "Default", "DefaultColor", 
        "DefaultDuplicateCellStyle", "DefaultFont", "DefaultFontProperties", 
        "DefaultFormatType", "DefaultFormatTypeForStyle", 
        "DefaultInlineFormatType", "DefaultInputFormatType", 
        "DefaultNaturalLanguage", "DefaultNewCellStyle", 
        "DefaultNewInlineCellStyle", "DefaultNotebook", 
        "DefaultOutputFormatType", "DefaultStyleDefinitions", 
        "DefaultTextFormatType", "DefaultTextInlineFormatType", 
        "DefaultValues", "DefineExternal", "Definition", "Degree", 
        "DegreeLexicographic", "DegreeReverseLexicographic", "Deletable", 
        "Delete", "DeleteCases", "DeleteContents", "DeleteDirectory", 
        "DeleteFile", "DeletionWarning", "DelimiterFlashTime", 
        "DelimiterMatching", "Delimiters", "Denominator", "DensityGraphics", 
        "DensityPlot", "DependentVariables", "Depth", "Derivative", "Det", 
        "Developer`BesselSimplify", "Developer`BitLength", 
        "Developer`BitShiftLeft", "Developer`BitShiftRight", 
        "Developer`BoxesToMathML", "Developer`ClearCache", 
        "Developer`CompensatedAdd", "Developer`ContextFreeForm", 
        "Developer`FibonacciSimplify", "Developer`FileInformation", 
        "Developer`ForceLocalFrontEnd", "Developer`FourierListConvolve", 
        "Developer`FromPackedArray", "Developer`GammaSimplify", 
        "Developer`HermiteNormalForm", "Developer`InequalityInstance", 
        "Developer`InitializationFunction", "Developer`InstallFrontEnd", 
        "Developer`LaunchCommand", "Developer`LaunchFlags", 
        "Developer`LinearExpressionToMatrix", 
        "Developer`LinearExpressionToSparseMatrix", 
        "Developer`MachineComplexQ", "Developer`MachineIntegerQ", 
        "Developer`MachineRealQ", "Developer`MathMLToBoxes", 
        "Developer`NotebookInformation", "Developer`PackedArrayForm", 
        "Developer`PackedArrayQ", "Developer`PartitionMap", 
        "Developer`PolyGammaSimplify", "Developer`PolyLogSimplify", 
        "Developer`PolynomialDivision", "Developer`PseudoFunctionsSimplify", 
        "Developer`ReplaceAllUnheld", "Developer`SetSystemOptions", 
        "Developer`SparseLinearSolve", "Developer`SystemOptions", 
        "Developer`ToPackedArray", "Developer`TrigToRadicals", 
        "Developer`UninstallFrontEnd", "Developer`UseFrontEnd", 
        "Developer`ZeroQ", "Developer`ZetaSimplify", 
        "Developer`$MaxMachineInteger", "Developer`$SymbolShadowingFunction", 
        "Developer`$SymbolSystemShadowing", "DiacriticalPositioning", 
        "DiagonalMatrix", "Dialog", "DialogIndent", "DialogLevel", 
        "DialogProlog", "DialogSymbols", "diams", "diams$", "DifferenceOrder",
         "DigitBlock", "DigitCharacter", "DigitCount", "DigitQ", "Dimensions",
         "DiracDelta", "DirectedInfinity", "Direction", "Directory", 
        "DirectoryName", "DirectoryStack", "dirJar", 
        "dirmyMathematicaDesktop", "dirmyMathematicaLaptop", 
        "DisableConsolePrintPacket", "DiscreteDelta", "Discrete`Difference", 
        "Discrete`FactorialPower", "Disk", "Dispatch", "Display", 
        "displayAgentDataFrame", "DisplayAnimation", "DisplayEndPacket", 
        "DisplayFlushImagePacket", "DisplayForm", "DisplayFunction", 
        "DisplayPacket", "DisplayRules", "DisplaySetSizePacket", 
        "DisplayString", "dispose", "dist", "Distribute", "dist$", "Divide", 
        "DivideBy", "DivisionFreeRowReduction", "Divisors", "DivisorSigma", 
        "Do", "DoModal", "DOSTextFormat", "Dot", "DoubleExponential", 
        "DoublyInfinite", "Down", "DownValues", "DragAndDrop", "drawAgent", 
        "drawCollision", "DrawHighlighted", "drawOval", "drawRect", "Drop", 
        "DSolve", "DSolve`DSolve2Order1NonlinearODEs", 
        "DSolve`DSolve3Order1NonlinearODEs", 
        "DSolve`DSolveBoundaryValueProblem", "DSolve`DSolveClassifyAbelODE", 
        "DSolve`DSolveCompleteIntegral", 
        "DSolve`DSolveCoreNilpotentDecomposition", 
        "DSolve`DSolveDegreeBoundForPolynomialSolutionsOfLinearFirstOrderODEs"\
, "DSolve`DSolveDispatchFirstOrderODEs", "DSolve`DSolveDispatchODE", 
        "DSolve`DSolveDispatchPDE", "DSolve`DSolveDispatchPiecewiseODE", 
        "DSolve`DSolveFirstOrderODE", "DSolve`DSolveFirstOrderODEs", 
        "DSolve`DSolveFlatten", "DSolve`DSolveFromPureFunctionToLimit", 
        "DSolve`DSolveHigherOrderODE", "DSolve`DSolveIntegrate", 
        "DSolve`DSolveKovacic", "DSolve`DSolveLinearExactODE", 
        "DSolve`DSolveLinearFirstOrderDAEs", 
        "DSolve`DSolveLinearHomogeneousWithConstantCoefficients", 
        "DSolve`DSolveLinearLegendreEquation", "DSolve`DSolveLinearPDE", 
        "DSolve`DSolveLinearSecondOrderODE", "DSolve`DSolveMakeEquations", 
        "DSolve`DSolveMethodOfUndeterminedCoefficients", 
        "DSolve`DSolveNonlinear2ndOrderODE", "DSolve`DSolveNonZeroQ", 
        "DSolve`DSolveOrder2PFQSols", "DSolve`DSolveOuter", 
        "DSolve`DSolveParser", "DSolve`DSolvePDE", 
        "DSolve`DSolvePFQTypeSolutions", "DSolve`DSolveQuasiLinearPDE", 
        "DSolve`DSolveRationalAndExponentialSolutions", 
        "DSolve`DSolveRationalQ", "DSolve`DSolveSecondOrderODE", 
        "DSolve`DSolveSolve", "DSolve`DSolveSpecialLinearSecondOrderODE", 
        "DSolve`DSolveSpecialLinearThirdOrderODE", 
        "DSolve`DSolveSuccessiveReductionOfOrder", 
        "DSolve`DSolveToPureFunction", "DSolve`DSolveTransformations", 
        "DSolve`DSolveValuation", "DSolve`DSolveVariationOfParameters", 
        "DSolve`DSolveZeroQ", "DSolve`$DSolveLeafCountConstraint", 
        "DSolve`$DSolveSymmetryDegreeConstraint", 
        "DSolve`$DSolveZeroQTimeConstraint", "Dt", "DualLinearProgramming", 
        "DumpGet", "DumpSave", "e", "E", "EdgeForm", "Edit", "Editable", 
        "EditButtonSettings", "EditCellTagsSettings", "EditDefinition", 
        "EditIn", "Eigensystem", "Eigenvalues", "Eigenvectors", "Element", 
        "Eliminate", "EliminationOrder", "EllipticE", "EllipticExp", 
        "EllipticExpPrime", "EllipticF", "EllipticK", "EllipticLog", 
        "EllipticNomeQ", "EllipticPi", "EllipticReducedHalfPeriods", 
        "EllipticTheta", "EllipticThetaPrime", "Empty", 
        "EnableConsolePrintPacket", "Encode", "Encoding", "End", "EndAdd", 
        "EndDialogPacket", "EndFrontEndInteractionPacket", "EndJavaBlock", 
        "EndModal", "EndOfFile", "EndOfLine", "EndOfString", "EndPackage", 
        "EngineeringForm", "Enter", "EnterExpressionPacket", 
        "EnterTextPacket", "Environment", "Epilog", "Equal", "EqualColumns", 
        "EqualRows", "EquatedTo", "Erf", "Erfc", "Erfi", "err", "ErrorBox", 
        "ErrorBoxOptions", "ErrorNorm", "ErrorPacket", "ErrorsDialogSettings",
         "EulerE", "EulerGamma", "EulerPhi", "Evaluatable", "Evaluate", 
        "EvaluatePacket", "EvaluateToImage", "EvaluateToTypeset", 
        "EvaluationCell", "EvaluationCompletionAction", "EvaluationMonitor", 
        "EvaluationNotebook", "Evaluator", "EvaluatorNames", "EvenQ", 
        "EventEvaluator", "evt", "ExactNumberQ", "ExactRootIsolation", 
        "Except", "ExcludedForms", "Exists", "exit", "Exit", "ExitDialog", 
        "Exp", "Expand", "ExpandAll", "ExpandDenominator", "ExpandNumerator", 
        "Experimental`BinaryExport", "Experimental`BinaryExportString", 
        "Experimental`BinaryImport", "Experimental`BinaryImportString", 
        "Experimental`CompileEvaluate", 
        "Experimental`CreateNumericalFunction", 
        "Experimental`CylindricalAlgebraicDecomposition", 
        "Experimental`DefaultValue", "Experimental`DiophantineInstance", 
        "Experimental`ExistsRealQ", "Experimental`ExtendedLinearSolve", 
        "Experimental`ExtendedLUBackSubstitution", 
        "Experimental`ExtendedMessageOptions", "Experimental`FileBrowse", 
        "Experimental`ForAllRealQ", 
        "Experimental`GenericCylindricalAlgebraicDecomposition", 
        "Experimental`ImpliesQ", "Experimental`ImpliesRealQ", 
        "Experimental`Infimum", "Experimental`IntegerPartitions", 
        "Experimental`IntegerValued", "Experimental`Maximize", 
        "Experimental`Minimize", "Experimental`NumberScale", 
        "Experimental`NumericalFunction", "Experimental`OptimizationSymbol", 
        "Experimental`OptimizedExpression", "Experimental`OptimizeExpression",
         "Experimental`Orientation", "Experimental`PopDirection", 
        "Experimental`PopupBox", "Experimental`PopupBoxOptions", 
        "Experimental`Range", "Experimental`RegisterConverter", 
        "Experimental`RegisterEncoding", "Experimental`Resolve", 
        "Experimental`SetExtendedMessageOptions", "Experimental`SliderBox", 
        "Experimental`SliderBoxOptions", "Experimental`StructuralForms", 
        "Experimental`Supremum", "Experimental`TrackingFunction", 
        "Experimental`ValueFunction", "Experimental`$BinaryExportFormats", 
        "Experimental`$BinaryImportFormats", "Experimental`$EqualTolerance", 
        "Experimental`$SameQTolerance", "ExpIntegralE", "ExpIntegralEi", 
        "Exponent", "ExponentFunction", "ExponentPosition", "ExponentStep", 
        "Export", "ExportAutoReplacements", "ExportPacket", "ExportString", 
        "Expression", "ExpressionPacket", "ExpToTrig", "ExtendedGCD", 
        "Extension", "ExternalCall", "ExternalDataCharacterEncoding", 
        "Extract", "FaceForm", "FaceGrids", "Factor", "FactorComplete", 
        "Factorial", "Factorial2", "FactorInteger", "FactorList", 
        "FactorSquareFree", "FactorSquareFreeList", "FactorTerms", 
        "FactorTermsList", "Factor`VarForAlgebraic", "Factor`VarForNumeric", 
        "Factor`VarForTrig", "Fail", "False", "FE`a", "FE`allrules", 
        "FE`alphabetrules", "FE`any", "FE`b", "FE`box", "FE`BoxFormData", 
        "FE`c", "FE`cdirWasOff", "FE`DefineFrontEndGlobals", 
        "FE`DefineFrontEndSymbols", "FE`dirCharPos", 
        "FEDisableConsolePrintPacket", "FE`doubleSeparator", "FE`dropLength", 
        "FE`dropPath", "FE`e", "FEEnableConsolePrintPacket", "FE`expr", 
        "FE`FC", "FE`FlC", "FE`FlCGD", "FE`form", "FE`FromBoxForm", "FE`FT", 
        "FE`fullPath", "FE`FunctionInspector", "FE`FunctionInspectorTemplate",
         "FE`GetSpecialTemplate", "FE`getTemplateFromUsage", "FE`includePath",
         "FE`InterpretInlineCells", "FE`language", "FE`lastElement", 
        "FE`list", "FE`makeRPC", "FE`makeRPCutil", "FE`makeSymbol", "FE`msg", 
        "FE`name", "FE`nameString", "FE`pat", "FE`patWild", "FE`ResetMedium", 
        "FE`s", "FESafe`saved$Line", "FE`saveAttributes", "FE`SC", 
        "FE`sepPos", "FE`SetBoxForms", "FE`SetLanguage", "FE`SetResultForm", 
        "FE`spell111Off", "FE`spellOff", "FE`sym", "FE`testFile", 
        "FE`testPos", "FE`theNames", "FE`tr", "FE`typesetToInputForm", 
        "FE`usage", "FE`utilfun", "FE`w", "FE`WW", 
        "FE`$FrontEndPackageVersion", "FE`$NoInputFormRules", 
        "FE`$PrePrintAllInputForms", "FE`$PrePrintNoInputForGraphics", 
        "Fibonacci", "FieldFunction", "Fields", "File", "FileByteCount", 
        "FileDate", "FileFormat", "FileInformation", "FileName", 
        "FileNameDialogSettings", "FileNames", "FileType", "fillBoo", 
        "fillBoo$", "fillOval", "fillRect", "Find", "FindFit", "FindInstance",
         "FindList", "FindMaximum", "FindMinimum", 
        "FindMinimum`ConjugateGradient", "FindMinimum`FMsymbol", 
        "FindMinimum`InitializeMethod", "FindMinimum`LevenbergMarquardt", 
        "FindRoot", "FindRoot`InitializeMethod", "FindRoot`Newton", 
        "FindRoot`Secant", "FindSettings", "First", "Fit", "FitAll", 
        "FixedPoint", "FixedPointList", "Flat", "Flatten", "FlattenAt", 
        "Floor", "FlushPrintOutputPacket", "Fold", "FoldList", "Font", 
        "FontColor", "FontFamily", "FontForm", "FontName", 
        "FontPostScriptName", "FontProperties", "FontReencoding", "FontSize", 
        "FontSlant", "FontSubstitutions", "FontTracking", "FontVariations", 
        "FontWeight", "For", "ForAll", "ForceLaunch", "Format", "FormatRules",
         "FormatType", "FormatTypeAutoConvert", "FormatValues", 
        "Format`$GenericForm", "FormBox", "FormBoxOptions", "FortranForm", 
        "Forward", "ForwardBackward", "Fourier", "FourierCosTransform", 
        "FourierParameters", "FourierSinTransform", "FourierTransform", 
        "FractionalPart", "FractionBox", "FractionBoxOptions", "FractionLine",
         "Frame", "Frame`ABORT", "Frame`ALLBITS", "Frame`BOTTOMUALIGNMENT", 
        "FrameBox", "FrameBoxOptions", "Frame`CENTERUALIGNMENT", 
        "Frame`CROSSHAIRUCURSOR", "Frame`DEFAULTUCURSOR", "Frame`ERROR", 
        "Frame`EURESIZEUCURSOR", "Frame`FRAMEBITS", "Frame`getFrames", 
        "Frame`HANDUCURSOR", "Frame`HEIGHT", "Frame`ICONIFIED", "FrameLabel", 
        "Frame`LEFTUALIGNMENT", "Frame`MAXIMIZEDUBOTH", 
        "Frame`MAXIMIZEDUHORIZ", "Frame`MAXIMIZEDUVERT", "Frame`MOVEUCURSOR", 
        "Frame`NEURESIZEUCURSOR", "Frame`NORMAL", "Frame`NURESIZEUCURSOR", 
        "Frame`NWURESIZEUCURSOR", "Frame`PROPERTIES", "Frame`RIGHTUALIGNMENT",
         "Frame`SEURESIZEUCURSOR", "Frame`SOMEBITS", "FrameStyle", 
        "Frame`SURESIZEUCURSOR", "Frame`SWURESIZEUCURSOR", 
        "Frame`TEXTUCURSOR", "FrameTicks", "Frame`TOPUALIGNMENT", 
        "Frame`WAITUCURSOR", "Frame`WIDTH", "Frame`WURESIZEUCURSOR", "FreeQ", 
        "FresnelC", "FresnelS", "FromCharacterCode", "FromContinuedFraction", 
        "FromDate", "FromDigits", "FrontEnd`AbsoluteOptions", 
        "FrontEnd`ButtonNotebook", "FrontEnd`CellPrint", 
        "FrontEnd`ClipboardNotebook", "FrontEnd`CompletionsListPacket", 
        "FrontEnd`ConsoleMessagePacket", "FrontEnd`CopyAsMathML", 
        "FrontEnd`DefaultFormatTypeForStyle", "FrontEnd`DoHTMLMathMLSave", 
        "FrontEnd`DoHTMLSave", "FrontEnd`DoNotebookMLMathMLSave", 
        "FrontEnd`DoNotebookMLSave", "FrontEnd`DotechexplorerSave", 
        "FrontEnd`DoTeXSave", "FrontEnd`EvaluationNotebook", 
        "FrontEndExecute", "FrontEnd`FEDisableConsolePrintPacket", 
        "FrontEnd`FEEnableConsolePrintPacket", "FrontEnd`FileBrowse", 
        "FrontEnd`FileName", "FrontEnd`FrontEndExecute", 
        "FrontEnd`FrontEndToken", "FrontEnd`FullOptions", 
        "FrontEnd`GenerateBitmapCaches", "FrontEnd`HelpBrowserLookup", 
        "FrontEnd`HelpBrowserNotebook", "FrontEnd`InputNotebook", 
        "FrontEnd`InputToInputForm", "FrontEnd`InputToStandardForm", 
        "FrontEnd`Interactive", "FrontEndLink", "FrontEnd`MessagesNotebook", 
        "FrontEnd`MessagesToConsole", 
        "FrontEnd`NeedCurrentFrontEndPackagePacket", "FrontEnd`NotebookApply",
         "FrontEnd`NotebookClose", "FrontEnd`NotebookConvert", 
        "FrontEnd`NotebookCreateReturnObject", "FrontEnd`NotebookDelete", 
        "FrontEnd`NotebookFindReturnObject", "FrontEnd`NotebookGet", 
        "FrontEnd`NotebookInformation", "FrontEnd`NotebookLocate", 
        "FrontEnd`NotebookObject", "FrontEnd`NotebookOpenReturnObject", 
        "FrontEnd`NotebookPrint", "FrontEnd`NotebookPut", 
        "FrontEnd`NotebookPutReturnObject", "FrontEnd`NotebookRead", 
        "FrontEnd`Notebooks", "FrontEnd`NotebookSave", 
        "FrontEnd`NotebookWrite", "FrontEndObject", "FrontEnd`Options", 
        "FrontEnd`OutputToOutputForm", "FrontEnd`OutputToStandardForm", 
        "FrontEnd`PreserveStyleSheet", "FrontEnd`ReturnInputFormPacket", 
        "FrontEnd`SelectedNotebook", "FrontEnd`SelectionAnimate", 
        "FrontEnd`SelectionCreateCell", "FrontEnd`SelectionEvaluate", 
        "FrontEnd`SelectionEvaluateCreateCell", "FrontEnd`SelectionMove", 
        "FrontEnd`SetBoxFormNamesPacket", "FrontEnd`SetOptions", 
        "FrontEnd`SetSelectedNotebook", "FrontEndSharedQ", 
        "FrontEndStackSize", "FrontEnd`ToFileName", "FrontEndToken", 
        "FrontEndTokenExecute", "FrontEnd`UpdateDynamicObjects", 
        "FrontEnd`Value", "FrontEndVersion", "Full", "FullAxes", 
        "FullDefinition", "FullForm", "FullGraphics", "FullOptions", 
        "FullSimplify", "Function", "FunctionExpand", "FunctionInterpolation",
         "g", "Gamma", "GammaRegularized", "GaussianIntegers", "GaussKronrod",
         "GaussPoints", "gc", "GCD", "GegenbauerC", "General", 
        "GenerateBitmapCaches", "GenerateConditions", "GeneratedCell", 
        "GeneratedParameters", "Generic", "Get", "GetBoundingBoxSizePacket", 
        "GetClass", "GetClassPath", "getClickCount", "GetComplexClass", 
        "getContentPane", "GetContext", "getenv", "GetFileName", 
        "GetFrontEndOptionsDataPacket", "getGraphics", "GetJavaException", 
        "GetLinebreakInformationPacket", "GetMenusPacket", 
        "GetPageBreakInformationPacket", "getProperties", "getProperty", 
        "getSecurityManager", "Glaisher", "GlobalPreferences", 
        "GlobalSession", "GoldenRatio", "Goto", "Gradient", "Graphics", 
        "Graphics3D", "GraphicsArray", "Graphics`Arrow`Private`a", 
        "Graphics`Arrow`Private`args", "Graphics`Arrow`Private`arrow", 
        "Graphics`Arrow`Private`arrowscale", "Graphics`Arrow`Private`b", 
        "Graphics`Arrow`Private`beg", "Graphics`Arrow`Private`beg$", 
        "Graphics`Arrow`Private`buildhead", 
        "Graphics`Arrow`Private`buildzero", "Graphics`Arrow`Private`bx", 
        "Graphics`Arrow`Private`by", "Graphics`Arrow`Private`c", 
        "Graphics`Arrow`Private`cent", "Graphics`Arrow`Private`cent$", 
        "Graphics`Arrow`Private`end", "Graphics`Arrow`Private`end$", 
        "Graphics`Arrow`Private`evalarrow", "Graphics`Arrow`Private`ex", 
        "Graphics`Arrow`Private`ey", "Graphics`Arrow`Private`fromdescription",
         "Graphics`Arrow`Private`fromline", 
        "Graphics`Arrow`Private`fromparams", 
        "Graphics`Arrow`Private`frompoint", "Graphics`Arrow`Private`frompoly",
         "Graphics`Arrow`Private`fromsparams", "Graphics`Arrow`Private`g", 
        "Graphics`Arrow`Private`garg", "Graphics`Arrow`Private`generatehead", 
        "Graphics`Arrow`Private`generatezero", "Graphics`Arrow`Private`ghead",
         "Graphics`Arrow`Private`gopts", "Graphics`Arrow`Private`gr", 
        "Graphics`Arrow`Private`grout", "Graphics`Arrow`Private`grout$", 
        "Graphics`Arrow`Private`head", "Graphics`Arrow`Private`heads", 
        "Graphics`Arrow`Private`head$", "Graphics`Arrow`Private`igarg", 
        "Graphics`Arrow`Private`igopts", "Graphics`Arrow`Private`initial", 
        "Graphics`Arrow`Private`initial$", "Graphics`Arrow`Private`l", 
        "Graphics`Arrow`Private`len", "Graphics`Arrow`Private`len$", 
        "Graphics`Arrow`Private`listtostring", 
        "Graphics`Arrow`Private`mathtops", "Graphics`Arrow`Private`nbx", 
        "Graphics`Arrow`Private`nbx$", "Graphics`Arrow`Private`nby", 
        "Graphics`Arrow`Private`nby$", "Graphics`Arrow`Private`ncs", 
        "Graphics`Arrow`Private`ncs$", "Graphics`Arrow`Private`nex", 
        "Graphics`Arrow`Private`nex$", "Graphics`Arrow`Private`ney", 
        "Graphics`Arrow`Private`ney$", "Graphics`Arrow`Private`nls", 
        "Graphics`Arrow`Private`nls$", "Graphics`Arrow`Private`num", 
        "Graphics`Arrow`Private`numberQ", 
        "Graphics`Arrow`Private`numtostring", "Graphics`Arrow`Private`nws", 
        "Graphics`Arrow`Private`nws$", "Graphics`Arrow`Private`oldgaopt", 
        "Graphics`Arrow`Private`oldgaopts", 
        "Graphics`Arrow`Private`oldgaopt$", 
        "Graphics`Arrow`Private`oldgropts", 
        "Graphics`Arrow`Private`oldgropts$", "Graphics`Arrow`Private`opts", 
        "Graphics`Arrow`Private`p", "Graphics`Arrow`Private`pos", 
        "Graphics`Arrow`Private`pos$", "Graphics`Arrow`Private`preparearrows",
         "Graphics`Arrow`Private`prolog", "Graphics`Arrow`Private`prolog$", 
        "Graphics`Arrow`Private`pshead", "Graphics`Arrow`Private`pshead$", 
        "Graphics`Arrow`Private`p$", "Graphics`Arrow`Private`rest", 
        "Graphics`Arrow`Private`rotatesystem", 
        "Graphics`Arrow`Private`routine", "Graphics`Arrow`Private`routine$", 
        "Graphics`Arrow`Private`scale", "Graphics`Arrow`Private`scale$", 
        "Graphics`Arrow`Private`str", "Graphics`Arrow`Private`stream", 
        "Graphics`Arrow`Private`str$", "Graphics`Arrow`Private`t", 
        "Graphics`Arrow`Private`tocoords", "Graphics`Arrow`Private`w", 
        "Graphics`Arrow`Private`width", "Graphics`Arrow`Private`width$", 
        "Graphics`Arrow`Private`ws", "Graphics`Arrow`Private`ws$", 
        "Graphics`Arrow`Private`x", "Graphics`Arrow`Private`y", 
        "Graphics`Arrow`Private`z", "Graphics`Arrow`Private`zero", 
        "Graphics`Arrow`Private`zeros", "Graphics`Arrow`Private`zero$", 
        "Graphics`Arrow`Private`zhead", "Graphics`Arrow`Private`zhead$", 
        "Graphics`Arrow`Private`zscale", "Graphics`Arrow`Private`zscale$", 
        "Graphics`Arrow`Private`$$HeadDescriptions", 
        "Graphics`Arrow`Private`$$HeadRoutines", 
        "Graphics`Arrow`Private`$$ZeroDescriptions", 
        "Graphics`Arrow`Private`$$ZeroRoutines", "GraphicsData", 
        "GraphicsGrouping", "Graphics`PlotMarkers", "GraphicsSpacing", "Gray",
         "GrayLevel", "Greater", "GreaterEqual", "Green", "Grid", 
        "GridBaseline", "GridBox", "GridBoxOptions", "GridCreationSettings", 
        "GridDefaultElement", "GridFrame", "GridFrameMargins", "GridLines", 
        "GroebnerBasis", "GroebnerGCD`modPolynomialGCD", 
        "GroebnerWalk`ConvertOnly", "GroebnerWalk`FirstConeSelectionStrategy",
         "GroebnerWalk`InitialMonomialOrder", 
        "GroebnerWalk`MinimalGroebnerBasis", "GroebnerWalk`Perturbation", 
        "GroebnerWalk`RestConesMethod", 
        "GroebnerWalk`RestConesSelectionStrategy", 
        "GroebnerWalk`TransformationMatrix", "GroupPageBreakWithin", 
        "HarmonicNumber", "Hash", "HashTable", "Head", "HeadCenter", 
        "HeadCompose", "HeadLength", "Heads", "HeadScaling", "HeadShape", 
        "HeadWidth", "HeldPart", "HelpBrowserLookup", "HelpBrowserNotebook", 
        "HelpBrowserSettings", "HermiteH", "HessenbergDecomposition", 
        "Hessian", "HiddenSurface", "Hold", "HoldAll", "HoldAllComplete", 
        "HoldComplete", "HoldFirst", "HoldForm", "HoldPattern", "HoldRest", 
        "HomeDirectory", "Horizontal", "HorizontalForm", 
        "HorizontalScrollPosition", "HTMLSave", "Hue", "Hypergeometric0F1", 
        "Hypergeometric0F1Regularized", "Hypergeometric1F1", 
        "Hypergeometric1F1Regularized", "Hypergeometric2F1", 
        "Hypergeometric2F1Regularized", 
        "HypergeometricLogDump`HypergeometricPFQMa", 
        "HypergeometricLogDump`MeijerGAMain", "HypergeometricPFQ", 
        "HypergeometricPFQRegularized", "HypergeometricU", 
        "HyperlinkCreationSettings", "Hyphenation", "HyphenationOptions", "i",
         "I", "id", "Identity", "identityHashCode", "IdentityMatrix", "id$", 
        "If", "IgnoreCase", "Im", "ImageCache", "ImageCacheValid", 
        "ImageMargins", "ImageOffset", "ImageRangeCache", "ImageRegion", 
        "ImageResolution", "ImageRotated", "Image`SCALEUAREAUAVERAGING", 
        "Image`SCALEUDEFAULT", "Image`SCALEUFAST", "Image`SCALEUREPLICATE", 
        "Image`SCALEUSMOOTH", "ImageSize", "Image`UndefinedProperty", 
        "ImplementJavaInterface", "Implies", "Import", 
        "ImportAutoReplacements", "ImportString", "in", "In", 
        "IncludeFileExtension", "IncludeSingularTerm", "Increment", "Indent", 
        "IndentingNewlineSpacings", "IndentMaxFraction", "Indeterminate", 
        "IndexCreationOptions", "Inequality", "InexactNumberQ", 
        "InexactNumbers", "Infinity", "Infix", "Information", "Inherited", 
        "init", "InitializationCell", "InitializationCellEvaluation", 
        "InitializationCellWarning", "InlineCounterAssignments", 
        "InlineCounterIncrements", "InlineRules", "Inner", "Input", 
        "InputAliases", "InputAutoFormat", "InputAutoReplacements", 
        "InputEvent`ACTIONUEVENTUMASK", "InputEvent`ADJUSTMENTUEVENTUMASK", 
        "InputEvent`ALTUDOWNUMASK", "InputEvent`ALTUGRAPHUDOWNUMASK", 
        "InputEvent`ALTUGRAPHUMASK", "InputEvent`ALTUMASK", 
        "InputEvent`BUTTON1UDOWNUMASK", "InputEvent`BUTTON1UMASK", 
        "InputEvent`BUTTON2UDOWNUMASK", "InputEvent`BUTTON2UMASK", 
        "InputEvent`BUTTON3UDOWNUMASK", "InputEvent`BUTTON3UMASK", 
        "InputEvent`COMPONENTUEVENTUMASK", "InputEvent`COMPONENTUFIRST", 
        "InputEvent`COMPONENTUHIDDEN", "InputEvent`COMPONENTULAST", 
        "InputEvent`COMPONENTUMOVED", "InputEvent`COMPONENTURESIZED", 
        "InputEvent`COMPONENTUSHOWN", "InputEvent`CONTAINERUEVENTUMASK", 
        "InputEvent`CTRLUDOWNUMASK", "InputEvent`CTRLUMASK", 
        "InputEvent`FOCUSUEVENTUMASK", "InputEvent`getModifiersExText", 
        "InputEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "InputEvent`HIERARCHYUEVENTUMASK", 
        "InputEvent`INPUTUMETHODUEVENTUMASK", 
        "InputEvent`INVOCATIONUEVENTUMASK", "InputEvent`ITEMUEVENTUMASK", 
        "InputEvent`KEYUEVENTUMASK", "InputEvent`METAUDOWNUMASK", 
        "InputEvent`METAUMASK", "InputEvent`MOUSEUEVENTUMASK", 
        "InputEvent`MOUSEUMOTIONUEVENTUMASK", 
        "InputEvent`MOUSEUWHEELUEVENTUMASK", "InputEvent`PAINTUEVENTUMASK", 
        "InputEvent`RESERVEDUIDUMAX", "InputEvent`SHIFTUDOWNUMASK", 
        "InputEvent`SHIFTUMASK", "InputEvent`TEXTUEVENTUMASK", 
        "InputEvent`WINDOWUEVENTUMASK", "InputEvent`WINDOWUFOCUSUEVENTUMASK", 
        "InputEvent`WINDOWUSTATEUEVENTUMASK", "InputForm", "InputGrouping", 
        "InputNamePacket", "InputNotebook", "InputPacket", "InputSettings", 
        "InputStream", "InputString", "InputStringPacket", 
        "InputToBoxFormPacket", "InputToInputForm", "InputToStandardForm", 
        "Insert", "InsertionPointObject", "Install", "InstallJava", 
        "InstanceOf", "InString", "Integer", "IntegerDigits", 
        "IntegerExponent", "IntegerPart", "IntegerQ", "Integers", "Integrate",
         "Integrate`A", "Integrate`aaaaa", "Integrate`APART", 
        "Integrate`ApartList", "Integrate`APARTLIST", "Integrate`C", 
        "Integrate`ccccc", "Integrate`ConstRules", "Integrate`Consts", 
        "Integrate`DebugAlgebraics", "Integrate`Definite", 
        "Integrate`Degenerate", "Integrate`DENOMINATOR", "Integrate`Deps", 
        "Integrate`Elliptic`Elliptic", "Integrate`EXPAND", 
        "Integrate`ExpandHold", "Integrate`FACTOR", "Integrate`FACTORLIST", 
        "Integrate`FACTORSQUAREFREE", "Integrate`FACTORSQUAREFREELIST", 
        "Integrate`FACTORTERMS", "Integrate`FACTORTERMSLIST", 
        "Integrate`Fail", "Integrate`H", "Integrate`hideConstants", 
        "Integrate`INPUTEXPR", "Integrate`IntegrateAlgebraic", 
        "Integrate`IntegrateG", "Integrate`IntegrateM", "Integrate`INTERNAL", 
        "Integrate`K", "Integrate`LINEARSOLVE", "Integrate`LogRules", 
        "Integrate`Logs", "Integrate`NLtheorem", "Integrate`nnnnn", 
        "Integrate`NUMERATOR", "Integrate`OAlist", "Integrate`Overdetermined",
         "Integrate`P", "Integrate`PolylogIntegrals", 
        "Integrate`POLYNOMIALGCD", "Integrate`POLYNOMIALLCM", 
        "Integrate`PolyQ", "Integrate`Powers", "Integrate`PPlus", 
        "Integrate`PPlusVector", "Integrate`PPower", "Integrate`PQuotient", 
        "Integrate`Primitives", "Integrate`PTimes", 
        "Integrate`PTimesConstant", "Integrate`PurePlus", 
        "Integrate`PurePower", "Integrate`PureTimes", "Integrate`PVector", 
        "Integrate`QuickLookUp", "Integrate`Radicals", 
        "Integrate`ResetElemNoCC", "Integrate`RESULTANT", 
        "Integrate`ResultantAlpha", "Integrate`S", "Integrate`Singular", 
        "Integrate`SPIN", "Integrate`SPINQ", "Integrate`StructureAlist", 
        "Integrate`StructureStack", "Integrate`TableLookUp", "Integrate`TAR", 
        "Integrate`Thetas", "Integrate`TOGETHER", "Integrate`Tokens", 
        "Integrate`TrigRules", "Integrate`TrivialLogs", 
        "Integrate`TrivialPowers", "Integrate`U", "Integrate`Undefineds", 
        "Integrate`Underdetermined", "Integrate`V", "Integrate`VARIABLES", 
        "Integrate`Y", "Integrate`yyyyy", "Integrate`Z", "Integrate`ZDefs", 
        "Integrate`ZE", "Integrate`ZNest", "Integrate`ZOne", "Integrate`ZPi", 
        "Integrate`ZRanks", "Integrate`ZX", "Integrate`$Algebraic", 
        "Integrate`$Algebraics", "Integrate`$ArcTan2", "Integrate`$Circ", 
        "Integrate`$CRoot", "Integrate`$D", "Integrate`$E", 
        "Integrate`$Hyper", "Integrate`$I", "Integrate`$Im", "Integrate`$Log",
         "Integrate`$Power", "Integrate`$Primitive", "Integrate`$PRoot", 
        "Integrate`$Pure", "Integrate`$Radical", "Integrate`$Re", 
        "Integrate`$Special", "Integrate`$Token", "Integrate`$Transcendental",
         "Integrate`$$a", "Integrate`$$b", "Integrate`$$c", "Integrate`$$u", 
        "Interactive", "Interlaced", "Internal`AddHandler", 
        "Internal`AddPeriodical", "Internal`AlgebraDimension", 
        "Internal`AllSymbols", "Internal`AllUnheldSymbols", "Internal`Bag", 
        "Internal`BagPart", "Internal`BlockFlatten", 
        "Internal`CacheConstants", "Internal`CheckCache", 
        "Internal`CheckSolutions", "Internal`ColorRules", 
        "Internal`CompareNumeric", "Internal`CompareToPAT", 
        "Internal`CompileError", "Internal`CompileInline", 
        "Internal`CompileOnDemand", "Internal`CompileValues", 
        "Internal`ConvertFormTest", "Internal`CubeRootModList", 
        "Internal`CubeRootOfUnity", "Internal`CubicResidueQ", 
        "Internal`CubicSwitch", "Internal`DeactivateMessages", 
        "Internal`DeleteCache", "Internal`DeleteTrailingZeros", 
        "Internal`DenseToSparse", "Internal`DependsOnQ", 
        "Internal`DirectPartitionsP", "Internal`DirectPartitionsQ", 
        "Internal`DisplayFormTest", "Internal`DistributedTermsList", 
        "Internal`DynamicEvaluate", "Internal`EffectivePrecision", 
        "Internal`EmbeddedSymbols", "Internal`EncodeCharacters", 
        "Internal`Escape", "Internal`ExactQuotient", "Internal`ExtendedGCDLG",
         "Internal`ExtendedGCDLI", "Internal`ExtendedGCDSG", 
        "Internal`ExtendedGCDSI", "Internal`ExtraExtendedGCD", 
        "Internal`FIECM", "Internal`FindDivisions", "Internal`FindOneRoot", 
        "Internal`FromCoefficientList", "Internal`FromContinuedFraction", 
        "Internal`FromDistributedTermsList", "Internal`FromNestedTermsList", 
        "Internal`FromPiecewise", "Internal`FundamentalDiscriminantQ", 
        "Internal`GCDLG", "Internal`GCDLI", "Internal`GCDSG", 
        "Internal`GCDSI", "Internal`GetPendingTrackChanges", 
        "Internal`GetRefreshers", "Internal`GetTrackChanges", 
        "Internal`GetTrackedIDs", "Internal`GetTrackedSymbols", 
        "Internal`GroebnerWalk", "Internal`HandlerBlock", "Internal`Handlers",
         "Internal`HarmonicNumber", "Internal`HashSameQ", 
        "Internal`HelpBrowserHyperlinkText", "Internal`HGCD", 
        "Internal`HoldUntil", "Internal`HornerEvaluate", 
        "Internal`InequalitySolverOptions", "Internal`InheritedBlock", 
        "Internal`InnermostToOutermost", "Internal`IntegerPartitionQ", 
        "Internal`IntegerPartitions", "Internal`IteratorFloor", 
        "Internal`LeastQuadraticNonresidue", "Internal`LejaOrder", 
        "Internal`LinearQ", "Internal`LiteralPresentQ", 
        "Internal`LoadEncodingFile", "Internal`MakePolynomial", 
        "Internal`MakeRat", "Internal`MaxAbs", 
        "Internal`MessageButtonHandler", "Internal`MultivariateResultant", 
        "Internal`NestedTermsList", "Internal`NextIntegerPartition", 
        "Internal`NumericContinuedFraction", "Internal`OutermostToInnermost", 
        "Internal`P2", "Internal`PerfectPower", "Internal`Periodicals", 
        "Internal`PiecewiseOptions", "Internal`PiecewiseOrderless", 
        "Internal`PolyGCDCacheHead", "Internal`PolynomialEvaluate", 
        "Internal`PowerMatrix", "Internal`PowerMatrix1", 
        "Internal`PowerMatrix2", "Internal`PreprocessEquations", 
        "Internal`PreviousIntegerPartition", "Internal`PrintSwitchSettings", 
        "Internal`ProcessEquations`CanonicalizeRecurrence", 
        "Internal`ProcessEquations`CheckDependentVariables", 
        "Internal`ProcessEquations`CheckListability", 
        "Internal`ProcessEquations`Decouple", 
        "Internal`ProcessEquations`DependentSubstitute", 
        "Internal`ProcessEquations`DifferentialOrder", 
        "Internal`ProcessEquations`FindDependentVariables", 
        "Internal`ProcessEquations`FindJacobianDependency", 
        "Internal`ProcessEquations`FirstOrderize", 
        "Internal`ProcessEquations`FirstOrderizeRecurrence", 
        "Internal`ProcessEquations`FirstOrderReplace", 
        "Internal`ProcessEquations`GetArguments", 
        "Internal`ProcessEquations`RecurrenceOrder", 
        "Internal`ProcessEquations`SeparateEquations", 
        "Internal`ProcessEquations`SimplifyDependent", 
        "Internal`ProcessEquations`SubstituteDependentRules", 
        "Internal`ProcessEquations`ToEquationList", 
        "Internal`ProcessEquations`$SubstituteEvaluate", 
        "Internal`ProcessEquations`$SubstituteIndex", 
        "Internal`ProcessEquations`$SubstitutePattern", 
        "Internal`PutInformation", "Internal`QuadraticFundamentalUnit", 
        "Internal`QuadraticIrrationalQ", "Internal`QuadraticSieve", 
        "Internal`QuarticSwitch", "Internal`QuotientMod", 
        "Internal`RadicalMemberQ", "Internal`RasterGraphics", 
        "Internal`RationalNoReduce", "Internal`RealContinuedFraction", 
        "Internal`ReduceOptions", "Internal`RemoveHandler", 
        "Internal`RemovePeriodical", "Internal`RepetitionFromMultiplicity", 
        "Internal`RiemannR", "Internal`S1", "Internal`S2", 
        "Internal`SetCache", "Internal`SetDivisorBound", 
        "Internal`SetHGCDBound", "Internal`SetInequalitySolverOptions", 
        "Internal`SetPiecewiseOptions", "Internal`SetPM1PrimeBound", 
        "Internal`SetPowerMatrixBound", "Internal`SetProductBound", 
        "Internal`SetProductBound2", "Internal`SetQuotientBound", 
        "Internal`SetReduceOptions", "Internal`SetSimplificationOptions", 
        "Internal`SetValueTrack", "Internal`SimplificationOptions", 
        "Internal`SparseFactorModList", "Internal`SparseFactorModList2", 
        "Internal`SparseToDense", "Internal`SpellingChecker", 
        "Internal`SqrtMod", "Internal`SqrtModList", "Internal`SqrtModPrime", 
        "Internal`StuffBag", "Internal`SwitchForm", "Internal`SymbolList", 
        "Internal`TakePart", "Internal`TensorTypeQ", "Internal`ToPiecewise", 
        "Internal`ToricGroebnerBasis", "Internal`TrackChangesPacket", 
        "Internal`TrackExpression", "Internal`TrackExpressionNonStrict", 
        "Internal`TransposeIntegerPartition", "Internal`TryLinearSolve", 
        "Internal`TypeOf", "Internal`UnsignedBitNot", "Internal`ValueTrack", 
        "Internal`WithLocalSettings", "Internal`$ContextMarks", 
        "Internal`$ConvertForms", "Internal`$CreationID", 
        "Internal`$FileCharacterEncoding", "Internal`$GlobalTime", 
        "Internal`$PackageDependencies", "Internal`$ThisPeriodical", 
        "InterpolatingFunction", "InterpolatingPolynomial", "Interpolation", 
        "InterpolationOrder", "InterpolationPoints", "InterpolationPrecision",
         "InterpretationBox", "InterpretationBoxOptions", "InterpretTemplate",
         "Interrupt", "InterruptSettings", "Intersection", "Interval", 
        "IntervalIntersection", "IntervalMemberQ", "IntervalUnion", "Inverse",
         "InverseBetaRegularized", "InverseEllipticNomeQ", "InverseErf", 
        "InverseErfc", "InverseFourier", "InverseFourierCosTransform", 
        "InverseFourierSinTransform", "InverseFourierTransform", 
        "InverseFunction", "InverseFunctions", "InverseGammaRegularized", 
        "InverseJacobiCD", "InverseJacobiCN", "InverseJacobiCS", 
        "InverseJacobiDC", "InverseJacobiDN", "InverseJacobiDS", 
        "InverseJacobiNC", "InverseJacobiND", "InverseJacobiNS", 
        "InverseJacobiSC", "InverseJacobiSD", "InverseJacobiSN", 
        "InverseLaplaceTransform", "InverseSeries", "InverseWeierstrassP", 
        "InverseZTransform", "isMetaDown", "JacobiAmplitude", "Jacobian", 
        "JacobiCD", "JacobiCN", "JacobiCS", "JacobiDC", "JacobiDN", 
        "JacobiDS", "JacobiNC", "JacobiND", "JacobiNS", "JacobiP", "JacobiSC",
         "JacobiSD", "JacobiSN", "JacobiSymbol", "JacobiZeta", "Java", 
        "java`awt`AWTEvent`ACTIONUEVENTUMASK", 
        "java`awt`AWTEvent`ADJUSTMENTUEVENTUMASK", 
        "java`awt`AWTEvent`COMPONENTUEVENTUMASK", 
        "java`awt`AWTEvent`CONTAINERUEVENTUMASK", 
        "java`awt`AWTEvent`FOCUSUEVENTUMASK", 
        "java`awt`AWTEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`AWTEvent`HIERARCHYUEVENTUMASK", 
        "java`awt`AWTEvent`INPUTUMETHODUEVENTUMASK", 
        "java`awt`AWTEvent`INVOCATIONUEVENTUMASK", 
        "java`awt`AWTEvent`ITEMUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`ACTIONUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`ADJUSTMENTUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`COMPONENTUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`CONTAINERUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`FOCUSUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`getID", 
        "java`awt`AWTEvent`JPrivate`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`HIERARCHYUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`INPUTUMETHODUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`INVOCATIONUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`ITEMUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`KEYUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`MOUSEUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`PAINTUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`paramString", 
        "java`awt`AWTEvent`JPrivate`RESERVEDUIDUMAX", 
        "java`awt`AWTEvent`JPrivate`setSource", 
        "java`awt`AWTEvent`JPrivate`TEXTUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`toString", 
        "java`awt`AWTEvent`JPrivate`WINDOWUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`AWTEvent`JPrivate`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`AWTEvent`KEYUEVENTUMASK", 
        "java`awt`AWTEvent`MOUSEUEVENTUMASK", 
        "java`awt`AWTEvent`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`AWTEvent`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`AWTEvent`PAINTUEVENTUMASK", 
        "java`awt`AWTEvent`RESERVEDUIDUMAX", 
        "java`awt`AWTEvent`TEXTUEVENTUMASK", 
        "java`awt`AWTEvent`WINDOWUEVENTUMASK", 
        "java`awt`AWTEvent`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`AWTEvent`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`BorderLayout`AFTERULASTULINE", 
        "java`awt`BorderLayout`AFTERULINEUENDS", 
        "java`awt`BorderLayout`BEFOREUFIRSTULINE", 
        "java`awt`BorderLayout`BEFOREULINEUBEGINS", 
        "java`awt`BorderLayout`CENTER", "java`awt`BorderLayout`EAST", 
        "java`awt`BorderLayout`JPrivate`addLayoutComponent", 
        "java`awt`BorderLayout`JPrivate`AFTERULASTULINE", 
        "java`awt`BorderLayout`JPrivate`AFTERULINEUENDS", 
        "java`awt`BorderLayout`JPrivate`BEFOREUFIRSTULINE", 
        "java`awt`BorderLayout`JPrivate`BEFOREULINEUBEGINS", 
        "java`awt`BorderLayout`JPrivate`CENTER", 
        "java`awt`BorderLayout`JPrivate`EAST", 
        "java`awt`BorderLayout`JPrivate`getHgap", 
        "java`awt`BorderLayout`JPrivate`getLayoutAlignmentX", 
        "java`awt`BorderLayout`JPrivate`getLayoutAlignmentY", 
        "java`awt`BorderLayout`JPrivate`getVgap", 
        "java`awt`BorderLayout`JPrivate`invalidateLayout", 
        "java`awt`BorderLayout`JPrivate`layoutContainer", 
        "java`awt`BorderLayout`JPrivate`LINEUEND", 
        "java`awt`BorderLayout`JPrivate`LINEUSTART", 
        "java`awt`BorderLayout`JPrivate`maximumLayoutSize", 
        "java`awt`BorderLayout`JPrivate`minimumLayoutSize", 
        "java`awt`BorderLayout`JPrivate`NORTH", 
        "java`awt`BorderLayout`JPrivate`PAGEUEND", 
        "java`awt`BorderLayout`JPrivate`PAGEUSTART", 
        "java`awt`BorderLayout`JPrivate`preferredLayoutSize", 
        "java`awt`BorderLayout`JPrivate`removeLayoutComponent", 
        "java`awt`BorderLayout`JPrivate`setHgap", 
        "java`awt`BorderLayout`JPrivate`setVgap", 
        "java`awt`BorderLayout`JPrivate`SOUTH", 
        "java`awt`BorderLayout`JPrivate`toString", 
        "java`awt`BorderLayout`JPrivate`WEST", 
        "java`awt`BorderLayout`LINEUEND", "java`awt`BorderLayout`LINEUSTART", 
        "java`awt`BorderLayout`NORTH", "java`awt`BorderLayout`PAGEUEND", 
        "java`awt`BorderLayout`PAGEUSTART", "java`awt`BorderLayout`SOUTH", 
        "java`awt`BorderLayout`WEST", "java`awt`Color`BITMASK", 
        "java`awt`Color`black", "java`awt`Color`BLACK", "java`awt`Color`blue",
         "java`awt`Color`BLUE", "java`awt`Color`cyan", "java`awt`Color`CYAN", 
        "java`awt`Color`darkGray", "java`awt`Color`DARKUGRAY", 
        "java`awt`Color`decode", "java`awt`Color`getColor", 
        "java`awt`Color`getHSBColor", "java`awt`Color`gray", 
        "java`awt`Color`GRAY", "java`awt`Color`green", "java`awt`Color`GREEN",
         "java`awt`Color`HSBtoRGB", "java`awt`Color`JPrivate`BITMASK", 
        "java`awt`Color`JPrivate`black", "java`awt`Color`JPrivate`BLACK", 
        "java`awt`Color`JPrivate`blue", "java`awt`Color`JPrivate`BLUE", 
        "java`awt`Color`JPrivate`brighter", 
        "java`awt`Color`JPrivate`createContext", 
        "java`awt`Color`JPrivate`cyan", "java`awt`Color`JPrivate`CYAN", 
        "java`awt`Color`JPrivate`darker", "java`awt`Color`JPrivate`darkGray", 
        "java`awt`Color`JPrivate`DARKUGRAY", "java`awt`Color`JPrivate`decode",
         "java`awt`Color`JPrivate`equals", "java`awt`Color`JPrivate`getAlpha",
         "java`awt`Color`JPrivate`getBlue", 
        "java`awt`Color`JPrivate`getColor", 
        "java`awt`Color`JPrivate`getColorComponents", 
        "java`awt`Color`JPrivate`getColorSpace", 
        "java`awt`Color`JPrivate`getComponents", 
        "java`awt`Color`JPrivate`getGreen", 
        "java`awt`Color`JPrivate`getHSBColor", 
        "java`awt`Color`JPrivate`getRed", "java`awt`Color`JPrivate`getRGB", 
        "java`awt`Color`JPrivate`getRGBColorComponents", 
        "java`awt`Color`JPrivate`getRGBComponents", 
        "java`awt`Color`JPrivate`getTransparency", 
        "java`awt`Color`JPrivate`gray", "java`awt`Color`JPrivate`GRAY", 
        "java`awt`Color`JPrivate`green", "java`awt`Color`JPrivate`GREEN", 
        "java`awt`Color`JPrivate`hashCode", 
        "java`awt`Color`JPrivate`HSBtoRGB", 
        "java`awt`Color`JPrivate`lightGray", 
        "java`awt`Color`JPrivate`LIGHTUGRAY", 
        "java`awt`Color`JPrivate`magenta", "java`awt`Color`JPrivate`MAGENTA", 
        "java`awt`Color`JPrivate`OPAQUE", "java`awt`Color`JPrivate`orange", 
        "java`awt`Color`JPrivate`ORANGE", "java`awt`Color`JPrivate`pink", 
        "java`awt`Color`JPrivate`PINK", "java`awt`Color`JPrivate`red", 
        "java`awt`Color`JPrivate`RED", "java`awt`Color`JPrivate`RGBtoHSB", 
        "java`awt`Color`JPrivate`toString", 
        "java`awt`Color`JPrivate`TRANSLUCENT", 
        "java`awt`Color`JPrivate`white", "java`awt`Color`JPrivate`WHITE", 
        "java`awt`Color`JPrivate`yellow", "java`awt`Color`JPrivate`YELLOW", 
        "java`awt`Color`lightGray", "java`awt`Color`LIGHTUGRAY", 
        "java`awt`Color`magenta", "java`awt`Color`MAGENTA", 
        "java`awt`Color`OPAQUE", "java`awt`Color`orange", 
        "java`awt`Color`ORANGE", "java`awt`Color`pink", "java`awt`Color`PINK",
         "java`awt`Color`red", "java`awt`Color`RED", 
        "java`awt`Color`RGBtoHSB", "java`awt`Color`TRANSLUCENT", 
        "java`awt`Color`white", "java`awt`Color`WHITE", 
        "java`awt`Color`yellow", "java`awt`Color`YELLOW", 
        "java`awt`Component`ABORT", "java`awt`Component`ALLBITS", 
        "java`awt`Component`BOTTOMUALIGNMENT", 
        "java`awt`Component`CENTERUALIGNMENT", "java`awt`Component`ERROR", 
        "java`awt`Component`FRAMEBITS", "java`awt`Component`HEIGHT", 
        "java`awt`Component`JPrivate`ABORT", 
        "java`awt`Component`JPrivate`action", 
        "java`awt`Component`JPrivate`add", 
        "java`awt`Component`JPrivate`addComponentListener", 
        "java`awt`Component`JPrivate`addFocusListener", 
        "java`awt`Component`JPrivate`addHierarchyBoundsListener", 
        "java`awt`Component`JPrivate`addHierarchyListener", 
        "java`awt`Component`JPrivate`addInputMethodListener", 
        "java`awt`Component`JPrivate`addKeyListener", 
        "java`awt`Component`JPrivate`addMouseListener", 
        "java`awt`Component`JPrivate`addMouseMotionListener", 
        "java`awt`Component`JPrivate`addMouseWheelListener", 
        "java`awt`Component`JPrivate`addNotify", 
        "java`awt`Component`JPrivate`addPropertyChangeListener", 
        "java`awt`Component`JPrivate`ALLBITS", 
        "java`awt`Component`JPrivate`applyComponentOrientation", 
        "java`awt`Component`JPrivate`areFocusTraversalKeysSet", 
        "java`awt`Component`JPrivate`BOTTOMUALIGNMENT", 
        "java`awt`Component`JPrivate`bounds", 
        "java`awt`Component`JPrivate`CENTERUALIGNMENT", 
        "java`awt`Component`JPrivate`checkImage", 
        "java`awt`Component`JPrivate`contains", 
        "java`awt`Component`JPrivate`createImage", 
        "java`awt`Component`JPrivate`createVolatileImage", 
        "java`awt`Component`JPrivate`deliverEvent", 
        "java`awt`Component`JPrivate`disable", 
        "java`awt`Component`JPrivate`dispatchEvent", 
        "java`awt`Component`JPrivate`doLayout", 
        "java`awt`Component`JPrivate`enable", 
        "java`awt`Component`JPrivate`enableInputMethods", 
        "java`awt`Component`JPrivate`ERROR", 
        "java`awt`Component`JPrivate`FRAMEBITS", 
        "java`awt`Component`JPrivate`getAccessibleContext", 
        "java`awt`Component`JPrivate`getAlignmentX", 
        "java`awt`Component`JPrivate`getAlignmentY", 
        "java`awt`Component`JPrivate`getBackground", 
        "java`awt`Component`JPrivate`getBounds", 
        "java`awt`Component`JPrivate`getColorModel", 
        "java`awt`Component`JPrivate`getComponentAt", 
        "java`awt`Component`JPrivate`getComponentListeners", 
        "java`awt`Component`JPrivate`getComponentOrientation", 
        "java`awt`Component`JPrivate`getCursor", 
        "java`awt`Component`JPrivate`getDropTarget", 
        "java`awt`Component`JPrivate`getFocusCycleRootAncestor", 
        "java`awt`Component`JPrivate`getFocusListeners", 
        "java`awt`Component`JPrivate`getFocusTraversalKeys", 
        "java`awt`Component`JPrivate`getFocusTraversalKeysEnabled", 
        "java`awt`Component`JPrivate`getFont", 
        "java`awt`Component`JPrivate`getFontMetrics", 
        "java`awt`Component`JPrivate`getForeground", 
        "java`awt`Component`JPrivate`getGraphics", 
        "java`awt`Component`JPrivate`getGraphicsConfiguration", 
        "java`awt`Component`JPrivate`getHeight", 
        "java`awt`Component`JPrivate`getHierarchyBoundsListeners", 
        "java`awt`Component`JPrivate`getHierarchyListeners", 
        "java`awt`Component`JPrivate`getIgnoreRepaint", 
        "java`awt`Component`JPrivate`getInputContext", 
        "java`awt`Component`JPrivate`getInputMethodListeners", 
        "java`awt`Component`JPrivate`getInputMethodRequests", 
        "java`awt`Component`JPrivate`getKeyListeners", 
        "java`awt`Component`JPrivate`getListeners", 
        "java`awt`Component`JPrivate`getLocale", 
        "java`awt`Component`JPrivate`getLocation", 
        "java`awt`Component`JPrivate`getLocationOnScreen", 
        "java`awt`Component`JPrivate`getMaximumSize", 
        "java`awt`Component`JPrivate`getMinimumSize", 
        "java`awt`Component`JPrivate`getMouseListeners", 
        "java`awt`Component`JPrivate`getMouseMotionListeners", 
        "java`awt`Component`JPrivate`getMouseWheelListeners", 
        "java`awt`Component`JPrivate`getName", 
        "java`awt`Component`JPrivate`getParent", 
        "java`awt`Component`JPrivate`getPeer", 
        "java`awt`Component`JPrivate`getPreferredSize", 
        "java`awt`Component`JPrivate`getPropertyChangeListeners", 
        "java`awt`Component`JPrivate`getSize", 
        "java`awt`Component`JPrivate`getToolkit", 
        "java`awt`Component`JPrivate`getTreeLock", 
        "java`awt`Component`JPrivate`getWidth", 
        "java`awt`Component`JPrivate`getX", 
        "java`awt`Component`JPrivate`getY", 
        "java`awt`Component`JPrivate`gotFocus", 
        "java`awt`Component`JPrivate`handleEvent", 
        "java`awt`Component`JPrivate`hasFocus", 
        "java`awt`Component`JPrivate`HEIGHT", 
        "java`awt`Component`JPrivate`hide", 
        "java`awt`Component`JPrivate`imageUpdate", 
        "java`awt`Component`JPrivate`inside", 
        "java`awt`Component`JPrivate`invalidate", 
        "java`awt`Component`JPrivate`isBackgroundSet", 
        "java`awt`Component`JPrivate`isCursorSet", 
        "java`awt`Component`JPrivate`isDisplayable", 
        "java`awt`Component`JPrivate`isDoubleBuffered", 
        "java`awt`Component`JPrivate`isEnabled", 
        "java`awt`Component`JPrivate`isFocusable", 
        "java`awt`Component`JPrivate`isFocusCycleRoot", 
        "java`awt`Component`JPrivate`isFocusOwner", 
        "java`awt`Component`JPrivate`isFocusTraversable", 
        "java`awt`Component`JPrivate`isFontSet", 
        "java`awt`Component`JPrivate`isForegroundSet", 
        "java`awt`Component`JPrivate`isLightweight", 
        "java`awt`Component`JPrivate`isOpaque", 
        "java`awt`Component`JPrivate`isShowing", 
        "java`awt`Component`JPrivate`isValid", 
        "java`awt`Component`JPrivate`isVisible", 
        "java`awt`Component`JPrivate`keyDown", 
        "java`awt`Component`JPrivate`keyUp", 
        "java`awt`Component`JPrivate`layout", 
        "java`awt`Component`JPrivate`LEFTUALIGNMENT", 
        "java`awt`Component`JPrivate`list", 
        "java`awt`Component`JPrivate`locate", 
        "java`awt`Component`JPrivate`location", 
        "java`awt`Component`JPrivate`lostFocus", 
        "java`awt`Component`JPrivate`minimumSize", 
        "java`awt`Component`JPrivate`mouseDown", 
        "java`awt`Component`JPrivate`mouseDrag", 
        "java`awt`Component`JPrivate`mouseEnter", 
        "java`awt`Component`JPrivate`mouseExit", 
        "java`awt`Component`JPrivate`mouseMove", 
        "java`awt`Component`JPrivate`mouseUp", 
        "java`awt`Component`JPrivate`move", 
        "java`awt`Component`JPrivate`nextFocus", 
        "java`awt`Component`JPrivate`paint", 
        "java`awt`Component`JPrivate`paintAll", 
        "java`awt`Component`JPrivate`postEvent", 
        "java`awt`Component`JPrivate`preferredSize", 
        "java`awt`Component`JPrivate`prepareImage", 
        "java`awt`Component`JPrivate`print", 
        "java`awt`Component`JPrivate`printAll", 
        "java`awt`Component`JPrivate`PROPERTIES", 
        "java`awt`Component`JPrivate`remove", 
        "java`awt`Component`JPrivate`removeComponentListener", 
        "java`awt`Component`JPrivate`removeFocusListener", 
        "java`awt`Component`JPrivate`removeHierarchyBoundsListener", 
        "java`awt`Component`JPrivate`removeHierarchyListener", 
        "java`awt`Component`JPrivate`removeInputMethodListener", 
        "java`awt`Component`JPrivate`removeKeyListener", 
        "java`awt`Component`JPrivate`removeMouseListener", 
        "java`awt`Component`JPrivate`removeMouseMotionListener", 
        "java`awt`Component`JPrivate`removeMouseWheelListener", 
        "java`awt`Component`JPrivate`removeNotify", 
        "java`awt`Component`JPrivate`removePropertyChangeListener", 
        "java`awt`Component`JPrivate`repaint", 
        "java`awt`Component`JPrivate`requestFocus", 
        "java`awt`Component`JPrivate`requestFocusInWindow", 
        "java`awt`Component`JPrivate`reshape", 
        "java`awt`Component`JPrivate`resize", 
        "java`awt`Component`JPrivate`RIGHTUALIGNMENT", 
        "java`awt`Component`JPrivate`setBackground", 
        "java`awt`Component`JPrivate`setBounds", 
        "java`awt`Component`JPrivate`setComponentOrientation", 
        "java`awt`Component`JPrivate`setCursor", 
        "java`awt`Component`JPrivate`setDropTarget", 
        "java`awt`Component`JPrivate`setEnabled", 
        "java`awt`Component`JPrivate`setFocusable", 
        "java`awt`Component`JPrivate`setFocusTraversalKeys", 
        "java`awt`Component`JPrivate`setFocusTraversalKeysEnabled", 
        "java`awt`Component`JPrivate`setFont", 
        "java`awt`Component`JPrivate`setForeground", 
        "java`awt`Component`JPrivate`setIgnoreRepaint", 
        "java`awt`Component`JPrivate`setLocale", 
        "java`awt`Component`JPrivate`setLocation", 
        "java`awt`Component`JPrivate`setName", 
        "java`awt`Component`JPrivate`setSize", 
        "java`awt`Component`JPrivate`setVisible", 
        "java`awt`Component`JPrivate`show", 
        "java`awt`Component`JPrivate`size", 
        "java`awt`Component`JPrivate`SOMEBITS", 
        "java`awt`Component`JPrivate`TOPUALIGNMENT", 
        "java`awt`Component`JPrivate`toString", 
        "java`awt`Component`JPrivate`transferFocus", 
        "java`awt`Component`JPrivate`transferFocusBackward", 
        "java`awt`Component`JPrivate`transferFocusUpCycle", 
        "java`awt`Component`JPrivate`update", 
        "java`awt`Component`JPrivate`validate", 
        "java`awt`Component`JPrivate`WIDTH", 
        "java`awt`Component`LEFTUALIGNMENT", "java`awt`Component`PROPERTIES", 
        "java`awt`Component`RIGHTUALIGNMENT", "java`awt`Component`SOMEBITS", 
        "java`awt`Component`TOPUALIGNMENT", "java`awt`Component`WIDTH", 
        "java`awt`Container`ABORT", "java`awt`Container`ALLBITS", 
        "java`awt`Container`BOTTOMUALIGNMENT", 
        "java`awt`Container`CENTERUALIGNMENT", "java`awt`Container`ERROR", 
        "java`awt`Container`FRAMEBITS", "java`awt`Container`HEIGHT", 
        "java`awt`Container`JPrivate`ABORT", 
        "java`awt`Container`JPrivate`add", 
        "java`awt`Container`JPrivate`addContainerListener", 
        "java`awt`Container`JPrivate`addMouseListener", 
        "java`awt`Container`JPrivate`addNotify", 
        "java`awt`Container`JPrivate`addPropertyChangeListener", 
        "java`awt`Container`JPrivate`ALLBITS", 
        "java`awt`Container`JPrivate`applyComponentOrientation", 
        "java`awt`Container`JPrivate`areFocusTraversalKeysSet", 
        "java`awt`Container`JPrivate`BOTTOMUALIGNMENT", 
        "java`awt`Container`JPrivate`CENTERUALIGNMENT", 
        "java`awt`Container`JPrivate`countComponents", 
        "java`awt`Container`JPrivate`createImage", 
        "java`awt`Container`JPrivate`deliverEvent", 
        "java`awt`Container`JPrivate`doLayout", 
        "java`awt`Container`JPrivate`ERROR", 
        "java`awt`Container`JPrivate`findComponentAt", 
        "java`awt`Container`JPrivate`FRAMEBITS", 
        "java`awt`Container`JPrivate`getAlignmentX", 
        "java`awt`Container`JPrivate`getAlignmentY", 
        "java`awt`Container`JPrivate`getComponent", 
        "java`awt`Container`JPrivate`getComponentAt", 
        "java`awt`Container`JPrivate`getComponentCount", 
        "java`awt`Container`JPrivate`getComponents", 
        "java`awt`Container`JPrivate`getContainerListeners", 
        "java`awt`Container`JPrivate`getFocusTraversalKeys", 
        "java`awt`Container`JPrivate`getFocusTraversalPolicy", 
        "java`awt`Container`JPrivate`getInsets", 
        "java`awt`Container`JPrivate`getLayout", 
        "java`awt`Container`JPrivate`getListeners", 
        "java`awt`Container`JPrivate`getMaximumSize", 
        "java`awt`Container`JPrivate`getMinimumSize", 
        "java`awt`Container`JPrivate`getPreferredSize", 
        "java`awt`Container`JPrivate`HEIGHT", 
        "java`awt`Container`JPrivate`insets", 
        "java`awt`Container`JPrivate`invalidate", 
        "java`awt`Container`JPrivate`isAncestorOf", 
        "java`awt`Container`JPrivate`isFocusCycleRoot", 
        "java`awt`Container`JPrivate`isFocusTraversalPolicySet", 
        "java`awt`Container`JPrivate`layout", 
        "java`awt`Container`JPrivate`LEFTUALIGNMENT", 
        "java`awt`Container`JPrivate`list", 
        "java`awt`Container`JPrivate`locate", 
        "java`awt`Container`JPrivate`minimumSize", 
        "java`awt`Container`JPrivate`paint", 
        "java`awt`Container`JPrivate`paintComponents", 
        "java`awt`Container`JPrivate`preferredSize", 
        "java`awt`Container`JPrivate`print", 
        "java`awt`Container`JPrivate`printComponents", 
        "java`awt`Container`JPrivate`PROPERTIES", 
        "java`awt`Container`JPrivate`remove", 
        "java`awt`Container`JPrivate`removeAll", 
        "java`awt`Container`JPrivate`removeContainerListener", 
        "java`awt`Container`JPrivate`removeNotify", 
        "java`awt`Container`JPrivate`RIGHTUALIGNMENT", 
        "java`awt`Container`JPrivate`setBounds", 
        "java`awt`Container`JPrivate`setFocusCycleRoot", 
        "java`awt`Container`JPrivate`setFocusTraversalKeys", 
        "java`awt`Container`JPrivate`setFocusTraversalPolicy", 
        "java`awt`Container`JPrivate`setFont", 
        "java`awt`Container`JPrivate`setLayout", 
        "java`awt`Container`JPrivate`setLocation", 
        "java`awt`Container`JPrivate`setSize", 
        "java`awt`Container`JPrivate`setVisible", 
        "java`awt`Container`JPrivate`SOMEBITS", 
        "java`awt`Container`JPrivate`TOPUALIGNMENT", 
        "java`awt`Container`JPrivate`transferFocusBackward", 
        "java`awt`Container`JPrivate`transferFocusDownCycle", 
        "java`awt`Container`JPrivate`update", 
        "java`awt`Container`JPrivate`validate", 
        "java`awt`Container`JPrivate`WIDTH", 
        "java`awt`Container`LEFTUALIGNMENT", "java`awt`Container`PROPERTIES", 
        "java`awt`Container`RIGHTUALIGNMENT", "java`awt`Container`SOMEBITS", 
        "java`awt`Container`TOPUALIGNMENT", "java`awt`Container`WIDTH", 
        "java`awt`event`AdjustmentListener`JPrivate`adjustmentValueChanged", 
        "java`awt`event`ComponentEvent`ACTIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`COMPONENTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`COMPONENTUFIRST", 
        "java`awt`event`ComponentEvent`COMPONENTUHIDDEN", 
        "java`awt`event`ComponentEvent`COMPONENTULAST", 
        "java`awt`event`ComponentEvent`COMPONENTUMOVED", 
        "java`awt`event`ComponentEvent`COMPONENTURESIZED", 
        "java`awt`event`ComponentEvent`COMPONENTUSHOWN", 
        "java`awt`event`ComponentEvent`CONTAINERUEVENTUMASK", 
        "java`awt`event`ComponentEvent`FOCUSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`HIERARCHYUEVENTUMASK", 
        "java`awt`event`ComponentEvent`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`ComponentEvent`INVOCATIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`ITEMUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`ACTIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTUFIRST", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTUHIDDEN", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTULAST", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTUMOVED", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTURESIZED", 
        "java`awt`event`ComponentEvent`JPrivate`COMPONENTUSHOWN", 
        "java`awt`event`ComponentEvent`JPrivate`CONTAINERUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`FOCUSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`getComponent", 
        "java`awt`event`ComponentEvent`JPrivate`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`HIERARCHYUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`INVOCATIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`ITEMUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`KEYUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`MOUSEUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`PAINTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`paramString", 
        "java`awt`event`ComponentEvent`JPrivate`RESERVEDUIDUMAX", 
        "java`awt`event`ComponentEvent`JPrivate`TEXTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`WINDOWUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`JPrivate`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`event`ComponentEvent`KEYUEVENTUMASK", 
        "java`awt`event`ComponentEvent`MOUSEUEVENTUMASK", 
        "java`awt`event`ComponentEvent`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`ComponentEvent`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`ComponentEvent`PAINTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`RESERVEDUIDUMAX", 
        "java`awt`event`ComponentEvent`TEXTUEVENTUMASK", 
        "java`awt`event`ComponentEvent`WINDOWUEVENTUMASK", 
        "java`awt`event`ComponentEvent`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`ComponentEvent`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`event`InputEvent`ACTIONUEVENTUMASK", 
        "java`awt`event`InputEvent`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`InputEvent`ALTUDOWNUMASK", 
        "java`awt`event`InputEvent`ALTUGRAPHUDOWNUMASK", 
        "java`awt`event`InputEvent`ALTUGRAPHUMASK", 
        "java`awt`event`InputEvent`ALTUMASK", 
        "java`awt`event`InputEvent`BUTTON1UDOWNUMASK", 
        "java`awt`event`InputEvent`BUTTON1UMASK", 
        "java`awt`event`InputEvent`BUTTON2UDOWNUMASK", 
        "java`awt`event`InputEvent`BUTTON2UMASK", 
        "java`awt`event`InputEvent`BUTTON3UDOWNUMASK", 
        "java`awt`event`InputEvent`BUTTON3UMASK", 
        "java`awt`event`InputEvent`COMPONENTUEVENTUMASK", 
        "java`awt`event`InputEvent`COMPONENTUFIRST", 
        "java`awt`event`InputEvent`COMPONENTUHIDDEN", 
        "java`awt`event`InputEvent`COMPONENTULAST", 
        "java`awt`event`InputEvent`COMPONENTUMOVED", 
        "java`awt`event`InputEvent`COMPONENTURESIZED", 
        "java`awt`event`InputEvent`COMPONENTUSHOWN", 
        "java`awt`event`InputEvent`CONTAINERUEVENTUMASK", 
        "java`awt`event`InputEvent`CTRLUDOWNUMASK", 
        "java`awt`event`InputEvent`CTRLUMASK", 
        "java`awt`event`InputEvent`FOCUSUEVENTUMASK", 
        "java`awt`event`InputEvent`getModifiersExText", 
        "java`awt`event`InputEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`InputEvent`HIERARCHYUEVENTUMASK", 
        "java`awt`event`InputEvent`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`InputEvent`INVOCATIONUEVENTUMASK", 
        "java`awt`event`InputEvent`ITEMUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`ACTIONUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`ALTUDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`ALTUGRAPHUDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`ALTUGRAPHUMASK", 
        "java`awt`event`InputEvent`JPrivate`ALTUMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON1UDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON1UMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON2UDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON2UMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON3UDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`BUTTON3UMASK", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTUFIRST", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTUHIDDEN", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTULAST", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTUMOVED", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTURESIZED", 
        "java`awt`event`InputEvent`JPrivate`COMPONENTUSHOWN", 
        "java`awt`event`InputEvent`JPrivate`consume", 
        "java`awt`event`InputEvent`JPrivate`CONTAINERUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`CTRLUDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`CTRLUMASK", 
        "java`awt`event`InputEvent`JPrivate`FOCUSUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`getModifiers", 
        "java`awt`event`InputEvent`JPrivate`getModifiersEx", 
        "java`awt`event`InputEvent`JPrivate`getModifiersExText", 
        "java`awt`event`InputEvent`JPrivate`getWhen", 
        "java`awt`event`InputEvent`JPrivate`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`HIERARCHYUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`INVOCATIONUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`isAltDown", 
        "java`awt`event`InputEvent`JPrivate`isAltGraphDown", 
        "java`awt`event`InputEvent`JPrivate`isConsumed", 
        "java`awt`event`InputEvent`JPrivate`isControlDown", 
        "java`awt`event`InputEvent`JPrivate`isMetaDown", 
        "java`awt`event`InputEvent`JPrivate`isShiftDown", 
        "java`awt`event`InputEvent`JPrivate`ITEMUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`KEYUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`METAUDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`METAUMASK", 
        "java`awt`event`InputEvent`JPrivate`MOUSEUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`PAINTUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`RESERVEDUIDUMAX", 
        "java`awt`event`InputEvent`JPrivate`SHIFTUDOWNUMASK", 
        "java`awt`event`InputEvent`JPrivate`SHIFTUMASK", 
        "java`awt`event`InputEvent`JPrivate`TEXTUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`WINDOWUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`InputEvent`JPrivate`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`event`InputEvent`KEYUEVENTUMASK", 
        "java`awt`event`InputEvent`METAUDOWNUMASK", 
        "java`awt`event`InputEvent`METAUMASK", 
        "java`awt`event`InputEvent`MOUSEUEVENTUMASK", 
        "java`awt`event`InputEvent`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`InputEvent`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`InputEvent`PAINTUEVENTUMASK", 
        "java`awt`event`InputEvent`RESERVEDUIDUMAX", 
        "java`awt`event`InputEvent`SHIFTUDOWNUMASK", 
        "java`awt`event`InputEvent`SHIFTUMASK", 
        "java`awt`event`InputEvent`TEXTUEVENTUMASK", 
        "java`awt`event`InputEvent`WINDOWUEVENTUMASK", 
        "java`awt`event`InputEvent`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`InputEvent`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`event`MouseEvent`ACTIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`MouseEvent`ALTUDOWNUMASK", 
        "java`awt`event`MouseEvent`ALTUGRAPHUDOWNUMASK", 
        "java`awt`event`MouseEvent`ALTUGRAPHUMASK", 
        "java`awt`event`MouseEvent`ALTUMASK", 
        "java`awt`event`MouseEvent`BUTTON1", 
        "java`awt`event`MouseEvent`BUTTON1UDOWNUMASK", 
        "java`awt`event`MouseEvent`BUTTON1UMASK", 
        "java`awt`event`MouseEvent`BUTTON2", 
        "java`awt`event`MouseEvent`BUTTON2UDOWNUMASK", 
        "java`awt`event`MouseEvent`BUTTON2UMASK", 
        "java`awt`event`MouseEvent`BUTTON3", 
        "java`awt`event`MouseEvent`BUTTON3UDOWNUMASK", 
        "java`awt`event`MouseEvent`BUTTON3UMASK", 
        "java`awt`event`MouseEvent`COMPONENTUEVENTUMASK", 
        "java`awt`event`MouseEvent`COMPONENTUFIRST", 
        "java`awt`event`MouseEvent`COMPONENTUHIDDEN", 
        "java`awt`event`MouseEvent`COMPONENTULAST", 
        "java`awt`event`MouseEvent`COMPONENTUMOVED", 
        "java`awt`event`MouseEvent`COMPONENTURESIZED", 
        "java`awt`event`MouseEvent`COMPONENTUSHOWN", 
        "java`awt`event`MouseEvent`CONTAINERUEVENTUMASK", 
        "java`awt`event`MouseEvent`CTRLUDOWNUMASK", 
        "java`awt`event`MouseEvent`CTRLUMASK", 
        "java`awt`event`MouseEvent`FOCUSUEVENTUMASK", 
        "java`awt`event`MouseEvent`getModifiersExText", 
        "java`awt`event`MouseEvent`getMouseModifiersText", 
        "java`awt`event`MouseEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`MouseEvent`HIERARCHYUEVENTUMASK", 
        "java`awt`event`MouseEvent`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`MouseEvent`INVOCATIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`ITEMUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ACTIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ADJUSTMENTUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ALTUDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ALTUGRAPHUDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ALTUGRAPHUMASK", 
        "java`awt`event`MouseEvent`JPrivate`ALTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON1", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON1UDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON1UMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON2", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON2UDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON2UMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON3", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON3UDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`BUTTON3UMASK", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTUFIRST", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTUHIDDEN", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTULAST", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTUMOVED", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTURESIZED", 
        "java`awt`event`MouseEvent`JPrivate`COMPONENTUSHOWN", 
        "java`awt`event`MouseEvent`JPrivate`CONTAINERUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`CTRLUDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`CTRLUMASK", 
        "java`awt`event`MouseEvent`JPrivate`FOCUSUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`getButton", 
        "java`awt`event`MouseEvent`JPrivate`getClickCount", 
        "java`awt`event`MouseEvent`JPrivate`getModifiersExText", 
        "java`awt`event`MouseEvent`JPrivate`getMouseModifiersText", 
        "java`awt`event`MouseEvent`JPrivate`getPoint", 
        "java`awt`event`MouseEvent`JPrivate`getX", 
        "java`awt`event`MouseEvent`JPrivate`getY", 
        "java`awt`event`MouseEvent`JPrivate`HIERARCHYUBOUNDSUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`HIERARCHYUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`INPUTUMETHODUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`INVOCATIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`isMetaDown", 
        "java`awt`event`MouseEvent`JPrivate`isPopupTrigger", 
        "java`awt`event`MouseEvent`JPrivate`ITEMUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`KEYUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`METAUDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`METAUMASK", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUCLICKED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUDRAGGED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUENTERED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUEXITED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUFIRST", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEULAST", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUMOVED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUPRESSED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEURELEASED", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUWHEEL", 
        "java`awt`event`MouseEvent`JPrivate`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`NOBUTTON", 
        "java`awt`event`MouseEvent`JPrivate`PAINTUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`paramString", 
        "java`awt`event`MouseEvent`JPrivate`RESERVEDUIDUMAX", 
        "java`awt`event`MouseEvent`JPrivate`SHIFTUDOWNUMASK", 
        "java`awt`event`MouseEvent`JPrivate`SHIFTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`TEXTUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`translatePoint", 
        "java`awt`event`MouseEvent`JPrivate`WINDOWUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`MouseEvent`JPrivate`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`event`MouseEvent`KEYUEVENTUMASK", 
        "java`awt`event`MouseEvent`METAUDOWNUMASK", 
        "java`awt`event`MouseEvent`METAUMASK", 
        "java`awt`event`MouseEvent`MOUSEUCLICKED", 
        "java`awt`event`MouseEvent`MOUSEUDRAGGED", 
        "java`awt`event`MouseEvent`MOUSEUENTERED", 
        "java`awt`event`MouseEvent`MOUSEUEVENTUMASK", 
        "java`awt`event`MouseEvent`MOUSEUEXITED", 
        "java`awt`event`MouseEvent`MOUSEUFIRST", 
        "java`awt`event`MouseEvent`MOUSEULAST", 
        "java`awt`event`MouseEvent`MOUSEUMOTIONUEVENTUMASK", 
        "java`awt`event`MouseEvent`MOUSEUMOVED", 
        "java`awt`event`MouseEvent`MOUSEUPRESSED", 
        "java`awt`event`MouseEvent`MOUSEURELEASED", 
        "java`awt`event`MouseEvent`MOUSEUWHEEL", 
        "java`awt`event`MouseEvent`MOUSEUWHEELUEVENTUMASK", 
        "java`awt`event`MouseEvent`NOBUTTON", 
        "java`awt`event`MouseEvent`PAINTUEVENTUMASK", 
        "java`awt`event`MouseEvent`RESERVEDUIDUMAX", 
        "java`awt`event`MouseEvent`SHIFTUDOWNUMASK", 
        "java`awt`event`MouseEvent`SHIFTUMASK", 
        "java`awt`event`MouseEvent`TEXTUEVENTUMASK", 
        "java`awt`event`MouseEvent`WINDOWUEVENTUMASK", 
        "java`awt`event`MouseEvent`WINDOWUFOCUSUEVENTUMASK", 
        "java`awt`event`MouseEvent`WINDOWUSTATEUEVENTUMASK", 
        "java`awt`Frame`ABORT", "java`awt`Frame`ALLBITS", 
        "java`awt`Frame`BOTTOMUALIGNMENT", "java`awt`Frame`CENTERUALIGNMENT", 
        "java`awt`Frame`CROSSHAIRUCURSOR", "java`awt`Frame`DEFAULTUCURSOR", 
        "java`awt`Frame`ERROR", "java`awt`Frame`EURESIZEUCURSOR", 
        "java`awt`Frame`FRAMEBITS", "java`awt`Frame`getFrames", 
        "java`awt`Frame`HANDUCURSOR", "java`awt`Frame`HEIGHT", 
        "java`awt`Frame`ICONIFIED", "java`awt`Frame`JPrivate`ABORT", 
        "java`awt`Frame`JPrivate`addNotify", 
        "java`awt`Frame`JPrivate`ALLBITS", 
        "java`awt`Frame`JPrivate`BOTTOMUALIGNMENT", 
        "java`awt`Frame`JPrivate`CENTERUALIGNMENT", 
        "java`awt`Frame`JPrivate`CROSSHAIRUCURSOR", 
        "java`awt`Frame`JPrivate`DEFAULTUCURSOR", 
        "java`awt`Frame`JPrivate`ERROR", 
        "java`awt`Frame`JPrivate`EURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`FRAMEBITS", 
        "java`awt`Frame`JPrivate`getAccessibleContext", 
        "java`awt`Frame`JPrivate`getCursorType", 
        "java`awt`Frame`JPrivate`getExtendedState", 
        "java`awt`Frame`JPrivate`getFrames", 
        "java`awt`Frame`JPrivate`getIconImage", 
        "java`awt`Frame`JPrivate`getMaximizedBounds", 
        "java`awt`Frame`JPrivate`getMenuBar", 
        "java`awt`Frame`JPrivate`getState", 
        "java`awt`Frame`JPrivate`getTitle", 
        "java`awt`Frame`JPrivate`HANDUCURSOR", 
        "java`awt`Frame`JPrivate`HEIGHT", "java`awt`Frame`JPrivate`ICONIFIED",
         "java`awt`Frame`JPrivate`isResizable", 
        "java`awt`Frame`JPrivate`isUndecorated", 
        "java`awt`Frame`JPrivate`LEFTUALIGNMENT", 
        "java`awt`Frame`JPrivate`MAXIMIZEDUBOTH", 
        "java`awt`Frame`JPrivate`MAXIMIZEDUHORIZ", 
        "java`awt`Frame`JPrivate`MAXIMIZEDUVERT", 
        "java`awt`Frame`JPrivate`MOVEUCURSOR", 
        "java`awt`Frame`JPrivate`NEURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`NORMAL", 
        "java`awt`Frame`JPrivate`NURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`NWURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`PROPERTIES", 
        "java`awt`Frame`JPrivate`remove", 
        "java`awt`Frame`JPrivate`removeNotify", 
        "java`awt`Frame`JPrivate`RIGHTUALIGNMENT", 
        "java`awt`Frame`JPrivate`setBounds", 
        "java`awt`Frame`JPrivate`setCursor", 
        "java`awt`Frame`JPrivate`setExtendedState", 
        "java`awt`Frame`JPrivate`setIconImage", 
        "java`awt`Frame`JPrivate`setLocation", 
        "java`awt`Frame`JPrivate`setMaximizedBounds", 
        "java`awt`Frame`JPrivate`setMenuBar", 
        "java`awt`Frame`JPrivate`setResizable", 
        "java`awt`Frame`JPrivate`setSize", "java`awt`Frame`JPrivate`setState",
         "java`awt`Frame`JPrivate`setTitle", 
        "java`awt`Frame`JPrivate`setUndecorated", 
        "java`awt`Frame`JPrivate`setVisible", 
        "java`awt`Frame`JPrivate`SEURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`SOMEBITS", 
        "java`awt`Frame`JPrivate`SURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`SWURESIZEUCURSOR", 
        "java`awt`Frame`JPrivate`TEXTUCURSOR", 
        "java`awt`Frame`JPrivate`TOPUALIGNMENT", 
        "java`awt`Frame`JPrivate`WAITUCURSOR", 
        "java`awt`Frame`JPrivate`WIDTH", 
        "java`awt`Frame`JPrivate`WURESIZEUCURSOR", 
        "java`awt`Frame`LEFTUALIGNMENT", "java`awt`Frame`MAXIMIZEDUBOTH", 
        "java`awt`Frame`MAXIMIZEDUHORIZ", "java`awt`Frame`MAXIMIZEDUVERT", 
        "java`awt`Frame`MOVEUCURSOR", "java`awt`Frame`NEURESIZEUCURSOR", 
        "java`awt`Frame`NORMAL", "java`awt`Frame`NURESIZEUCURSOR", 
        "java`awt`Frame`NWURESIZEUCURSOR", "java`awt`Frame`PROPERTIES", 
        "java`awt`Frame`RIGHTUALIGNMENT", "java`awt`Frame`SEURESIZEUCURSOR", 
        "java`awt`Frame`SOMEBITS", "java`awt`Frame`SURESIZEUCURSOR", 
        "java`awt`Frame`SWURESIZEUCURSOR", "java`awt`Frame`TEXTUCURSOR", 
        "java`awt`Frame`TOPUALIGNMENT", "java`awt`Frame`WAITUCURSOR", 
        "java`awt`Frame`WIDTH", "java`awt`Frame`WURESIZEUCURSOR", 
        "java`awt`Graphics2D`JPrivate`addRenderingHints", 
        "java`awt`Graphics2D`JPrivate`clip", 
        "java`awt`Graphics2D`JPrivate`draw", 
        "java`awt`Graphics2D`JPrivate`draw3DRect", 
        "java`awt`Graphics2D`JPrivate`drawGlyphVector", 
        "java`awt`Graphics2D`JPrivate`drawImage", 
        "java`awt`Graphics2D`JPrivate`drawRenderableImage", 
        "java`awt`Graphics2D`JPrivate`drawRenderedImage", 
        "java`awt`Graphics2D`JPrivate`drawString", 
        "java`awt`Graphics2D`JPrivate`fill", 
        "java`awt`Graphics2D`JPrivate`fill3DRect", 
        "java`awt`Graphics2D`JPrivate`getBackground", 
        "java`awt`Graphics2D`JPrivate`getComposite", 
        "java`awt`Graphics2D`JPrivate`getDeviceConfiguration", 
        "java`awt`Graphics2D`JPrivate`getFontRenderContext", 
        "java`awt`Graphics2D`JPrivate`getPaint", 
        "java`awt`Graphics2D`JPrivate`getRenderingHint", 
        "java`awt`Graphics2D`JPrivate`getRenderingHints", 
        "java`awt`Graphics2D`JPrivate`getStroke", 
        "java`awt`Graphics2D`JPrivate`getTransform", 
        "java`awt`Graphics2D`JPrivate`hit", 
        "java`awt`Graphics2D`JPrivate`rotate", 
        "java`awt`Graphics2D`JPrivate`scale", 
        "java`awt`Graphics2D`JPrivate`setBackground", 
        "java`awt`Graphics2D`JPrivate`setComposite", 
        "java`awt`Graphics2D`JPrivate`setPaint", 
        "java`awt`Graphics2D`JPrivate`setRenderingHint", 
        "java`awt`Graphics2D`JPrivate`setRenderingHints", 
        "java`awt`Graphics2D`JPrivate`setStroke", 
        "java`awt`Graphics2D`JPrivate`setTransform", 
        "java`awt`Graphics2D`JPrivate`shear", 
        "java`awt`Graphics2D`JPrivate`transform", 
        "java`awt`Graphics2D`JPrivate`translate", 
        "java`awt`Graphics`JPrivate`clearRect", 
        "java`awt`Graphics`JPrivate`clipRect", 
        "java`awt`Graphics`JPrivate`copyArea", 
        "java`awt`Graphics`JPrivate`create", 
        "java`awt`Graphics`JPrivate`dispose", 
        "java`awt`Graphics`JPrivate`draw3DRect", 
        "java`awt`Graphics`JPrivate`drawArc", 
        "java`awt`Graphics`JPrivate`drawBytes", 
        "java`awt`Graphics`JPrivate`drawChars", 
        "java`awt`Graphics`JPrivate`drawImage", 
        "java`awt`Graphics`JPrivate`drawLine", 
        "java`awt`Graphics`JPrivate`drawOval", 
        "java`awt`Graphics`JPrivate`drawPolygon", 
        "java`awt`Graphics`JPrivate`drawPolyline", 
        "java`awt`Graphics`JPrivate`drawRect", 
        "java`awt`Graphics`JPrivate`drawRoundRect", 
        "java`awt`Graphics`JPrivate`drawString", 
        "java`awt`Graphics`JPrivate`fill3DRect", 
        "java`awt`Graphics`JPrivate`fillArc", 
        "java`awt`Graphics`JPrivate`fillOval", 
        "java`awt`Graphics`JPrivate`fillPolygon", 
        "java`awt`Graphics`JPrivate`fillRect", 
        "java`awt`Graphics`JPrivate`fillRoundRect", 
        "java`awt`Graphics`JPrivate`finalize", 
        "java`awt`Graphics`JPrivate`getClip", 
        "java`awt`Graphics`JPrivate`getClipBounds", 
        "java`awt`Graphics`JPrivate`getClipRect", 
        "java`awt`Graphics`JPrivate`getColor", 
        "java`awt`Graphics`JPrivate`getFont", 
        "java`awt`Graphics`JPrivate`getFontMetrics", 
        "java`awt`Graphics`JPrivate`hitClip", 
        "java`awt`Graphics`JPrivate`setClip", 
        "java`awt`Graphics`JPrivate`setColor", 
        "java`awt`Graphics`JPrivate`setFont", 
        "java`awt`Graphics`JPrivate`setPaintMode", 
        "java`awt`Graphics`JPrivate`setXORMode", 
        "java`awt`Graphics`JPrivate`toString", 
        "java`awt`Graphics`JPrivate`translate", 
        "java`awt`image`BufferedImage`JPrivate`addTileObserver", 
        "java`awt`image`BufferedImage`JPrivate`coerceData", 
        "java`awt`image`BufferedImage`JPrivate`copyData", 
        "java`awt`image`BufferedImage`JPrivate`createGraphics", 
        "java`awt`image`BufferedImage`JPrivate`flush", 
        "java`awt`image`BufferedImage`JPrivate`getAlphaRaster", 
        "java`awt`image`BufferedImage`JPrivate`getColorModel", 
        "java`awt`image`BufferedImage`JPrivate`getData", 
        "java`awt`image`BufferedImage`JPrivate`getGraphics", 
        "java`awt`image`BufferedImage`JPrivate`getHeight", 
        "java`awt`image`BufferedImage`JPrivate`getMinTileX", 
        "java`awt`image`BufferedImage`JPrivate`getMinTileY", 
        "java`awt`image`BufferedImage`JPrivate`getMinX", 
        "java`awt`image`BufferedImage`JPrivate`getMinY", 
        "java`awt`image`BufferedImage`JPrivate`getNumXTiles", 
        "java`awt`image`BufferedImage`JPrivate`getNumYTiles", 
        "java`awt`image`BufferedImage`JPrivate`getProperty", 
        "java`awt`image`BufferedImage`JPrivate`getPropertyNames", 
        "java`awt`image`BufferedImage`JPrivate`getRaster", 
        "java`awt`image`BufferedImage`JPrivate`getRGB", 
        "java`awt`image`BufferedImage`JPrivate`getSampleModel", 
        "java`awt`image`BufferedImage`JPrivate`getSource", 
        "java`awt`image`BufferedImage`JPrivate`getSources", 
        "java`awt`image`BufferedImage`JPrivate`getSubimage", 
        "java`awt`image`BufferedImage`JPrivate`getTile", 
        "java`awt`image`BufferedImage`JPrivate`getTileGridXOffset", 
        "java`awt`image`BufferedImage`JPrivate`getTileGridYOffset", 
        "java`awt`image`BufferedImage`JPrivate`getTileHeight", 
        "java`awt`image`BufferedImage`JPrivate`getTileWidth", 
        "java`awt`image`BufferedImage`JPrivate`getType", 
        "java`awt`image`BufferedImage`JPrivate`getWidth", 
        "java`awt`image`BufferedImage`JPrivate`getWritableTile", 
        "java`awt`image`BufferedImage`JPrivate`getWritableTileIndices", 
        "java`awt`image`BufferedImage`JPrivate`hasTileWriters", 
        "java`awt`image`BufferedImage`JPrivate`isAlphaPremultiplied", 
        "java`awt`image`BufferedImage`JPrivate`isTileWritable", 
        "java`awt`image`BufferedImage`JPrivate`releaseWritableTile", 
        "java`awt`image`BufferedImage`JPrivate`removeTileObserver", 
        "java`awt`image`BufferedImage`JPrivate`SCALEUAREAUAVERAGING", 
        "java`awt`image`BufferedImage`JPrivate`SCALEUDEFAULT", 
        "java`awt`image`BufferedImage`JPrivate`SCALEUFAST", 
        "java`awt`image`BufferedImage`JPrivate`SCALEUREPLICATE", 
        "java`awt`image`BufferedImage`JPrivate`SCALEUSMOOTH", 
        "java`awt`image`BufferedImage`JPrivate`setData", 
        "java`awt`image`BufferedImage`JPrivate`setRGB", 
        "java`awt`image`BufferedImage`JPrivate`toString", 
        "java`awt`image`BufferedImage`JPrivate`TYPEU3BYTEUBGR", 
        "java`awt`image`BufferedImage`JPrivate`TYPEU4BYTEUABGR", 
        "java`awt`image`BufferedImage`JPrivate`TYPEU4BYTEUABGRUPRE", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUBINARY", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUGRAY", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUBYTEUINDEXED", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUCUSTOM", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUINTUARGB", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUINTUARGBUPRE", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUINTUBGR", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUINTURGB", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTU555URGB", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTU565URGB", 
        "java`awt`image`BufferedImage`JPrivate`TYPEUUSHORTUGRAY", 
        "java`awt`image`BufferedImage`JPrivate`UndefinedProperty", 
        "java`awt`image`BufferedImage`SCALEUAREAUAVERAGING", 
        "java`awt`image`BufferedImage`SCALEUDEFAULT", 
        "java`awt`image`BufferedImage`SCALEUFAST", 
        "java`awt`image`BufferedImage`SCALEUREPLICATE", 
        "java`awt`image`BufferedImage`SCALEUSMOOTH", 
        "java`awt`image`BufferedImage`TYPEU3BYTEUBGR", 
        "java`awt`image`BufferedImage`TYPEU4BYTEUABGR", 
        "java`awt`image`BufferedImage`TYPEU4BYTEUABGRUPRE", 
        "java`awt`image`BufferedImage`TYPEUBYTEUBINARY", 
        "java`awt`image`BufferedImage`TYPEUBYTEUGRAY", 
        "java`awt`image`BufferedImage`TYPEUBYTEUINDEXED", 
        "java`awt`image`BufferedImage`TYPEUCUSTOM", 
        "java`awt`image`BufferedImage`TYPEUINTUARGB", 
        "java`awt`image`BufferedImage`TYPEUINTUARGBUPRE", 
        "java`awt`image`BufferedImage`TYPEUINTUBGR", 
        "java`awt`image`BufferedImage`TYPEUINTURGB", 
        "java`awt`image`BufferedImage`TYPEUUSHORTU555URGB", 
        "java`awt`image`BufferedImage`TYPEUUSHORTU565URGB", 
        "java`awt`image`BufferedImage`TYPEUUSHORTUGRAY", 
        "java`awt`image`BufferedImage`UndefinedProperty", 
        "java`awt`Image`JPrivate`flush", 
        "java`awt`Image`JPrivate`getGraphics", 
        "java`awt`Image`JPrivate`getHeight", 
        "java`awt`Image`JPrivate`getProperty", 
        "java`awt`Image`JPrivate`getScaledInstance", 
        "java`awt`Image`JPrivate`getSource", 
        "java`awt`Image`JPrivate`getWidth", 
        "java`awt`Image`JPrivate`SCALEUAREAUAVERAGING", 
        "java`awt`Image`JPrivate`SCALEUDEFAULT", 
        "java`awt`Image`JPrivate`SCALEUFAST", 
        "java`awt`Image`JPrivate`SCALEUREPLICATE", 
        "java`awt`Image`JPrivate`SCALEUSMOOTH", 
        "java`awt`Image`JPrivate`UndefinedProperty", 
        "java`awt`Image`SCALEUAREAUAVERAGING", "java`awt`Image`SCALEUDEFAULT",
         "java`awt`Image`SCALEUFAST", "java`awt`Image`SCALEUREPLICATE", 
        "java`awt`Image`SCALEUSMOOTH", "java`awt`Image`UndefinedProperty", 
        "java`awt`Scrollbar`ABORT", "java`awt`Scrollbar`ALLBITS", 
        "java`awt`Scrollbar`BOTTOMUALIGNMENT", 
        "java`awt`Scrollbar`CENTERUALIGNMENT", "java`awt`Scrollbar`ERROR", 
        "java`awt`Scrollbar`FRAMEBITS", "java`awt`Scrollbar`HEIGHT", 
        "java`awt`Scrollbar`HORIZONTAL", "java`awt`Scrollbar`JPrivate`ABORT", 
        "java`awt`Scrollbar`JPrivate`addAdjustmentListener", 
        "java`awt`Scrollbar`JPrivate`addNotify", 
        "java`awt`Scrollbar`JPrivate`ALLBITS", 
        "java`awt`Scrollbar`JPrivate`BOTTOMUALIGNMENT", 
        "java`awt`Scrollbar`JPrivate`CENTERUALIGNMENT", 
        "java`awt`Scrollbar`JPrivate`ERROR", 
        "java`awt`Scrollbar`JPrivate`FRAMEBITS", 
        "java`awt`Scrollbar`JPrivate`getAccessibleContext", 
        "java`awt`Scrollbar`JPrivate`getAdjustmentListeners", 
        "java`awt`Scrollbar`JPrivate`getBlockIncrement", 
        "java`awt`Scrollbar`JPrivate`getLineIncrement", 
        "java`awt`Scrollbar`JPrivate`getListeners", 
        "java`awt`Scrollbar`JPrivate`getMaximum", 
        "java`awt`Scrollbar`JPrivate`getMinimum", 
        "java`awt`Scrollbar`JPrivate`getOrientation", 
        "java`awt`Scrollbar`JPrivate`getPageIncrement", 
        "java`awt`Scrollbar`JPrivate`getUnitIncrement", 
        "java`awt`Scrollbar`JPrivate`getValue", 
        "java`awt`Scrollbar`JPrivate`getValueIsAdjusting", 
        "java`awt`Scrollbar`JPrivate`getVisible", 
        "java`awt`Scrollbar`JPrivate`getVisibleAmount", 
        "java`awt`Scrollbar`JPrivate`HEIGHT", 
        "java`awt`Scrollbar`JPrivate`HORIZONTAL", 
        "java`awt`Scrollbar`JPrivate`LEFTUALIGNMENT", 
        "java`awt`Scrollbar`JPrivate`NOUORIENTATION", 
        "java`awt`Scrollbar`JPrivate`PROPERTIES", 
        "java`awt`Scrollbar`JPrivate`removeAdjustmentListener", 
        "java`awt`Scrollbar`JPrivate`RIGHTUALIGNMENT", 
        "java`awt`Scrollbar`JPrivate`setBlockIncrement", 
        "java`awt`Scrollbar`JPrivate`setLineIncrement", 
        "java`awt`Scrollbar`JPrivate`setMaximum", 
        "java`awt`Scrollbar`JPrivate`setMinimum", 
        "java`awt`Scrollbar`JPrivate`setOrientation", 
        "java`awt`Scrollbar`JPrivate`setPageIncrement", 
        "java`awt`Scrollbar`JPrivate`setUnitIncrement", 
        "java`awt`Scrollbar`JPrivate`setValue", 
        "java`awt`Scrollbar`JPrivate`setValueIsAdjusting", 
        "java`awt`Scrollbar`JPrivate`setValues", 
        "java`awt`Scrollbar`JPrivate`setVisibleAmount", 
        "java`awt`Scrollbar`JPrivate`SOMEBITS", 
        "java`awt`Scrollbar`JPrivate`TOPUALIGNMENT", 
        "java`awt`Scrollbar`JPrivate`VERTICAL", 
        "java`awt`Scrollbar`JPrivate`WIDTH", 
        "java`awt`Scrollbar`LEFTUALIGNMENT", 
        "java`awt`Scrollbar`NOUORIENTATION", "java`awt`Scrollbar`PROPERTIES", 
        "java`awt`Scrollbar`RIGHTUALIGNMENT", "java`awt`Scrollbar`SOMEBITS", 
        "java`awt`Scrollbar`TOPUALIGNMENT", "java`awt`Scrollbar`VERTICAL", 
        "java`awt`Scrollbar`WIDTH", "java`awt`Window`ABORT", 
        "java`awt`Window`ALLBITS", "java`awt`Window`BOTTOMUALIGNMENT", 
        "java`awt`Window`CENTERUALIGNMENT", "java`awt`Window`ERROR", 
        "java`awt`Window`FRAMEBITS", "java`awt`Window`HEIGHT", 
        "java`awt`Window`JPrivate`ABORT", 
        "java`awt`Window`JPrivate`addNotify", 
        "java`awt`Window`JPrivate`addPropertyChangeListener", 
        "java`awt`Window`JPrivate`addWindowFocusListener", 
        "java`awt`Window`JPrivate`addWindowListener", 
        "java`awt`Window`JPrivate`addWindowStateListener", 
        "java`awt`Window`JPrivate`ALLBITS", 
        "java`awt`Window`JPrivate`applyResourceBundle", 
        "java`awt`Window`JPrivate`BOTTOMUALIGNMENT", 
        "java`awt`Window`JPrivate`CENTERUALIGNMENT", 
        "java`awt`Window`JPrivate`createBufferStrategy", 
        "java`awt`Window`JPrivate`dispose", "java`awt`Window`JPrivate`ERROR", 
        "java`awt`Window`JPrivate`FRAMEBITS", 
        "java`awt`Window`JPrivate`getAccessibleContext", 
        "java`awt`Window`JPrivate`getBufferStrategy", 
        "java`awt`Window`JPrivate`getFocusableWindowState", 
        "java`awt`Window`JPrivate`getFocusCycleRootAncestor", 
        "java`awt`Window`JPrivate`getFocusOwner", 
        "java`awt`Window`JPrivate`getFocusTraversalKeys", 
        "java`awt`Window`JPrivate`getGraphicsConfiguration", 
        "java`awt`Window`JPrivate`getInputContext", 
        "java`awt`Window`JPrivate`getListeners", 
        "java`awt`Window`JPrivate`getLocale", 
        "java`awt`Window`JPrivate`getMostRecentFocusOwner", 
        "java`awt`Window`JPrivate`getOwnedWindows", 
        "java`awt`Window`JPrivate`getOwner", 
        "java`awt`Window`JPrivate`getToolkit", 
        "java`awt`Window`JPrivate`getWarningString", 
        "java`awt`Window`JPrivate`getWindowFocusListeners", 
        "java`awt`Window`JPrivate`getWindowListeners", 
        "java`awt`Window`JPrivate`getWindowStateListeners", 
        "java`awt`Window`JPrivate`HEIGHT", "java`awt`Window`JPrivate`hide", 
        "java`awt`Window`JPrivate`isActive", 
        "java`awt`Window`JPrivate`isFocusableWindow", 
        "java`awt`Window`JPrivate`isFocusCycleRoot", 
        "java`awt`Window`JPrivate`isFocused", 
        "java`awt`Window`JPrivate`isShowing", 
        "java`awt`Window`JPrivate`LEFTUALIGNMENT", 
        "java`awt`Window`JPrivate`pack", "java`awt`Window`JPrivate`postEvent",
         "java`awt`Window`JPrivate`PROPERTIES", 
        "java`awt`Window`JPrivate`removeWindowFocusListener", 
        "java`awt`Window`JPrivate`removeWindowListener", 
        "java`awt`Window`JPrivate`removeWindowStateListener", 
        "java`awt`Window`JPrivate`RIGHTUALIGNMENT", 
        "java`awt`Window`JPrivate`setBounds", 
        "java`awt`Window`JPrivate`setCursor", 
        "java`awt`Window`JPrivate`setFocusableWindowState", 
        "java`awt`Window`JPrivate`setFocusCycleRoot", 
        "java`awt`Window`JPrivate`setLocation", 
        "java`awt`Window`JPrivate`setLocationRelativeTo", 
        "java`awt`Window`JPrivate`setSize", 
        "java`awt`Window`JPrivate`setVisible", 
        "java`awt`Window`JPrivate`show", "java`awt`Window`JPrivate`SOMEBITS", 
        "java`awt`Window`JPrivate`toBack", "java`awt`Window`JPrivate`toFront",
         "java`awt`Window`JPrivate`TOPUALIGNMENT", 
        "java`awt`Window`JPrivate`WIDTH", "java`awt`Window`LEFTUALIGNMENT", 
        "java`awt`Window`PROPERTIES", "java`awt`Window`RIGHTUALIGNMENT", 
        "java`awt`Window`SOMEBITS", "java`awt`Window`TOPUALIGNMENT", 
        "java`awt`Window`WIDTH", "JavaBlock", "JavaClass", "JavaClassPath", 
        "JavaGC", "java`lang`Object`JPrivate`equals", 
        "java`lang`Object`JPrivate`getClass", 
        "java`lang`Object`JPrivate`hashCode", 
        "java`lang`Object`JPrivate`notify", 
        "java`lang`Object`JPrivate`notifyAll", 
        "java`lang`Object`JPrivate`toString", 
        "java`lang`Object`JPrivate`wait", "java`lang`System`arraycopy", 
        "java`lang`System`currentTimeMillis", "java`lang`System`err", 
        "java`lang`System`exit", "java`lang`System`gc", 
        "java`lang`System`getenv", "java`lang`System`getProperties", 
        "java`lang`System`getProperty", "java`lang`System`getSecurityManager",
         "java`lang`System`identityHashCode", "java`lang`System`in", 
        "java`lang`System`JPrivate`arraycopy", 
        "java`lang`System`JPrivate`currentTimeMillis", 
        "java`lang`System`JPrivate`err", "java`lang`System`JPrivate`exit", 
        "java`lang`System`JPrivate`gc", "java`lang`System`JPrivate`getenv", 
        "java`lang`System`JPrivate`getProperties", 
        "java`lang`System`JPrivate`getProperty", 
        "java`lang`System`JPrivate`getSecurityManager", 
        "java`lang`System`JPrivate`identityHashCode", 
        "java`lang`System`JPrivate`in", "java`lang`System`JPrivate`load", 
        "java`lang`System`JPrivate`loadLibrary", 
        "java`lang`System`JPrivate`mapLibraryName", 
        "java`lang`System`JPrivate`out", 
        "java`lang`System`JPrivate`runFinalization", 
        "java`lang`System`JPrivate`runFinalizersOnExit", 
        "java`lang`System`JPrivate`setErr", "java`lang`System`JPrivate`setIn",
         "java`lang`System`JPrivate`setOut", 
        "java`lang`System`JPrivate`setProperties", 
        "java`lang`System`JPrivate`setProperty", 
        "java`lang`System`JPrivate`setSecurityManager", 
        "java`lang`System`load", "java`lang`System`loadLibrary", 
        "java`lang`System`mapLibraryName", "java`lang`System`out", 
        "java`lang`System`runFinalization", 
        "java`lang`System`runFinalizersOnExit", "java`lang`System`setErr", 
        "java`lang`System`setIn", "java`lang`System`setOut", 
        "java`lang`System`setProperties", "java`lang`System`setProperty", 
        "java`lang`System`setSecurityManager", "JavaLink", "JavaNew", 
        "JavaObject", "JavaObjectQ", "JavaObjectToExpression", "JavaShow", 
        "JavaThrow", "JavaUILink", "java`util`EventObject`JPrivate`getSource",
         "java`util`EventObject`JPrivate`toString", 
        "javax`swing`JComponent`ABORT", "javax`swing`JComponent`ALLBITS", 
        "javax`swing`JComponent`BOTTOMUALIGNMENT", 
        "javax`swing`JComponent`CENTERUALIGNMENT", 
        "javax`swing`JComponent`ERROR", "javax`swing`JComponent`FRAMEBITS", 
        "javax`swing`JComponent`getDefaultLocale", 
        "javax`swing`JComponent`HEIGHT", 
        "javax`swing`JComponent`isLightweightComponent", 
        "javax`swing`JComponent`JPrivate`ABORT", 
        "javax`swing`JComponent`JPrivate`add", 
        "javax`swing`JComponent`JPrivate`addAncestorListener", 
        "javax`swing`JComponent`JPrivate`addMouseListener", 
        "javax`swing`JComponent`JPrivate`addNotify", 
        "javax`swing`JComponent`JPrivate`addPropertyChangeListener", 
        "javax`swing`JComponent`JPrivate`addVetoableChangeListener", 
        "javax`swing`JComponent`JPrivate`ALLBITS", 
        "javax`swing`JComponent`JPrivate`BOTTOMUALIGNMENT", 
        "javax`swing`JComponent`JPrivate`CENTERUALIGNMENT", 
        "javax`swing`JComponent`JPrivate`computeVisibleRect", 
        "javax`swing`JComponent`JPrivate`contains", 
        "javax`swing`JComponent`JPrivate`createImage", 
        "javax`swing`JComponent`JPrivate`createToolTip", 
        "javax`swing`JComponent`JPrivate`disable", 
        "javax`swing`JComponent`JPrivate`enable", 
        "javax`swing`JComponent`JPrivate`ERROR", 
        "javax`swing`JComponent`JPrivate`firePropertyChange", 
        "javax`swing`JComponent`JPrivate`FRAMEBITS", 
        "javax`swing`JComponent`JPrivate`getAccessibleContext", 
        "javax`swing`JComponent`JPrivate`getActionForKeyStroke", 
        "javax`swing`JComponent`JPrivate`getActionMap", 
        "javax`swing`JComponent`JPrivate`getAlignmentX", 
        "javax`swing`JComponent`JPrivate`getAlignmentY", 
        "javax`swing`JComponent`JPrivate`getAncestorListeners", 
        "javax`swing`JComponent`JPrivate`getAutoscrolls", 
        "javax`swing`JComponent`JPrivate`getBorder", 
        "javax`swing`JComponent`JPrivate`getBounds", 
        "javax`swing`JComponent`JPrivate`getClientProperty", 
        "javax`swing`JComponent`JPrivate`getConditionForKeyStroke", 
        "javax`swing`JComponent`JPrivate`getDebugGraphicsOptions", 
        "javax`swing`JComponent`JPrivate`getDefaultLocale", 
        "javax`swing`JComponent`JPrivate`getGraphics", 
        "javax`swing`JComponent`JPrivate`getHeight", 
        "javax`swing`JComponent`JPrivate`getInputMap", 
        "javax`swing`JComponent`JPrivate`getInputVerifier", 
        "javax`swing`JComponent`JPrivate`getInsets", 
        "javax`swing`JComponent`JPrivate`getListeners", 
        "javax`swing`JComponent`JPrivate`getLocation", 
        "javax`swing`JComponent`JPrivate`getMaximumSize", 
        "javax`swing`JComponent`JPrivate`getMinimumSize", 
        "javax`swing`JComponent`JPrivate`getNextFocusableComponent", 
        "javax`swing`JComponent`JPrivate`getPreferredSize", 
        "javax`swing`JComponent`JPrivate`getPropertyChangeListeners", 
        "javax`swing`JComponent`JPrivate`getRegisteredKeyStrokes", 
        "javax`swing`JComponent`JPrivate`getRootPane", 
        "javax`swing`JComponent`JPrivate`getSize", 
        "javax`swing`JComponent`JPrivate`getToolTipLocation", 
        "javax`swing`JComponent`JPrivate`getToolTipText", 
        "javax`swing`JComponent`JPrivate`getTopLevelAncestor", 
        "javax`swing`JComponent`JPrivate`getTransferHandler", 
        "javax`swing`JComponent`JPrivate`getUIClassID", 
        "javax`swing`JComponent`JPrivate`getVerifyInputWhenFocusTarget", 
        "javax`swing`JComponent`JPrivate`getVetoableChangeListeners", 
        "javax`swing`JComponent`JPrivate`getVisibleRect", 
        "javax`swing`JComponent`JPrivate`getWidth", 
        "javax`swing`JComponent`JPrivate`getX", 
        "javax`swing`JComponent`JPrivate`getY", 
        "javax`swing`JComponent`JPrivate`grabFocus", 
        "javax`swing`JComponent`JPrivate`HEIGHT", 
        "javax`swing`JComponent`JPrivate`isDoubleBuffered", 
        "javax`swing`JComponent`JPrivate`isLightweightComponent", 
        "javax`swing`JComponent`JPrivate`isManagingFocus", 
        "javax`swing`JComponent`JPrivate`isMaximumSizeSet", 
        "javax`swing`JComponent`JPrivate`isMinimumSizeSet", 
        "javax`swing`JComponent`JPrivate`isOpaque", 
        "javax`swing`JComponent`JPrivate`isOptimizedDrawingEnabled", 
        "javax`swing`JComponent`JPrivate`isPaintingTile", 
        "javax`swing`JComponent`JPrivate`isPreferredSizeSet", 
        "javax`swing`JComponent`JPrivate`isRequestFocusEnabled", 
        "javax`swing`JComponent`JPrivate`isValidateRoot", 
        "javax`swing`JComponent`JPrivate`LEFTUALIGNMENT", 
        "javax`swing`JComponent`JPrivate`paint", 
        "javax`swing`JComponent`JPrivate`paintImmediately", 
        "javax`swing`JComponent`JPrivate`print", 
        "javax`swing`JComponent`JPrivate`printAll", 
        "javax`swing`JComponent`JPrivate`PROPERTIES", 
        "javax`swing`JComponent`JPrivate`putClientProperty", 
        "javax`swing`JComponent`JPrivate`registerKeyboardAction", 
        "javax`swing`JComponent`JPrivate`removeAncestorListener", 
        "javax`swing`JComponent`JPrivate`removeNotify", 
        "javax`swing`JComponent`JPrivate`removePropertyChangeListener", 
        "javax`swing`JComponent`JPrivate`removeVetoableChangeListener", 
        "javax`swing`JComponent`JPrivate`repaint", 
        "javax`swing`JComponent`JPrivate`requestDefaultFocus", 
        "javax`swing`JComponent`JPrivate`requestFocus", 
        "javax`swing`JComponent`JPrivate`requestFocusInWindow", 
        "javax`swing`JComponent`JPrivate`resetKeyboardActions", 
        "javax`swing`JComponent`JPrivate`reshape", 
        "javax`swing`JComponent`JPrivate`revalidate", 
        "javax`swing`JComponent`JPrivate`RIGHTUALIGNMENT", 
        "javax`swing`JComponent`JPrivate`scrollRectToVisible", 
        "javax`swing`JComponent`JPrivate`setActionMap", 
        "javax`swing`JComponent`JPrivate`setAlignmentX", 
        "javax`swing`JComponent`JPrivate`setAlignmentY", 
        "javax`swing`JComponent`JPrivate`setAutoscrolls", 
        "javax`swing`JComponent`JPrivate`setBackground", 
        "javax`swing`JComponent`JPrivate`setBorder", 
        "javax`swing`JComponent`JPrivate`setBounds", 
        "javax`swing`JComponent`JPrivate`setDebugGraphicsOptions", 
        "javax`swing`JComponent`JPrivate`setDefaultLocale", 
        "javax`swing`JComponent`JPrivate`setDoubleBuffered", 
        "javax`swing`JComponent`JPrivate`setEnabled", 
        "javax`swing`JComponent`JPrivate`setFont", 
        "javax`swing`JComponent`JPrivate`setForeground", 
        "javax`swing`JComponent`JPrivate`setInputMap", 
        "javax`swing`JComponent`JPrivate`setInputVerifier", 
        "javax`swing`JComponent`JPrivate`setLayout", 
        "javax`swing`JComponent`JPrivate`setMaximumSize", 
        "javax`swing`JComponent`JPrivate`setMinimumSize", 
        "javax`swing`JComponent`JPrivate`setNextFocusableComponent", 
        "javax`swing`JComponent`JPrivate`setOpaque", 
        "javax`swing`JComponent`JPrivate`setPreferredSize", 
        "javax`swing`JComponent`JPrivate`setRequestFocusEnabled", 
        "javax`swing`JComponent`JPrivate`setToolTipText", 
        "javax`swing`JComponent`JPrivate`setTransferHandler", 
        "javax`swing`JComponent`JPrivate`setVerifyInputWhenFocusTarget", 
        "javax`swing`JComponent`JPrivate`setVisible", 
        "javax`swing`JComponent`JPrivate`SOMEBITS", 
        "javax`swing`JComponent`JPrivate`TOOLUTIPUTEXTUKEY", 
        "javax`swing`JComponent`JPrivate`TOPUALIGNMENT", 
        "javax`swing`JComponent`JPrivate`UNDEFINEDUCONDITION", 
        "javax`swing`JComponent`JPrivate`unregisterKeyboardAction", 
        "javax`swing`JComponent`JPrivate`update", 
        "javax`swing`JComponent`JPrivate`updateUI", 
        "javax`swing`JComponent`JPrivate`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "javax`swing`JComponent`JPrivate`WHENUFOCUSED", 
        "javax`swing`JComponent`JPrivate`WHENUINUFOCUSEDUWINDOW", 
        "javax`swing`JComponent`JPrivate`WIDTH", 
        "javax`swing`JComponent`LEFTUALIGNMENT", 
        "javax`swing`JComponent`PROPERTIES", 
        "javax`swing`JComponent`RIGHTUALIGNMENT", 
        "javax`swing`JComponent`setDefaultLocale", 
        "javax`swing`JComponent`SOMEBITS", 
        "javax`swing`JComponent`TOOLUTIPUTEXTUKEY", 
        "javax`swing`JComponent`TOPUALIGNMENT", 
        "javax`swing`JComponent`UNDEFINEDUCONDITION", 
        "javax`swing`JComponent`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "javax`swing`JComponent`WHENUFOCUSED", 
        "javax`swing`JComponent`WHENUINUFOCUSEDUWINDOW", 
        "javax`swing`JComponent`WIDTH", "javax`swing`JFrame`ABORT", 
        "javax`swing`JFrame`ALLBITS", "javax`swing`JFrame`BOTTOMUALIGNMENT", 
        "javax`swing`JFrame`CENTERUALIGNMENT", 
        "javax`swing`JFrame`CROSSHAIRUCURSOR", 
        "javax`swing`JFrame`DEFAULTUCURSOR", 
        "javax`swing`JFrame`DISPOSEUONUCLOSE", 
        "javax`swing`JFrame`DOUNOTHINGUONUCLOSE", "javax`swing`JFrame`ERROR", 
        "javax`swing`JFrame`EURESIZEUCURSOR", 
        "javax`swing`JFrame`EXITUONUCLOSE", "javax`swing`JFrame`FRAMEBITS", 
        "javax`swing`JFrame`getFrames", "javax`swing`JFrame`HANDUCURSOR", 
        "javax`swing`JFrame`HEIGHT", "javax`swing`JFrame`HIDEUONUCLOSE", 
        "javax`swing`JFrame`ICONIFIED", 
        "javax`swing`JFrame`isDefaultLookAndFeelDecorated", 
        "javax`swing`JFrame`JPrivate`ABORT", 
        "javax`swing`JFrame`JPrivate`ALLBITS", 
        "javax`swing`JFrame`JPrivate`BOTTOMUALIGNMENT", 
        "javax`swing`JFrame`JPrivate`CENTERUALIGNMENT", 
        "javax`swing`JFrame`JPrivate`CROSSHAIRUCURSOR", 
        "javax`swing`JFrame`JPrivate`DEFAULTUCURSOR", 
        "javax`swing`JFrame`JPrivate`DISPOSEUONUCLOSE", 
        "javax`swing`JFrame`JPrivate`DOUNOTHINGUONUCLOSE", 
        "javax`swing`JFrame`JPrivate`ERROR", 
        "javax`swing`JFrame`JPrivate`EURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`EXITUONUCLOSE", 
        "javax`swing`JFrame`JPrivate`FRAMEBITS", 
        "javax`swing`JFrame`JPrivate`getAccessibleContext", 
        "javax`swing`JFrame`JPrivate`getContentPane", 
        "javax`swing`JFrame`JPrivate`getDefaultCloseOperation", 
        "javax`swing`JFrame`JPrivate`getFrames", 
        "javax`swing`JFrame`JPrivate`getGlassPane", 
        "javax`swing`JFrame`JPrivate`getJMenuBar", 
        "javax`swing`JFrame`JPrivate`getLayeredPane", 
        "javax`swing`JFrame`JPrivate`getRootPane", 
        "javax`swing`JFrame`JPrivate`HANDUCURSOR", 
        "javax`swing`JFrame`JPrivate`HEIGHT", 
        "javax`swing`JFrame`JPrivate`HIDEUONUCLOSE", 
        "javax`swing`JFrame`JPrivate`ICONIFIED", 
        "javax`swing`JFrame`JPrivate`isDefaultLookAndFeelDecorated", 
        "javax`swing`JFrame`JPrivate`LEFTUALIGNMENT", 
        "javax`swing`JFrame`JPrivate`MAXIMIZEDUBOTH", 
        "javax`swing`JFrame`JPrivate`MAXIMIZEDUHORIZ", 
        "javax`swing`JFrame`JPrivate`MAXIMIZEDUVERT", 
        "javax`swing`JFrame`JPrivate`MOVEUCURSOR", 
        "javax`swing`JFrame`JPrivate`NEURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`NORMAL", 
        "javax`swing`JFrame`JPrivate`NURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`NWURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`PROPERTIES", 
        "javax`swing`JFrame`JPrivate`remove", 
        "javax`swing`JFrame`JPrivate`RIGHTUALIGNMENT", 
        "javax`swing`JFrame`JPrivate`setBounds", 
        "javax`swing`JFrame`JPrivate`setContentPane", 
        "javax`swing`JFrame`JPrivate`setDefaultCloseOperation", 
        "javax`swing`JFrame`JPrivate`setDefaultLookAndFeelDecorated", 
        "javax`swing`JFrame`JPrivate`setGlassPane", 
        "javax`swing`JFrame`JPrivate`setJMenuBar", 
        "javax`swing`JFrame`JPrivate`setLayeredPane", 
        "javax`swing`JFrame`JPrivate`setLayout", 
        "javax`swing`JFrame`JPrivate`setResizable", 
        "javax`swing`JFrame`JPrivate`setVisible", 
        "javax`swing`JFrame`JPrivate`SEURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`SOMEBITS", 
        "javax`swing`JFrame`JPrivate`SURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`SWURESIZEUCURSOR", 
        "javax`swing`JFrame`JPrivate`TEXTUCURSOR", 
        "javax`swing`JFrame`JPrivate`TOPUALIGNMENT", 
        "javax`swing`JFrame`JPrivate`update", 
        "javax`swing`JFrame`JPrivate`WAITUCURSOR", 
        "javax`swing`JFrame`JPrivate`WIDTH", 
        "javax`swing`JFrame`JPrivate`WURESIZEUCURSOR", 
        "javax`swing`JFrame`LEFTUALIGNMENT", 
        "javax`swing`JFrame`MAXIMIZEDUBOTH", 
        "javax`swing`JFrame`MAXIMIZEDUHORIZ", 
        "javax`swing`JFrame`MAXIMIZEDUVERT", "javax`swing`JFrame`MOVEUCURSOR",
         "javax`swing`JFrame`NEURESIZEUCURSOR", "javax`swing`JFrame`NORMAL", 
        "javax`swing`JFrame`NURESIZEUCURSOR", 
        "javax`swing`JFrame`NWURESIZEUCURSOR", 
        "javax`swing`JFrame`PROPERTIES", "javax`swing`JFrame`RIGHTUALIGNMENT",
         "javax`swing`JFrame`setDefaultLookAndFeelDecorated", 
        "javax`swing`JFrame`SEURESIZEUCURSOR", "javax`swing`JFrame`SOMEBITS", 
        "javax`swing`JFrame`SURESIZEUCURSOR", 
        "javax`swing`JFrame`SWURESIZEUCURSOR", 
        "javax`swing`JFrame`TEXTUCURSOR", "javax`swing`JFrame`TOPUALIGNMENT", 
        "javax`swing`JFrame`WAITUCURSOR", "javax`swing`JFrame`WIDTH", 
        "javax`swing`JFrame`WURESIZEUCURSOR", "javax`swing`JPanel`ABORT", 
        "javax`swing`JPanel`ALLBITS", "javax`swing`JPanel`BOTTOMUALIGNMENT", 
        "javax`swing`JPanel`CENTERUALIGNMENT", "javax`swing`JPanel`ERROR", 
        "javax`swing`JPanel`FRAMEBITS", "javax`swing`JPanel`getDefaultLocale",
         "javax`swing`JPanel`HEIGHT", 
        "javax`swing`JPanel`isLightweightComponent", 
        "javax`swing`JPanel`JPrivate`ABORT", 
        "javax`swing`JPanel`JPrivate`add", 
        "javax`swing`JPanel`JPrivate`addMouseListener", 
        "javax`swing`JPanel`JPrivate`ALLBITS", 
        "javax`swing`JPanel`JPrivate`BOTTOMUALIGNMENT", 
        "javax`swing`JPanel`JPrivate`CENTERUALIGNMENT", 
        "javax`swing`JPanel`JPrivate`createImage", 
        "javax`swing`JPanel`JPrivate`ERROR", 
        "javax`swing`JPanel`JPrivate`FRAMEBITS", 
        "javax`swing`JPanel`JPrivate`getAccessibleContext", 
        "javax`swing`JPanel`JPrivate`getDefaultLocale", 
        "javax`swing`JPanel`JPrivate`getUI", 
        "javax`swing`JPanel`JPrivate`getUIClassID", 
        "javax`swing`JPanel`JPrivate`HEIGHT", 
        "javax`swing`JPanel`JPrivate`isLightweightComponent", 
        "javax`swing`JPanel`JPrivate`LEFTUALIGNMENT", 
        "javax`swing`JPanel`JPrivate`PROPERTIES", 
        "javax`swing`JPanel`JPrivate`RIGHTUALIGNMENT", 
        "javax`swing`JPanel`JPrivate`setBounds", 
        "javax`swing`JPanel`JPrivate`setDefaultLocale", 
        "javax`swing`JPanel`JPrivate`setLayout", 
        "javax`swing`JPanel`JPrivate`setUI", 
        "javax`swing`JPanel`JPrivate`SOMEBITS", 
        "javax`swing`JPanel`JPrivate`TOOLUTIPUTEXTUKEY", 
        "javax`swing`JPanel`JPrivate`TOPUALIGNMENT", 
        "javax`swing`JPanel`JPrivate`UNDEFINEDUCONDITION", 
        "javax`swing`JPanel`JPrivate`updateUI", 
        "javax`swing`JPanel`JPrivate`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "javax`swing`JPanel`JPrivate`WHENUFOCUSED", 
        "javax`swing`JPanel`JPrivate`WHENUINUFOCUSEDUWINDOW", 
        "javax`swing`JPanel`JPrivate`WIDTH", 
        "javax`swing`JPanel`LEFTUALIGNMENT", "javax`swing`JPanel`PROPERTIES", 
        "javax`swing`JPanel`RIGHTUALIGNMENT", 
        "javax`swing`JPanel`setDefaultLocale", "javax`swing`JPanel`SOMEBITS", 
        "javax`swing`JPanel`TOOLUTIPUTEXTUKEY", 
        "javax`swing`JPanel`TOPUALIGNMENT", 
        "javax`swing`JPanel`UNDEFINEDUCONDITION", 
        "javax`swing`JPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "javax`swing`JPanel`WHENUFOCUSED", 
        "javax`swing`JPanel`WHENUINUFOCUSEDUWINDOW", 
        "javax`swing`JPanel`WIDTH", "JComponent`ABORT", "JComponent`ALLBITS", 
        "JComponent`BOTTOMUALIGNMENT", "JComponent`CENTERUALIGNMENT", 
        "JComponent`ERROR", "JComponent`FRAMEBITS", 
        "JComponent`getDefaultLocale", "JComponent`HEIGHT", 
        "JComponent`isLightweightComponent", "JComponent`LEFTUALIGNMENT", 
        "JComponent`PROPERTIES", "JComponent`RIGHTUALIGNMENT", 
        "JComponent`setDefaultLocale", "JComponent`SOMEBITS", 
        "JComponent`TOOLUTIPUTEXTUKEY", "JComponent`TOPUALIGNMENT", 
        "JComponent`UNDEFINEDUCONDITION", 
        "JComponent`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "JComponent`WHENUFOCUSED", "JComponent`WHENUINUFOCUSEDUWINDOW", 
        "JComponent`WIDTH", "JFrame`ABORT", "JFrame`ALLBITS", 
        "JFrame`BOTTOMUALIGNMENT", "JFrame`CENTERUALIGNMENT", 
        "JFrame`CROSSHAIRUCURSOR", "JFrame`DEFAULTUCURSOR", 
        "JFrame`DISPOSEUONUCLOSE", "JFrame`DOUNOTHINGUONUCLOSE", 
        "JFrame`ERROR", "JFrame`EURESIZEUCURSOR", "JFrame`EXITUONUCLOSE", 
        "JFrame`FRAMEBITS", "JFrame`getFrames", "JFrame`HANDUCURSOR", 
        "JFrame`HEIGHT", "JFrame`HIDEUONUCLOSE", "JFrame`ICONIFIED", 
        "JFrame`isDefaultLookAndFeelDecorated", "JFrame`LEFTUALIGNMENT", 
        "JFrame`MAXIMIZEDUBOTH", "JFrame`MAXIMIZEDUHORIZ", 
        "JFrame`MAXIMIZEDUVERT", "JFrame`MOVEUCURSOR", 
        "JFrame`NEURESIZEUCURSOR", "JFrame`NORMAL", "JFrame`NURESIZEUCURSOR", 
        "JFrame`NWURESIZEUCURSOR", "JFrame`PROPERTIES", 
        "JFrame`RIGHTUALIGNMENT", "JFrame`setDefaultLookAndFeelDecorated", 
        "JFrame`SEURESIZEUCURSOR", "JFrame`SOMEBITS", 
        "JFrame`SURESIZEUCURSOR", "JFrame`SWURESIZEUCURSOR", 
        "JFrame`TEXTUCURSOR", "JFrame`TOPUALIGNMENT", "JFrame`WAITUCURSOR", 
        "JFrame`WIDTH", "JFrame`WURESIZEUCURSOR", 
        "JLink`ArgumentTests`Private`allow", "JLink`ArgumentTests`Private`x", 
        "JLink`CallJava`Private`a", "JLink`CallJava`Private`allLoadedClasses",
         "JLink`CallJava`Private`allowShortContext", 
        "JLink`CallJava`Private`allowShortContext$", 
        "JLink`CallJava`Private`alreadyLoaded", 
        "JLink`CallJava`Private`alreadyLoaded$", "JLink`CallJava`Private`arg",
         "JLink`CallJava`Private`argc", "JLink`CallJava`Private`argc$", 
        "JLink`CallJava`Private`argName", "JLink`CallJava`Private`argNames", 
        "JLink`CallJava`Private`argNames$", "JLink`CallJava`Private`argName$",
         "JLink`CallJava`Private`argPairs", 
        "JLink`CallJava`Private`argPairs$", "JLink`CallJava`Private`argPats", 
        "JLink`CallJava`Private`argPats$", "JLink`CallJava`Private`args", 
        "JLink`CallJava`Private`args$", "JLink`CallJava`Private`argType", 
        "JLink`CallJava`Private`argTypes", 
        "JLink`CallJava`Private`argTypesAndVals", 
        "JLink`CallJava`Private`argTypes$", 
        "JLink`CallJava`Private`argTypeToPattern", 
        "JLink`CallJava`Private`argType$", "JLink`CallJava`Private`arg$1", 
        "JLink`CallJava`Private`arg$10", "JLink`CallJava`Private`arg$11", 
        "JLink`CallJava`Private`arg$12", "JLink`CallJava`Private`arg$13", 
        "JLink`CallJava`Private`arg$14", "JLink`CallJava`Private`arg$15", 
        "JLink`CallJava`Private`arg$16", "JLink`CallJava`Private`arg$17", 
        "JLink`CallJava`Private`arg$18", "JLink`CallJava`Private`arg$19", 
        "JLink`CallJava`Private`arg$2", "JLink`CallJava`Private`arg$20", 
        "JLink`CallJava`Private`arg$21", "JLink`CallJava`Private`arg$22", 
        "JLink`CallJava`Private`arg$23", "JLink`CallJava`Private`arg$24", 
        "JLink`CallJava`Private`arg$25", "JLink`CallJava`Private`arg$26", 
        "JLink`CallJava`Private`arg$27", "JLink`CallJava`Private`arg$28", 
        "JLink`CallJava`Private`arg$29", "JLink`CallJava`Private`arg$3", 
        "JLink`CallJava`Private`arg$30", "JLink`CallJava`Private`arg$31", 
        "JLink`CallJava`Private`arg$32", "JLink`CallJava`Private`arg$33", 
        "JLink`CallJava`Private`arg$34", "JLink`CallJava`Private`arg$35", 
        "JLink`CallJava`Private`arg$36", "JLink`CallJava`Private`arg$37", 
        "JLink`CallJava`Private`arg$38", "JLink`CallJava`Private`arg$39", 
        "JLink`CallJava`Private`arg$4", "JLink`CallJava`Private`arg$40", 
        "JLink`CallJava`Private`arg$5", "JLink`CallJava`Private`arg$6", 
        "JLink`CallJava`Private`arg$7", "JLink`CallJava`Private`arg$8", 
        "JLink`CallJava`Private`arg$9", "JLink`CallJava`Private`arrayDepth", 
        "JLink`CallJava`Private`arrayDepth$", 
        "JLink`CallJava`Private`arrayType", 
        "JLink`CallJava`Private`arrayType$", 
        "JLink`CallJava`Private`atLeastOneStatic", 
        "JLink`CallJava`Private`atLeastOneStatic$", 
        "JLink`CallJava`Private`b", "JLink`CallJava`Private`c", 
        "JLink`CallJava`Private`c1", "JLink`CallJava`Private`c2", 
        "JLink`CallJava`Private`cacheInstanceFunc", 
        "JLink`CallJava`Private`callJava", 
        "JLink`CallJava`Private`callOnLoadClassMethod", 
        "JLink`CallJava`Private`callOnUnloadClassMethod", 
        "JLink`CallJava`Private`checkFieldResult", 
        "JLink`CallJava`Private`checkMethodResult", 
        "JLink`CallJava`Private`class", "JLink`CallJava`Private`classContext",
         "JLink`CallJava`Private`classContext$", 
        "JLink`CallJava`Private`classes", "JLink`CallJava`Private`classes$", 
        "JLink`CallJava`Private`classFromName", 
        "JLink`CallJava`Private`classIndex", 
        "JLink`CallJava`Private`classIndexFromName", 
        "JLink`CallJava`Private`classIndex$", 
        "JLink`CallJava`Private`className", 
        "JLink`CallJava`Private`clearAllClassContexts", 
        "JLink`CallJava`Private`clearOutClassContext", 
        "JLink`CallJava`Private`cls", "JLink`CallJava`Private`clsIndex", 
        "JLink`CallJava`Private`clsName", "JLink`CallJava`Private`clsName$", 
        "JLink`CallJava`Private`cls$", "JLink`CallJava`Private`complexClass", 
        "JLink`CallJava`Private`complexClassName", 
        "JLink`CallJava`Private`complexClass$", 
        "JLink`CallJava`Private`contextNameFromClassIndex", 
        "JLink`CallJava`Private`createArgPairs", 
        "JLink`CallJava`Private`createConstructorStubs", 
        "JLink`CallJava`Private`createCtorDef", 
        "JLink`CallJava`Private`createFieldDef", 
        "JLink`CallJava`Private`createFieldStubs", 
        "JLink`CallJava`Private`createJavaClass", 
        "JLink`CallJava`Private`createMethodDef", 
        "JLink`CallJava`Private`createMethodStubs", 
        "JLink`CallJava`Private`ctorList", 
        "JLink`CallJava`Private`ctorListForNonObjectDups", 
        "JLink`CallJava`Private`ctorListForNonObjectDups$", 
        "JLink`CallJava`Private`ctorListForObjectDups", 
        "JLink`CallJava`Private`ctorListForObjectDups$", 
        "JLink`CallJava`Private`ctorList$", "JLink`CallJava`Private`ctorRecs",
         "JLink`CallJava`Private`ctorRecs$", "JLink`CallJava`Private`ctors", 
        "JLink`CallJava`Private`ctorsWithObjects", 
        "JLink`CallJava`Private`ctorsWithObjects$", 
        "JLink`CallJava`Private`ctorsWithoutObjects", 
        "JLink`CallJava`Private`ctorsWithoutObjects$", 
        "JLink`CallJava`Private`ctxt", "JLink`CallJava`Private`ctxt$", 
        "JLink`CallJava`Private`curClsIndex", 
        "JLink`CallJava`Private`curClsIndex$", "JLink`CallJava`Private`d", 
        "JLink`CallJava`Private`decs", "JLink`CallJava`Private`decs$", 
        "JLink`CallJava`Private`destroyLoadedClassInfo", 
        "JLink`CallJava`Private`dups", "JLink`CallJava`Private`dups$", 
        "JLink`CallJava`Private`e", "JLink`CallJava`Private`equivs", 
        "JLink`CallJava`Private`e$", "JLink`CallJava`Private`f", 
        "JLink`CallJava`Private`field", "JLink`CallJava`Private`fieldCall", 
        "JLink`CallJava`Private`fieldName", 
        "JLink`CallJava`Private`fieldNames", 
        "JLink`CallJava`Private`fieldNames$", 
        "JLink`CallJava`Private`fieldName$", 
        "JLink`CallJava`Private`fieldRecs", 
        "JLink`CallJava`Private`fieldRecs$", "JLink`CallJava`Private`fields", 
        "JLink`CallJava`Private`fieldTag", "JLink`CallJava`Private`field$", 
        "JLink`CallJava`Private`findName", "JLink`CallJava`Private`fmt", 
        "JLink`CallJava`Private`fmt$", "JLink`CallJava`Private`heldName", 
        "JLink`CallJava`Private`i", "JLink`CallJava`Private`index", 
        "JLink`CallJava`Private`index$", "JLink`CallJava`Private`indices", 
        "JLink`CallJava`Private`indices$", "JLink`CallJava`Private`instance", 
        "JLink`CallJava`Private`instanceFunc", 
        "JLink`CallJava`Private`instance$", "JLink`CallJava`Private`instFunc",
         "JLink`CallJava`Private`interfaceQFromIndex", 
        "JLink`CallJava`Private`isBeingLoadedAsComplexClass", 
        "JLink`CallJava`Private`isInterface", 
        "JLink`CallJava`Private`isInterface$", 
        "JLink`CallJava`Private`isJavaStaticSymbol", 
        "JLink`CallJava`Private`isLoadedClass", 
        "JLink`CallJava`Private`isMethod", 
        "JLink`CallJava`Private`isPreemptive", "JLink`CallJava`Private`i$", 
        "JLink`CallJava`Private`javaConstructor", 
        "JLink`CallJava`Private`javaField", 
        "JLink`CallJava`Private`javaMethod", 
        "JLink`CallJava`Private`javaNames", 
        "JLink`CallJava`Private`javaNames$", "JLink`CallJava`Private`javaNew",
         "JLink`CallJava`Private`jc", "JLink`CallJava`Private`jc$", 
        "JLink`CallJava`Private`jlinkExternalCall", 
        "JLink`CallJava`Private`lc", "JLink`CallJava`Private`lc$", 
        "JLink`CallJava`Private`legalClassName", 
        "JLink`CallJava`Private`legalClassName$", 
        "JLink`CallJava`Private`link", "JLink`CallJava`Private`loadedClasses",
         "JLink`CallJava`Private`looksLikeModuleVar", 
        "JLink`CallJava`Private`looksLikeModuleVar$", 
        "JLink`CallJava`Private`lookupInstanceFunc", 
        "JLink`CallJava`Private`makeStaticFieldDefs", 
        "JLink`CallJava`Private`meth", 
        "JLink`CallJava`Private`methListForNonObjectDups", 
        "JLink`CallJava`Private`methListForNonObjectDups$", 
        "JLink`CallJava`Private`methListForObjectDups", 
        "JLink`CallJava`Private`methListForObjectDups$", 
        "JLink`CallJava`Private`methName", "JLink`CallJava`Private`methNames",
         "JLink`CallJava`Private`methNames$", 
        "JLink`CallJava`Private`methName$", 
        "JLink`CallJava`Private`methodCall", 
        "JLink`CallJava`Private`methRecs", "JLink`CallJava`Private`methRecs$",
         "JLink`CallJava`Private`meths", 
        "JLink`CallJava`Private`methsWithObjects", 
        "JLink`CallJava`Private`methsWithObjects$", 
        "JLink`CallJava`Private`methsWithoutObjects", 
        "JLink`CallJava`Private`methsWithoutObjects$", 
        "JLink`CallJava`Private`meth$", "JLink`CallJava`Private`n", 
        "JLink`CallJava`Private`name", "JLink`CallJava`Private`nameLen", 
        "JLink`CallJava`Private`nameLen$", "JLink`CallJava`Private`nameStr", 
        "JLink`CallJava`Private`nameStr$", "JLink`CallJava`Private`name$", 
        "JLink`CallJava`Private`nms", "JLink`CallJava`Private`nms$", 
        "JLink`CallJava`Private`nonDups", "JLink`CallJava`Private`nonDups$", 
        "JLink`CallJava`Private`n$", "JLink`CallJava`Private`obj", 
        "JLink`CallJava`Private`objSupplyingClassLoader", 
        "JLink`CallJava`Private`obj$", "JLink`CallJava`Private`opts", 
        "JLink`CallJava`Private`p", "JLink`CallJava`Private`packet", 
        "JLink`CallJava`Private`parentClass", 
        "JLink`CallJava`Private`parentClass$", 
        "JLink`CallJava`Private`parentClsIndex", 
        "JLink`CallJava`Private`parentClsIndex$", 
        "JLink`CallJava`Private`pat", "JLink`CallJava`Private`patternFunc", 
        "JLink`CallJava`Private`patternFunc$", "JLink`CallJava`Private`pat$", 
        "JLink`CallJava`Private`pctxt", "JLink`CallJava`Private`pctxt$", 
        "JLink`CallJava`Private`pickWidest", "JLink`CallJava`Private`pkt", 
        "JLink`CallJava`Private`privSym", "JLink`CallJava`Private`privSym$", 
        "JLink`CallJava`Private`prot", "JLink`CallJava`Private`removeClass", 
        "JLink`CallJava`Private`res", "JLink`CallJava`Private`result", 
        "JLink`CallJava`Private`resultFunc", 
        "JLink`CallJava`Private`resultFunc$", "JLink`CallJava`Private`res$", 
        "JLink`CallJava`Private`returnedClassName", 
        "JLink`CallJava`Private`returnedClassName$", 
        "JLink`CallJava`Private`s", "JLink`CallJava`Private`setField", 
        "JLink`CallJava`Private`shortClassContext", 
        "JLink`CallJava`Private`shortClassContextFromClassContext", 
        "JLink`CallJava`Private`shortClassContext$", 
        "JLink`CallJava`Private`shortCtxt", 
        "JLink`CallJava`Private`shortCtxt$", 
        "JLink`CallJava`Private`staticField", 
        "JLink`CallJava`Private`staticsVisible", 
        "JLink`CallJava`Private`staticsVisible$", 
        "JLink`CallJava`Private`storeClass", "JLink`CallJava`Private`sums", 
        "JLink`CallJava`Private`sums$", "JLink`CallJava`Private`sym", 
        "JLink`CallJava`Private`symStr", "JLink`CallJava`Private`sym$", 
        "JLink`CallJava`Private`tag", "JLink`CallJava`Private`tag$", 
        "JLink`CallJava`Private`toContextName", 
        "JLink`CallJava`Private`toLegalName", 
        "JLink`CallJava`Private`TYPEARRAY1", 
        "JLink`CallJava`Private`TYPEARRAY2", 
        "JLink`CallJava`Private`TYPEARRAY3", "JLink`CallJava`Private`TYPEBAD",
         "JLink`CallJava`Private`TYPEBIGDECIMAL", 
        "JLink`CallJava`Private`TYPEBIGINTEGER", 
        "JLink`CallJava`Private`TYPEBOOLEAN", 
        "JLink`CallJava`Private`TYPEBYTE", "JLink`CallJava`Private`TYPECHAR", 
        "JLink`CallJava`Private`TYPECOMPLEX", 
        "JLink`CallJava`Private`TYPEDOUBLE", 
        "JLink`CallJava`Private`TYPEDOUBLEORINT", 
        "JLink`CallJava`Private`TYPEEXPR", "JLink`CallJava`Private`TYPEFLOAT",
         "JLink`CallJava`Private`TYPEFLOATORINT", 
        "JLink`CallJava`Private`TYPEINT", "JLink`CallJava`Private`TYPELONG", 
        "JLink`CallJava`Private`TYPEOBJECT", 
        "JLink`CallJava`Private`TYPESHORT", 
        "JLink`CallJava`Private`TYPESTRING", 
        "JLink`CallJava`Private`usesShortContext", 
        "JLink`CallJava`Private`useTypeChecking", 
        "JLink`CallJava`Private`useTypeChecking$", 
        "JLink`CallJava`Private`usingShortContext", 
        "JLink`CallJava`Private`usingShortContext$", 
        "JLink`CallJava`Private`val", "JLink`CallJava`Private`val$", 
        "JLink`CallJava`Private`warnForDups", "JLink`CallJava`Private`wasOn1",
         "JLink`CallJava`Private`wasOn1$", "JLink`CallJava`Private`wasOn2", 
        "JLink`CallJava`Private`wasOn2$", "JLink`CallJava`Private`wasOn3", 
        "JLink`CallJava`Private`wasOn3$", "JLink`CallJava`Private`widest", 
        "JLink`CallJava`Private`widest$", "JLink`CallJava`Private`x", 
        "JLink`CallJava`Private`x$", "JLink`CallJava`Private`$argNames", 
        "JLink`CallJava`Private`$byRef", 
        "JLink`CallJava`Private`$externalCallLink", 
        "JLink`CallJava`Private`$inPreemptiveCallToJava", 
        "JLink`CallJava`Private`$instanceFuncCache", 
        "JLink`CallJava`Private`$isNestedLoad", "JLink`Debug`Private`action", 
        "JLink`Debug`Private`e", "JLink`Debug`Private`expr", 
        "JLink`Debug`Private`exprs", "JLink`Debug`Private`e$", 
        "JLink`Debug`Private`lev", "JLink`Debug`Private`t", 
        "JLink`Debug`Private`test", "JLink`Debug`Private`tst", 
        "JLink`EvaluateTo`Private`cellExpr", 
        "JLink`EvaluateTo`Private`cellOpts", "JLink`EvaluateTo`Private`e", 
        "JLink`EvaluateTo`Private`expr", "JLink`EvaluateTo`Private`fmt", 
        "JLink`EvaluateTo`Private`format", "JLink`EvaluateTo`Private`frm", 
        "JLink`EvaluateTo`Private`opts", "JLink`EvaluateTo`Private`pageWidth",
         "JLink`EvaluateTo`Private`ps", "JLink`EvaluateTo`Private`pWidth", 
        "JLink`EvaluateTo`Private`result", "JLink`EvaluateTo`Private`useFE", 
        "JLink`Exceptions`Private`a", "JLink`Exceptions`Private`a$", 
        "JLink`Exceptions`Private`e", "JLink`Exceptions`Private`excHandler", 
        "JLink`Exceptions`Private`excHandler$", 
        "JLink`Exceptions`Private`handleDirtyException", 
        "JLink`Exceptions`Private`handlePostException", 
        "JLink`Exceptions`Private`isPost", "JLink`Exceptions`Private`junk", 
        "JLink`Exceptions`Private`junk$", "JLink`Exceptions`Private`link", 
        "JLink`Exceptions`Private`oldMsgPrePrint", 
        "JLink`Exceptions`Private`readException", 
        "JLink`Exceptions`Private`readManualResult", 
        "JLink`Exceptions`Private`reportException", 
        "JLink`Exceptions`Private`res", "JLink`Exceptions`Private`res$", 
        "JLink`Exceptions`Private`str", "JLink`Exceptions`Private`str$", 
        "JLink`Exceptions`Private`$internalJavaExceptionHandler", 
        "JLink`FrontEndServer`Private`cmd", 
        "JLink`FrontEndServer`Private`cmdLine", 
        "JLink`FrontEndServer`Private`expr", 
        "JLink`FrontEndServer`Private`feInitFunc", 
        "JLink`FrontEndServer`Private`fePath", 
        "JLink`FrontEndServer`Private`flags", 
        "JLink`FrontEndServer`Private`forceLaunch", 
        "JLink`FrontEndServer`Private`kernelHasUseFrontEnd", 
        "JLink`FrontEndServer`Private`launchFlags", 
        "JLink`FrontEndServer`Private`nbOpts", 
        "JLink`FrontEndServer`Private`nbs", 
        "JLink`FrontEndServer`Private`opts", 
        "JLink`FrontEndServer`Private`parts", 
        "JLink`FrontEndServer`Private`preventUnsafeFEShutdown", 
        "JLink`FrontEndServer`Private`$externalFELink", 
        "JLink`Information`$CreationDate", "JLink`Information`$CreationID", 
        "JLink`Information`$ReleaseNumber", "JLink`Information`$Version", 
        "JLink`Information`$VersionNumber", "JLink`InstallJava`Private`a", 
        "JLink`InstallJava`Private`appDirs", 
        "JLink`InstallJava`Private`appPaths", 
        "JLink`InstallJava`Private`args", "JLink`InstallJava`Private`args$", 
        "JLink`InstallJava`Private`cmdLine", 
        "JLink`InstallJava`Private`cmdLine$", 
        "JLink`InstallJava`Private`command", "JLink`InstallJava`Private`cp", 
        "JLink`InstallJava`Private`CP", "JLink`InstallJava`Private`cpSep", 
        "JLink`InstallJava`Private`cpSep$", 
        "JLink`InstallJava`Private`cpSpec", 
        "JLink`InstallJava`Private`cpSpec$", "JLink`InstallJava`Private`CP$", 
        "JLink`InstallJava`Private`createCommandLine", 
        "JLink`InstallJava`Private`DispatchToJava", 
        "JLink`InstallJava`Private`e", "JLink`InstallJava`Private`err", 
        "JLink`InstallJava`Private`err$", 
        "JLink`InstallJava`Private`extraArgs", 
        "JLink`InstallJava`Private`extraArgs$", 
        "JLink`InstallJava`Private`e$", 
        "JLink`InstallJava`Private`filterOptions", 
        "JLink`InstallJava`Private`initJava", 
        "JLink`InstallJava`Private`InstallJavaInternalOLD", 
        "JLink`InstallJava`Private`InstallToInternalLink", 
        "JLink`InstallJava`Private`isParentLink", 
        "JLink`InstallJava`Private`isParentLink$", 
        "JLink`InstallJava`Private`javaCmd", 
        "JLink`InstallJava`Private`javaCmd$", 
        "JLink`InstallJava`Private`javaDirs", 
        "JLink`InstallJava`Private`jlinkDefineInternal", 
        "JLink`InstallJava`Private`jlinkInternalCall", 
        "JLink`InstallJava`Private`jlinkPath", 
        "JLink`InstallJava`Private`jlinkPath$", 
        "JLink`InstallJava`Private`jvmArgs", 
        "JLink`InstallJava`Private`jvmArgs$", 
        "JLink`InstallJava`Private`launcherLink", 
        "JLink`InstallJava`Private`launcherLink$", 
        "JLink`InstallJava`Private`link", 
        "JLink`InstallJava`Private`linkSwitchPostFunc", 
        "JLink`InstallJava`Private`linkSwitchPreFunc", 
        "JLink`InstallJava`Private`link$", "JLink`InstallJava`Private`loop", 
        "JLink`InstallJava`Private`macLink", 
        "JLink`InstallJava`Private`macLink$", "JLink`InstallJava`Private`n", 
        "JLink`InstallJava`Private`oldFrontEnd", 
        "JLink`InstallJava`Private`options", "JLink`InstallJava`Private`opts",
         "JLink`InstallJava`Private`p", "JLink`InstallJava`Private`packet", 
        "JLink`InstallJava`Private`pat", "JLink`InstallJava`Private`pat$", 
        "JLink`InstallJava`Private`pkt", 
        "JLink`InstallJava`Private`prefsSpec", 
        "JLink`InstallJava`Private`prefsSpec$", 
        "JLink`InstallJava`Private`prot", "JLink`InstallJava`Private`prot$", 
        "JLink`InstallJava`Private`res", 
        "JLink`InstallJava`Private`resetMathematica", 
        "JLink`InstallJava`Private`result", 
        "JLink`InstallJava`Private`result$", 
        "JLink`InstallJava`Private`setupUILink", 
        "JLink`InstallJava`Private`splitClasspath", 
        "JLink`InstallJava`Private`str", "JLink`InstallJava`Private`strm", 
        "JLink`InstallJava`Private`str$", "JLink`InstallJava`Private`tes", 
        "JLink`InstallJava`Private`thisPkgPath", 
        "JLink`InstallJava`Private`thisPkgPath$", 
        "JLink`InstallJava`Private`uiLink", 
        "JLink`InstallJava`Private`useUILink", 
        "JLink`InstallJava`Private`useUILinkQ", 
        "JLink`InstallJava`Private`useUILink$", 
        "JLink`InstallJava`Private`$disablePrefs", 
        "JLink`InstallJava`Private`$InternalLink", 
        "JLink`InstallJava`Private`$jlink", 
        "JLink`InstallJava`Private`$uilink", "JLink`JavaBlock`Private`e", 
        "JLink`JavaBlock`Private`keep", "JLink`JavaBlock`Private`keep$", 
        "JLink`JavaBlock`Private`keptObjectsSlatedForRelease", 
        "JLink`JavaBlock`Private`keptObjectsSlatedForRelease$", 
        "JLink`JavaBlock`Private`man", "JLink`JavaBlock`Private`nsyms", 
        "JLink`JavaBlock`Private`nsyms$", "JLink`JavaBlock`Private`obj", 
        "JLink`JavaBlock`Private`objs", "JLink`JavaBlock`Private`opts", 
        "JLink`JavaBlock`Private`prevBlockRecord", 
        "JLink`JavaBlock`Private`prevBlockRecord$", 
        "JLink`JavaBlock`Private`release", "JLink`JavaBlock`Private`release$",
         "JLink`JavaBlock`Private`res", "JLink`JavaBlock`Private`result", 
        "JLink`JavaBlock`Private`res$", "JLink`JavaBlock`Private`syms", 
        "JLink`JavaBlock`Private`$javaBlockRecord", 
        "JLink`MakeJavaObject`Private`a", "JLink`MakeJavaObject`Private`e", 
        "JLink`MakeJavaObject`Private`i", "JLink`MakeJavaObject`Private`mjo1",
         "JLink`MakeJavaObject`Private`mjo2", 
        "JLink`MakeJavaObject`Private`mjo3", 
        "JLink`MakeJavaObject`Private`obj", 
        "JLink`MakeJavaObject`Private`part", 
        "JLink`MakeJavaObject`Private`result", 
        "JLink`MakeJavaObject`Private`s", "JLink`MakeJavaObject`Private`t", 
        "JLink`MakeJavaObject`Private`x", "JLink`Misc`Private`applet", 
        "JLink`Misc`Private`classIndex", "JLink`Misc`Private`cls", 
        "JLink`Misc`Private`clsName", "JLink`Misc`Private`cls$", 
        "JLink`Misc`Private`console", "JLink`Misc`Private`console$", 
        "JLink`Misc`Private`defaults", "JLink`Misc`Private`doModal", 
        "JLink`Misc`Private`e", "JLink`Misc`Private`endModal", 
        "JLink`Misc`Private`exc", "JLink`Misc`Private`getClassLoader", 
        "JLink`Misc`Private`handlerMappings", "JLink`Misc`Private`host", 
        "JLink`Misc`Private`interfaces", "JLink`Misc`Private`interfaces$", 
        "JLink`Misc`Private`intf", "JLink`Misc`Private`intfs", 
        "JLink`Misc`Private`invHandler", "JLink`Misc`Private`invHandler$", 
        "JLink`Misc`Private`isFirstTime", "JLink`Misc`Private`isJava", 
        "JLink`Misc`Private`isJava$", "JLink`Misc`Private`isNET", 
        "JLink`Misc`Private`isNET$", "JLink`Misc`Private`jc", 
        "JLink`Misc`Private`jl", "JLink`Misc`Private`link", 
        "JLink`Misc`Private`locs", "JLink`Misc`Private`msg", 
        "JLink`Misc`Private`obj", "JLink`Misc`Private`obj1", 
        "JLink`Misc`Private`obj2", "JLink`Misc`Private`optName", 
        "JLink`Misc`Private`optNames", "JLink`Misc`Private`optNameStrings", 
        "JLink`Misc`Private`optNameStrings$", "JLink`Misc`Private`opts", 
        "JLink`Misc`Private`params", "JLink`Misc`Private`port", 
        "JLink`Misc`Private`proxy", "JLink`Misc`Private`proxy$", 
        "JLink`Misc`Private`put", "JLink`Misc`Private`releaseAllObjects", 
        "JLink`Misc`Private`res", "JLink`Misc`Private`result", 
        "JLink`Misc`Private`setCapture", "JLink`Misc`Private`setFirstTime", 
        "JLink`Misc`Private`setLocation", "JLink`Misc`Private`setSize", 
        "JLink`Misc`Private`stringifiedOptionDefaults", 
        "JLink`Misc`Private`stringifiedOptionDefaults$", 
        "JLink`Misc`Private`stringifiedOptionSettings", 
        "JLink`Misc`Private`stringifiedOptionSettings$", 
        "JLink`Misc`Private`strms", "JLink`Misc`Private`wnd", 
        "JLink`Misc`Private`x", "JLink`Misc`Private`$complexClass", 
        "JLink`Objects`JavaObject16777217", 
        "JLink`Objects`JavaObject281470698520577", 
        "JLink`Objects`JavaObject300312535498753", 
        "JLink`Objects`JavaObject4294967297", "JLink`Package`addToJavaBlock", 
        "JLink`Package`allow", "JLink`Package`argCount", "JLink`Package`args",
         "JLink`Package`Assert", "JLink`Package`AssertAction", 
        "JLink`Package`AsyncInstall", "JLink`Package`autoClassPath", 
        "JLink`Package`autoException", 
        "JLink`Package`callAllUnloadClassMethods", "JLink`Package`class", 
        "JLink`Package`classFromIndex", "JLink`Package`classIndex", 
        "JLink`Package`classIndexFromClass", 
        "JLink`Package`classIndexFromInstance", "JLink`Package`className", 
        "JLink`Package`classNameFromClass", 
        "JLink`Package`classNameFromIndex", "JLink`Package`clearComplexClass",
         "JLink`Package`clearJavaDefs", 
        "JLink`Package`contextIndependentOptions", 
        "JLink`Package`createInstanceDefs", "JLink`Package`DebugPrint", 
        "JLink`Package`dir", "JLink`Package`dirs", 
        "JLink`Package`enteringModal", "JLink`Package`exc", 
        "JLink`Package`force", "JLink`Package`getActiveJavaLink", 
        "JLink`Package`handleCleanException", "JLink`Package`indices", 
        "JLink`Package`inherited", "JLink`Package`InstallJavaInternal", 
        "JLink`Package`instance", "JLink`Package`instances", 
        "JLink`Package`isBigDecimal", "JLink`Package`isBigDecimalArray2", 
        "JLink`Package`isBigDecimalArray3", "JLink`Package`isBigDecimalList", 
        "JLink`Package`isBigInteger", "JLink`Package`isBigIntegerArray2", 
        "JLink`Package`isBigIntegerArray3", "JLink`Package`isBigIntegerList", 
        "JLink`Package`isComplex", "JLink`Package`isComplexArray2", 
        "JLink`Package`isComplexArray3", "JLink`Package`isComplexClass", 
        "JLink`Package`isComplexList", "JLink`Package`isExprArray2", 
        "JLink`Package`isExprArray3", "JLink`Package`isExprList", 
        "JLink`Package`isIntegerArray2", "JLink`Package`isIntegerArray3", 
        "JLink`Package`isIntegerList", "JLink`Package`isJavaBigDecimalArray", 
        "JLink`Package`isJavaBigIntegerArray", 
        "JLink`Package`isJavaBooleanArray", 
        "JLink`Package`isJavaComplexArray", "JLink`Package`isJavaExprArray", 
        "JLink`Package`isJavaIntegerArray", "JLink`Package`isJavaObjectArray",
         "JLink`Package`isJavaRealArray", "JLink`Package`isJavaStringArray", 
        "JLink`Package`isNumberArray2", "JLink`Package`isNumberArray3", 
        "JLink`Package`isNumberList", "JLink`Package`isObjectArray2", 
        "JLink`Package`isObjectArray3", "JLink`Package`isObjectList", 
        "JLink`Package`isPreemptiveKernel", "JLink`Package`isRealArray2", 
        "JLink`Package`isRealArray3", "JLink`Package`isRealList", 
        "JLink`Package`isServiceFrontEnd", "JLink`Package`isString", 
        "JLink`Package`isStringArray2", "JLink`Package`isStringArray3", 
        "JLink`Package`isStringList", 
        "JLink`Package`issueNoDefaultCtorMessage", 
        "JLink`Package`isTrueFalseArray2", "JLink`Package`isTrueFalseArray3", 
        "JLink`Package`isTrueFalseList", "JLink`Package`jAddToClassPath", 
        "JLink`Package`jAllowRaggedArrays", 
        "JLink`Package`jAllowUIComputations", "JLink`Package`jCallJava", 
        "JLink`Package`jClassPath", "JLink`Package`jConnectToFEServer", 
        "JLink`Package`jDisconnectToFEServer", "JLink`Package`jForcePolling", 
        "JLink`Package`jGC", "JLink`Package`jGetComplex", 
        "JLink`Package`jGetConsole", "JLink`Package`jGetException", 
        "JLink`Package`jInstanceOf", "JLink`Package`jlinkDefineExternal", 
        "JLink`Package`jLoadClass", "JLink`Package`jOnLoadClass", 
        "JLink`Package`jOnUnloadClass", "JLink`Package`jPeekClasses", 
        "JLink`Package`jPeekObjects", "JLink`Package`jReflect", 
        "JLink`Package`jReleaseAllObjects", "JLink`Package`jReleaseObject", 
        "JLink`Package`jSameQ", "JLink`Package`jSetComplex", 
        "JLink`Package`jSetUserDir", "JLink`Package`jShow", 
        "JLink`Package`jThrow", "JLink`Package`jUILink", 
        "JLink`Package`jUIThreadWaitingQ", "JLink`Package`jUnloadClass", 
        "JLink`Package`jVal", "JLink`Package`jYieldTime", 
        "JLink`Package`linkName", 
        "JLink`Package`loadClassAndCreateInstanceDefs", 
        "JLink`Package`loadClassFromJava", "JLink`Package`manualException", 
        "JLink`Package`millis", "JLink`Package`msg", 
        "JLink`Package`myLinkReadyQ", "JLink`Package`name", 
        "JLink`Package`obj", "JLink`Package`obj1", "JLink`Package`obj2", 
        "JLink`Package`objSupplyingClassLoader", 
        "JLink`Package`osIsClassicMac", "JLink`Package`osIsMacOSX", 
        "JLink`Package`osIsWindows", 
        "JLink`Package`parentClassIndexFromClassIndex", 
        "JLink`Package`prepareForManualReturn", "JLink`Package`prot", 
        "JLink`Package`protocol", "JLink`Package`resetJavaBlock", 
        "JLink`Package`searchForJars", "JLink`Package`Trigger", 
        "JLink`Package`type", "JLink`Package`Verify", 
        "JLink`Package`VerifyAction", "JLink`Package`wnd", 
        "JLink`Package`yielder", "JLink`Package`$allowRaggedArrays", 
        "JLink`Package`$AssertAction", "JLink`Package`$Debug", 
        "JLink`Package`$DebugCommandLine", "JLink`Package`$DebugDups", 
        "JLink`Package`$DebugExceptions", "JLink`Package`$DebugLevel", 
        "JLink`Package`$inPreemptiveCallFromJava", "JLink`Package`$jlinkDir", 
        "JLink`Package`$VerifyAction", "JLink`Reflection`Private`a", 
        "JLink`Reflection`Private`a$", "JLink`Reflection`Private`b", 
        "JLink`Reflection`Private`b$", "JLink`Reflection`Private`cls", 
        "JLink`Reflection`Private`clsName", "JLink`Reflection`Private`cls$", 
        "JLink`Reflection`Private`ctors", "JLink`Reflection`Private`d", 
        "JLink`Reflection`Private`decl", 
        "JLink`Reflection`Private`dropPrefixes", 
        "JLink`Reflection`Private`d$", "JLink`Reflection`Private`extractName",
         "JLink`Reflection`Private`fields", 
        "JLink`Reflection`Private`ignoreCase", 
        "JLink`Reflection`Private`ignoreCase$", 
        "JLink`Reflection`Private`includeInherited", 
        "JLink`Reflection`Private`inherit", 
        "JLink`Reflection`Private`inherit$", 
        "JLink`Reflection`Private`isField", 
        "JLink`Reflection`Private`isFinal", 
        "JLink`Reflection`Private`isFinal$", 
        "JLink`Reflection`Private`isStatic", 
        "JLink`Reflection`Private`isStatic$", 
        "JLink`Reflection`Private`methods", "JLink`Reflection`Private`obj", 
        "JLink`Reflection`Private`opts", "JLink`Reflection`Private`parenPos", 
        "JLink`Reflection`Private`parenPos$", "JLink`Reflection`Private`pat", 
        "JLink`Reflection`Private`periodPos", 
        "JLink`Reflection`Private`periodPos$", "JLink`Reflection`Private`s", 
        "JLink`Reflection`Private`shortenNames", 
        "JLink`Reflection`Private`sortOnName", 
        "JLink`Reflection`Private`spacePos", 
        "JLink`Reflection`Private`spacePositions", 
        "JLink`Reflection`Private`spacePositions$", 
        "JLink`Reflection`Private`spacePos$", "JLink`Reflection`Private`str", 
        "JLink`Reflection`Private`str$", "JLink`Reflection`Private`x", 
        "JLink`Sharing`Private`a", "JLink`Sharing`Private`activeLink", 
        "JLink`Sharing`Private`b", "JLink`Sharing`Private`box", 
        "JLink`Sharing`Private`c", 
        "JLink`Sharing`Private`cleanupEnterExprSyntaxError", 
        "JLink`Sharing`Private`cleanupEnterTextSyntaxError", 
        "JLink`Sharing`Private`code", "JLink`Sharing`Private`createLinkInfo", 
        "JLink`Sharing`Private`curLink", "JLink`Sharing`Private`curLink$", 
        "JLink`Sharing`Private`dead", "JLink`Sharing`Private`deadPos", 
        "JLink`Sharing`Private`deadPos$", 
        "JLink`Sharing`Private`destroyServerNb", 
        "JLink`Sharing`Private`destroySyntaxRule", 
        "JLink`Sharing`Private`doPeriodical", "JLink`Sharing`Private`e", 
        "JLink`Sharing`Private`endFEMode", "JLink`Sharing`Private`enterExpr", 
        "JLink`Sharing`Private`enterText", "JLink`Sharing`Private`evaluator", 
        "JLink`Sharing`Private`evaluatorName", 
        "JLink`Sharing`Private`evaluatorName$", 
        "JLink`Sharing`Private`evaluator$", "JLink`Sharing`Private`expr", 
        "JLink`Sharing`Private`e$", "JLink`Sharing`Private`fe", 
        "JLink`Sharing`Private`fes", 
        "JLink`Sharing`Private`fesThatWillRemain", 
        "JLink`Sharing`Private`fesThatWillRemain$", 
        "JLink`Sharing`Private`feToksForThisLink", 
        "JLink`Sharing`Private`feToksForThisLink$", 
        "JLink`Sharing`Private`fe$", 
        "JLink`Sharing`Private`getFrontEndObject", 
        "JLink`Sharing`Private`getLink", "JLink`Sharing`Private`getTokenList",
         "JLink`Sharing`Private`goToFE", "JLink`Sharing`Private`goToLink", 
        "JLink`Sharing`Private`goToLinkSyntaxError", 
        "JLink`Sharing`Private`goToLoopback", 
        "JLink`Sharing`Private`goToLoopbackFirstTime", 
        "JLink`Sharing`Private`goToLoopbackImplementation", 
        "JLink`Sharing`Private`goToOther", "JLink`Sharing`Private`id", 
        "JLink`Sharing`Private`ids", "JLink`Sharing`Private`id$", 
        "JLink`Sharing`Private`inst", "JLink`Sharing`Private`inStr", 
        "JLink`Sharing`Private`isFE", "JLink`Sharing`Private`javaAvailable", 
        "JLink`Sharing`Private`l", "JLink`Sharing`Private`last", 
        "JLink`Sharing`Private`li", "JLink`Sharing`Private`lineNum", 
        "JLink`Sharing`Private`lineNumber", "JLink`Sharing`Private`lineNum$", 
        "JLink`Sharing`Private`link", "JLink`Sharing`Private`linkForThisTok", 
        "JLink`Sharing`Private`linkForThisTok$", 
        "JLink`Sharing`Private`linkInfo", "JLink`Sharing`Private`linkName", 
        "JLink`Sharing`Private`linkName$", "JLink`Sharing`Private`linkResult",
         "JLink`Sharing`Private`linkResult$", "JLink`Sharing`Private`links", 
        "JLink`Sharing`Private`linkStr", "JLink`Sharing`Private`links$", 
        "JLink`Sharing`Private`linkToPointAt", "JLink`Sharing`Private`lnk", 
        "JLink`Sharing`Private`lnk$", 
        "JLink`Sharing`Private`loopIsParentLink", 
        "JLink`Sharing`Private`mainLoop", 
        "JLink`Sharing`Private`matchingRecPosition", 
        "JLink`Sharing`Private`matchingRecPosition$", 
        "JLink`Sharing`Private`mergeLinkInfo", "JLink`Sharing`Private`nbOpts",
         "JLink`Sharing`Private`nbOpts$", 
        "JLink`Sharing`Private`netAvailable", "JLink`Sharing`Private`netLink",
         "JLink`Sharing`Private`netLink$", "JLink`Sharing`Private`new", 
        "JLink`Sharing`Private`newEvalNames", 
        "JLink`Sharing`Private`newEvalNames$", 
        "JLink`Sharing`Private`newLinkInfoRec", 
        "JLink`Sharing`Private`newLinkInfoRec$", 
        "JLink`Sharing`Private`newLinkName", 
        "JLink`Sharing`Private`newLinkName$", "JLink`Sharing`Private`old", 
        "JLink`Sharing`Private`opts", "JLink`Sharing`Private`origEvalNames", 
        "JLink`Sharing`Private`origEvalNames$", "JLink`Sharing`Private`p", 
        "JLink`Sharing`Private`pairs", "JLink`Sharing`Private`parentLinkIsFE",
         "JLink`Sharing`Private`parentLinkIsFE$", "JLink`Sharing`Private`per",
         "JLink`Sharing`Private`per$", "JLink`Sharing`Private`pkt", 
        "JLink`Sharing`Private`pos", "JLink`Sharing`Private`pos$", 
        "JLink`Sharing`Private`preemptiveShareKernel", 
        "JLink`Sharing`Private`preemptiveUnshareKernel", 
        "JLink`Sharing`Private`prompt", "JLink`Sharing`Private`Prompt", 
        "JLink`Sharing`Private`prompt$", "JLink`Sharing`Private`protocol", 
        "JLink`Sharing`Private`protocol$", "JLink`Sharing`Private`purge", 
        "JLink`Sharing`Private`p$", "JLink`Sharing`Private`recs", 
        "JLink`Sharing`Private`removeDeadLinks", 
        "JLink`Sharing`Private`removeToken", "JLink`Sharing`Private`result", 
        "JLink`Sharing`Private`result$", "JLink`Sharing`Private`savedOut", 
        "JLink`Sharing`Private`savedOut$", "JLink`Sharing`Private`secs", 
        "JLink`Sharing`Private`sendInputNamePkt", 
        "JLink`Sharing`Private`sendLoopContents", 
        "JLink`Sharing`Private`serverNb", "JLink`Sharing`Private`serverNbs", 
        "JLink`Sharing`Private`serverNbs$", "JLink`Sharing`Private`serverNb$",
         "JLink`Sharing`Private`servicePeriodicals", 
        "JLink`Sharing`Private`serviceShareFrontEnd", 
        "JLink`Sharing`Private`serviceUnshareFrontEnd", 
        "JLink`Sharing`Private`setupServerNb", 
        "JLink`Sharing`Private`setupSyntaxRule", 
        "JLink`Sharing`Private`suppressPacket", 
        "JLink`Sharing`Private`syntaxErrorType", 
        "JLink`Sharing`Private`theseFes", "JLink`Sharing`Private`theseFes$", 
        "JLink`Sharing`Private`tmpOut", "JLink`Sharing`Private`tok", 
        "JLink`Sharing`Private`tokList", "JLink`Sharing`Private`toks", 
        "JLink`Sharing`Private`toks$", "JLink`Sharing`Private`tok$", 
        "JLink`Sharing`Private`unshKernel", "JLink`Sharing`Private`wasOn", 
        "JLink`Sharing`Private`$fes", "JLink`Sharing`Private`$forceTCP", 
        "JLink`Sharing`Private`$loop", 
        "JLink`Sharing`Private`$nextShareKernelToken", 
        "JLink`Sharing`Private`$periodicalLink", 
        "JLink`Sharing`Private`$periodicals", "JLink`Sharing`Private`$prompt",
         "JLink`Sharing`Private`$serverNb", 
        "JLink`Sharing`Private`$shareFrontEndTokens", 
        "JLink`Sharing`Private`$SleepInterval", "Join", "JordanDecomposition",
         "JPanel`ABORT", "JPanel`ALLBITS", "JPanel`BOTTOMUALIGNMENT", 
        "JPanel`CENTERUALIGNMENT", "JPanel`ERROR", "JPanel`FRAMEBITS", 
        "JPanel`getDefaultLocale", "JPanel`HEIGHT", 
        "JPanel`isLightweightComponent", "JPanel`LEFTUALIGNMENT", 
        "JPanel`PROPERTIES", "JPanel`RIGHTUALIGNMENT", 
        "JPanel`setDefaultLocale", "JPanel`SOMEBITS", 
        "JPanel`TOOLUTIPUTEXTUKEY", "JPanel`TOPUALIGNMENT", 
        "JPanel`UNDEFINEDUCONDITION", 
        "JPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", "JPanel`WHENUFOCUSED", 
        "JPanel`WHENUINUFOCUSEDUWINDOW", "JPanel`WIDTH", "JVMArguments", "K", 
        "KeepJavaObject", "KeepObjects", "KernelSharedQ", "Khinchin", 
        "KleinInvariantJ", "KroneckerDelta", "Label", "label1", "label2", 
        "label3", "label4", "label5", "LaguerreL", "Language", 
        "LanguageCategory", "LaplaceTransform", "Larger", "Last", 
        "LatticeReduce", "Launch", "LayoutInformation", "LCM", "LeafCount", 
        "Left", "LegendreP", "LegendreQ", "LegendreType", "Length", 
        "LerchPhi", "Less", "LessEqual", "LetterCharacter", "LetterQ", 
        "Level", "Lexicographic", "LicenseID", "Lighting", "LightSources", 
        "Limit", "LimitsPositioning", "LimitsPositioningTokens", "Limit`t", 
        "Line", "LinearAlgebra`Arnoldi", "LinearAlgebra`BLAS`ASUM", 
        "LinearAlgebra`BLAS`AXPY", "LinearAlgebra`BLAS`COPY", 
        "LinearAlgebra`BLAS`DOT", "LinearAlgebra`BLAS`DOTC", 
        "LinearAlgebra`BLAS`DOTU", "LinearAlgebra`BLAS`GEMM", 
        "LinearAlgebra`BLAS`GEMV", "LinearAlgebra`BLAS`GER", 
        "LinearAlgebra`BLAS`GERC", "LinearAlgebra`BLAS`GERU", 
        "LinearAlgebra`BLAS`HERK", "LinearAlgebra`BLAS`IAMAX", 
        "LinearAlgebra`BLAS`NestedPart", "LinearAlgebra`BLAS`NRM2", 
        "LinearAlgebra`BLAS`ROT", "LinearAlgebra`BLAS`ROTG", 
        "LinearAlgebra`BLAS`SCAL", "LinearAlgebra`BLAS`SWAP", 
        "LinearAlgebra`BLAS`SYRK", "LinearAlgebra`BLAS`TestArgument", 
        "LinearAlgebra`BLAS`TRMM", "LinearAlgebra`BLAS`TRMV", 
        "LinearAlgebra`BLAS`TRSM", "LinearAlgebra`BLAS`TRSV", 
        "LinearAlgebra`Direct", 
        "LinearAlgebra`Implementations`InversePermutation", 
        "LinearAlgebra`Implementations`PermutationQ", 
        "LinearAlgebra`LAPACK`ComputedParams", "LinearAlgebra`LAPACK`GEBAK", 
        "LinearAlgebra`LAPACK`GEBAL", "LinearAlgebra`LAPACK`GECON", 
        "LinearAlgebra`LAPACK`GEEQU", "LinearAlgebra`LAPACK`GEEV", 
        "LinearAlgebra`LAPACK`GEHRD", "LinearAlgebra`LAPACK`GEQP3", 
        "LinearAlgebra`LAPACK`GEQRF", "LinearAlgebra`LAPACK`GERFS", 
        "LinearAlgebra`LAPACK`GESV", "LinearAlgebra`LAPACK`GESVX", 
        "LinearAlgebra`LAPACK`GETRF", "LinearAlgebra`LAPACK`GETRI", 
        "LinearAlgebra`LAPACK`GETRS", "LinearAlgebra`LAPACK`HSEQR", 
        "LinearAlgebra`LAPACK`LACON", "LinearAlgebra`LAPACK`LACPY", 
        "LinearAlgebra`LAPACK`LADIV", "LinearAlgebra`LAPACK`LAHRD", 
        "LinearAlgebra`LAPACK`LALN2", "LinearAlgebra`LAPACK`LAMCH", 
        "LinearAlgebra`LAPACK`LANGE", "LinearAlgebra`LAPACK`LANHS", 
        "LinearAlgebra`LAPACK`LANTR", "LinearAlgebra`LAPACK`LANV2", 
        "LinearAlgebra`LAPACK`LAPY2", "LinearAlgebra`LAPACK`LAQGE", 
        "LinearAlgebra`LAPACK`LARF", "LinearAlgebra`LAPACK`LARFB", 
        "LinearAlgebra`LAPACK`LARFG", "LinearAlgebra`LAPACK`LARFT", 
        "LinearAlgebra`LAPACK`LARFX", "LinearAlgebra`LAPACK`LARTG", 
        "LinearAlgebra`LAPACK`LASCL", "LinearAlgebra`LAPACK`LASET", 
        "LinearAlgebra`LAPACK`LASSQ", "LinearAlgebra`LAPACK`LASWP", 
        "LinearAlgebra`LAPACK`LATRS", "LinearAlgebra`LAPACK`ORGHR", 
        "LinearAlgebra`LAPACK`ORGQR", "LinearAlgebra`LAPACK`ORMQR", 
        "LinearAlgebra`LAPACK`PermutationToPivot", 
        "LinearAlgebra`LAPACK`PivotToPermutation", 
        "LinearAlgebra`LAPACK`POSV", "LinearAlgebra`LAPACK`POTRF", 
        "LinearAlgebra`LAPACK`POTRS", "LinearAlgebra`LAPACK`SYTRF", 
        "LinearAlgebra`LAPACK`SYTRS", "LinearAlgebra`LAPACK`TREVC", 
        "LinearAlgebra`LAPACK`TRTRI", "LinearAlgebra`LAPACK`UNGHR", 
        "LinearAlgebra`LAPACK`UNGQR", "LinearAlgebra`LAPACK`UNMQR", 
        "LinearAlgebra`LeastSquares", 
        "LinearAlgebra`LinearSolve`IterativeRefinement", 
        "LinearAlgebra`LinearSolve`IterativeRefinementLinearSolve", 
        "LinearAlgebra`LinearSolve`Krylov", 
        "LinearAlgebra`MatrixCayleyTransform", 
        "LinearAlgebra`MatrixConditionNumber", 
        "LinearAlgebra`MatrixPolynomial", "LinearAlgebra`Private`MatrixScale",
         "LinearAlgebra`Private`MatrixScalingFactor", 
        "LinearAlgebra`VandermondeInverse", "LinearAlgebra`VandermondeMatrix",
         "LinearAlgebra`VandermondeResidual", 
        "LinearAlgebra`VandermondeSolve", "LinearProgramming", "LinearSolve", 
        "LinearSolveFunction", "LineBreak", "LinebreakAdjustments", 
        "LineBreakWithin", "LineForm", "LineIndent", "LineSpacing", 
        "LineWrapParts", "LinkActivate", "LinkClose", "LinkConnect", 
        "LinkConnectedQ", "LinkCreate", "LinkError", "LinkFlush", "LinkHost", 
        "LinkInterrupt", "LinkLaunch", "LinkMode", "LinkObject", "LinkOpen", 
        "LinkOptions", "LinkPatterns", "LinkProtocol", "LinkRead", 
        "LinkReadHeld", "LinkReadyQ", "Links", "LinkWrite", "LinkWriteHeld", 
        "List", "Listable", "ListContourPlot", "ListConvolve", 
        "ListCorrelate", "ListDensityPlot", "Listen", "ListInterpolation", 
        "ListPlay", "ListPlot", "ListPlot3D", "ListQ", "Literal", 
        "LiteralSearch", "load", "LoadClass", "LoadJavaClass", "loadLibrary", 
        "Locked", "Log", "LogGamma", "LogicalExpand", "LogIntegral", 
        "LongestMatch", "LongForm", "Loopback", "LowerCaseQ", 
        "LUBackSubstitution", "LUDecomposition", "MachineID", "MachineName", 
        "MachineNumberQ", "MachinePrecision", "MacintoshSystemPageSetup", 
        "Magenta", "Magnification", "MainSolve", "MakeBoxes", 
        "MakeExpression", "MakeJavaExpr", "MakeJavaObject", "MakeRules", 
        "MantissaExponent", "Manual", "Map", "MapAll", "MapAt", "MapIndexed", 
        "mapLibraryName", "MapThread", "MatchLocalNameQ", "MatchLocalNames", 
        "MatchQ", "MathematicaModel`create", "MathematicaNotation", 
        "mathFrame", "MathFrame`ABORT", "MathFrame`ALLBITS", 
        "MathFrame`BOTTOMUALIGNMENT", "MathFrame`CENTERUALIGNMENT", 
        "MathFrame`CROSSHAIRUCURSOR", "MathFrame`DEFAULTUCURSOR", 
        "MathFrame`ERROR", "MathFrame`EURESIZEUCURSOR", "MathFrame`FRAMEBITS",
         "MathFrame`getFrames", "MathFrame`HANDUCURSOR", "MathFrame`HEIGHT", 
        "MathFrame`ICONIFIED", "MathFrame`LEFTUALIGNMENT", 
        "MathFrame`MAXIMIZEDUBOTH", "MathFrame`MAXIMIZEDUHORIZ", 
        "MathFrame`MAXIMIZEDUVERT", "MathFrame`MOVEUCURSOR", 
        "MathFrame`NEURESIZEUCURSOR", "MathFrame`NORMAL", 
        "MathFrame`NURESIZEUCURSOR", "MathFrame`NWURESIZEUCURSOR", 
        "MathFrame`PROPERTIES", "MathFrame`RIGHTUALIGNMENT", 
        "MathFrame`SEURESIZEUCURSOR", "MathFrame`SOMEBITS", 
        "MathFrame`SURESIZEUCURSOR", "MathFrame`SWURESIZEUCURSOR", 
        "MathFrame`TEXTUCURSOR", "MathFrame`TOPUALIGNMENT", 
        "MathFrame`WAITUCURSOR", "MathFrame`WIDTH", 
        "MathFrame`WURESIZEUCURSOR", "MathGraphicsJPanel`ABORT", 
        "MathGraphicsJPanel`ALLBITS", "MathGraphicsJPanel`BOTTOMUALIGNMENT", 
        "MathGraphicsJPanel`CENTERUALIGNMENT", "MathGraphicsJPanel`ERROR", 
        "MathGraphicsJPanel`FRAMEBITS", "MathGraphicsJPanel`getDefaultLocale",
         "MathGraphicsJPanel`GRAPHICS", "MathGraphicsJPanel`HEIGHT", 
        "MathGraphicsJPanel`isLightweightComponent", 
        "MathGraphicsJPanel`LEFTUALIGNMENT", "MathGraphicsJPanel`PROPERTIES", 
        "MathGraphicsJPanel`RIGHTUALIGNMENT", 
        "MathGraphicsJPanel`setDefaultLocale", "MathGraphicsJPanel`SOMEBITS", 
        "MathGraphicsJPanel`TOOLUTIPUTEXTUKEY", 
        "MathGraphicsJPanel`TOPUALIGNMENT", "MathGraphicsJPanel`TYPESET", 
        "MathGraphicsJPanel`UNDEFINEDUCONDITION", 
        "MathGraphicsJPanel`WHENUANCESTORUOFUFOCUSEDUCOMPONENT", 
        "MathGraphicsJPanel`WHENUFOCUSED", 
        "MathGraphicsJPanel`WHENUINUFOCUSEDUWINDOW", 
        "MathGraphicsJPanel`WIDTH", "MathieuC", "MathieuCharacteristicA", 
        "MathieuCharacteristicB", "MathieuCharacteristicExponent", 
        "MathieuCPrime", "MathieuS", "MathieuSPrime", "MathJFrame`ABORT", 
        "MathJFrame`ALLBITS", "MathJFrame`BOTTOMUALIGNMENT", 
        "MathJFrame`CENTERUALIGNMENT", "MathJFrame`CROSSHAIRUCURSOR", 
        "MathJFrame`DEFAULTUCURSOR", "MathJFrame`DISPOSEUONUCLOSE", 
        "MathJFrame`DOUNOTHINGUONUCLOSE", "MathJFrame`ERROR", 
        "MathJFrame`EURESIZEUCURSOR", "MathJFrame`EXITUONUCLOSE", 
        "MathJFrame`FRAMEBITS", "MathJFrame`getFrames", 
        "MathJFrame`HANDUCURSOR", "MathJFrame`HEIGHT", 
        "MathJFrame`HIDEUONUCLOSE", "MathJFrame`ICONIFIED", 
        "MathJFrame`isDefaultLookAndFeelDecorated", 
        "MathJFrame`LEFTUALIGNMENT", "MathJFrame`MAXIMIZEDUBOTH", 
        "MathJFrame`MAXIMIZEDUHORIZ", "MathJFrame`MAXIMIZEDUVERT", 
        "MathJFrame`MOVEUCURSOR", "MathJFrame`NEURESIZEUCURSOR", 
        "MathJFrame`NORMAL", "MathJFrame`NURESIZEUCURSOR", 
        "MathJFrame`NWURESIZEUCURSOR", "MathJFrame`PROPERTIES", 
        "MathJFrame`RIGHTUALIGNMENT", 
        "MathJFrame`setDefaultLookAndFeelDecorated", 
        "MathJFrame`SEURESIZEUCURSOR", "MathJFrame`SOMEBITS", 
        "MathJFrame`SURESIZEUCURSOR", "MathJFrame`SWURESIZEUCURSOR", 
        "MathJFrame`TEXTUCURSOR", "MathJFrame`TOPUALIGNMENT", 
        "MathJFrame`WAITUCURSOR", "MathJFrame`WIDTH", 
        "MathJFrame`WURESIZEUCURSOR", "MathLink`AddSharingLink", 
        "MathLink`AllowPreemptive", "MathLink`CallFrontEnd", 
        "MathLink`CallFrontEndHeld", "MathLink`CreateFrontEndLink", 
        "MathLink`CreateFrontEndLinkProtocol", "MathLink`CreateFrontEndLinks",
         "MathLink`EnablePreemptiveFunctions", "MathLink`FrontEndBlock", 
        "MathLink`GetMessageLink", "MathLink`ImmediateStart", 
        "MathLink`Information`$InterfaceNumber", 
        "MathLink`Information`$RevisionNumber", "MathLink`IsNotebookFrontEnd",
         "MathLink`IsPreemptive", "MathLink`LinkAddInterruptMessageHandler", 
        "MathLink`LinkDeviceInformation", "MathLink`LinkGetPrintFullSymbols", 
        "MathLink`LinkRemoveInterruptMessageHandler", 
        "MathLink`LinkRemoveYieldFunction", 
        "MathLink`LinkSetPrintFullSymbols", "MathLink`LinkSwitchPost", 
        "MathLink`LinkSwitchPre", "MathLink`MainLoopIdleEvaluation", 
        "MathLink`NotebookFrontEndLinkQ", "MathLink`RemoveSharingLink", 
        "MathLink`RestoreFrontEnd", "MathLink`SetFrontEnd", 
        "MathLink`SetMessageLink", "MathLink`SetServiceFrontEnd", 
        "MathLink`SharingLinks", "MathLink`$PreemptiveLink", 
        "MathLink`$ServiceLink", "MathLink`$SlaveLink", "MathMLForm", 
        "MathMLText", "mathPanel", "MatrixExp", "MatrixForm", "MatrixPower", 
        "MatrixQ", "MatrixRank", "Max", "MaxBend", "Maximize", 
        "MaxIterations", "MaxMemoryUsed", "MaxPlotPoints", "MaxPoints", 
        "MaxRecursion", "MaxStepFraction", "MaxSteps", "MaxStepSize", "Mean", 
        "Median", "MeijerG", "MemberQ", "MemoryConstrained", "MemoryInUse", 
        "MenuPacket", "Mesh", "MeshRange", "MeshStyle", "Message", 
        "MessageList", "MessageName", "MessageOptions", "MessagePacket", 
        "Messages", "MessagesNotebook", "MetaCharacters", "Method", 
        "MethodFunction", "MethodOptions", "Methods", "Min", "minAgent", 
        "minAgent$", "minDist", "minDist$", "Minimize", "Minors", 
        "MinRecursion", "MinSize", "Minus", "MLFS`Close", 
        "MLFS`CopyDirectory", "MLFS`CopyFile", "MLFS`CreateDirectory", 
        "MLFS`DeleteDirectory", "MLFS`DeleteFile", "MLFS`FileByteCount", 
        "MLFS`FileDate", "MLFS`FileNames", "MLFS`FileType", "MLFS`Get", 
        "MLFS`OpenAppend", "MLFS`OpenRead", "MLFS`OpenWrite", "MLFS`Put", 
        "MLFS`PutAppend", "MLFS`Read", "MLFS`RenameDirectory", 
        "MLFS`RenameFile", "MLFS`SetFileDate", "MLFS`SetStreamPosition", 
        "MLFS`StreamPosition", "MLFS`WriteString", "mml", "Mod", "Mode", 
        "Modular", "ModularLambda", "Module", "Modulus", "MoebiusMu", 
        "MonomialOrder", "MonteCarlo", "Most", "motion", "motion0", 
        "MouseEvent`ACTIONUEVENTUMASK", "MouseEvent`ADJUSTMENTUEVENTUMASK", 
        "MouseEvent`ALTUDOWNUMASK", "MouseEvent`ALTUGRAPHUDOWNUMASK", 
        "MouseEvent`ALTUGRAPHUMASK", "MouseEvent`ALTUMASK", 
        "MouseEvent`BUTTON1", "MouseEvent`BUTTON1UDOWNUMASK", 
        "MouseEvent`BUTTON1UMASK", "MouseEvent`BUTTON2", 
        "MouseEvent`BUTTON2UDOWNUMASK", "MouseEvent`BUTTON2UMASK", 
        "MouseEvent`BUTTON3", "MouseEvent`BUTTON3UDOWNUMASK", 
        "MouseEvent`BUTTON3UMASK", "MouseEvent`COMPONENTUEVENTUMASK", 
        "MouseEvent`COMPONENTUFIRST", "MouseEvent`COMPONENTUHIDDEN", 
        "MouseEvent`COMPONENTULAST", "MouseEvent`COMPONENTUMOVED", 
        "MouseEvent`COMPONENTURESIZED", "MouseEvent`COMPONENTUSHOWN", 
        "MouseEvent`CONTAINERUEVENTUMASK", "MouseEvent`CTRLUDOWNUMASK", 
        "MouseEvent`CTRLUMASK", "MouseEvent`FOCUSUEVENTUMASK", 
        "MouseEvent`getModifiersExText", "MouseEvent`getMouseModifiersText", 
        "MouseEvent`HIERARCHYUBOUNDSUEVENTUMASK", 
        "MouseEvent`HIERARCHYUEVENTUMASK", 
        "MouseEvent`INPUTUMETHODUEVENTUMASK", 
        "MouseEvent`INVOCATIONUEVENTUMASK", "MouseEvent`ITEMUEVENTUMASK", 
        "MouseEvent`KEYUEVENTUMASK", "MouseEvent`METAUDOWNUMASK", 
        "MouseEvent`METAUMASK", "MouseEvent`MOUSEUCLICKED", 
        "MouseEvent`MOUSEUDRAGGED", "MouseEvent`MOUSEUENTERED", 
        "MouseEvent`MOUSEUEVENTUMASK", "MouseEvent`MOUSEUEXITED", 
        "MouseEvent`MOUSEUFIRST", "MouseEvent`MOUSEULAST", 
        "MouseEvent`MOUSEUMOTIONUEVENTUMASK", "MouseEvent`MOUSEUMOVED", 
        "MouseEvent`MOUSEUPRESSED", "MouseEvent`MOUSEURELEASED", 
        "MouseEvent`MOUSEUWHEEL", "MouseEvent`MOUSEUWHEELUEVENTUMASK", 
        "MouseEvent`NOBUTTON", "MouseEvent`PAINTUEVENTUMASK", 
        "MouseEvent`RESERVEDUIDUMAX", "MouseEvent`SHIFTUDOWNUMASK", 
        "MouseEvent`SHIFTUMASK", "MouseEvent`TEXTUEVENTUMASK", 
        "MouseEvent`WINDOWUEVENTUMASK", "MouseEvent`WINDOWUFOCUSUEVENTUMASK", 
        "MouseEvent`WINDOWUSTATEUEVENTUMASK", "mouseOffset", "mouseOffset$", 
        "MousePointerNote", "mousePressedFunc", "MultiDimensional", 
        "MultilaunchWarning", "MultilineFunction", "Multinomial", 
        "MultiplicativeOrder", "Multiplicity", 
        "MultivariateResultant`DixonResultant", 
        "MultivariateResultant`MacaulayResultant", 
        "MultivariateResultant`ResultantSystems", 
        "MultivariateResultant`UResultant", "N", "NameQ", "Names", "Nand", 
        "NBernoulliB", "NDSolve", "NDSolve`Adams", 
        "NDSolve`BaderSequenceFunction", "NDSolve`BDF", 
        "NDSolve`BulirschSequenceFunction", "NDSolve`Chasing", 
        "NDSolve`Chasing`Implementation`ChaseInitialConditions", 
        "NDSolve`Chasing`NonlinearChasing", "NDSolve`Composition", 
        "NDSolve`ConsistentCoefficientsQ", "NDSolve`CreateMethodData", 
        "NDSolve`CreateWorkspace", "NDSolve`CreateWorkspaceList", 
        "NDSolve`CubicHermite", "NDSolve`DCayleyInverse", 
        "NDSolve`DExpInverse", "NDSolve`DExpInverseCoefficients", 
        "NDSolve`DoubleStep", 
        "NDSolve`EmbeddedExplicitRungeKuttaCoefficients", 
        "NDSolve`EstimateStartingStep", "NDSolve`EventLocator", 
        "NDSolve`EventLocator`BracketEvent", "NDSolve`EventLocator`Brent", 
        "NDSolve`ExplicitEuler", "NDSolve`ExplicitMidpoint", 
        "NDSolve`ExplicitModifiedMidpoint", "NDSolve`ExplicitRungeKutta", 
        "NDSolve`Extrapolation", "NDSolve`FiniteDifferenceDerivative", 
        "NDSolve`FiniteDifferenceDerivativeFunction", 
        "NDSolve`FiniteDifferenceDerivativeFunction`Grid", 
        "NDSolve`FixedPoint", "NDSolve`FixedStep", 
        "NDSolve`GetDefaultDifferenceOrder", "NDSolve`GetMethodOptionValues", 
        "NDSolve`GMRES", "NDSolve`HairerOstermannSequenceFunction", 
        "NDSolve`HarmonicSequenceFunction", "NDSolve`IDA", 
        "NDSolve`ImplicitRungeKutta", 
        "NDSolve`ImplicitRungeKuttaAdjointCoefficients", 
        "NDSolve`ImplicitRungeKuttaCoefficients", 
        "NDSolve`ImplicitRungeKuttaGaussCoefficients", 
        "NDSolve`ImplicitRungeKuttaLobattoIIIACoefficients", 
        "NDSolve`ImplicitRungeKuttaLobattoIIIBCoefficients", 
        "NDSolve`ImplicitRungeKuttaLobattoIIICCoefficients", 
        "NDSolve`ImplicitRungeKuttaRadauIACoefficients", 
        "NDSolve`ImplicitRungeKuttaRadauIIACoefficients", 
        "NDSolve`InitializeMethod", "NDSolve`InitializeSubmethod", 
        "NDSolve`InitializeSubmethods", "NDSolve`InvokeMethod", 
        "NDSolve`Iterate", "NDSolve`LinearlyImplicitEuler", 
        "NDSolve`LinearlyImplicitMidpoint", 
        "NDSolve`LinearlyImplicitModifiedMidpoint", 
        "NDSolve`LocalInterpolation", "NDSolve`LocallyExact", 
        "NDSolve`LocalSeries", "NDSolve`LSODA", "NDSolve`MethodData", 
        "NDSolve`MethodOfLines", "NDSolve`MethodOfLines`TensorProductGrid", 
        "NDSolve`MethodSymbol", "NDSolve`Newton", "NDSolve`Newton`Band", 
        "NDSolve`NumericalFunctionToEquations", 
        "NDSolve`OptimalRoundingSequenceFunction", 
        "NDSolve`OrthogonalProjection", "NDSolve`Private`TestIVPCopy", 
        "NDSolve`ProcessEquations", "NDSolve`ProcessOptionNames", 
        "NDSolve`ProcessSolutions", "NDSolve`Projection", 
        "NDSolve`Reinitialize", "NDSolve`ReinitializeVector", 
        "NDSolve`RombergSequenceFunction", "NDSolve`SamePrecisionQ", 
        "NDSolve`ScaledVectorNorm", "NDSolve`Splitting", "NDSolve`StateData", 
        "NDSolve`StateData`ProcessExpression", "NDSolve`StiffnessSwitching", 
        "NDSolve`StiffnessTest", "NDSolve`StiffnessTestOptionValues", 
        "NDSolve`StringName", "NDSolve`SymmetricCompositionCoefficients", 
        "NDSolve`SymmetricCompositionSymmetricMethodCoefficients", 
        "NDSolve`SymplecticPartitionedRungeKutta", 
        "NDSolve`SymplecticPartitionedRungeKuttaCoefficients", 
        "NDSolve`TestImplicitSolver", "NDSolve`ToSymbol", 
        "NDSolve`ValidNumericalFunctionQ", "NDSolve`ValidScaledVectorNormQ", 
        "NDSolve`$EventSolution", "NDSolve`$NDSolveVersion", 
        "NeedCurrentFrontEndPackagePacket", 
        "NeedCurrentFrontEndSymbolsPacket", "Needs", "Negative", "Nest", 
        "NestedScriptRules", "NestList", "NestWhile", "NestWhileList", 
        "NETLink`NETLink", "NETLink`NETObjectQ", 
        "NETLink`Package`nAllowUIComputations", 
        "NETLink`Package`nConnectToFEServer", 
        "NETLink`Package`nDisconnectToFEServer", 
        "NETLink`Package`nShareKernel", "NevilleThetaC", "NevilleThetaD", 
        "NevilleThetaN", "NevilleThetaS", "Newton", "Next", "NHoldAll", 
        "NHoldFirst", "NHoldRest", "NIntegrate", "NIntegrate`OscNInt`OscNInt",
         "NMaximize", "NMinimize", "NMinimize`DifferentialEvolution", 
        "NMinimize`NelderMead", "NMinimize`NonlinearInteriorPoint", 
        "NMinimize`RandomSearch", "NMinimize`SimulatedAnnealing", 
        "NonAssociative", "NonCommutativeMultiply", "NonConstants", "None", 
        "NonNegative", "NonPositive", "Nor", "Norm", "Normal", 
        "NormalGrouping", "NormalSelection", "NormFunction", "Not", 
        "Notebook", "NotebookApply", "NotebookAutoSave", "NotebookClose", 
        "NotebookConvert", "NotebookConvertSettings", "NotebookCreate", 
        "NotebookCreateReturnObject", "NotebookDefault", "NotebookDelete", 
        "NotebookDirectory", "NotebookFind", "NotebookFindReturnObject", 
        "NotebookGet", "NotebookGetLayoutInformationPacket", 
        "NotebookGetMisspellingsPacket", "NotebookInformation", 
        "NotebookLocate", "NotebookObject", "NotebookOpen", 
        "NotebookOpenReturnObject", "NotebookPath", "NotebookPrint", 
        "NotebookPut", "NotebookPutReturnObject", "NotebookRead", 
        "NotebookResetGeneratedCells", "Notebooks", "NotebookSave", 
        "NotebookSaveAs", "NotebookSelection", 
        "NotebookSetupLayoutInformationPacket", "NotebooksMenu", 
        "NotebookWrite", "NotElement", "NProduct", "NProductExtraFactors", 
        "NProductFactors", "NRoots", "NSolve", "NSum", "NSumExtraTerms", 
        "NSumTerms", "Null", "NullRecords", "NullSpace", "NullWords", 
        "numAgents", "numAgents0", "numAgentsUser", "Number", "NumberForm", 
        "NumberFormat", "NumberMarks", "NumberMultiplier", "NumberPadding", 
        "NumberPoint", "NumberQ", "NumberSeparator", "NumberSigns", 
        "NumberString", "NumberTheory`AlgebraicNumberFields`Algebraic", 
        "NumberTheory`AlgebraicNumberFields`AlgebraicIntegerQ", 
        "NumberTheory`AlgebraicNumberFields`AlgebraicNumberDenominator", 
        "NumberTheory`AlgebraicNumberFields`AlgebraicNumberNorm", 
        "NumberTheory`AlgebraicNumberFields`AlgebraicNumberTrace", 
        "NumberTheory`AlgebraicNumberFields`AlgebraicUnitQ", 
        "NumberTheory`AlgebraicNumberFields`FundamentalUnits", 
        "NumberTheory`AlgebraicNumberFields`IntegralBasis", 
        "NumberTheory`AlgebraicNumberFields`MinimalPolynomial", 
        "NumberTheory`AlgebraicNumberFields`NormRepresentatives", 
        "NumberTheory`AlgebraicNumberFields`\
NumberFieldCharacteristicPolynomial", 
        "NumberTheory`AlgebraicNumberFields`NumberFieldDiscriminant", 
        "NumberTheory`AlgebraicNumberFields`NumberFieldNorm", 
        "NumberTheory`AlgebraicNumberFields`NumberFieldRegulator", 
        "NumberTheory`AlgebraicNumberFields`NumberFieldSignature", 
        "NumberTheory`AlgebraicNumberFields`NumberFieldTrace", 
        "NumberTheory`AlgebraicNumberFields`RootOfUnityQ", 
        "NumberTheory`AlgebraicNumberFields`RootsOfUnity", 
        "NumberTheory`AlgebraicNumberFields`SmallestField", 
        "NumberTheory`AlgebraicNumberFields`ToCommonField", 
        "NumberTheory`AlgebraicNumberFields`ToNumberFieldElement", 
        "NumberTheory`PrimePower", "NumberTheory`PrimitiveRootQ", 
        "numCollisions", "numCollisions$", "Numerator", 
        "NumericalMath`FixedPrecisionEvaluate", "NumericalMath`$NumberBits", 
        "NumericFunction", "NumericQ", "NValues", "O", "OddQ", "Off", 
        "offscreen", "OffScreenImage`SCALEUAREAUAVERAGING", 
        "OffScreenImage`SCALEUDEFAULT", "OffScreenImage`SCALEUFAST", 
        "OffScreenImage`SCALEUREPLICATE", "OffScreenImage`SCALEUSMOOTH", 
        "OffScreenImage`TYPEU3BYTEUBGR", "OffScreenImage`TYPEU4BYTEUABGR", 
        "OffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "OffScreenImage`TYPEUBYTEUBINARY", "OffScreenImage`TYPEUBYTEUGRAY", 
        "OffScreenImage`TYPEUBYTEUINDEXED", "OffScreenImage`TYPEUCUSTOM", 
        "OffScreenImage`TYPEUINTUARGB", "OffScreenImage`TYPEUINTUARGBUPRE", 
        "OffScreenImage`TYPEUINTUBGR", "OffScreenImage`TYPEUINTURGB", 
        "OffScreenImage`TYPEUUSHORTU555URGB", 
        "OffScreenImage`TYPEUUSHORTU565URGB", 
        "OffScreenImage`TYPEUUSHORTUGRAY", "OffScreenImage`UndefinedProperty",
         "offSet", "Offset", "OLEData", "On", "OneIdentity", 
        "OneStepRowReduction", "Open", "OpenAppend", 
        "OpenFunctionInspectorPacket", "OpenRead", "OpenSpecialOptions", 
        "OpenTemporary", "OpenWrite", "Operate", 
        "Optimization`InternalModifiedCholesky", "OptimizationLevel", 
        "Optimization`LinearProgramming`CheckDualLinearProgrammingSolution", 
        "Optimization`LinearProgramming`DualLinearProgrammingNM", 
        "Optimization`LinearProgramming`InteriorPoint", 
        "Optimization`LinearProgramming`LinearProgrammingCaller", 
        "Optimization`LinearProgramming`Private`MPS2LP", 
        "Optimization`LinearProgramming`Simplex", 
        "Optimization`LinearProgramming`TryLinearProgramming", 
        "Optimization`LineSearch", "Optimization`LineSearch`Backtracking", 
        "Optimization`ModifiedCholeskyDecomposition", 
        "Optimization`MPSData`MPSData", "Optimization`NonlinearInteriorPoint",
         "Optimization`TrustRegion", "Optional", "OptionInspectorSettings", 
        "OptionQ", "Options", "OptionsPacket", "OptionValueBox", 
        "OptionValueBoxOptions", "opts", "Or", "Orange", "Order", "OrderedQ", 
        "Ordering", "Orderless", "Oscillatory", "out", "Out", "Outer", 
        "OutputAutoOverwrite", "OutputForm", "OutputFormData", 
        "OutputGrouping", "OutputMathEditExpression", "OutputNamePacket", 
        "OutputStream", "OutputToOutputForm", "OutputToStandardForm", "Over", 
        "Overflow", "Overlaps", "Overscript", "OverscriptBox", 
        "OverscriptBoxOptions", "OwnValues", "PaddedForm", "PadLeft", 
        "PadRight", "PageBreakAbove", "PageBreakBelow", "PageBreakWithin", 
        "PageFooterLines", "PageFooters", "PageHeaderLines", "PageHeaders", 
        "PageHeight", "PageWidth", "PalettePath", "panelFrameSizeX", 
        "panelFrameSizeY", "PaperWidth", "ParagraphIndent", 
        "ParagraphSpacing", "ParameterVariables", "ParametricPlot", 
        "ParametricPlot3D", "ParentClass", "ParentConnect", "ParentDirectory",
         "ParentForm", "Parenthesize", "Part", "Partition", "PartitionsP", 
        "PartitionsQ", "PasteBoxFormInlineCells", "Path", "Pattern", 
        "PatternTest", "Pause", "PeekClasses", "PeekObjects", "Periodical", 
        "Periodicals", "PeriodicInterpolation", "Permutations", "Pi", "Pick", 
        "Piecewise", "PiecewiseExpand", "Pink", "Pivoting", 
        "PixelConstrained", "Placeholder", "Plain", "Play", "PlayRange", 
        "Plot", "Plot3D", "Plot3Matrix", "PlotDivision", "PlotJoined", 
        "PlotLabel", "PlotPoints", "PlotRange", "PlotRegion", "PlotStyle", 
        "Plus", "Pochhammer", "Point", "PointForm", "PointSize", "PolyGamma", 
        "Polygon", "PolygonIntersections", "PolyLog", "PolynomialForm", 
        "PolynomialGCD", "PolynomialLCM", "PolynomialMod", "PolynomialQ", 
        "PolynomialQuotient", "PolynomialReduce", "PolynomialRemainder", 
        "Polynomials", "Position", "Positive", "Postfix", "PostScript", 
        "Power", "PowerExpand", "PowerMod", "PowerModList", "Precedence", 
        "PrecedenceForm", "Precision", "PrecisionGoal", "PreDecrement", 
        "PreferencesPath", "Prefix", "PreIncrement", "Prepend", "PrependTo", 
        "PreserveStyleSheet", "Previous", "PrimaryPlaceholder", "Prime", 
        "PrimePi", "PrimeQ", "Primes", "PrincipalValue", "Print", 
        "PrintAction", "PrintForm", "PrintingCopies", "PrintingOptions", 
        "PrintingPageRange", "PrintingStartingPageNumber", 
        "PrintingStyleEnvironment", "PrintPrecision", "PrivateCellOptions", 
        "PrivateEvaluationOptions", "PrivateFontOptions", 
        "PrivateNotebookOptions", "PrivatePaths", "probeFrame", "probeFrameX",
         "probeFrameXDim", "probeFrameXDim$", "probeFrameX$", "probeFrameY", 
        "probeFrameYDim", "probeFrameYDim$", "probeFrameY$", "probeLayout", 
        "Product", "ProductLog", "programName", "programName$", "Prolog", 
        "PromptForm", "Protect", "Protected", "Proxy`newProxyInstance", 
        "PseudoInverse", "Purple", "Put", "PutAppend", "QRDecomposition", 
        "Quantifier`LocalVariable", "Quantifier`LocalVariable$1", 
        "Quantifier`LocalVariable$10", "Quantifier`LocalVariable$2", 
        "Quantifier`LocalVariable$3", "Quantifier`LocalVariable$4", 
        "Quantifier`LocalVariable$5", "Quantifier`LocalVariable$6", 
        "Quantifier`LocalVariable$7", "Quantifier`LocalVariable$8", 
        "Quantifier`LocalVariable$9", "Quantile", "Quartics", 
        "QuasiMonteCarlo", "QuasiNewton", "Quit", "QuitJava", "Quotient", 
        "RadicalBox", "RadicalBoxOptions", "Random", "RandomSeed", "Range", 
        "Raster", "RasterArray", "Rational", "RationalFunctions", 
        "Rationalize", "Rationals", "Raw", "RawData", "RawMedium", "Re", 
        "Read", "ReadList", "ReadProtected", "Real", "RealBlockForm", 
        "RealDigits", "Reals", "Reap", "Record", "RecordLists", 
        "RecordSeparators", "Rectangle", "Red", "Reduce", 
        "Reduce`AnalyticMinimize", "Reduce`AnnotatedPolynomial", 
        "Reduce`BQDReduce", "Reduce`CADAlgVar", "Reduce`CADPoint", 
        "Reduce`CADVar", "Reduce`CongruenceReduce", "Reduce`CPInstance", 
        "Reduce`CPReduce", "Reduce`Discontinuities", "Reduce`DISieve", 
        "Reduce`ExpandReduce", "Reduce`FindMatrixIndices", 
        "Reduce`FindNegativeValue", "Reduce`InertIm", "Reduce`InertPower", 
        "Reduce`InertRe", "Reduce`InexactPoint", "Reduce`IntegerRoots", 
        "Reduce`LinearDiophantineSolve", "Reduce`MinAuxVar", 
        "Reduce`ModReduce", "Reduce`NaturalLinearSolve", 
        "Reduce`NonlinearDiophantineReduce", "Reduce`ParamCleanup", 
        "Reduce`PrepElem", "Reduce`ProductExp", 
        "Reduce`QuadNormRepresentatives", "Reduce`RationalNumberQ", 
        "Reduce`RChineseRemainder", "Reduce`RealAlgDec", 
        "Reduce`ReduceInstance", "Reduce`ReduceToRules", "Reduce`ReduceVar", 
        "Reduce`SolutionQ", "Reduce`SortAnswer", "Reduce`SqrtMod2k", 
        "Reduce`SqrtModpk", "Reduce`SumOfSquaresReps", "Reduce`ThueReduce", 
        "Reduce`ToDNF", "Reduce`ToRationalNumber", 
        "Reduce`TranscendentalReduce", "Reduce`TryDivisibility", 
        "Reduce`UniqueParameters", "Reduce`UnivariateOptimize", 
        "Reduce`ZeroDimRealSol", "Refine", "Refresh", "RegularExpression", 
        "Reinstall", "ReinstallJava", "Relative", "Release", "ReleaseHold", 
        "ReleaseJavaObject", "ReleaseObject", "Remove", "Removed", 
        "RemovePeriodical", "RenameDirectory", "RenameFile", "RenderAll", 
        "RenderingOptions", "Repeated", "RepeatedNull", "RepeatedString", 
        "Replace", "ReplaceAll", "ReplaceHeldPart", "ReplaceList", 
        "ReplacePart", "ReplaceRepeated", "Rescale", "ResetDirectory", 
        "ResetMenusPacket", "Residue", "Resolve", "Rest", "RestartJava", 
        "Resultant", "ResumePacket", "Return", "ReturnAsJavaObject", 
        "ReturnExpressionPacket", "ReturnInputFormPacket", "ReturnPacket", 
        "ReturnTextPacket", "Reverse", "RGBColor", "RiemannSiegelTheta", 
        "RiemannSiegelZ", "Right", "Root", "RootReduce", "Roots", "RootSum", 
        "RotateLabel", "RotateLeft", "RotateRight", "Round", "Row", 
        "RowAlignments", "RowBox", "RowLines", "RowMinHeight", "RowReduce", 
        "RowsEqual", "RowSpacings", "RSolve", "RSolve`qRSolve", 
        "RSolve`RSolve2Order1NonlinearODEs", 
        "RSolve`RSolveBoundaryValueProblem", 
        "RSolve`RSolveCoreNilpotentDecomposition", 
        "RSolve`RSolveDegreeBoundForPolynomialSolutionsOfLinearFirstOrderODEs"\
, "RSolve`RSolveDelta", "RSolve`RSolveDenominatorsOfRationalSolutions", 
        "RSolve`RSolveDispatchFirstOrderODEs", "RSolve`RSolveDispatchODE", 
        "RSolve`RSolveDispatchPDE", "RSolve`RSolveFirstOrderODE", 
        "RSolve`RSolveFirstOrderODEs", "RSolve`RSolveFlatten", 
        "RSolve`RSolveHigherOrderODE", "RSolve`RSolveLinearExactODE", 
        "RSolve`RSolveLinearFirstOrderDAEs", 
        "RSolve`RSolveLinearHomogeneousWithConstantCoefficients", 
        "RSolve`RSolveLinearWithRationalCoefficients", 
        "RSolve`RSolveMethodOfUndeterminedCoefficients", 
        "RSolve`RSolveNonZeroQ", "RSolve`RSolveOuter", "RSolve`RSolveParser", 
        "RSolve`RSolvePDE", "RSolve`RSolvePFQTypeSolutions", 
        "RSolve`RSolveProduct", "RSolve`RSolveRationalQ", 
        "RSolve`RSolveRationalSolutions", 
        "RSolve`RSolveRationalSolutionsOfLinearFirstOrderODEs", 
        "RSolve`RSolveSecondOrderODE", 
        "RSolve`RSolveSpecialLinearSecondOrderODE", 
        "RSolve`RSolveSuccessiveReductionOfOrder", "RSolve`RSolveSum", 
        "RSolve`RSolveToPureFunction", "RSolve`RSolveTransformations", 
        "RSolve`RSolveValuation", "RSolve`RSolveVariationOfParameters", 
        "RSolve`RSolveZeroQ", "RSolve`$RSolveLeafCountConstraint", "Rule", 
        "RuleCondition", "RuleDelayed", "RuleForm", "RulerUnits", "Run", 
        "runFinalization", "runFinalizersOnExit", "RunThrough", 
        "RuntimeTools`AddMessageBreaks", "RuntimeTools`AddwatchBreaks", 
        "RuntimeTools`BreakEnable", "RuntimeTools`BreakNow", 
        "RuntimeTools`ChangeBreakpoint", "RuntimeTools`DebugAbort", 
        "RuntimeTools`DebugFinish", "RuntimeTools`DebugHandle", 
        "RuntimeTools`DebugNext", "RuntimeTools`DebugOff", 
        "RuntimeTools`DebugOn", "RuntimeTools`DebugStep", 
        "RuntimeTools`DropMessageBreaks", "RuntimeTools`DropWatchBreaks", 
        "RuntimeTools`EvaluationStack", "RuntimeTools`EvaluationStackBlock", 
        "RuntimeTools`ExecutionState", "RuntimeTools`GetBreakpoints", 
        "RuntimeTools`GetMessageBreaks", "RuntimeTools`GetTagInformation", 
        "RuntimeTools`GetTags", "RuntimeTools`GetWatchBreaks", 
        "RuntimeTools`LockedStack", "RuntimeTools`Profile", 
        "RuntimeTools`ProfileFunction", "RuntimeTools`SetBreakpoints", 
        "RuntimeTools`SetExecutionState", 
        "RuntimeTools`SetExpressionWatchpoints", 
        "RuntimeTools`SetMessageBreaks", "RuntimeTools`SetRuntimeMode", 
        "RuntimeTools`SetWatchBreaks", "RuntimeTools`TagNull", 
        "RuntimeTools`TagToExpr", "RuntimeTools`TagToExprs", 
        "RuntimeTools`TimeLimit", "RuntimeTools`ToolsInitialize", 
        "RuntimeTools`ToolsUninitialize", "RuntimeTools`ToTag", 
        "RuntimeTools`Tracing", "RuntimeTools`TreeSize", "SameObjectQ", 
        "SameQ", "SameTest", "SampleDepth", "SampledSoundFunction", 
        "SampledSoundList", "SampleRate", "Save", "Saveable", 
        "SaveAutoDelete", "Scaled", "Scan", "scheduleMethodBeginning", 
        "SchurDecomposition", "ScientificForm", "ScreenRectangle", 
        "ScreenStyleEnvironment", "ScriptBaselineShifts", "ScriptLevel", 
        "ScriptMinSize", "ScriptRules", "ScriptSizeMultipliers", 
        "Scrollbar`ABORT", "Scrollbar`ALLBITS", "Scrollbar`BOTTOMUALIGNMENT", 
        "Scrollbar`CENTERUALIGNMENT", "Scrollbar`ERROR", 
        "Scrollbar`FRAMEBITS", "Scrollbar`HEIGHT", "Scrollbar`HORIZONTAL", 
        "Scrollbar`LEFTUALIGNMENT", "Scrollbar`NOUORIENTATION", 
        "Scrollbar`PROPERTIES", "Scrollbar`RIGHTUALIGNMENT", 
        "Scrollbar`SOMEBITS", "Scrollbar`TOPUALIGNMENT", "Scrollbar`VERTICAL",
         "Scrollbar`WIDTH", "ScrollingOptions", "scrollPos", "ScrollPosition",
         "Sec", "Sech", "Second", "SectionGrouping", "SeedRandom", "Select", 
        "Selectable", "SelectedNotebook", "Selection", "SelectionAnimate", 
        "SelectionCell", "SelectionCellCreateCell", 
        "SelectionCellDefaultStyle", "SelectionCellParentStyle", 
        "SelectionCreateCell", "SelectionDuplicateCell", "SelectionEvaluate", 
        "SelectionEvaluateCreateCell", "SelectionMove", "SelectionSetStyle", 
        "SelectionStrategy", "SendFontInformationToKernel", "Sequence", 
        "SequenceForm", "SequenceHold", "SequenceLimit", "Series", 
        "SeriesCoefficient", "SeriesData", "ServiceJava", "SessionTime", 
        "Set", "SetAccuracy", "setAlignment", "SetAttributes", "setBounds", 
        "SetBoxFormNamesPacket", "setColor", "SetComplexClass", "SetDelayed", 
        "SetDirectory", "setEditable", "setErr", "SetEvaluationNotebook", 
        "SetField", "SetFileDate", "SetFileLoadingContext", "setHandler", 
        "setImage", "setIn", "SetInternetProxy", "setLayout", "setModal", 
        "SetNotebookStatusLine", "SetOptions", "SetOptionsPacket", "setOut", 
        "SetPeriodicalInterval", "SetPersistentFrontEnd", "SetPrecision", 
        "setProperties", "setProperty", "setResizable", "setSecurityManager", 
        "SetSelectedNotebook", "SetSpeechParametersPacket", 
        "SetStreamPosition", "setText", "SetValue", "setVisible", "Shading", 
        "Shallow", "Share", "ShareFrontEnd", "ShareKernel", "SharingLinks", 
        "SharingPrompt", "Short", "ShortestMatch", "Show", "ShowAutoStyles", 
        "ShowCellBracket", "ShowCellLabel", "ShowCellTags", 
        "ShowClosedCellArea", "ShowContents", "ShowCursorTracker", 
        "ShowGroupOpenCloseIcon", "ShowJavaConsole", "ShowPageBreaks", 
        "ShowSelection", "ShowShortBoxForm", "ShowSpecialCharacters", 
        "ShowStringCharacters", "ShrinkWrapBoundingBox", "Sign", "Signature", 
        "SignPadding", "Simplify", "Simplify`Expand0F3", "Simplify`Expand1F2",
         "Simplify`ExpandHypergeometric2F1", "Simplify`FunctionExpandRules", 
        "Simplify`GPElement", "Simplify`IneqBounds", 
        "Simplify`InertIntegrate", "Simplify`InertProduct", 
        "Simplify`InertSum", "Simplify`InfinitePiecewiseRepresent", 
        "Simplify`PiecewiseGerm", "Simplify`PiecewiseIntegrate", 
        "Simplify`PiecewiseNIntegrate", "Simplify`PWCOND", 
        "Simplify`PWPlotCases", "Simplify`PWToIntervals", 
        "Simplify`SearchNumberTheory", "Simplify`SimplifyAuxVar", 
        "Simplify`SimplifyBessel", "Simplify`SimplifyFibonacci", 
        "Simplify`SimplifyGamma", "Simplify`SimplifyHypergeometricPFQ", 
        "Simplify`SimplifyInequalities", "Simplify`SimplifyPolyGamma", 
        "Simplify`SimplifyPolyLog", "Simplify`SimplifyPseudoFunctions", 
        "Simplify`SimplifyZeta", "Simulate", "Sin", "SingleLetterItalics", 
        "SingularityDepth", "SingularValueDecomposition", "SingularValueList",
         "SingularValues", "Sinh", "SinhIntegral", "SinIntegral", 
        "SixJSymbol", "size", "sizeMax", "sizeMax$", "sizeMin", "sizeMin$", 
        "size$", "Skeleton", "Skip", "slider", "sliderFrame", "sliderFrameX", 
        "sliderFrameXDim", "sliderFrameY", "sliderFrameYDim", "sliderFunc", 
        "sliderLayout", "sliderListener", "Slot", "SlotSequence", "Smaller", 
        "Socket", "Solve", "Solve`a", "SolveAlways", "Solve`Auxiliary", 
        "Solve`b", "Solve`c", "Solve`d", "SolveDelayed", "Solve`DirInf", 
        "Solve`ElimVar", "Solve`f", "Solve`g", "Solve`h", "Solve`InvFun", 
        "Solve`InvFunVar", "Solve`k", "Solve`ParamEqual", 
        "Solve`ParamUnequal", "Solve`ParmVar", "Solve`RadVar", 
        "Solve`RecipVar", "Solve`RootsAuxVar", "Solve`SolvVar", 
        "Solve`Temp1Var", "Solve`Temp2Var", "Solve`w", "Solve`ZeroTestHead", 
        "Sort", "Sound", "SoundAndGraphics", "Sow", "Space", "SpaceForm", 
        "SpanAdjustments", "SpanCharacterRounding", "SpanLineThickness", 
        "SpanMaxSize", "SpanMinSize", "SpanningCharacters", "SpanSymmetric", 
        "Sparse", "SparseArray", "SparseArray`Arnoldi", 
        "SparseArray`BlockArray", "SparseArray`BlockTriangularOrdering", 
        "SparseArray`BreadthFirstSearch", "SparseArray`Equal", 
        "SparseArray`GraphDistance", "SparseArray`GraphDistanceMatrix", 
        "SparseArray`GraphPlacement", "SparseArray`GraphPlacement3D", 
        "SparseArray`HermitianQ", "SparseArray`HighDimensionalEmbedding", 
        "SparseArray`KrylovLinearSolve", "SparseArray`LayeredDrawing", 
        "SparseArray`MaximalBipartiteMatching", 
        "SparseArray`MaximalIndependentVertexSet", 
        "SparseArray`MaximalMatching", "SparseArray`MinCut", 
        "SparseArray`Multilevel", "SparseArray`NestedDissection", 
        "SparseArray`Private`GraphPlot", "SparseArray`Private`GraphPlot3D", 
        "SparseArray`PseudoDiameter", "SparseArray`RadialDrawing", 
        "SparseArray`RecursionMethod", "SparseArray`SpanningTree", 
        "SparseArray`SparseArrayDimensions", "SparseArray`SparseArrayFlatten",
         "SparseArray`SparseArrayJoin", "SparseArray`SparseArrayOp", 
        "SparseArray`SparseArrayRemoveDiagonal", 
        "SparseArray`SparseArrayScalingFactors", 
        "SparseArray`SparseArrayTensorRank", 
        "SparseArray`SparseIdentityArray", 
        "SparseArray`SparseLUDecomposition", 
        "SparseArray`SparseMatrixApplyILU", "SparseArray`SparseMatrixILU", 
        "SparseArray`SparseRuleForm", "SparseArray`SpringElectricalModel", 
        "SparseArray`SpringEnergy", "SparseArray`SpringModel", 
        "SparseArray`StronglyConnectedComponents", "SparseArray`SVDArnoldi", 
        "SparseArray`SymmetricQ", "SparseArray`ToTriangular", 
        "SparseArray`TreeQ", "SparseArray`VectorToDiagonalSparseArray", 
        "SpeakTextPacket", "speedBnd", "speedBndLarge", "speedBndSmall", 
        "speedBnd$", "SpellingCorrection", "SpellingDictionaries", 
        "SpellingDictionariesPath", "SpellingOptions", 
        "SpellingSuggestionsPacket", "Spherical", "SphericalHarmonicY", 
        "SphericalRegion", "Splice", "Split", "Sqrt", "SqrtBox", 
        "SqrtBoxOptions", "Stack", "StackBegin", "StackComplete", 
        "StackInhibit", "StandardDeviation", "StandardForm", "start", 
        "StartingStepSize", "StartJava", "StartOfLine", "StartOfString", 
        "StartupSound", "StaticsVisible", 
        "Statistics`ClusterAnalysis`Agglomerate", 
        "Statistics`ClusterAnalysis`BrayCurtisDistance", 
        "Statistics`ClusterAnalysis`CanberraDistance", 
        "Statistics`ClusterAnalysis`Cluster", 
        "Statistics`ClusterAnalysis`CorrelationDissimilarity", 
        "Statistics`ClusterAnalysis`CosineAngleDissimilarity", 
        "Statistics`ClusterAnalysis`DiceDissimilarity", 
        "Statistics`ClusterAnalysis`DirectAgglomerate", 
        "Statistics`ClusterAnalysis`DistanceFunction", 
        "Statistics`ClusterAnalysis`DistanceMatrix", 
        "Statistics`ClusterAnalysis`EditDistance", 
        "Statistics`ClusterAnalysis`EuclideanDistance", 
        "Statistics`ClusterAnalysis`FindClusters", 
        "Statistics`ClusterAnalysis`FindClusters`DispersionFromData", 
        "Statistics`ClusterAnalysis`FindClusters`DispersionFromDCMatrix", 
        "Statistics`ClusterAnalysis`FindClusters`FindClustersDispatch", 
        "Statistics`ClusterAnalysis`FindClusters`KMediodsUpdate", 
        "Statistics`ClusterAnalysis`FindClusters`MediodsFromData", 
        "Statistics`ClusterAnalysis`FindClusters`MediodsFromDCMatrix", 
        "Statistics`ClusterAnalysis`FindClusters`PAMUpdate", 
        "Statistics`ClusterAnalysis`FindClusters`SilhouetteFromDCMatrix", 
        "Statistics`ClusterAnalysis`JaccardDissimilarity", 
        "Statistics`ClusterAnalysis`Linkage", 
        "Statistics`ClusterAnalysis`ManhattanDistance", 
        "Statistics`ClusterAnalysis`MatchingDissimilarity", 
        "Statistics`ClusterAnalysis`RogersTanimotoDissimilarity", 
        "Statistics`ClusterAnalysis`RussleRaoDissimilarity", 
        "Statistics`ClusterAnalysis`SokalSneathDissimilarity", 
        "Statistics`ClusterAnalysis`SquaredEuclideanDistance", 
        "Statistics`ClusterAnalysis`SupDistance", 
        "Statistics`ClusterAnalysis`YuleDissimilarity", "step", "StepMonitor",
         "StieltjesGamma", "StirlingS1", "StirlingS2", "StoppingTest", 
        "straightLine", "StreamPosition", "Streams", "String", "StringBreak", 
        "StringByteCount", "StringCases", "StringCount", "StringDrop", 
        "StringExpression", "StringForm", "StringFreeQ", "StringInsert", 
        "StringJoin", "StringLength", "StringMatchQ", 
        "StringPattern`CountCapGrInRegExp", 
        "StringPattern`Lexer`ChangeLexerState", 
        "StringPattern`Lexer`IfLexerState", "StringPattern`Lexer`Lexer", 
        "StringPattern`LongestCommonSubsequence", 
        "StringPattern`PatternConvert", "StringPosition", "StringQ", 
        "StringReplace", "StringReplaceList", "StringReplacePart", 
        "StringReverse", "StringSkeleton", "StringSplit", "StringTake", 
        "StringToStream", "StripBoxes", "StripWrapperBoxes", 
        "StructuredSelection", "StruveH", "StruveL", "Stub", "StyleBox", 
        "StyleBoxAutoDelete", "StyleBoxOptions", "StyleData", 
        "StyleDefinitions", "StyleForm", "StyleMenuListing", 
        "StyleNameDialogSettings", "StylePrint", "StyleSheetPath", 
        "Subresultants", "Subscript", "SubscriptBox", "SubscriptBoxOptions", 
        "Subscripted", "Subsets", "Subsuperscript", "SubsuperscriptBox", 
        "SubsuperscriptBoxOptions", "Subtract", "SubtractFrom", "SubValues", 
        "SugarCube", "Sum", "Sum`SumAccurate", "Sum`SumCompleteApart", 
        "Sum`SumHypergeometricTerm", "Sum`SumNonZeroQ", 
        "Sum`SumPolynomialExponentialFunction", "Sum`SumPolynomialFunction", 
        "Sum`SumRationalFunction", "Sum`SumRationalQ", 
        "Sum`SumSimplifyHypergeometricTerm", "Sum`SumZeroQ", 
        "sun`awt`image`AcceleratedOffScreenImage`getAccelerationThreshold", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
getAccelerationThreshold", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`getGraphics", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`getSnapshot", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
getSourceSurfaceData", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
initAcceleratedBackground", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`rasterChanged", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`rasterStolen", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`restoreContents", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
SCALEUAREAUAVERAGING", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUDEFAULT", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUFAST", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUREPLICATE", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`SCALEUSMOOTH", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEU3BYTEUBGR", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEU4BYTEUABGR", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEU4BYTEUABGRUPRE", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUBYTEUBINARY", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUBYTEUGRAY", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUBYTEUINDEXED", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUCUSTOM", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTUARGB", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTUARGBUPRE", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTUBGR", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUINTURGB", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUUSHORTU555URGB", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`\
TYPEUUSHORTU565URGB", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`TYPEUUSHORTUGRAY", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`UndefinedProperty", 
        "sun`awt`image`AcceleratedOffScreenImage`JPrivate`validate", 
        "sun`awt`image`AcceleratedOffScreenImage`SCALEUAREAUAVERAGING", 
        "sun`awt`image`AcceleratedOffScreenImage`SCALEUDEFAULT", 
        "sun`awt`image`AcceleratedOffScreenImage`SCALEUFAST", 
        "sun`awt`image`AcceleratedOffScreenImage`SCALEUREPLICATE", 
        "sun`awt`image`AcceleratedOffScreenImage`SCALEUSMOOTH", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEU3BYTEUBGR", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEU4BYTEUABGR", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUBINARY", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUGRAY", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUBYTEUINDEXED", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUCUSTOM", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUARGB", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUARGBUPRE", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUINTUBGR", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUINTURGB", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTU555URGB", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTU565URGB", 
        "sun`awt`image`AcceleratedOffScreenImage`TYPEUUSHORTUGRAY", 
        "sun`awt`image`AcceleratedOffScreenImage`UndefinedProperty", 
        "sun`awt`image`OffScreenImage`JPrivate`createGraphics", 
        "sun`awt`image`OffScreenImage`JPrivate`getGraphics", 
        "sun`awt`image`OffScreenImage`JPrivate`getSource", 
        "sun`awt`image`OffScreenImage`JPrivate`getSourceSurfaceData", 
        "sun`awt`image`OffScreenImage`JPrivate`initBackground", 
        "sun`awt`image`OffScreenImage`JPrivate`restoreContents", 
        "sun`awt`image`OffScreenImage`JPrivate`SCALEUAREAUAVERAGING", 
        "sun`awt`image`OffScreenImage`JPrivate`SCALEUDEFAULT", 
        "sun`awt`image`OffScreenImage`JPrivate`SCALEUFAST", 
        "sun`awt`image`OffScreenImage`JPrivate`SCALEUREPLICATE", 
        "sun`awt`image`OffScreenImage`JPrivate`SCALEUSMOOTH", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEU3BYTEUBGR", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEU4BYTEUABGR", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEU4BYTEUABGRUPRE", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUBINARY", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUGRAY", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUBYTEUINDEXED", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUCUSTOM", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUARGB", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUARGBUPRE", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUINTUBGR", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUINTURGB", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTU555URGB", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTU565URGB", 
        "sun`awt`image`OffScreenImage`JPrivate`TYPEUUSHORTUGRAY", 
        "sun`awt`image`OffScreenImage`JPrivate`UndefinedProperty", 
        "sun`awt`image`OffScreenImage`SCALEUAREAUAVERAGING", 
        "sun`awt`image`OffScreenImage`SCALEUDEFAULT", 
        "sun`awt`image`OffScreenImage`SCALEUFAST", 
        "sun`awt`image`OffScreenImage`SCALEUREPLICATE", 
        "sun`awt`image`OffScreenImage`SCALEUSMOOTH", 
        "sun`awt`image`OffScreenImage`TYPEU3BYTEUBGR", 
        "sun`awt`image`OffScreenImage`TYPEU4BYTEUABGR", 
        "sun`awt`image`OffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "sun`awt`image`OffScreenImage`TYPEUBYTEUBINARY", 
        "sun`awt`image`OffScreenImage`TYPEUBYTEUGRAY", 
        "sun`awt`image`OffScreenImage`TYPEUBYTEUINDEXED", 
        "sun`awt`image`OffScreenImage`TYPEUCUSTOM", 
        "sun`awt`image`OffScreenImage`TYPEUINTUARGB", 
        "sun`awt`image`OffScreenImage`TYPEUINTUARGBUPRE", 
        "sun`awt`image`OffScreenImage`TYPEUINTUBGR", 
        "sun`awt`image`OffScreenImage`TYPEUINTURGB", 
        "sun`awt`image`OffScreenImage`TYPEUUSHORTU555URGB", 
        "sun`awt`image`OffScreenImage`TYPEUUSHORTU565URGB", 
        "sun`awt`image`OffScreenImage`TYPEUUSHORTUGRAY", 
        "sun`awt`image`OffScreenImage`UndefinedProperty", 
        "sun`awt`windows`Win32OffScreenImage`getAccelerationThreshold", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`displayChanged", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`flush", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`\
getAccelerationThreshold", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`getGraphics", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`\
initAcceleratedBackground", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`paletteChanged", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`restoreContents", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUAREAUAVERAGING", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUDEFAULT", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUFAST", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUREPLICATE", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`SCALEUSMOOTH", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEU3BYTEUBGR", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEU4BYTEUABGR", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEU4BYTEUABGRUPRE", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUBYTEUBINARY", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUBYTEUGRAY", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUBYTEUINDEXED", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUCUSTOM", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTUARGB", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTUARGBUPRE", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTUBGR", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUINTURGB", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUUSHORTU555URGB", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUUSHORTU565URGB", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`TYPEUUSHORTUGRAY", 
        "sun`awt`windows`Win32OffScreenImage`JPrivate`UndefinedProperty", 
        "sun`awt`windows`Win32OffScreenImage`SCALEUAREAUAVERAGING", 
        "sun`awt`windows`Win32OffScreenImage`SCALEUDEFAULT", 
        "sun`awt`windows`Win32OffScreenImage`SCALEUFAST", 
        "sun`awt`windows`Win32OffScreenImage`SCALEUREPLICATE", 
        "sun`awt`windows`Win32OffScreenImage`SCALEUSMOOTH", 
        "sun`awt`windows`Win32OffScreenImage`TYPEU3BYTEUBGR", 
        "sun`awt`windows`Win32OffScreenImage`TYPEU4BYTEUABGR", 
        "sun`awt`windows`Win32OffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUBINARY", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUGRAY", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUBYTEUINDEXED", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUCUSTOM", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUINTUARGB", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUINTUARGBUPRE", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUINTUBGR", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUINTURGB", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTU555URGB", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTU565URGB", 
        "sun`awt`windows`Win32OffScreenImage`TYPEUUSHORTUGRAY", 
        "sun`awt`windows`Win32OffScreenImage`UndefinedProperty", 
        "SunGraphics2D`CLIPUDEVICE", "SunGraphics2D`CLIPURECTANGULAR", 
        "SunGraphics2D`CLIPUSHAPE", "SunGraphics2D`COMPUALPHA", 
        "SunGraphics2D`COMPUCUSTOM", "SunGraphics2D`COMPUISCOPY", 
        "SunGraphics2D`COMPUXOR", "SunGraphics2D`isRotated", 
        "SunGraphics2D`makeFontMetrics", "SunGraphics2D`metricsCache", 
        "SunGraphics2D`MinPenSizeAASquared", 
        "SunGraphics2D`MinPenSizeSquared", "SunGraphics2D`PAINTUSINGLECOLOR", 
        "SunGraphics2D`PAINTUSOLIDCOLOR", "SunGraphics2D`PAINTUTILE", 
        "SunGraphics2D`STROKEUCUSTOM", "SunGraphics2D`STROKEUTHIN", 
        "SunGraphics2D`STROKEUWIDE", "SunGraphics2D`TRANSFORMUGENERIC", 
        "SunGraphics2D`TRANSFORMUISIDENT", 
        "SunGraphics2D`TRANSFORMUTRANSLATEONLY", 
        "SunGraphics2D`TRANSFORMUTRANSLATESCALE", "SunGraphics2D`XRGBModel", 
        "sun`java2d`SunGraphics2D`CLIPUDEVICE", 
        "sun`java2d`SunGraphics2D`CLIPURECTANGULAR", 
        "sun`java2d`SunGraphics2D`CLIPUSHAPE", 
        "sun`java2d`SunGraphics2D`COMPUALPHA", 
        "sun`java2d`SunGraphics2D`COMPUCUSTOM", 
        "sun`java2d`SunGraphics2D`COMPUISCOPY", 
        "sun`java2d`SunGraphics2D`COMPUXOR", 
        "sun`java2d`SunGraphics2D`isRotated", 
        "sun`java2d`SunGraphics2D`JPrivate`addRenderingHints", 
        "sun`java2d`SunGraphics2D`JPrivate`alphafill", 
        "sun`java2d`SunGraphics2D`JPrivate`antialiasHint", 
        "sun`java2d`SunGraphics2D`JPrivate`backgroundColor", 
        "sun`java2d`SunGraphics2D`JPrivate`checkFontInfo", 
        "sun`java2d`SunGraphics2D`JPrivate`clearRect", 
        "sun`java2d`SunGraphics2D`JPrivate`clip", 
        "sun`java2d`SunGraphics2D`JPrivate`clipRect", 
        "sun`java2d`SunGraphics2D`JPrivate`clipRegion", 
        "sun`java2d`SunGraphics2D`JPrivate`clipState", 
        "sun`java2d`SunGraphics2D`JPrivate`CLIPUDEVICE", 
        "sun`java2d`SunGraphics2D`JPrivate`CLIPURECTANGULAR", 
        "sun`java2d`SunGraphics2D`JPrivate`CLIPUSHAPE", 
        "sun`java2d`SunGraphics2D`JPrivate`cloneTransform", 
        "sun`java2d`SunGraphics2D`JPrivate`complexTransform", 
        "sun`java2d`SunGraphics2D`JPrivate`composite", 
        "sun`java2d`SunGraphics2D`JPrivate`compositeState", 
        "sun`java2d`SunGraphics2D`JPrivate`COMPUALPHA", 
        "sun`java2d`SunGraphics2D`JPrivate`COMPUCUSTOM", 
        "sun`java2d`SunGraphics2D`JPrivate`COMPUISCOPY", 
        "sun`java2d`SunGraphics2D`JPrivate`COMPUXOR", 
        "sun`java2d`SunGraphics2D`JPrivate`constrain", 
        "sun`java2d`SunGraphics2D`JPrivate`constrainClip", 
        "sun`java2d`SunGraphics2D`JPrivate`constrainX", 
        "sun`java2d`SunGraphics2D`JPrivate`constrainY", 
        "sun`java2d`SunGraphics2D`JPrivate`convertRaster", 
        "sun`java2d`SunGraphics2D`JPrivate`copyArea", 
        "sun`java2d`SunGraphics2D`JPrivate`copyImage", 
        "sun`java2d`SunGraphics2D`JPrivate`create", 
        "sun`java2d`SunGraphics2D`JPrivate`dispose", 
        "sun`java2d`SunGraphics2D`JPrivate`draw", 
        "sun`java2d`SunGraphics2D`JPrivate`drawArc", 
        "sun`java2d`SunGraphics2D`JPrivate`drawBytes", 
        "sun`java2d`SunGraphics2D`JPrivate`drawChars", 
        "sun`java2d`SunGraphics2D`JPrivate`drawGlyphVector", 
        "sun`java2d`SunGraphics2D`JPrivate`drawImage", 
        "sun`java2d`SunGraphics2D`JPrivate`drawLine", 
        "sun`java2d`SunGraphics2D`JPrivate`drawOval", 
        "sun`java2d`SunGraphics2D`JPrivate`drawpipe", 
        "sun`java2d`SunGraphics2D`JPrivate`drawPolygon", 
        "sun`java2d`SunGraphics2D`JPrivate`drawPolyline", 
        "sun`java2d`SunGraphics2D`JPrivate`drawRect", 
        "sun`java2d`SunGraphics2D`JPrivate`drawRenderableImage", 
        "sun`java2d`SunGraphics2D`JPrivate`drawRenderedImage", 
        "sun`java2d`SunGraphics2D`JPrivate`drawRoundRect", 
        "sun`java2d`SunGraphics2D`JPrivate`drawString", 
        "sun`java2d`SunGraphics2D`JPrivate`fill", 
        "sun`java2d`SunGraphics2D`JPrivate`fillArc", 
        "sun`java2d`SunGraphics2D`JPrivate`fillComp", 
        "sun`java2d`SunGraphics2D`JPrivate`fillOval", 
        "sun`java2d`SunGraphics2D`JPrivate`fillpipe", 
        "sun`java2d`SunGraphics2D`JPrivate`fillPolygon", 
        "sun`java2d`SunGraphics2D`JPrivate`fillRect", 
        "sun`java2d`SunGraphics2D`JPrivate`fillRoundRect", 
        "sun`java2d`SunGraphics2D`JPrivate`finalize", 
        "sun`java2d`SunGraphics2D`JPrivate`fontInfo", 
        "sun`java2d`SunGraphics2D`JPrivate`foregroundColor", 
        "sun`java2d`SunGraphics2D`JPrivate`getBackground", 
        "sun`java2d`SunGraphics2D`JPrivate`getClip", 
        "sun`java2d`SunGraphics2D`JPrivate`getClipBounds", 
        "sun`java2d`SunGraphics2D`JPrivate`getColor", 
        "sun`java2d`SunGraphics2D`JPrivate`getCompClip", 
        "sun`java2d`SunGraphics2D`JPrivate`getComposite", 
        "sun`java2d`SunGraphics2D`JPrivate`getDeviceColorModel", 
        "sun`java2d`SunGraphics2D`JPrivate`getDeviceConfiguration", 
        "sun`java2d`SunGraphics2D`JPrivate`getFont", 
        "sun`java2d`SunGraphics2D`JPrivate`getFontMetrics", 
        "sun`java2d`SunGraphics2D`JPrivate`getFontRenderContext", 
        "sun`java2d`SunGraphics2D`JPrivate`getPaint", 
        "sun`java2d`SunGraphics2D`JPrivate`getRenderingHint", 
        "sun`java2d`SunGraphics2D`JPrivate`getRenderingHints", 
        "sun`java2d`SunGraphics2D`JPrivate`getStroke", 
        "sun`java2d`SunGraphics2D`JPrivate`getSurfaceData", 
        "sun`java2d`SunGraphics2D`JPrivate`getTransform", 
        "sun`java2d`SunGraphics2D`JPrivate`hints", 
        "sun`java2d`SunGraphics2D`JPrivate`hit", 
        "sun`java2d`SunGraphics2D`JPrivate`hitClip", 
        "sun`java2d`SunGraphics2D`JPrivate`imageComp", 
        "sun`java2d`SunGraphics2D`JPrivate`imagepipe", 
        "sun`java2d`SunGraphics2D`JPrivate`interpolationHint", 
        "sun`java2d`SunGraphics2D`JPrivate`isRotated", 
        "sun`java2d`SunGraphics2D`JPrivate`lastGlyphVectorFontInfo", 
        "sun`java2d`SunGraphics2D`JPrivate`loops", 
        "sun`java2d`SunGraphics2D`JPrivate`makeFontMetrics", 
        "sun`java2d`SunGraphics2D`JPrivate`metricsCache", 
        "sun`java2d`SunGraphics2D`JPrivate`MinPenSizeAASquared", 
        "sun`java2d`SunGraphics2D`JPrivate`MinPenSizeSquared", 
        "sun`java2d`SunGraphics2D`JPrivate`paint", 
        "sun`java2d`SunGraphics2D`JPrivate`paintState", 
        "sun`java2d`SunGraphics2D`JPrivate`PAINTUSINGLECOLOR", 
        "sun`java2d`SunGraphics2D`JPrivate`PAINTUSOLIDCOLOR", 
        "sun`java2d`SunGraphics2D`JPrivate`PAINTUTILE", 
        "sun`java2d`SunGraphics2D`JPrivate`pixel", 
        "sun`java2d`SunGraphics2D`JPrivate`renderHint", 
        "sun`java2d`SunGraphics2D`JPrivate`rgb", 
        "sun`java2d`SunGraphics2D`JPrivate`rotate", 
        "sun`java2d`SunGraphics2D`JPrivate`scale", 
        "sun`java2d`SunGraphics2D`JPrivate`setBackground", 
        "sun`java2d`SunGraphics2D`JPrivate`setClip", 
        "sun`java2d`SunGraphics2D`JPrivate`setColor", 
        "sun`java2d`SunGraphics2D`JPrivate`setComposite", 
        "sun`java2d`SunGraphics2D`JPrivate`setDevClip", 
        "sun`java2d`SunGraphics2D`JPrivate`setFont", 
        "sun`java2d`SunGraphics2D`JPrivate`setPaint", 
        "sun`java2d`SunGraphics2D`JPrivate`setPaintMode", 
        "sun`java2d`SunGraphics2D`JPrivate`setRenderingHint", 
        "sun`java2d`SunGraphics2D`JPrivate`setRenderingHints", 
        "sun`java2d`SunGraphics2D`JPrivate`setStroke", 
        "sun`java2d`SunGraphics2D`JPrivate`setTransform", 
        "sun`java2d`SunGraphics2D`JPrivate`setXORMode", 
        "sun`java2d`SunGraphics2D`JPrivate`shapepipe", 
        "sun`java2d`SunGraphics2D`JPrivate`shear", 
        "sun`java2d`SunGraphics2D`JPrivate`stroke", 
        "sun`java2d`SunGraphics2D`JPrivate`strokeHint", 
        "sun`java2d`SunGraphics2D`JPrivate`strokeState", 
        "sun`java2d`SunGraphics2D`JPrivate`STROKEUCUSTOM", 
        "sun`java2d`SunGraphics2D`JPrivate`STROKEUTHIN", 
        "sun`java2d`SunGraphics2D`JPrivate`STROKEUWIDE", 
        "sun`java2d`SunGraphics2D`JPrivate`surfaceData", 
        "sun`java2d`SunGraphics2D`JPrivate`textAntialiasHint", 
        "sun`java2d`SunGraphics2D`JPrivate`textpipe", 
        "sun`java2d`SunGraphics2D`JPrivate`transform", 
        "sun`java2d`SunGraphics2D`JPrivate`transformState", 
        "sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUGENERIC", 
        "sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUISIDENT", 
        "sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUTRANSLATEONLY", 
        "sun`java2d`SunGraphics2D`JPrivate`TRANSFORMUTRANSLATESCALE", 
        "sun`java2d`SunGraphics2D`JPrivate`translate", 
        "sun`java2d`SunGraphics2D`JPrivate`transX", 
        "sun`java2d`SunGraphics2D`JPrivate`transY", 
        "sun`java2d`SunGraphics2D`JPrivate`untransformShape", 
        "sun`java2d`SunGraphics2D`JPrivate`usrClip", 
        "sun`java2d`SunGraphics2D`JPrivate`validatePipe", 
        "sun`java2d`SunGraphics2D`JPrivate`XRGBModel", 
        "sun`java2d`SunGraphics2D`makeFontMetrics", 
        "sun`java2d`SunGraphics2D`metricsCache", 
        "sun`java2d`SunGraphics2D`MinPenSizeAASquared", 
        "sun`java2d`SunGraphics2D`MinPenSizeSquared", 
        "sun`java2d`SunGraphics2D`PAINTUSINGLECOLOR", 
        "sun`java2d`SunGraphics2D`PAINTUSOLIDCOLOR", 
        "sun`java2d`SunGraphics2D`PAINTUTILE", 
        "sun`java2d`SunGraphics2D`STROKEUCUSTOM", 
        "sun`java2d`SunGraphics2D`STROKEUTHIN", 
        "sun`java2d`SunGraphics2D`STROKEUWIDE", 
        "sun`java2d`SunGraphics2D`TRANSFORMUGENERIC", 
        "sun`java2d`SunGraphics2D`TRANSFORMUISIDENT", 
        "sun`java2d`SunGraphics2D`TRANSFORMUTRANSLATEONLY", 
        "sun`java2d`SunGraphics2D`TRANSFORMUTRANSLATESCALE", 
        "sun`java2d`SunGraphics2D`XRGBModel", "Superscript", "SuperscriptBox",
         "SuperscriptBoxOptions", "SurfaceColor", "SurfaceGraphics", 
        "SuspendPacket", "Switch", "SylvesterMatrix", "Symbol", 
        "SymbolicProduct`SymbolicProduct", "SymbolicSum`SymbolicSum", 
        "SymbolName", "Syntax", "SyntaxForm", "SyntaxLength", "SyntaxPacket", 
        "SyntaxQ", "System`ComplexExpand`AbsExpr", 
        "System`ComplexExpand`ArgExpr", "System`ComplexExpand`ConjugateExpr", 
        "System`ComplexExpand`ReImExpr", "System`ComplexExpand`ReImFail", 
        "System`ComplexExpand`SignExpr", "System`Convert`CommonDump`boxes", 
        "System`Convert`CommonDump`contents", 
        "System`Convert`CommonDump`EliminateRepetition", 
        "System`Convert`CommonDump`EmbeddedStringWithLinearSyntaxQ", 
        "System`Convert`CommonDump`form", 
        "System`Convert`CommonDump`GetStyleSheet", 
        "System`Convert`CommonDump`Recursive", 
        "System`Convert`CommonDump`RemoveLinearSyntax", 
        "System`Convert`CommonDump`style", 
        "System`Convert`MathMLDump`annotations", 
        "System`Convert`MathMLDump`boxOptions", 
        "System`Convert`MathMLDump`boxStructureQ", 
        "System`Convert`MathMLDump`chooseAndMakeAnnotation", 
        "System`Convert`MathMLDump`mathMLExport", 
        "System`Convert`MathMLDump`mathMLImport", 
        "System`Convert`MathMLDump`stripBoxes", 
        "System`Convert`MLStringDataDump`LetterLikeQ", 
        "System`Convert`MLStringDataDump`OperatorQ", 
        "System`Convert`MLStringDataDump`$PrivateCharacterToUnicodeEntities", 
        "System`Convert`MLStringDataDump`$UnicodeToHTML4Entities", 
        "System`Convert`MLStringDataDump`$UnicodeToMathML1Entities", 
        "System`Convert`MLStringDataDump`$UnicodeToMathML2Entities", 
        "System`Convert`NotebookMLDump`ExpressionMLGet", 
        "System`Convert`NotebookMLDump`ExpressionMLSave", 
        "System`Convert`NotebookMLDump`exprmlGet", 
        "System`Convert`NotebookMLDump`exprmlSave", 
        "System`Convert`NotebookMLDump`nbmlGet", 
        "System`Convert`NotebookMLDump`nbmlSave", 
        "System`Convert`NotebookMLDump`NotebookMLGet", 
        "System`Convert`NotebookMLDump`NotebookMLSave", 
        "System`Convert`SVGDump`ExportSVGZ", 
        "System`Convert`SVGDump`ImportSVGZ", "System`Convert`SVGDump`svgGet", 
        "System`Convert`SVGDump`SVGGet", "System`Convert`SVGDump`svgSave", 
        "System`Convert`SVGDump`SVGSave", 
        "System`Convert`TableDump`ComplexTableFormat", 
        "System`Convert`TableDump`CSVFormat", 
        "System`Convert`TableDump`FromCForm", 
        "System`Convert`TableDump`ParseElement", 
        "System`Convert`TableDump`StringCSVFormat", 
        "System`Convert`TableDump`TableFormat", 
        "System`Convert`TableDump`TryDate", 
        "System`Convert`XMLDump`ExportSymbolicXML", 
        "System`Convert`XMLDump`ExportXML", 
        "System`Convert`XMLDump`ImportXML", 
        "System`Convert`XMLDump`symbolicXMLExport", 
        "System`Convert`XMLDump`symbolicXMLImport", 
        "System`Convert`XMLDump`WriteSymbolicXML", "System`CrossDump`m", 
        "System`CrossDump`m$", "System`CrossDump`n", "System`CrossDump`n$", 
        "System`CrossDump`test", "System`CrossDump`test$", 
        "System`CrossDump`vList", "System`Dump`a", "System`Dump`A", 
        "System`Dump`addmessagebutton", "System`Dump`addmessagebuttons", 
        "System`Dump`allowprotect", "System`Dump`allowprotect$", 
        "System`Dump`AllSyms", "System`Dump`alltags", "System`Dump`alltags$", 
        "System`Dump`any", "System`Dump`applyUsageStyles", "System`Dump`arg", 
        "System`Dump`arg1", "System`Dump`arg1$", "System`Dump`arg2", 
        "System`Dump`arg2$", "System`Dump`argname", "System`Dump`args", 
        "System`Dump`args$", "System`Dump`ArgumentCount`ArgCountBetween", 
        "System`Dump`ArgumentCount`ArgCountEitherOr", 
        "System`Dump`ArgumentCount`ArgCountMore", 
        "System`Dump`ArgumentCount`ArgCountSpecific", 
        "System`Dump`ArgumentCount`count1", 
        "System`Dump`ArgumentCount`count2", 
        "System`Dump`ArgumentCount`expected", 
        "System`Dump`ArgumentCount`head", "System`Dump`ArgumentCount`len", 
        "System`Dump`ArgumentCount`max", "System`Dump`ArgumentCount`min", 
        "System`Dump`ArgumentCount`received", "System`Dump`asp", 
        "System`Dump`asp$", "System`Dump`AutoLoad", "System`Dump`axes", 
        "System`Dump`axes$", "System`Dump`a$", "System`Dump`b", 
        "System`Dump`B", "System`Dump`base", "System`Dump`binary", 
        "System`Dump`binary$", "System`Dump`bitmap", "System`Dump`Bitmap", 
        "System`Dump`body", "System`Dump`box", "System`Dump`box$", 
        "System`Dump`breakblanksstring", "System`Dump`butsizes", 
        "System`Dump`butsizes$", "System`Dump`button", 
        "System`Dump`buttoncontentstructure", "System`Dump`buttonstyle", 
        "System`Dump`buttonstyleoptions", "System`Dump`buttonstyle$", 
        "System`Dump`b$", "System`Dump`c", "System`Dump`c1", "System`Dump`c2",
         "System`Dump`cells", "System`Dump`cellstyleoptions", 
        "System`Dump`channel", "System`Dump`chars", 
        "System`Dump`CheckBoolean", "System`Dump`checkFEfilesystemQ", 
        "System`Dump`CheckGopt", "System`Dump`CheckPositive", 
        "System`Dump`CheckSymbolQ", "System`Dump`chi", "System`Dump`chi$", 
        "System`Dump`cleanname", "System`Dump`cleanname$", 
        "System`Dump`ClearUsageStyles", "System`Dump`cmd", 
        "System`Dump`cnames", "System`Dump`cnames$", "System`Dump`comm", 
        "System`Dump`command", "System`Dump`con", 
        "System`Dump`ConnectToExternalPackage", "System`Dump`constructbutton",
         "System`Dump`constructgroups", "System`Dump`cont", 
        "System`Dump`cont1", "System`Dump`cont1$", "System`Dump`cont2", 
        "System`Dump`cont2$", "System`Dump`context", "System`Dump`conts", 
        "System`Dump`conts$", "System`Dump`convertcell", 
        "System`Dump`convertexpr", "System`Dump`corder", "System`Dump`crest", 
        "System`Dump`ctags", "System`Dump`ctags$", "System`Dump`currstys", 
        "System`Dump`d", "System`Dump`dat", "System`Dump`data", 
        "System`Dump`ddx", "System`Dump`ddx$", 
        "System`Dump`DeactivateMessages", 
        "System`Dump`DeactivateReadProtected", "System`Dump`defaults", 
        "System`Dump`defaults$", "System`Dump`defined", 
        "System`Dump`defineLinkObject", "System`Dump`delta", 
        "System`Dump`den", "System`Dump`den$", "System`Dump`DGTest", 
        "System`Dump`dig", "System`Dump`digit", "System`Dump`digitcountcore", 
        "System`Dump`digits", "System`Dump`DisplayInternal", 
        "System`Dump`DisplayInternal0", "System`Dump`DisplayToGIFOptions", 
        "System`Dump`dist", "System`Dump`doinformation", "System`Dump`dOpts", 
        "System`Dump`dx", "System`Dump`dx$", "System`Dump`dy", 
        "System`Dump`dy$", "System`Dump`e", "System`Dump`EditDef", 
        "System`Dump`EditInAux", "System`Dump`EditIO", 
        "System`Dump`EditString", "System`Dump`eh", "System`Dump`end", 
        "System`Dump`end$", "System`Dump`eps", "System`Dump`epsString", 
        "System`Dump`EvalIO", "System`Dump`expandall", 
        "System`Dump`expandAll", "System`Dump`expandDenominator", 
        "System`Dump`expandNumerator", "System`Dump`ExportToGIF", 
        "System`Dump`exppatt", "System`Dump`expr", "System`Dump`expvect", 
        "System`Dump`ExternalAnswer", "System`Dump`extractSizeFromEPS", 
        "System`Dump`extras", "System`Dump`extras$", "System`Dump`e$", 
        "System`Dump`f", "System`Dump`fc", "System`Dump`feflag", 
        "System`Dump`feflag$", "System`Dump`feGIFData", 
        "System`Dump`feGIFData$", "System`Dump`file", "System`Dump`filename", 
        "System`Dump`fileOrPipe", "System`Dump`file$", 
        "System`Dump`FilterOptions", "System`Dump`firstnumberfromstring", 
        "System`Dump`fixcelltags", "System`Dump`fixfile", 
        "System`Dump`fixmessagename", "System`Dump`fixmessagestring", 
        "System`Dump`fixname", "System`Dump`fixremaps", "System`Dump`fmt", 
        "System`Dump`fmtpatt", "System`Dump`fn", "System`Dump`fname", 
        "System`Dump`format", "System`Dump`formatcode", 
        "System`Dump`formatflag", "System`Dump`formatusage", 
        "System`Dump`ForwardCheckFunction", "System`Dump`ForwardContext", 
        "System`Dump`found", "System`Dump`found$", "System`Dump`fu", 
        "System`Dump`fullname", "System`Dump`fullname$", 
        "System`Dump`fulltag", "System`Dump`fulltag$", "System`Dump`f$", 
        "System`Dump`g", "System`Dump`generategridcell", 
        "System`Dump`generateinfocells", "System`Dump`generaterandomtag", 
        "System`Dump`getbuttonsize", "System`Dump`getFEfile", 
        "System`Dump`getfileinprivatecontext", 
        "System`Dump`getfulldefinitioncells", "System`Dump`GetMatrix", 
        "System`Dump`GetMesh", "System`Dump`getnbcacheoffset", 
        "System`Dump`getRefGuide", "System`Dump`getusagecellfromRefGuide", 
        "System`Dump`getvalidmessagenames", "System`Dump`GetYesNo", 
        "System`Dump`globalsym", "System`Dump`globalsym$", 
        "System`Dump`goodsymbolQ", "System`Dump`gopts", "System`Dump`grid", 
        "System`Dump`grid$", "System`Dump`groups", "System`Dump`groups$", 
        "System`Dump`GRTest", "System`Dump`GTest", "System`Dump`g$", 
        "System`Dump`h", "System`Dump`halftag", "System`Dump`halftag$", 
        "System`Dump`heldsyms", "System`Dump`h$", "System`Dump`i", 
        "System`Dump`imppatt", "System`Dump`inames", 
        "System`Dump`InitializeRasterLink", "System`Dump`inname", 
        "System`Dump`input", "System`Dump`iOffset", "System`Dump`ipiz2", 
        "System`Dump`ipiz2$", "System`Dump`iResolution", 
        "System`Dump`iRotated", "System`Dump`iSize", "System`Dump`i$", 
        "System`Dump`j", "System`Dump`j$", "System`Dump`k", 
        "System`Dump`keywords", "System`Dump`k$", "System`Dump`l", 
        "System`Dump`lcoptions", "System`Dump`lcoptions$", "System`Dump`len", 
        "System`Dump`lens", "System`Dump`lens$", "System`Dump`len$", 
        "System`Dump`lev", "System`Dump`lev$", "System`Dump`lf", 
        "System`Dump`lf$", "System`Dump`line", "System`Dump`lines", 
        "System`Dump`link", "System`Dump`LinkOpenWithArgs", 
        "System`Dump`linkPatterns", "System`Dump`LinkQuote", 
        "System`Dump`LinksHelper", "System`Dump`link$", "System`Dump`lis", 
        "System`Dump`localRasterValue", "System`Dump`locked", 
        "System`Dump`longform", "System`Dump`l$", "System`Dump`m", 
        "System`Dump`makeBytes", "System`Dump`makegrid", 
        "System`Dump`MakeRectangles", "System`Dump`makesymbolbuttoncore", 
        "System`Dump`makesymbolbuttons", "System`Dump`matchnames", 
        "System`Dump`matchnames$", "System`Dump`MathEditor", 
        "System`Dump`max", "System`Dump`medit", "System`Dump`mesh", 
        "System`Dump`mesh$", "System`Dump`mess", 
        "System`Dump`messagenamecache", "System`Dump`messageopts", 
        "System`Dump`messageopts$", "System`Dump`messages", 
        "System`Dump`messagetocellcontents", "System`Dump`messagetocells", 
        "System`Dump`messconts", "System`Dump`messconts$", 
        "System`Dump`mess$", "System`Dump`mFile", "System`Dump`min", 
        "System`Dump`mName", "System`Dump`mName1", "System`Dump`mod", 
        "System`Dump`mod$", "System`Dump`msgs", "System`Dump`m$", 
        "System`Dump`n", "System`Dump`na", "System`Dump`name", 
        "System`Dump`name1", "System`Dump`name1$", "System`Dump`name2", 
        "System`Dump`names", "System`Dump`names$", "System`Dump`name$", 
        "System`Dump`nb", "System`Dump`nbops", "System`Dump`nbops$", 
        "System`Dump`nc", "System`Dump`newcont", "System`Dump`newcont$", 
        "System`Dump`newdata", "System`Dump`newdata$", "System`Dump`NotList", 
        "System`Dump`NoValuesTest", "System`Dump`npatt", "System`Dump`nt", 
        "System`Dump`NTest", "System`Dump`num", "System`Dump`num1", 
        "System`Dump`num2", "System`Dump`num$", "System`Dump`nx", 
        "System`Dump`nx$", "System`Dump`ny", "System`Dump`ny$", 
        "System`Dump`n$", "System`Dump`o1", "System`Dump`o2", 
        "System`Dump`obj", "System`Dump`offd", "System`Dump`offd1", 
        "System`Dump`offset", "System`Dump`offx", "System`Dump`offx$", 
        "System`Dump`offy", "System`Dump`offy$", "System`Dump`ok", 
        "System`Dump`ok$", "System`Dump`OldAutoLoad", "System`Dump`oldcont", 
        "System`Dump`oldcontextpath", "System`Dump`oldcontextpath$", 
        "System`Dump`oldconts", "System`Dump`oldconts$", 
        "System`Dump`oldValue", "System`Dump`opt", "System`Dump`options", 
        "System`Dump`optpat", "System`Dump`optpat$", "System`Dump`opts", 
        "System`Dump`opts$", "System`Dump`orderfun", "System`Dump`other", 
        "System`Dump`outputinfo", "System`Dump`outStream", 
        "System`Dump`outStream$", "System`Dump`OverrideFE", "System`Dump`p", 
        "System`Dump`packet", "System`Dump`pat", "System`Dump`pat1", 
        "System`Dump`pat2", "System`Dump`pats", "System`Dump`pat$", 
        "System`Dump`plrng", "System`Dump`plrng$", "System`Dump`prim", 
        "System`Dump`prompt", "System`Dump`prot", "System`Dump`protected", 
        "System`Dump`protected$", "System`Dump`proto", "System`Dump`PutGIF", 
        "System`Dump`quote", "System`Dump`quotedname", 
        "System`Dump`quotedname$", "System`Dump`r", "System`Dump`r1", 
        "System`Dump`r2", "System`Dump`randomtag", "System`Dump`randtag", 
        "System`Dump`randtag$", "System`Dump`readcell", "System`Dump`ReadIO", 
        "System`Dump`reallygetRefGuide", "System`Dump`reap", 
        "System`Dump`ReapBinaryRead", "System`Dump`reap$", "System`Dump`rec", 
        "System`Dump`rect", "System`Dump`rec$", "System`Dump`reducename", 
        "System`Dump`reformatdefinition", "System`Dump`res", 
        "System`Dump`resfile", "System`Dump`resol", "System`Dump`resp", 
        "System`Dump`rest", "System`Dump`result", "System`Dump`result$", 
        "System`Dump`res$", "System`Dump`rng", "System`Dump`rotated", 
        "System`Dump`rx", "System`Dump`rx$", "System`Dump`ry", 
        "System`Dump`ry$", "System`Dump`r$", "System`Dump`s", 
        "System`Dump`scale", "System`Dump`SendTwoNumbers", 
        "System`Dump`serialnumber", "System`Dump`SetUsageStyles", 
        "System`Dump`sfname", "System`Dump`sfname$", 
        "System`Dump`ShadowFunction", "System`Dump`shi", "System`Dump`shi$", 
        "System`Dump`size", "System`Dump`sname", "System`Dump`sName", 
        "System`Dump`sourcecont", "System`Dump`sourcecontext", 
        "System`Dump`sp", "System`Dump`space", "System`Dump`SpaceCheck", 
        "System`Dump`spat", "System`Dump`splitstring", "System`Dump`spx", 
        "System`Dump`spy", "System`Dump`sp$", "System`Dump`ssofar", 
        "System`Dump`ssofar$", "System`Dump`stm", "System`Dump`stmp", 
        "System`Dump`stmp$", "System`Dump`str", "System`Dump`stream", 
        "System`Dump`StreamFileName", "System`Dump`streamhead", 
        "System`Dump`stream$", "System`Dump`stringpatternQ", 
        "System`Dump`stripwhitespace", "System`Dump`strm", 
        "System`Dump`StrmTest", "System`Dump`strm$", "System`Dump`stub1", 
        "System`Dump`stub1$", "System`Dump`stub2", "System`Dump`stub2$", 
        "System`Dump`stylename", "System`Dump`sym", "System`Dump`symbols", 
        "System`Dump`symname", "System`Dump`symname$", "System`Dump`symnew", 
        "System`Dump`syms", "System`Dump`sym$", "System`Dump`synt", 
        "System`Dump`synt$", "System`Dump`s$", "System`Dump`t", 
        "System`Dump`tag", "System`Dump`tagname", "System`Dump`tagname$", 
        "System`Dump`targetnb", "System`Dump`targetnb$", 
        "System`Dump`TestBase", "System`Dump`TestDCArgs", 
        "System`Dump`TestDig", "System`Dump`TestIntegerList", 
        "System`Dump`TestIntegerListThrow", "System`Dump`TestLoad", 
        "System`Dump`TestN", "System`Dump`TextualCompact", 
        "System`Dump`ThrowBinaryRead", "System`Dump`ThrowBinaryWrite", 
        "System`Dump`tickPosition", "System`Dump`tmp", "System`Dump`tmpboxes",
         "System`Dump`tmpboxes$", "System`Dump`tmpeps", "System`Dump`tmpfile",
         "System`Dump`tmpfname", "System`Dump`tmpstr", "System`Dump`tmpstr$", 
        "System`Dump`tmp$", "System`Dump`tresult", "System`Dump`trig", 
        "System`Dump`trig$", "System`Dump`trim", "System`Dump`trueCharEnc", 
        "System`Dump`trueCharEnc$", "System`Dump`txt1", "System`Dump`txt2", 
        "System`Dump`TypesetCompact", "System`Dump`TypesetMessagesQ", 
        "System`Dump`uFile", "System`Dump`UninstallHelper", 
        "System`Dump`unset", "System`Dump`UsageCells", 
        "System`Dump`UsagePrint", "System`Dump`UsageStyles", 
        "System`Dump`UseExportFormatQ", "System`Dump`val", "System`Dump`vals",
         "System`Dump`vals$", "System`Dump`value", "System`Dump`vc", 
        "System`Dump`vc$", "System`Dump`w", "System`Dump`wasOn", 
        "System`Dump`wasOn$", "System`Dump`width", "System`Dump`width$", 
        "System`Dump`winmag", "System`Dump`winmag$", "System`Dump`winsize", 
        "System`Dump`winsize$", "System`Dump`writeArguments", 
        "System`Dump`writeBytes", "System`Dump`WriteDef", "System`Dump`w$", 
        "System`Dump`x", "System`Dump`x0", "System`Dump`x1", 
        "System`Dump`xmax", "System`Dump`xmax$", "System`Dump`xmin", 
        "System`Dump`xmin$", "System`Dump`x$", "System`Dump`y", 
        "System`Dump`ymax", "System`Dump`ymax$", "System`Dump`ymin", 
        "System`Dump`ymin$", "System`Dump`y$", "System`Dump`z", 
        "System`Dump`zmax", "System`Dump`zmax$", "System`Dump`zmin", 
        "System`Dump`zmin$", "System`Dump`$AutoLoad", 
        "System`Dump`$badsystemsyms", "System`Dump`$cachedLanguage", 
        "System`Dump`$experimentalanddevelopersyms", 
        "System`Dump`$extendedmessageoptions", 
        "System`Dump`$extendedmessageoptionsnames", "System`Dump`$FontPath", 
        "System`Dump`$holdlist", "System`Dump`$knownpackages", 
        "System`Dump`$MessagesInHelpBrowserAreKnown", 
        "System`Dump`$OldMessageLocation", "System`Dump`$usagestylepatterns", 
        "System`Dump`$usagestyles", "System`Dump`$$Dummy", "SystemException", 
        "System`exit", "System`FEDump`allNotebooks", 
        "System`FEDump`allNotebooks$", "System`FEDump`arg", 
        "System`FEDump`args", "System`FEDump`boxes", "System`FEDump`category",
         "System`FEDump`CheckFileSystem", "System`FEDump`cnt", 
        "System`FEDump`command", "System`FEDump`compnames", 
        "System`FEDump`data", "System`FEDump`dir", "System`FEDump`elems", 
        "System`FEDump`EqualizeCase", "System`FEDump`expr", "System`FEDump`f",
         "System`FEDump`fe", "System`FEDump`feLink", "System`FEDump`file", 
        "System`FEDump`filename", "System`FEDump`filename$", 
        "System`FEDump`formatType", "System`FEDump`formatType$", 
        "System`FEDump`fromFileName", "System`FEDump`FrontEndQ", 
        "System`FEDump`FrontEndValue", "System`FEDump`head", 
        "System`FEDump`id", "System`FEDump`insertSeparatorsAmongstList", 
        "System`FEDump`key", "System`FEDump`l", "System`FEDump`l1", 
        "System`FEDump`l2", "System`FEDump`list", "System`FEDump`markup", 
        "System`FEDump`messageopts", "System`FEDump`messageopts$", 
        "System`FEDump`name", "System`FEDump`nbFileName", 
        "System`FEDump`nbheads", "System`FEDump`nbName", 
        "System`FEDump`nbName$", "System`FEDump`nbObj", 
        "System`FEDump`nbTitle", "System`FEDump`newMessageOptions", 
        "System`FEDump`newname", "System`FEDump`newName", 
        "System`FEDump`newvers", "System`FEDump`NonOptionArgCount", 
        "System`FEDump`NoResult", "System`FEDump`note", 
        "System`FEDump`notebook", "System`FEDump`notebookNameMatchQ", 
        "System`FEDump`oldMessageOptions", "System`FEDump`option", 
        "System`FEDump`options", "System`FEDump`optlist", 
        "System`FEDump`opts", "System`FEDump`other", 
        "System`FEDump`otherboxes", "System`FEDump`outputForm", 
        "System`FEDump`outputForm$", "System`FEDump`p", 
        "System`FEDump`paddingElement", "System`FEDump`paddingElements", 
        "System`FEDump`processBoxesForMathML", "System`FEDump`r", 
        "System`FEDump`resnames", "System`FEDump`restopts", 
        "System`FEDump`result", "System`FEDump`result$", "System`FEDump`s", 
        "System`FEDump`seconds", "System`FEDump`select", 
        "System`FEDump`setconvertoptions", "System`FEDump`sf", 
        "System`FEDump`sf$", "System`FEDump`style", "System`FEDump`tag", 
        "System`FEDump`tempnb", "System`FEDump`title", "System`FEDump`title$",
         "System`FEDump`transformProcessedBoxesToMathML", 
        "System`FEDump`unit", "System`FEDump`usernb", "System`FEDump`varName",
         "System`FEDump`wasProtected", "System`FEDump`x", 
        "System`FEDump`$validNotebookHeads", 
        "System`FEDump`$validNotebookHeadsPattern", "SystemHelpPath", 
        "System`IntegerPartitionsDump`n", "System`IntegerPartitionsDump`pp", 
        "System`IntegerPartitionsDump`pq", 
        "System`InterpolatingFunction`Grid", 
        "System`InterpolatingFunction`ValuesOnGrid", 
        "System`LanguageEnhancements`a", "System`LanguageEnhancements`e", 
        "System`LanguageEnhancements`finalLevelOrder", 
        "System`LanguageEnhancements`finalLevelOrder$", 
        "System`LanguageEnhancements`flatSet", 
        "System`LanguageEnhancements`flatSet$", 
        "System`LanguageEnhancements`lengths", 
        "System`LanguageEnhancements`lengths$", 
        "System`LanguageEnhancements`m", 
        "System`LanguageEnhancements`mergedAtTop", 
        "System`LanguageEnhancements`mergedAtTop$", 
        "System`LanguageEnhancements`mm", "System`LanguageEnhancements`mm$", 
        "System`LanguageEnhancements`m$", "System`LanguageEnhancements`n", 
        "System`LanguageEnhancements`neg", "System`LanguageEnhancements`neg$",
         "System`LanguageEnhancements`nn", "System`LanguageEnhancements`nn$", 
        "System`LanguageEnhancements`permAfter", 
        "System`LanguageEnhancements`permAfter$", 
        "System`LanguageEnhancements`permBefore", 
        "System`LanguageEnhancements`permBefore$", 
        "System`LanguageEnhancements`R", "System`LanguageEnhancements`R$", 
        "System`LanguageEnhancements`s", 
        "System`LanguageEnhancements`setsOfLevels", 
        "System`LanguageEnhancements`setsOfLevels$", 
        "System`LanguageEnhancements`setsToMerge", 
        "System`LanguageEnhancements`startLevels", 
        "System`LanguageEnhancements`startLevels$", 
        "System`LanguageEnhancements`tempTensor", 
        "System`LanguageEnhancements`tempTensor$", 
        "System`LanguageEnhancements`tensor", 
        "System`LanguageEnhancements`toodeep", 
        "System`LanguageEnhancements`toodeep$", 
        "System`LanguageEnhancements`u", "System`LanguageEnhancements`union", 
        "System`LanguageEnhancements`union$", 
        "System`LanguageEnhancements`unscathedLevels", 
        "System`LanguageEnhancements`unscathedLevels$", 
        "System`LanguageEnhancements`u$", 
        "System`LanguageEnhancements`ValidSetsQ", 
        "System`LaplaceTransformDump`f", 
        "System`LaplaceTransformDump`inverse", 
        "System`LaplaceTransformDump`inverse$", 
        "System`LaplaceTransformDump`m", "System`LaplaceTransformDump`s", 
        "System`LaplaceTransformDump`t", "System`LaplaceTransformDump`t1", 
        "System`LaplaceTransformDump`t1$", "System`Private`Accumulate", 
        "System`Private`AlgebraicNumberQ", "System`Private`ApproxRoots", 
        "System`Private`AssumptionAccess", "System`Private`AssumptionsExp", 
        "System`Private`auto", "System`Private`binary", 
        "System`Private`CFunctionInterpolation", "System`Private`check", 
        "System`Private`Cholesky", "System`Private`CodeAddress", 
        "System`Private`ColorMap", "System`Private`CompileLocal1", 
        "System`Private`CompileLocal2", "System`Private`CompileLocal3", 
        "System`Private`CompileLocal4", "System`Private`CompileLocal5", 
        "System`Private`CompileSymbol", "System`Private`ComplexRoots", 
        "System`Private`cont", "System`Private`ConvertToSymbols", 
        "System`Private`CRCTGI", "System`Private`CyclotomicQ", 
        "System`Private`D", "System`Private`dir", "System`Private`DummyId", 
        "System`Private`DummySequence", "System`Private`ExpandFileName", 
        "System`Private`extra", "System`Private`file", 
        "System`Private`FindField", "System`Private`FindFile", 
        "System`Private`fn", "System`Private`FullOptions3D", 
        "System`Private`GBConvert", "System`Private`GCDcfLCMCancel", 
        "System`Private`GetFieldData", "System`Private`GetInputHeld", 
        "System`Private`heldSyms", "System`Private`heldSyms$", 
        "System`Private`InputFormNumberMarks", "System`Private`IntegerDummy", 
        "System`Private`InternalInverseErf", "System`Private`InternalSeries", 
        "System`Private`InternalSpace", "System`Private`InternSequence", 
        "System`Private`IsolatingSets", 
        "System`Private`LargeDegreePolynomialMod", 
        "System`Private`LinearInequalityReduce", 
        "System`Private`loadInitFile", "System`Private`MakeValidRoot", 
        "System`Private`MatchBox", "System`Private`MaxPiecewiseCasesMessage", 
        "System`Private`NCacheKey", "System`Private`NewerDate", 
        "System`Private`newsyms", "System`Private`NRelPrimeQ", 
        "System`Private`NRoot", "System`Private`NRRoot", 
        "System`Private`NRRoots", "System`Private`O", 
        "System`Private`oldContextPath", "System`Private`OldReduce", 
        "System`Private`origFrontEnd", "System`Private`PackedDisable", 
        "System`Private`PackedList", "System`Private`pFile", 
        "System`Private`PLt", "System`Private`PolyModInverse", 
        "System`Private`pow", "System`Private`PrimitiveRoot", 
        "System`Private`PTest", "System`Private`QuadraticRoot", 
        "System`Private`RadicalVar", "System`Private`RealBignumRoots", 
        "System`Private`RealRootQ", "System`Private`RealRoots", 
        "System`Private`ReImPair", "System`Private`ResetTagCCs", 
        "System`Private`RestoreAllValues", 
        "System`Private`RootIsolatingPoints", "System`Private`RRoot", 
        "System`Private`RuleHashTable", "System`Private`RuleTable", 
        "System`Private`SaveAllValues", 
        "System`Private`SeriesSingularityHandler", 
        "System`Private`SetSymbolAttributes", 
        "System`Private`SimplifyScaledArg", 
        "System`Private`SmallQuadraticValues", 
        "System`Private`StringTurnedIntoStream", "System`Private`test", 
        "System`Private`TestGccLengthBug", "System`Private`tmp", 
        "System`Private`tmp$", "System`Private`UnivariatePolynomialMod", 
        "System`Private`UnivPolys", "System`Private`UpUnset", 
        "System`Private`UsingOldVTs", "System`Private`ValidQ", 
        "System`Private`ValueList", "System`Private`values", 
        "System`Private`ValueTable", "System`Private`VerbatimSameQ", 
        "System`Private`ZetaDerivative", "System`Private`$AutoLoad", 
        "System`Private`$cachedRefGuide", 
        "System`Private`$cachedRefGuideOffset", 
        "System`Private`$ForceRebuild", "System`Private`$Gradient", 
        "System`Private`$GraphicsHeader", "System`Private`$IndentSuffix", 
        "System`Private`$InitsLoaded", "System`Private`$InputFileName", 
        "System`Private`$MessagesDir", "System`Private`$nbFormatType", 
        "System`Private`$nbFrontEndQ", "System`Private`$nbOpts", 
        "System`Private`$nbSystemPrint", "System`Private`$prevWasFE", 
        "System`Private`$PrintLoad", "System`Private`$PSRenderOptions", 
        "System`Private`$RasterLink", "System`Private`$SetCCMaxCCEnabled", 
        "System`Private`$SystemFileDir", "System`Private`$SystemPrint", 
        "System`Private`$SystemPrintInput", "System`Private`$TagCCsEnabled", 
        "System`Private`$TextAlter", "System`Private`$Unset", 
        "System`Private`$$Failure2", "System`Private`$$ParenForm", 
        "SystemStub", "sz0", "sz0$", "Tab", "TabFilling", "Table", 
        "TableAlignments", "TableDepth", "TableDirections", "TableForm", 
        "TableHeadings", "TableSpacing", "TabSpacings", "TagBox", 
        "TagBoxOptions", "TaggingRules", "TagSet", "TagSetDelayed", 
        "TagStyle", "TagUnset", "Take", "Tan", "Tanh", "TargetFunctions", 
        "Temporary", "TemporaryVariable", "TensorQ", "TensorRank", "TeXForm", 
        "TeXSave", "Text", "TextAlignment", "TextBoundingBox", "TextData", 
        "textField1", "textField2", "textField3", "textField4", "textField5", 
        "TextForm", "TextJustification", "TextLine", "TextPacket", 
        "TextParagraph", "TextRendering", "TextStyle", "Thickness", 
        "ThisLink", "Thread", "ThreeJSymbol", "Through", "Throw", "Ticks", 
        "TimeConstrained", "TimeConstraint", "Times", "TimesBy", "TimeUsed", 
        "TimeVariable", "TimeZone", "Timing", "TitleGrouping", "tNow", 
        "ToBoxes", "ToCharacterCode", "ToColor", "ToDate", "ToExpression", 
        "ToFileName", "Together", "Toggle", "ToggleFalse", "ToHeldExpression",
         "TokenWords", "Tolerance", "ToLowerCase", "TooBig", "Top", 
        "ToRadicals", "ToRules", "ToString", "Total", "TotalHeight", 
        "TotalWidth", "ToUpperCase", "Tr", "Trace", "TraceAbove", 
        "TraceAction", "TraceBackward", "TraceDepth", "TraceDialog", 
        "TraceForward", "TraceInternal", "TraceLevel", "TraceOff", "TraceOn", 
        "TraceOriginal", "TracePrint", "TraceScan", "TraditionalForm", 
        "TraditionalFunctionNotation", "TraditionalNotation", 
        "TraditionalOrder", "TransformationFunctions", "TransparentColor", 
        "Transpose", "Trapezoidal", "TreeForm", "Trig", "TrigExpand", 
        "TrigFactor", "TrigFactorList", "TrigReduce", "TrigToExp", "True", 
        "TrueQ", "Tuples", "type", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`addSimEventListener", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`clearMediaProducers", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
clearPropertyListeners", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireBooleanPropertyEvent", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireNumericPropertyEvent", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireObjectPropertyEvent", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`fireSimEvent", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
fireStringPropertyEvent", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`generateNewSeed", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getController", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getMediaProducers", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getModelManipulator", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
getParameterDescriptors", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getPropertiesValues", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getRngSeed", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`getTickCount", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`pause", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
registerDisplaySurface", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`registerMediaProducer",
         "uchicago`src`sim`engine`SimModelImpl`JPrivate`\
removeSimEventListener", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`setController", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`setRngSeed", 
        "uchicago`src`sim`engine`SimModelImpl`JPrivate`stop", "UnAlias", 
        "Underflow", "Underoverscript", "UnderoverscriptBox", 
        "UnderoverscriptBoxOptions", "Underscript", "UnderscriptBox", 
        "UnderscriptBoxOptions", "UndocumentedTestFEParserPacket", 
        "UndocumentedTestGetSelectionPacket", "Unequal", "Unevaluated", 
        "Uninstall", "UninstallJava", "Union", "Unique", "UnitStep", 
        "Unprotect", "UnsameQ", "Unset", "UnshareFrontEnd", "UnshareKernel", 
        "Up", "Update", "UpperCaseQ", "UpSet", "UpSetDelayed", "UpValues", 
        "URL", "UseFrontEnd", "UseTypeChecking", "Using", "V2Get", "Val", 
        "Value", "ValueBox", "ValueBoxOptions", "ValueForm", "ValueQ", 
        "Variables", "Variance", "VectorQ", "Verbatim", "Verbose", 
        "VerboseConvertToPostScriptPacket", "VerifyConvergence", 
        "VerifySolutions", "Version", "VersionNumber", "Vertical", 
        "VerticalForm", "ViewCenter", "ViewPoint", 
        "ViewPointSelectorSettings", "ViewVertical", "Visible", "VisibleCell",
         "vx", "vx$", "vy", "vy$", "WeierstrassHalfPeriods", 
        "WeierstrassInvariants", "WeierstrassP", "WeierstrassPPrime", 
        "WeierstrassSigma", "WeierstrassZeta", "Which", "While", "White", 
        "Whitespace", "WhitespaceCharacter", 
        "Win32OffScreenImage`getAccelerationThreshold", 
        "Win32OffScreenImage`SCALEUAREAUAVERAGING", 
        "Win32OffScreenImage`SCALEUDEFAULT", "Win32OffScreenImage`SCALEUFAST",
         "Win32OffScreenImage`SCALEUREPLICATE", 
        "Win32OffScreenImage`SCALEUSMOOTH", 
        "Win32OffScreenImage`TYPEU3BYTEUBGR", 
        "Win32OffScreenImage`TYPEU4BYTEUABGR", 
        "Win32OffScreenImage`TYPEU4BYTEUABGRUPRE", 
        "Win32OffScreenImage`TYPEUBYTEUBINARY", 
        "Win32OffScreenImage`TYPEUBYTEUGRAY", 
        "Win32OffScreenImage`TYPEUBYTEUINDEXED", 
        "Win32OffScreenImage`TYPEUCUSTOM", 
        "Win32OffScreenImage`TYPEUINTUARGB", 
        "Win32OffScreenImage`TYPEUINTUARGBUPRE", 
        "Win32OffScreenImage`TYPEUINTUBGR", 
        "Win32OffScreenImage`TYPEUINTURGB", 
        "Win32OffScreenImage`TYPEUUSHORTU555URGB", 
        "Win32OffScreenImage`TYPEUUSHORTU565URGB", 
        "Win32OffScreenImage`TYPEUUSHORTUGRAY", 
        "Win32OffScreenImage`UndefinedProperty", "Window`ABORT", 
        "Window`ALLBITS", "Window`BOTTOMUALIGNMENT", 
        "Window`CENTERUALIGNMENT", "WindowClickSelect", "WindowElements", 
        "Window`ERROR", "WindowFloating", "WindowFrame", "Window`FRAMEBITS", 
        "WindowFrameElements", "Window`HEIGHT", "Window`LEFTUALIGNMENT", 
        "WindowMargins", "WindowMovable", "Window`PROPERTIES", 
        "Window`RIGHTUALIGNMENT", "WindowSize", "Window`SOMEBITS", 
        "WindowTitle", "WindowToolbars", "Window`TOPUALIGNMENT", 
        "Window`WIDTH", "WindowWidth", "With", "Word", "WordBoundary", 
        "WordCharacter", "WordSearch", "WordSeparators", "WorkingPrecision", 
        "Write", "WriteString", "WynnDegree", "x", "x0", "x0$", "xM", 
        "XMLElement", "XML`FromSymbolicXML", "XML`MathML`BoxesToMathML", 
        "XML`MathML`BoxesToSymbolicMathML", "XML`MathML`ExpressionToMathML", 
        "XML`MathML`ExpressionToSymbolicMathML", "XML`MathML`MathMLToBoxes", 
        "XML`MathML`MathMLToExpression", "XML`MathML`SymbolicMathMLToBoxes", 
        "XML`MathML`SymbolicMathMLToExpression", 
        "XML`MathML`Symbols`Cardinality", 
        "XML`MathML`Symbols`CartesianProduct", "XML`MathML`Symbols`Codomain", 
        "XML`MathML`Symbols`ConditionedIntegrate", 
        "XML`MathML`Symbols`ConditionedLimit", 
        "XML`MathML`Symbols`ConditionedList", 
        "XML`MathML`Symbols`ConditionedMax", 
        "XML`MathML`Symbols`ConditionedMin", 
        "XML`MathML`Symbols`ConditionedProduct", 
        "XML`MathML`Symbols`ConditionedSet", 
        "XML`MathML`Symbols`ConditionedSum", 
        "XML`MathML`Symbols`CovariantDerivativeIndex", 
        "XML`MathML`Symbols`Declare", "XML`MathML`Symbols`DerivativeIndex", 
        "XML`MathML`Symbols`Divides", "XML`MathML`Symbols`Domain", 
        "XML`MathML`Symbols`DomainIntegrate", 
        "XML`MathML`Symbols`DomainOfApplication", 
        "XML`MathML`Symbols`DomainProduct", "XML`MathML`Symbols`DomainSum", 
        "XML`MathML`Symbols`Image", "XML`MathML`Symbols`IndefiniteProduct", 
        "XML`MathML`Symbols`IndefiniteSum", 
        "XML`MathML`Symbols`IntervalClosed", 
        "XML`MathML`Symbols`IntervalClosedOpen", 
        "XML`MathML`Symbols`IntervalOpen", 
        "XML`MathML`Symbols`IntervalOpenClosed", "XML`MathML`Symbols`Moment", 
        "XML`MathML`Symbols`MomentAbout", "XML`MathML`Symbols`Multiscripts", 
        "XML`NotebookML`ExpressionToSymbolicExpressionML", 
        "XML`NotebookML`NotebookToSymbolicNotebookML", 
        "XML`NotebookML`SymbolicExpressionMLToExpression", 
        "XML`NotebookML`SymbolicNotebookMLToNotebook", "XMLObject", 
        "XML`Parser`InitializeXMLParser", "XML`Parser`ReleaseXMLParser", 
        "XML`Parser`XMLGet", "XML`Parser`XMLGetString", 
        "XML`Parser`XMLParser", "XML`RawXML", "XML`SVG`GraphicsToSVG", 
        "XML`SVG`GraphicsToSymbolicSVG", "XML`SVG`SVGToGraphics", 
        "XML`SVG`SymbolicSVGToGraphics", "XML`SymbolicXMLErrors", 
        "XML`SymbolicXMLQ", "XML`ToCompactXML", "XML`ToSymbolicXML", 
        "XML`ToVerboseXML", "Xor", "xPos", "xPos$", "xs0", "xs0$", "xSpeed", 
        "xSpeed$", "x$", "y", "y0", "y0$", "Yellow", "yM", "yPos", "yPos$", 
        "ys0", "ys0$", "ySpeed", "ySpeed$", "y$", "ZeroShape", "ZeroTest", 
        "ZeroWidthTimes", "Zeta", "ZTransform", "$", "$Aborted", 
        "$AddOnsDirectory", "$AnimationDisplayFunction", "$AnimationFunction",
         "$Assumptions", "$BaseDirectory", "$BatchInput", "$BatchOutput", 
        "$BoxForms", "$ByteOrdering", "$CharacterEncoding", "$CommandLine", 
        "$ConditionHold", "$Context", "$ContextPath", "$CreationDate", 
        "$CurrentLink", "$DefaultFont", "$DefaultImageFormat", "$DefaultPath",
         "$Display", "$DisplayFunction", "$DumpDates", "$DumpSupported", 
        "$Echo", "$Epilog", "$ExportEncodings", "$ExportFormats", 
        "$ExtraClassPath", "$Failed", "$FormatType", "$FrontEnd", 
        "$FrontEndInitializationFunction", "$FrontEndLaunchCommand", 
        "$HistoryLength", "$HomeDirectory", "$IgnoreEOF", "$ImportEncodings", 
        "$ImportFormats", "$InitialDirectory", "$Input", "$Inspector", 
        "$InstallationDate", "$InstallationDirectory", 
        "$InterfaceEnvironment", "$IterationLimit", "$JavaExceptionHandler", 
        "$Language", "$LaunchDirectory", "$LicenseExpirationDate", 
        "$LicenseID", "$LicenseProcesses", "$LicenseServer", "$Line", 
        "$Linked", "$LinkSupported", "$MachineDomain", "$MachineEpsilon", 
        "$MachineID", "$MachineName", "$MachinePrecision", "$MachineType", 
        "$MaxExtraPrecision", "$MaxLicenseProcesses", "$MaxMachineNumber", 
        "$MaxNumber", "$MaxPiecewiseCases", "$MaxPrecision", "$MaxRootDegree",
         "$MessageList", "$MessagePrePrint", "$Messages", "$MinMachineNumber",
         "$MinNumber", "$MinPrecision", "$ModuleNumber", "$NetworkLicense", 
        "$NewMessage", "$NewSymbol", "$Notebooks", "$NumberMarks", "$Off", 
        "$OperatingSystem", "$Output", "$OutputForms", "$Packages", 
        "$ParentLink", "$ParentProcessID", "$PasswordFile", "$Path", 
        "$PathnameSeparator", "$PipeSupported", "$Post", "$Pre", 
        "$PreferencesDirectory", "$PrePrint", "$PreRead", "$PrintForms", 
        "$PrintLiteral", "$ProcessID", "$ProcessorType", 
        "$ProductInformation", "$ProgramName", "$PSDirectDisplay", 
        "$RandomState", "$RasterFunction", "$RecursionLimit", 
        "$RelaxedTypeChecking", "$ReleaseNumber", "$RootDirectory", 
        "$SessionID", "$SetParentLink", "$SoundDisplay", 
        "$SoundDisplayFunction", "$SuppressInputFormHeads", "$SyntaxHandler", 
        "$System", "$SystemCharacterEncoding", "$SystemID", 
        "$TemporaryPrefix", "$TextStyle", "$ThisPeriodical", "$TimeUnit", 
        "$TopDirectory", "$TraceOff", "$TraceOn", "$TracePattern", 
        "$TracePostAction", "$TracePreAction", "$Urgent", 
        "$UserAddOnsDirectory", "$UserBaseDirectory", "$UserName", "$Version",
         "$VersionNumber"}],
      Editable->False]], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[ColumnForm[Names["\<JLink`*\>"]]];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"AddPeriodical\"\>"},
          {"\<\"AddToClassPath\"\>"},
          {"\<\"AllowRaggedArrays\"\>"},
          {"\<\"AllowShortContext\"\>"},
          {"\<\"AppletViewer\"\>"},
          {"\<\"BeginJavaBlock\"\>"},
          {"\<\"ByRef\"\>"},
          {"\<\"ClassName\"\>"},
          {"\<\"ClassPath\"\>"},
          {"\<\"CloseFrontEnd\"\>"},
          {"\<\"CommandLine\"\>"},
          {"\<\"ConnectToFrontEnd\"\>"},
          {"\<\"Constructors\"\>"},
          {"\<\"ConvertToCellExpression\"\>"},
          {"\<\"DoModal\"\>"},
          {"\<\"EndJavaBlock\"\>"},
          {"\<\"EndModal\"\>"},
          {"\<\"EvaluateToImage\"\>"},
          {"\<\"EvaluateToTypeset\"\>"},
          {"\<\"FieldFunction\"\>"},
          {"\<\"Fields\"\>"},
          {"\<\"ForceLaunch\"\>"},
          {"\<\"FrontEndLink\"\>"},
          {"\<\"FrontEndSharedQ\"\>"},
          {"\<\"GetClass\"\>"},
          {"\<\"GetClassPath\"\>"},
          {"\<\"GetComplexClass\"\>"},
          {"\<\"GetJavaException\"\>"},
          {"\<\"ImplementJavaInterface\"\>"},
          {"\<\"InstallJava\"\>"},
          {"\<\"InstanceOf\"\>"},
          {"\<\"Java\"\>"},
          {"\<\"JavaBlock\"\>"},
          {"\<\"JavaClass\"\>"},
          {"\<\"JavaClassPath\"\>"},
          {"\<\"JavaGC\"\>"},
          {"\<\"JavaLink\"\>"},
          {"\<\"JavaNew\"\>"},
          {"\<\"JavaObject\"\>"},
          {"\<\"JavaObjectQ\"\>"},
          {"\<\"JavaObjectToExpression\"\>"},
          {"\<\"JavaShow\"\>"},
          {"\<\"JavaThrow\"\>"},
          {"\<\"JavaUILink\"\>"},
          {"\<\"JavaWindowToFront\"\>"},
          {"\<\"JVMArguments\"\>"},
          {"\<\"KeepJavaObject\"\>"},
          {"\<\"KeepObjects\"\>"},
          {"\<\"KernelSharedQ\"\>"},
          {"\<\"LoadClass\"\>"},
          {"\<\"LoadJavaClass\"\>"},
          {"\<\"MakeJavaExpr\"\>"},
          {"\<\"MakeJavaObject\"\>"},
          {"\<\"MethodFunction\"\>"},
          {"\<\"Methods\"\>"},
          {"\<\"ParentClass\"\>"},
          {"\<\"PeekClasses\"\>"},
          {"\<\"PeekObjects\"\>"},
          {"\<\"Periodical\"\>"},
          {"\<\"Periodicals\"\>"},
          {"\<\"QuitJava\"\>"},
          {"\<\"ReinstallJava\"\>"},
          {"\<\"ReleaseJavaObject\"\>"},
          {"\<\"ReleaseObject\"\>"},
          {"\<\"RemovePeriodical\"\>"},
          {"\<\"RestartJava\"\>"},
          {"\<\"ReturnAsJavaObject\"\>"},
          {"\<\"SameObjectQ\"\>"},
          {"\<\"ServiceJava\"\>"},
          {"\<\"SetComplexClass\"\>"},
          {"\<\"SetField\"\>"},
          {"\<\"SetInternetProxy\"\>"},
          {"\<\"SetPeriodicalInterval\"\>"},
          {"\<\"ShareFrontEnd\"\>"},
          {"\<\"ShareKernel\"\>"},
          {"\<\"SharingLinks\"\>"},
          {"\<\"SharingPrompt\"\>"},
          {"\<\"ShowJavaConsole\"\>"},
          {"\<\"StartJava\"\>"},
          {"\<\"StaticsVisible\"\>"},
          {"\<\"UninstallJava\"\>"},
          {"\<\"UnshareFrontEnd\"\>"},
          {"\<\"UnshareKernel\"\>"},
          {"\<\"UseFrontEnd\"\>"},
          {"\<\"UseTypeChecking\"\>"},
          {"\<\"Val\"\>"},
          {"\<\"$DefaultImageFormat\"\>"},
          {"\<\"$ExtraClassPath\"\>"},
          {"\<\"$FrontEndInitializationFunction\"\>"},
          {"\<\"$FrontEndLaunchCommand\"\>"},
          {"\<\"$JavaExceptionHandler\"\>"},
          {"\<\"$RelaxedTypeChecking\"\>"},
          {"\<\"$ThisPeriodical\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"AddPeriodical", "AddToClassPath", "AllowRaggedArrays", 
        "AllowShortContext", "AppletViewer", "BeginJavaBlock", "ByRef", 
        "ClassName", "ClassPath", "CloseFrontEnd", "CommandLine", 
        "ConnectToFrontEnd", "Constructors", "ConvertToCellExpression", 
        "DoModal", "EndJavaBlock", "EndModal", "EvaluateToImage", 
        "EvaluateToTypeset", "FieldFunction", "Fields", "ForceLaunch", 
        "FrontEndLink", "FrontEndSharedQ", "GetClass", "GetClassPath", 
        "GetComplexClass", "GetJavaException", "ImplementJavaInterface", 
        "InstallJava", "InstanceOf", "Java", "JavaBlock", "JavaClass", 
        "JavaClassPath", "JavaGC", "JavaLink", "JavaNew", "JavaObject", 
        "JavaObjectQ", "JavaObjectToExpression", "JavaShow", "JavaThrow", 
        "JavaUILink", "JavaWindowToFront", "JVMArguments", "KeepJavaObject", 
        "KeepObjects", "KernelSharedQ", "LoadClass", "LoadJavaClass", 
        "MakeJavaExpr", "MakeJavaObject", "MethodFunction", "Methods", 
        "ParentClass", "PeekClasses", "PeekObjects", "Periodical", 
        "Periodicals", "QuitJava", "ReinstallJava", "ReleaseJavaObject", 
        "ReleaseObject", "RemovePeriodical", "RestartJava", 
        "ReturnAsJavaObject", "SameObjectQ", "ServiceJava", "SetComplexClass",
         "SetField", "SetInternetProxy", "SetPeriodicalInterval", 
        "ShareFrontEnd", "ShareKernel", "SharingLinks", "SharingPrompt", 
        "ShowJavaConsole", "StartJava", "StaticsVisible", "UninstallJava", 
        "UnshareFrontEnd", "UnshareKernel", "UseFrontEnd", "UseTypeChecking", 
        "Val", "$DefaultImageFormat", "$ExtraClassPath", 
        "$FrontEndInitializationFunction", "$FrontEndLaunchCommand", 
        "$JavaExceptionHandler", "$RelaxedTypeChecking", "$ThisPeriodical"}],
      Editable->False]], "Print"]
}, Closed]],

Cell[BoxData[{
    \(Names["\<Scrollbar`*\>"]\), "\n", 
    \(Names["\<Color`*\>"]\)}], "Input"],

Cell[BoxData[
    \(\(Print[ColumnForm@PeekObjects[]];\)\)], "Input"],

Cell[BoxData[
    \(SharingLinks[]\)], "Input"],

Cell[BoxData[
    \(\(Print[ColumnForm@PeekClasses[]];\)\)], "Input"],

Cell[BoxData[
    \(\(?JLink`*\)\)], "Input"],

Cell[BoxData[
    \(\(\(Print[#, "\<\n\>", Constructors[#]] &\) /@ 
        PeekClasses[];\)\)], "Input"],

Cell[BoxData[
    \(\(\(Print[#, "\<\n\>", Fields[#], "\< \>", Methods[#]] &\) /@ 
        PeekClasses[];\)\)], "Input"],

Cell[BoxData[
    \(Methods[\(PeekClasses[]\)[\([29]\)]]\)], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 623}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1016, 592},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
ShowCellTags->True,
Magnification->1.25,
StyleDefinitions -> FrontEnd`FileName[{"StyleSheets"}, "myAuthorTools.nb", \
CharacterEncoding -> "WindowsANSI"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "run simulation"->{
    Cell[6856, 177, 228, 5, 67, "Input",
      CellTags->"run simulation"],
    Cell[7087, 184, 220, 5, 55, "Print",
      CellTags->"run simulation"],
    Cell[7310, 191, 242, 5, 55, "Print",
      CellTags->"run simulation"],
    Cell[7555, 198, 85, 2, 55, "Print",
      CellTags->"run simulation"],
    Cell[7643, 202, 357, 8, 55, "Print",
      CellTags->"run simulation"],
    Cell[8003, 212, 113850, 2639, 429, 28501, 1581, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"run simulation"],
    Cell[121856, 2853, 293, 6, 55, "Print",
      CellTags->"run simulation"],
    Cell[122152, 2861, 283, 6, 55, "Print",
      CellTags->"run simulation"]},
  "predator rules"->{
    Cell[799995, 19227, 8863, 164, 1517, "Input - Initialization Cell",
      CellTags->"predator rules"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"run simulation", 1641324, 34967},
  {"predator rules", 1642018, 34985}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 28, 0, 78, "Title"],
Cell[1807, 55, 135, 5, 53, "Subtitle"],
Cell[1945, 62, 71, 1, 28, "Author"],
Cell[2019, 65, 413, 10, 134, "TextAboutAuthor"],
Cell[2435, 77, 851, 15, 102, "Text"],
Cell[3289, 94, 189, 6, 30, "SmallText"],

Cell[CellGroupData[{
Cell[3503, 104, 45, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[3573, 108, 131, 3, 91, "Subsection"],
Cell[3707, 113, 86, 3, 56, "Text"],
Cell[3796, 118, 84, 4, 79, "Text"],

Cell[CellGroupData[{
Cell[3905, 126, 70, 1, 52, "Subsubsection"],
Cell[3978, 129, 2762, 37, 470, "Text"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6801, 173, 30, 0, 42, "Section"],

Cell[CellGroupData[{
Cell[6856, 177, 228, 5, 67, "Input",
  CellTags->"run simulation"],
Cell[7087, 184, 220, 5, 55, "Print",
  CellTags->"run simulation"],
Cell[7310, 191, 242, 5, 55, "Print",
  CellTags->"run simulation"],
Cell[7555, 198, 85, 2, 55, "Print",
  CellTags->"run simulation"],
Cell[7643, 202, 357, 8, 55, "Print",
  CellTags->"run simulation"],
Cell[8003, 212, 113850, 2639, 429, 28501, 1581, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"run simulation"],
Cell[121856, 2853, 293, 6, 55, "Print",
  CellTags->"run simulation"],
Cell[122152, 2861, 283, 6, 55, "Print",
  CellTags->"run simulation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[122484, 2873, 45, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[122554, 2877, 1346, 24, 387, "Input"],
Cell[123903, 2903, 273, 4, 39, "Message"],
Cell[124179, 2909, 417, 10, 59, "Print"],
Cell[124599, 2921, 299, 4, 39, "Message"],
Cell[124901, 2927, 165, 3, 39, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[125115, 2936, 61, 0, 42, "Section"],

Cell[CellGroupData[{
Cell[125201, 2940, 50, 0, 52, "Subsubsection"],
Cell[125254, 2942, 280, 5, 93, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125571, 2952, 35, 0, 52, "Subsubsection"],

Cell[CellGroupData[{
Cell[125631, 2956, 656, 15, 94, "Input"],

Cell[CellGroupData[{
Cell[126312, 2975, 43613, 1093, 223, 10631, 681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[169928, 4070, 43998, 1118, 223, 10985, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[213929, 5190, 39562, 905, 180, 8333, 515, "GraphicsData", "PostScript", \
"Graphics"],
Cell[253494, 6097, 51403, 1452, 180, 15687, 1006, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[304912, 7552, 1636, 40, 120, "Print"],
Cell[306551, 7594, 50, 1, 42, "Output"],

Cell[CellGroupData[{
Cell[306626, 7599, 52246, 1160, 223, 9945, 633, "GraphicsData", "PostScript", \
"Graphics"],
Cell[358875, 8761, 47994, 1167, 223, 10996, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[406872, 9930, 36739, 854, 180, 7972, 494, "GraphicsData", "PostScript", \
"Graphics"],
Cell[443614, 10786, 63012, 1556, 180, 14972, 958, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[506641, 12345, 1580, 39, 80, "Print"],
Cell[508224, 12386, 50, 1, 42, "Output"],

Cell[CellGroupData[{
Cell[508299, 12391, 52795, 1176, 223, 10158, 645, "GraphicsData", \
"PostScript", "Graphics"],
Cell[561097, 13569, 43244, 1109, 223, 10992, 706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[604344, 14680, 33484, 821, 180, 8099, 503, "GraphicsData", "PostScript", \
"Graphics"],
Cell[637831, 15503, 51136, 1418, 180, 15242, 970, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[688982, 16924, 1646, 38, 120, "Print"],
Cell[690631, 16964, 50, 1, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[690742, 16972, 32, 0, 42, "Section"],
Cell[690777, 16974, 140, 2, 72, "Input - Initialization Cell"],

Cell[CellGroupData[{
Cell[690942, 16980, 40, 0, 52, "Subsubsection"],
Cell[690985, 16982, 475, 8, 177, "Input - Initialization Cell"]
}, Open  ]],

Cell[CellGroupData[{
Cell[691497, 16995, 76, 0, 52, "Subsubsection"],

Cell[CellGroupData[{
Cell[691598, 16999, 1284, 27, 387, "Input - Initialization Cell"],
Cell[692885, 17028, 333, 8, 70, "Print"],
Cell[693221, 17038, 369, 8, 70, "Print"],
Cell[693593, 17048, 15900, 303, 70, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[709542, 17357, 47, 0, 52, "Subsubsection"],
Cell[709592, 17359, 77, 1, 51, "Input - Initialization Cell"]
}, Open  ]],

Cell[CellGroupData[{
Cell[709706, 17365, 33, 0, 52, "Subsubsection"],
Cell[709742, 17367, 48, 1, 50, "Input"],
Cell[709793, 17370, 46, 1, 50, "Input"],
Cell[709842, 17373, 54, 1, 50, "Input"],
Cell[709899, 17376, 519, 14, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[710455, 17395, 35, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[710515, 17399, 46, 0, 52, "Subsubsection"],
Cell[710564, 17401, 959, 18, 444, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[711560, 17424, 42, 0, 31, "Subsubsection"],
Cell[711605, 17426, 987, 19, 513, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[712629, 17450, 36, 0, 31, "Subsubsection"],
Cell[712668, 17452, 126, 5, 99, "Text"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[712855, 17464, 35, 0, 42, "Section"],

Cell[CellGroupData[{
Cell[712915, 17468, 33, 0, 52, "Subsubsection"],
Cell[712951, 17470, 6227, 112, 1378, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[719215, 17587, 29, 0, 31, "Subsubsection"],
Cell[719247, 17589, 10843, 202, 1957, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[730127, 17796, 29, 0, 31, "Subsubsection"],
Cell[730159, 17798, 12126, 231, 1778, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[742322, 18034, 32, 0, 31, "Subsubsection"],
Cell[742357, 18036, 160, 3, 33, "Text"],
Cell[742520, 18041, 466, 10, 156, "Input - Initialization Cell"],
Cell[742989, 18053, 20, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[743034, 18057, 84, 2, 51, "Input"],
Cell[743121, 18061, 53, 1, 42, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[743223, 18068, 29, 0, 31, "Subsubsection"],
Cell[743255, 18070, 900, 17, 378, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[744192, 18092, 29, 0, 31, "Subsubsection"],
Cell[744224, 18094, 4283, 80, 934, "Input - Initialization Cell"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[748556, 18180, 31, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[748612, 18184, 53, 0, 52, "Subsubsection"],
Cell[748668, 18186, 133, 3, 33, "Text"],
Cell[748804, 18191, 9871, 178, 1631, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[758712, 18374, 43, 0, 31, "Subsubsection"],
Cell[758758, 18376, 63, 0, 31, "Text"],
Cell[758824, 18378, 6054, 106, 1740, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[764915, 18489, 36, 0, 31, "Subsubsection"],
Cell[764954, 18491, 40, 0, 31, "Text"],
Cell[764997, 18493, 690, 14, 202, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[765724, 18512, 36, 0, 31, "Subsubsection"],
Cell[765763, 18514, 39, 0, 31, "Text"],
Cell[765805, 18516, 707, 14, 202, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[766549, 18535, 36, 0, 31, "Subsubsection"],
Cell[766588, 18537, 39, 0, 31, "Text"],
Cell[766630, 18539, 707, 14, 202, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[767374, 18558, 49, 0, 31, "Subsubsection"],
Cell[767426, 18560, 4588, 78, 1285, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[772051, 18643, 38, 0, 31, "Subsubsection"],
Cell[772092, 18645, 175, 3, 31, "Text"],
Cell[772270, 18650, 2894, 60, 440, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[775201, 18715, 38, 0, 31, "Subsubsection"],
Cell[775242, 18717, 27, 0, 31, "Text"],
Cell[775272, 18719, 676, 14, 202, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[775985, 18738, 87, 1, 39, "Subsection"],

Cell[CellGroupData[{
Cell[776097, 18743, 47, 0, 52, "Subsubsection"],
Cell[776147, 18745, 4228, 76, 1185, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[780412, 18826, 42, 0, 31, "Subsubsection"],
Cell[780457, 18828, 2779, 55, 483, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[783273, 18888, 41, 0, 31, "Subsubsection"],
Cell[783317, 18890, 3910, 67, 1263, "Input - Initialization Cell"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[787288, 18964, 30, 0, 76, "Section"],

Cell[CellGroupData[{
Cell[787343, 18968, 35, 0, 52, "Subsubsection"],
Cell[787381, 18970, 76, 0, 31, "Text"],
Cell[787460, 18972, 2481, 48, 522, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[789978, 19025, 39, 0, 31, "Subsubsection"],
Cell[790020, 19027, 81, 1, 53, "Input - Initialization Cell"],
Cell[790104, 19030, 496, 12, 155, "Text"],
Cell[790603, 19044, 8769, 161, 1397, "Input - Initialization Cell"],
Cell[799375, 19207, 443, 12, 131, "Text"],
Cell[799821, 19221, 171, 4, 81, "Text"],
Cell[799995, 19227, 8863, 164, 1517, "Input - Initialization Cell",
  CellTags->"predator rules"],
Cell[808861, 19393, 25, 0, 33, "Text"],
Cell[808889, 19395, 622, 15, 78, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[809548, 19415, 38, 0, 31, "Subsubsection"],
Cell[809589, 19417, 4592, 82, 768, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[814218, 19504, 38, 0, 31, "Subsubsection"],
Cell[814259, 19506, 1040, 20, 207, "Input - Initialization Cell"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[815348, 19532, 103, 4, 76, "Section"],

Cell[CellGroupData[{
Cell[815476, 19540, 33, 0, 52, "Subsubsection"],
Cell[815512, 19542, 49, 0, 31, "Text"],
Cell[815564, 19544, 532, 11, 158, "Input - Initialization Cell"],
Cell[816099, 19557, 20, 0, 31, "Text"],
Cell[816122, 19559, 128, 3, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[816287, 19567, 37, 0, 31, "Subsubsection"],
Cell[816327, 19569, 64, 0, 31, "Text"],
Cell[816394, 19571, 612, 13, 137, "Input - Initialization Cell"],
Cell[817009, 19586, 20, 0, 31, "Text"],
Cell[817032, 19588, 363, 9, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[817432, 19602, 33, 0, 31, "Subsubsection"],
Cell[817468, 19604, 38, 0, 33, "Text"],
Cell[817509, 19606, 821, 19, 114, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[818367, 19630, 34, 0, 31, "Subsubsection"],
Cell[818404, 19632, 76, 1, 51, "Input - Initialization Cell"],
Cell[818483, 19635, 37, 0, 33, "Text"],
Cell[818523, 19637, 934, 21, 210, "Input - Initialization Cell"],
Cell[819460, 19660, 38, 0, 33, "Text"],
Cell[819501, 19662, 2765, 58, 684, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[822303, 19725, 34, 0, 31, "Subsubsection"],
Cell[822340, 19727, 453, 9, 93, "Input - Initialization Cell"],
Cell[822796, 19738, 20, 0, 33, "Text"],
Cell[822819, 19740, 1436, 26, 345, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[824292, 19771, 35, 0, 31, "Subsubsection"],
Cell[824330, 19773, 109, 3, 32, "Text"],
Cell[824442, 19778, 613, 15, 92, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[825092, 19798, 38, 0, 31, "Subsubsection"],
Cell[825133, 19800, 578, 9, 117, "Text"],
Cell[825714, 19811, 1918, 36, 440, "Input - Initialization Cell"],
Cell[827635, 19849, 20, 0, 31, "Text"],
Cell[827658, 19851, 942, 19, 245, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[828637, 19875, 42, 0, 31, "Subsubsection"],
Cell[828682, 19877, 164, 3, 31, "Text"],
Cell[828849, 19882, 876, 17, 187, "Input - Initialization Cell"],
Cell[829728, 19901, 20, 0, 31, "Text"],
Cell[829751, 19903, 366, 7, 93, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[830154, 19915, 39, 0, 31, "Subsubsection"],
Cell[830196, 19917, 62, 0, 32, "Text"],
Cell[830261, 19919, 748, 15, 171, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[831046, 19939, 36, 0, 31, "Subsubsection"],
Cell[831085, 19941, 172, 3, 72, "Input - Initialization Cell"]
}, Closed]],

Cell[CellGroupData[{
Cell[831294, 19949, 65, 0, 31, "Subsubsection"],

Cell[CellGroupData[{
Cell[831384, 19953, 3757, 60, 1043, "Input"],
Cell[835144, 20015, 36069, 597, 375, 2524, 178, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[871250, 20617, 3755, 60, 1043, "Input"],
Cell[875008, 20679, 35708, 593, 375, 2516, 177, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[910777, 21279, 33, 0, 76, "Section"],
Cell[910813, 21281, 127, 4, 39, "Text"],

Cell[CellGroupData[{
Cell[910965, 21289, 78, 1, 51, "Input"],
Cell[911046, 21292, 723239, 13490, 135712, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[1634322, 34787, 77, 1, 43, "Input"],
Cell[1634402, 34790, 5389, 123, 1516, "Print"]
}, Closed]],
Cell[1639806, 34916, 96, 2, 64, "Input"],
Cell[1639905, 34920, 69, 1, 51, "Input"],
Cell[1639977, 34923, 47, 1, 51, "Input"],
Cell[1640027, 34926, 69, 1, 51, "Input"],
Cell[1640099, 34929, 45, 1, 51, "Input"],
Cell[1640147, 34932, 105, 2, 51, "Input"],
Cell[1640255, 34936, 120, 2, 51, "Input"],
Cell[1640378, 34940, 69, 1, 51, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

